@@ -84,7 +84,7 @@ static KCmdLineOptions options[] =
     { "getopenurl [startDir] [filter]", I18N_NOOP("File dialog to open an existing URL"), 0 },
     { "getsaveurl [startDir] [filter]", I18N_NOOP("File dialog to save a URL"), 0 },
     { "geticon [group] [context]", I18N_NOOP("Icon chooser dialog"), 0 },
-    { "progressbar <text> [totalsteps]", I18N_NOOP("Progress bar dialog, returns a DCOP reference for communication"), 0},
+    { "progressbar <text> [totalsteps]", I18N_NOOP("Progress bar dialog, returns a D-Bus reference for communication"), 0},
 
     // TODO gauge stuff, reading values from stdin
 
@@ -247,11 +247,11 @@ static int directCommand(KCmdLineArgs *args)
 
         if ( type == KMessageBox::WarningContinueCancel ) {
             /* TODO configurable button texts*/
-            ret = KMessageBox::messageBox( 0, type, text, title, KStdGuiItem::cont(),
-                KStdGuiItem::no(), dontagain );
+            ret = KMessageBox::messageBox( 0, type, text, title, KStandardGuiItem::cont(),
+                KStandardGuiItem::no(), dontagain );
         } else {
             ret = KMessageBox::messageBox( 0, type, text, title /*, TODO configurable button texts*/,
-                KStdGuiItem::yes(), KStdGuiItem::no(), dontagain );
+                KStandardGuiItem::yes(), KStandardGuiItem::no(), dontagain );
         }
         delete dontagaincfg;
         // ret is 1 for Ok, 2 for Cancel, 3 for Yes, 4 for No and 5 for Continue.
@@ -643,9 +643,9 @@ static int directCommand(KCmdLineArgs *args)
     // --progressbar text totalsteps
     if (args->isSet("progressbar"))
     {
-       cout << "org.kde.kdialog_" << getpid() << " /ProgressDialog" << endl;
+       cout << "org.kde.kdialog-" << getpid() << " /ProgressDialog" << endl;
        if (fork())
-           exit(0);
+           _exit(0);
        close(1);
 
        int totalsteps = 100;
