@@ -19,30 +19,33 @@
 #ifndef PROGRESSDIALOG_H
 #define PROGRESSDIALOG_H
 
-#include <kprogressbar.h>
 #include <kprogressdialog.h>
 class ProgressDialog : public KProgressDialog
 {
     Q_OBJECT
+    Q_PROPERTY(int value READ value WRITE setValue)
+    Q_PROPERTY(int maximum READ maximum WRITE setMaximum)
+    Q_PROPERTY(bool autoClose READ autoClose WRITE setAutoClose)
 
-    public:
-      ProgressDialog(QWidget* parent = 0, const QString& caption = QString(), const QString& text = QString(), int totalSteps = 100);
+ public:
+    ProgressDialog(QWidget* parent = 0, const QString& caption = QString(), const QString& text = QString(), int totalSteps = 100);
       
-      void setMaximum( int );
-      int maximum() const;
+    void setMaximum( int );
+    int maximum() const;
     
-      void setValue( int );
-      int value() const;
+    void setValue( int );
+    int value() const;
       
-      void setLabel(const QString&);
+    void setLabel(const QString&);
     
-      void showCancelButton(bool show);
-      bool wasCancelled() const;
+    void showCancelButton(bool show);
+    bool wasCancelled() const;
+    void ignoreCancel();
 
-      void setAutoClose( bool );
-      bool autoClose() const;
+    void setAutoClose( bool );
+    bool autoClose() const;
                   
-      void close();
+    void close();
 };
 
 #endif // PROGRESSDIALOG_H
