@@ -28,6 +28,7 @@
 #include <kservicetypetrader.h>
 #include <kparts/componentfactory.h>
 #include <kstandarddirs.h>
+#include <kiconloader.h>
 #include "kquery.h"
 #include "kftabdlg.h"
 #include <kservicetypetrader.h>
@@ -335,7 +336,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
           it != m_types.end(); ++it )
     {
       KMimeType::Ptr typ = *it;
-      typeBox->addItem(typ->pixmap( K3Icon::Small ), typ->comment());
+      typeBox->addItem(KIconLoader::global()->loadMimeTypeIcon( typ->iconName(), K3Icon::Small ), typ->comment());
     }
 
     if ( editRegExp ) {
@@ -415,7 +416,7 @@ KfindTabWidget::~KfindTabWidget()
 
 void KfindTabWidget::setURL( const KUrl & url )
 {
-  KConfig *conf = KGlobal::config();
+  KSharedConfig::Ptr conf = KGlobal::config();
   conf->setGroup("History");
   m_url = url;
   QStringList sl = conf->readPathListEntry("Directories");
@@ -425,15 +426,15 @@ void KfindTabWidget::setURL( const KUrl & url )
     dirBox->addItems(sl);
     // If the _searchPath already exists in the list we do not
     // want to add it again
-    int indx = sl.indexOf(m_url.url());
+    int indx = sl.indexOf(m_url.prettyUrl());
     if(indx == -1)
-      dirBox->addItem(m_url.url(), 0); // make it the first one
+      dirBox->addItem(m_url.prettyUrl(), 0); // make it the first one
     else
       dirBox->setCurrentIndex(indx);
   }
   else {
     QDir m_dir("/lib");
-    dirBox ->addItem( m_url.url() );
+    dirBox ->addItem( m_url.prettyUrl() );
     dirBox ->addItem( "file:" + QDir::homePath() );
     dirBox ->addItem( "file:/" );
     dirBox ->addItem( "file:/usr" );
@@ -488,7 +489,7 @@ void KfindTabWidget::saveHistory()
 void KfindTabWidget::loadHistory()
 {
   // Load pattern history
-  KConfig *conf = KGlobal::config();
+  KSharedConfig::Ptr conf = KGlobal::config();
   conf->setGroup("History");
   QStringList sl = conf->readEntry("Patterns", QStringList());
   if(!sl.isEmpty())
@@ -501,15 +502,15 @@ void KfindTabWidget::loadHistory()
     dirBox->addItems(sl);
     // If the _searchPath already exists in the list we do not
     // want to add it again
-    int indx = sl.indexOf(m_url.url());
+    int indx = sl.indexOf(m_url.prettyUrl());
     if(indx == -1)
-      dirBox->addItem(m_url.url(), 0); // make it the first one
+      dirBox->addItem(m_url.prettyUrl(), 0); // make it the first one
     else
       dirBox->setCurrentIndex(indx);
   }
   else {
     QDir m_dir("/lib");
-    dirBox ->addItem( m_url.url() );
+    dirBox ->addItem( m_url.prettyUrl() );
     dirBox ->addItem( "file:" + QDir::homePath() );
     dirBox ->addItem( "file:/" );
     dirBox ->addItem( "file:/usr" );
@@ -784,7 +785,7 @@ void KfindTabWidget::getDirectory()
 
 void KfindTabWidget::beginSearch()
 {
-///  dirlister->openURL(KUrl(dirBox->currentText().trimmed()));
+///  dirlister->openUrl(KUrl(dirBox->currentText().trimmed()));
 
   saveHistory();
   setEnabled( false );
@@ -882,7 +883,7 @@ static void save_pattern(QComboBox *obj,
     }
   }
 
-  KConfig *conf = KGlobal::config();
+  KSharedConfig::Ptr conf = KGlobal::config();
   conf->setGroup(group);
   conf->writePathEntry(entry, sl);
 }
