@@ -18,38 +18,23 @@
     02110-1301  USA.
 */
 
-/*! \class TEScreen
-
-    \brief The output image produced by the terminal emulation.
-
-    The terminal emulation ( TEmulation ) receives a serial stream of
-    input characters from the program currently running in the terminal,
-    and produces an image consisting of characters with associated attributes
-    (such as foreground and background colors).
-
-    In addition to the image which is visible on-screen, incoming lines are
-    added to an associated history scroll ( set using setScroll() ), so that
-    earlier output can be viewed.
-
-    getCookedImage() is used to retrieve the currently visible image
-    which is then used by the display widget to draw the output from the
-    terminal. 
-
-    \sa TEWidget \sa VT102Emulation \sa TEHistory
-*/
 
+// Standard
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <kdebug.h>
-
 #include <assert.h>
 #include <string.h>
 #include <ctype.h>
 
+// Qt
 #include <QTextStream>
 #include <QTime>
 
+// KDE
+#include <kdebug.h>
+
+// Konsole
 #include "konsole_wcwidth.h"
 #include "TEScreen.h"
 #include "TerminalCharacterDecoder.h"
@@ -62,14 +47,18 @@
 //
 //Originally the image was stored as one large contiguous block of 
 //memory, so a position within the image could be represented as an
-//offset from the beginning of the block.  Many internal parts
-//of this class still use this representation for parameters and so on,
+//offset from the beginning of the block.  For efficiency reasons this
+//is no longer the case.  
+//Many internal parts of this class still use this representation for parameters and so on,
 //notably moveImage() and clearImage().
 //This macro converts from an X,Y position into an image offset.
 #ifndef loc
 #define loc(X,Y) ((Y)*columns+(X))
 #endif
 
+
+ca TEScreen::defaultChar = ca(' ',cacol(CO_DFT,DEFAULT_FORE_COLOR),cacol(CO_DFT,DEFAULT_BACK_COLOR),DEFAULT_RENDITION);
+
 //#define REVERSE_WRAPPED_LINES  // for wrapped line debug
 
 /*! creates a `TEScreen' of `lines' lines and `columns' columns.
@@ -79,11 +68,12 @@ TEScreen::TEScreen(int l, int c)
   : lines(l),
     columns(c),
     screenLines(new ImageLine[lines+1] ),
+    _scrolledLines(0),
    // image(new ca[(lines+1)*columns]),
     histCursor(0),
     hist(new HistoryScrollNone()),
     cuX(0), cuY(0),
-    cu_fg(cacol()), cu_bg(cacol()), cu_re(0),
+    cu_re(0),
     tmargin(0), bmargin(0),
     tabstops(0),
     sel_begin(0), sel_TL(0), sel_BR(0),
@@ -91,7 +81,7 @@ TEScreen::TEScreen(int l, int c)
     columnmode(false),
     ef_fg(cacol()), ef_bg(cacol()), ef_re(0),
     sa_cuX(0), sa_cuY(0),
-    sa_cu_re(0), sa_cu_fg(cacol()), sa_cu_bg(cacol()),
+    sa_cu_re(0),
     lastPos(-1)
 {
   
@@ -209,6 +199,17 @@ void TEScreen::setMargins(int top, int bot)
   bmargin = bot;
   cuX = 0;
   cuY = getMode(MODE_Origin) ? top : 0;
+
+  resetScrolledLines();
+}
+
+int TEScreen::topMargin() const
+{
+    return tmargin;
+}
+int TEScreen::bottomMargin() const
+{
+    return bmargin;
 }
 
 /*!
@@ -284,11 +285,7 @@ void TEScreen::deleteChars(int n)
 {
   if (n == 0) n = 1; // Default
   if (n > columns) n = columns - 1;
-  int p = qMax(0,qMin(cuX+n,columns-1));
-
-  //##  moveImage(loc(cuX,cuY),loc(p,cuY),loc(columns-1,cuY));
-
-  screenLines[cuY].remove(cuX,p-cuX);
+  
   clearImage(loc(columns-n,cuY),loc(columns-1,cuY),' ');
 }
 
@@ -303,8 +300,6 @@ void TEScreen::insertChars(int n)
  // int p = qMax(0,qMin(columns-1-n,columns-1));
   int q = qMax(0,qMin(cuX+n,columns-1));
 
-  screenLines[cuY].insert(cuX,q-cuX,ca());
- //## moveImage(loc(q,cuY),loc(cuX,cuY),loc(p,cuY));
   clearImage(loc(cuX,cuY),loc(q-1,cuY),' ');
 }
 
@@ -536,6 +531,11 @@ void TEScreen::effectiveRendition()
     ef_fg.toggleIntensive();
 }
 
+/**ca* TEScreen::image()
+{
+
+}**/
+
 /*!
     returns the image.
 
@@ -555,8 +555,7 @@ ca* TEScreen::getCookedImage()
 
   int x,y;
   ca* merged = (ca*)malloc((lines*columns+1)*sizeof(ca));
-  ca dft(' ',cacol(CO_DFT,DEFAULT_FORE_COLOR),cacol(CO_DFT,DEFAULT_BACK_COLOR),DEFAULT_RENDITION);
-  merged[lines*columns] = dft;
+  merged[lines*columns] = defaultChar;
 
   for (y = 0; (y < lines) && (y < (hist->getLines()-histCursor)); y++)
   {
@@ -564,7 +563,7 @@ ca* TEScreen::getCookedImage()
     int yp  = y*columns;
 
     hist->getCells(y+histCursor,0,len,merged+yp);
-    for (x = len; x < columns; x++) merged[yp+x] = dft;
+    for (x = len; x < columns; x++) merged[yp+x] = defaultChar;
     if (sel_begin !=-1)
     for (x = 0; x < columns; x++)
       {
@@ -572,7 +571,7 @@ ca* TEScreen::getCookedImage()
         if (hist->isLINE_WRAPPED(y+histCursor))
           reverseRendition(&merged[p]);
 #endif
-        if (testIsSelected(x,y)) {
+        if (isSelected(x,y)) {
           int p=x + yp;
           reverseRendition(&merged[p]); // for selection
     }
@@ -587,13 +586,13 @@ ca* TEScreen::getCookedImage()
        for (x = 0; x < columns; x++)
        { int p = x + yp; int r = x + yr;
 
-         merged[p] = screenLines[r/columns].value(r%columns,dft);
+         merged[p] = screenLines[r/columns].value(r%columns,defaultChar);
 
 #ifdef REVERSE_WRAPPED_LINES
          if (lineProperties[y- hist->getLines() +histCursor] & LINE_WRAPPED)
            reverseRendition(&merged[p]);
 #endif
-         if (sel_begin != -1 && testIsSelected(x,y))
+         if (sel_begin != -1 && isSelected(x,y))
            reverseRendition(&merged[p]); // for selection
        }
 
@@ -800,7 +799,7 @@ void TEScreen::ShowCharacter(unsigned short c)
   }
 
   ca& currentChar = screenLines[cuY][cuX];
-  
+
   currentChar.c = c;
   currentChar.f = ef_fg;
   currentChar.b = ef_bg;
@@ -813,7 +812,10 @@ void TEScreen::ShowCharacter(unsigned short c)
   while(w)
   {
      i++;
-
+   
+     if ( screenLines[cuY].size() < cuX + i + 1 )
+         screenLines[cuY].resize(cuX+i+1);
+     
      ca& ch = screenLines[cuY][cuX + i];
      ch.c = 0;
      ch.f = ef_fg;
@@ -837,6 +839,16 @@ void TEScreen::compose(QString /*compose*/)
   image[lastPos].c = compose[0].unicode();*/
 }
 
+int TEScreen::scrolledLines() const
+{
+        return _scrolledLines;
+}
+
+void TEScreen::resetScrolledLines()
+{
+    _scrolledLines = 0;
+}
+
 // Region commands -------------------------------------------------------------
 
 void TEScreen::scrollUp(int n)
@@ -854,7 +866,9 @@ void TEScreen::scrollUp(int n)
 void TEScreen::scrollUp(int from, int n)
 {
   if (n <= 0 || from + n > bmargin) return;
-  
+
+  _scrolledLines -= n;
+
   //FIXME: make sure `tmargin', `bmargin', `from', `n' is in bounds.
   moveImage(loc(0,from),loc(0,from+n),loc(columns-1,bmargin));
   clearImage(loc(0,bmargin-n+1),loc(columns-1,bmargin),' ');
@@ -873,6 +887,9 @@ void TEScreen::scrollDown(int n)
 
 void TEScreen::scrollDown(int from, int n)
 {
+
+  _scrolledLines += n;
+
 //FIXME: make sure `tmargin', `bmargin', `from', `n' is in bounds.
   if (n <= 0) return;
   if (from > bmargin) return;
@@ -1015,17 +1032,15 @@ NOTE:  moveImage() can only move whole lines.
 
 void TEScreen::moveImage(int dest, int sourceBegin, int sourceEnd)
 {
-//FIXME: check positions
-  if (sourceEnd < sourceBegin) {
-    kDebug(1211) << "WARNING!!! call to TEScreen:moveImage with sourceEnd < sourceBegin!" << endl;
-    return;
-  }
+  Q_ASSERT( sourceBegin <= sourceEnd );
  
   int lines=(sourceEnd-sourceBegin)/columns;
 
   //move screen image and line properties:
-  //areas being copied may overlap, so it matters that we do the copy in the right
-  //order (forwards if destination-line < source-line or backwards otherwise)
+  //the source and destination areas of the image may overlap, 
+  //so it matters that we do the copy in the right order - 
+  //forwards if dest < sourceBegin or backwards otherwise.
+  //(search the web for 'memmove implementation' for details)
   if (dest < sourceBegin)
   {
     for (int i=0;i<=lines;i++)
@@ -1050,9 +1065,10 @@ void TEScreen::moveImage(int dest, int sourceBegin, int sourceEnd)
      if ((lastPos < 0) || (lastPos >= (lines*columns)))
         lastPos = -1;
   }
+     
+  // Adjust selection to follow scroll.
   if (sel_begin != -1)
   {
-     // Adjust selection to follow scroll.
      bool beginIsTL = (sel_begin == sel_TL);
      int diff = dest - sourceBegin; // Scroll by this amount
      int scr_TL=loc(0,hist->getLines());
@@ -1213,7 +1229,7 @@ void TEScreen::clearSelection()
   sel_begin = -1;
 }
 
-void TEScreen::setSelBeginXY(const int x, const int y, const bool mode)
+void TEScreen::setSelectionStart(const int x, const int y, const bool mode)
 {
 //  kDebug(1211) << "setSelBeginXY(" << x << "," << y << ")" << endl;
   sel_begin = loc(x,y+histCursor) ;
@@ -1226,7 +1242,7 @@ void TEScreen::setSelBeginXY(const int x, const int y, const bool mode)
   columnmode = mode;
 }
 
-void TEScreen::setSelExtentXY(const int x, const int y)
+void TEScreen::setSelectionEnd(const int x, const int y)
 {
 //  kDebug(1211) << "setSelExtentXY(" << x << "," << y << ")" << endl;
   if (sel_begin == -1) return;
@@ -1247,7 +1263,7 @@ void TEScreen::setSelExtentXY(const int x, const int y)
   }
 }
 
-bool TEScreen::testIsSelected(const int x,const int y)
+bool TEScreen::isSelected(const int x,const int y)
 {
   if (columnmode) {
     int sel_Left,sel_Right;
@@ -1275,11 +1291,19 @@ bool TEScreen::testIsSelected(const int x,const int y)
   return qc.isSpace();
 }*/
 
-QString TEScreen::getSelText(bool preserve_line_breaks)
+//FIXME:  preserve_line_breaks not handled yet.
+//        I considered removing this parameter altogether, requiring 
+//        writeToStream() to be used if text needs to be retrieved as 
+//        it appears on screen.
+//        -- needs more thought on the issue first though.
+QString TEScreen::selectedText(bool preserve_line_breaks)
 {
   QString result;
   QTextStream stream(&result, QIODevice::ReadWrite);
-  getSelText(preserve_line_breaks, &stream);
+  
+  PlainTextDecoder decoder;
+  writeSelectionToStream(&stream,&decoder);
+  
   return result;
 }
 
@@ -1317,7 +1341,7 @@ static QString makeString(int *m, int d, bool stripTrailingSpaces)
 }*/
 
 
-void TEScreen::selectedText(QTextStream* stream , TerminalCharacterDecoder* decoder)
+void TEScreen::writeSelectionToStream(QTextStream* stream , TerminalCharacterDecoder* decoder)
 {
 	int top = sel_TL / columns;	
 	int left = sel_TL % columns;
@@ -1374,9 +1398,8 @@ void TEScreen::copyLineToStream(int line , int start, int count,
             count = qMin(count,length);
 
 			//retrieve line from screen image
-			for (int i=0;i+start < count;i++)
+			for (int i=0;i < count;i++)
 			{
-				//	characterBuffer[i] = image[loc( start+i,line-hist->getLines() )];
 			    characterBuffer[i] = data[start+i];
             }
 		}
@@ -1392,14 +1415,6 @@ void TEScreen::copyLineToStream(int line , int start, int count,
 		decoder->decodeLine( (ca*) characterBuffer , count, 0 , stream);
 }
 
-void TEScreen::getSelText(bool preserve_line_breaks, QTextStream* stream)
-{
-	TerminalCharacterDecoder* decoder = new PlainTextDecoder();
-	selectedText( stream , decoder );
-	delete decoder;
-	return;	
-}
-
 #if 0
 void TEScreen::getSelText(bool preserve_line_breaks, QTextStream *stream)
 {
@@ -1636,22 +1651,23 @@ void TEScreen::getSelText(bool preserve_line_breaks, QTextStream *stream)
 }
 #endif
 
-void TEScreen::streamHistory(QTextStream* stream , TerminalCharacterDecoder* decoder) {
+void TEScreen::writeToStream(QTextStream* stream , TerminalCharacterDecoder* decoder) {
   sel_begin = 0;
   sel_BR = sel_begin;
   sel_TL = sel_begin;
-  setSelExtentXY(columns-1,lines-1+hist->getLines()-histCursor);
-  //getSelText(true, stream, decoder);
-  selectedText(stream,decoder);
+  setSelectionEnd(columns-1,lines-1+hist->getLines()-histCursor);
+  
+  writeSelectionToStream(stream,decoder);
+  
   clearSelection();
 }
 
-void TEScreen::streamHistory(QTextStream* stream, TerminalCharacterDecoder* decoder, int from, int to)
+void TEScreen::writeToStream(QTextStream* stream, TerminalCharacterDecoder* decoder, int from, int to)
 {
 	sel_begin = loc(0,from);
 	sel_TL = sel_begin;
 	sel_BR = loc(columns-1,to);
-	selectedText(stream,decoder);
+	writeSelectionToStream(stream,decoder);
 	clearSelection();
 }
 
@@ -1660,7 +1676,7 @@ QString TEScreen::getHistoryLine(int no)
   sel_begin = loc(0,no);
   sel_TL = sel_begin;
   sel_BR = loc(columns-1,no);
-  return getSelText(false);
+  return selectedText(false);
 }
 
 void TEScreen::addHistLine()
@@ -1734,6 +1750,8 @@ void TEScreen::addHistLine()
 
 void TEScreen::setHistCursor(int cursor)
 {
+  _scrolledLines += histCursor-cursor;
+
   histCursor = cursor; //FIXME:rangecheck
 }
 
