@@ -114,7 +114,7 @@
                   "abcdefgjijklmnopqrstuvwxyz" \
                   "0123456789./+@"
 
-extern bool argb_visual; // declared in main.cpp and konsole_part.cpp
+extern bool true_transparency; // declared in main.cpp and konsole_part.cpp
 
 // scroll increment used when dragging selection at top/bottom of window.
 
@@ -168,7 +168,7 @@ void TEWidget::setColorTable(const ColorEntry table[])
   const QPixmap* pm = 0; 
   if (!pm)
   {
-    if (!argb_visual || (qAlpha(blend_color) == 0xff))
+    if (!true_transparency || (qAlpha(blend_color) == 0xff))
     {
         QPalette p = palette();
         p.setColor( backgroundRole(), getDefaultBackColor() );
@@ -303,7 +303,7 @@ void TEWidget::fontChange(const QFont &)
 //printf("rawname: %s\n",font().rawName().toAscii().constData());
 
 /*
-#if defined(Q_CC_GNU)
+#ifdef __GNUC__
 #warning TODO: Review/fix vt100 extended font-mapping
 #endif
 */
@@ -422,10 +422,6 @@ TEWidget::TEWidget(QWidget *parent)
   // im
   setAttribute(Qt::WA_InputMethodEnabled, true);
 
-  if (!argb_visual)
-  {
-  }
-  
   //tell Qt to automatically fill the widget with the current background colour when
   //repainting.
   //the widget may then need to repaint over some of the area in a different colour
@@ -691,7 +687,7 @@ void TEWidget::drawAttrStr(QPainter &paint, const QRect& rect,
           attr->b == cacol(CO_DFT, colorsSwapped ? DEFAULT_FORE_COLOR : DEFAULT_BACK_COLOR) )
 
         // draw background colors with 75% opacity
-        if ( argb_visual && qAlpha(blend_color) < 0xff ) {
+        if ( true_transparency && qAlpha(blend_color) < 0xff ) {
           QRgb col = bColor.rgb();
 
           Q_UINT8 salpha = 192;
@@ -884,6 +880,54 @@ void TEWidget::setCursorPos(const int curx, const int cury)
     m_cursorCol = curx;
 }
 
+//scrolls the image by 'lines', down if lines > 0 or up otherwise.
+//
+//the terminal emulation keeps track of the scrolling of the character image as it receives input,
+//and when the view is updated, it calls scrollImage() with the final scroll amount.  this improves
+//performance because scrolling the display is much cheaper than re-rendering all the text for the part
+//of the image which has moved up or down.  instead only new lines have to be drawn
+//
+//note:  it is important that the area of the display which is scrolled aligns properly with
+//the character grid - which has a top left point at (0,1) , a cell width of font_w and a cell height
+//of font_h).    
+void TEWidget::scrollImage(int lines , const QRect& region)
+{
+    if ( lines == 0 || image == 0 || abs(lines) >= this->lines ) return;
+
+    kDebug(1211) << " scrolling " << lines << " lines, with region = " << region.top() << "," << region.bottom()
+            << endl;
+
+    QRect scrollRect;
+
+    //scroll internal image
+    if ( lines > 0 )
+    {   
+        //scrolling down
+        memmove( image , &image[lines*this->columns] , ( this->lines - lines ) * this->columns * sizeof(ca) );
+ 
+        //set region of display to scroll, making sure that
+        //the region aligns correctly to the character grid 
+        scrollRect = QRect( 0,1, this->columns * font_w , (this->lines - lines) * font_h );
+    }
+    else
+    {
+        //scrolling up
+        kDebug(1211) << "scrolling up " << abs(lines) << " lines." << endl;
+
+        memmove( &image[ abs(lines)*this->columns] , image , 
+                        (this->lines - abs(lines) ) * this->columns * sizeof(ca) );
+
+        //set region of the display to scroll, making sure that
+        //the region aligns correctly to the character grid
+        
+        QPoint topPoint( 0 , 1 + abs(lines)*font_h );
+
+        scrollRect = QRect( topPoint , QSize( this->columns*font_w , (this->lines - abs(lines)) * font_h ));
+    }
+
+    //scroll the display
+    scroll( 0 , font_h * (-lines) , scrollRect );
+}
 
 /*!
     The image can only be set completely.
@@ -914,6 +958,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
   char *dirtyMask = (char *) malloc(cols+2);
   QRegion dirtyRegion;
 
+
 //{ static int cnt = 0; printf("setImage %d\n",cnt++); }
   for (y = 0; y < lins; y++)
   {
@@ -1002,16 +1047,20 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
 		fixed_font = save_fixed_font;
         x += len - 1;
       }
+      
     }
 
 	//both the top and bottom halves of double height lines must always be redrawn
 	//although both top and bottom halves contain the same characters, only the top one is actually 
 	//drawn.
-	updateLine |= (lineProperties[y] & LINE_DOUBLEHEIGHT);
+    if (lineProperties.count() > y)
+        updateLine |= (lineProperties[y] & LINE_DOUBLEHEIGHT);
 	
     if (updateLine)
     {
-    	dirtyRegion |= QRect( bX+tLx , bY+tLy+font_h*y , font_w * cols , font_h ); 	
+        QRect dirtyRect = QRect( bX+tLx , bY+tLy+font_h*y , font_w * cols , font_h ); 	
+    
+        dirtyRegion |= dirtyRect;
     }
 
     dirtyMask--; // Set back
@@ -1346,7 +1395,12 @@ void TEWidget::updateImageSize()
   //      `emu' will call back via `setImage'.
 
   resizing = (oldlin!=lines) || (oldcol!=columns);
-  emit changedContentSizeSignal(contentHeight, contentWidth); // expose resizeEvent
+
+  if ( resizing )
+  {
+    emit changedContentSizeSignal(contentHeight, contentWidth); // expose resizeEvent
+  }
+  
   resizing = false;
 }
 
@@ -2216,9 +2270,9 @@ void TEWidget::Bell(bool visibleSession, QString message)
   if ( allowBell )
   {
     allowBell = false;
-    QTimer::singleShot(1000,this,SLOT(enableBell()));
+    QTimer::singleShot(500,this,SLOT(enableBell()));
  
-    kDebug() << __FUNCTION__ << endl;
+    kDebug(1211) << __FUNCTION__ << endl;
 
     if (m_bellMode==BELLSYSTEM) {
                 KNotification::beep();
@@ -2413,7 +2467,7 @@ void TEWidget::dropEvent(QDropEvent* event)
         dropText += ' ';
         m_cdAction->setEnabled( false );
       }
-      KUrl url = KIO::NetAccess::mostLocalURL( *it, 0 );
+      KUrl url = KIO::NetAccess::mostLocalUrl( *it, 0 );
       QString tmp;
       if (url.isLocalFile()) {
         tmp = url.path(); // local URL : remove protocol. This helps "ln" & "cd" and doesn't harm the others
