@@ -38,25 +38,25 @@
 #undef HAVE_XKB
 #endif
 
+// Standard 
+#include <stdio.h>
+#include <unistd.h>
+#include <assert.h>
+
+// Qt
+#include <QKeyEvent>
+#include <QByteArray>
+
+// KDE
+#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
+// Konsole
 #include "TEmuVt102.h"
 #include "TEWidget.h"
 #include "TEScreen.h"
 
-#include <stdio.h>
-#include <unistd.h>
-
-#include <assert.h>
-
-#include "TEmuVt102.moc"
-
-#include <kdebug.h>
-//Added by qt3to4:
-#include <QKeyEvent>
-#include <QByteArray>
-
 /* VT102 Terminal Emulation
 
    This class puts together the screens, the pty and the widget to a
@@ -87,44 +87,48 @@
 /*!
 */
 
-TEmuVt102::TEmuVt102(TEWidget* gui) : TEmulation(gui)
+TEmuVt102::TEmuVt102() : TEmulation()
 {
   titleUpdateTimer.setSingleShot(true);
 
-  //kDebug(1211)<<"TEmuVt102 ctor() connecting"<<endl;
-  QObject::connect(gui,SIGNAL(mouseSignal(int,int,int,int)),
-                   this,SLOT(onMouse(int,int,int,int)));
-  QObject::connect(gui, SIGNAL(sendStringToEmu(const char*)),
-		   this, SLOT(sendString(const char*)));
   QObject::connect(&titleUpdateTimer , SIGNAL(timeout()) , this , SLOT(updateTitle()));
 
-  //kDebug(1211)<<"TEmuVt102 ctor() initToken..."<<endl;
   initTokenizer();
-  //kDebug(1211)<<"TEmuVt102 ctor() reset()"<<endl;
   reset();
-  //kDebug(1211)<<"TEmuVt102 ctor() ctor done"<<endl;
 }
 
-/*!
-*/
-
-void TEmuVt102::changeGUI(TEWidget* newgui)
+void TEmuVt102::setReceiveViewInput(TEWidget* view , bool enable)
 {
-  if (static_cast<TEWidget *>( gui )==newgui) return;
-
-  if ( gui ) {
-    QObject::disconnect(gui,SIGNAL(mouseSignal(int,int,int,int)),
-                        this,SLOT(onMouse(int,int,int,int)));
-    QObject::disconnect(gui, SIGNAL(sendStringToEmu(const char*)),
-                        this, SLOT(sendString(const char*)));
-  }
-  TEmulation::changeGUI(newgui);
-  QObject::connect(gui,SIGNAL(mouseSignal(int,int,int,int)),
-                   this,SLOT(onMouse(int,int,int,int)));
-  QObject::connect(gui, SIGNAL(sendStringToEmu(const char*)),
-		   this, SLOT(sendString(const char*)));
+   if (enable)
+   {
+        QObject::connect(view,SIGNAL(mouseSignal(int,int,int,int)),
+                  this,SLOT(onMouse(int,int,int,int)));
+        QObject::connect(view, SIGNAL(sendStringToEmu(const char*)),
+ 		   this, SLOT(sendString(const char*)));
+   }
+   else
+   {
+        QObject::disconnect(view,SIGNAL(mouseSignal(int,int,int,int)),
+                  this,SLOT(onMouse(int,int,int,int)));
+        QObject::disconnect(view, SIGNAL(sendStringToEmu(const char*)),
+ 		   this, SLOT(sendString(const char*)));
+   }
 }
 
+void TEmuVt102::addView(TEWidget* view)
+{
+    TEmulation::addView(view);
+    setReceiveViewInput(view,true);
+}
+
+void TEmuVt102::removeView(TEWidget* view)
+{
+    TEmulation::removeView(view);
+    setReceiveViewInput(view,false);
+}
+
+
+
 /*!
 */
 
@@ -981,6 +985,26 @@ void TEmuVt102::onScrollLock()
   scrollLock(switchlock);
 }
 
+void TEmuVt102::scrollView( int lines )
+{
+    QListIterator<QPointer<TEWidget> > viewIter(_views);
+
+    while (viewIter.hasNext())
+        viewIter.next()->doScroll( lines );
+}
+
+void TEmuVt102::scrollViewPages( int pages )
+{
+    QListIterator< QPointer<TEWidget> > viewIter(_views);
+
+    while (viewIter.hasNext())
+    {
+        TEWidget* display = viewIter.next();
+        display->doScroll( pages * (display->Lines() / 2) );
+    }
+}
+
+
 #define encodeMode(M,B) BITS(B,getMode(M))
 #define encodeStat(M,B) BITS(B,((ev->modifiers() & (M)) == (M)))
 
@@ -997,8 +1021,7 @@ void TEmuVt102::onKeyPress( QKeyEvent* ev )
 
   // lookup in keyboard translation table ...
   int cmd = CMD_none; 
-  const char* txt; 
-  int len;
+  QByteArray txt; 
   bool metaspecified;
   if (keytrans->findEntry(ev->key(), encodeMode(MODE_NewLine  , BITS_NewLine   ) + // OLD,
                                      encodeMode(MODE_Ansi     , BITS_Ansi      ) + // OBSOLETE,
@@ -1007,16 +1030,16 @@ void TEmuVt102::onKeyPress( QKeyEvent* ev )
                                      encodeStat(Qt::ControlModifier , BITS_Control   ) +
                                      encodeStat(Qt::ShiftModifier   , BITS_Shift     ) +
                                      encodeStat(Qt::AltModifier     , BITS_Alt       ),
-                          &cmd, &txt, &len, &metaspecified ))
+                          &cmd, txt, &metaspecified ))
 //printf("cmd: %d, %s, %d\n",cmd,txt,len);
   if (connected)
   {
   switch(cmd) // ... and execute if found.
   {
-    case CMD_scrollPageUp   : gui->doScroll(-gui->Lines()/2); return;
-    case CMD_scrollPageDown : gui->doScroll(+gui->Lines()/2); return;
-    case CMD_scrollLineUp   : gui->doScroll(-1             ); return;
-    case CMD_scrollLineDown : gui->doScroll(+1             ); return;
+    case CMD_scrollPageUp   : scrollViewPages(-1); return;
+    case CMD_scrollPageDown : scrollViewPages(+1); return;
+    case CMD_scrollLineUp   : scrollView(-1             ); return;
+    case CMD_scrollLineDown : scrollView(+1             ); return;
     case CMD_scrollLock     : onScrollLock(                ); return;
   }
   }
@@ -1024,10 +1047,10 @@ void TEmuVt102::onKeyPress( QKeyEvent* ev )
   {
     switch(ev->key())
     {
-    case Qt::Key_Down : gui->doScroll(+1); return;
-    case Qt::Key_Up : gui->doScroll(-1); return;
-    case Qt::Key_PageUp : gui->doScroll(-gui->Lines()/2); return;
-    case Qt::Key_PageDown : gui->doScroll(gui->Lines()/2); return;
+    case Qt::Key_Down : scrollView(+1); return;
+    case Qt::Key_Up : scrollView(-1); return;
+    case Qt::Key_PageUp : scrollViewPages(-1); return;
+    case Qt::Key_PageDown : scrollViewPages(+1); return;
     }
   }
   
@@ -1039,7 +1062,7 @@ void TEmuVt102::onKeyPress( QKeyEvent* ev )
 
   if (cmd==CMD_send) {
     if ((ev->modifiers() & Qt::AltModifier) && !metaspecified ) sendString("\033");
-    emit sndBlock(txt,len);
+    emit sndBlock(txt.constData(), txt.length());
     return;
   }
 
@@ -1208,6 +1231,13 @@ void TEmuVt102::resetModes()
   holdScreen = false;
 }
 
+void TEmuVt102::setViewMouseMarks(bool marks)
+{
+    QListIterator< QPointer<TEWidget> > viewIter(_views);
+    while (viewIter.hasNext())
+            viewIter.next()->setMouseMarks(marks);
+}
+
 void TEmuVt102::setMode(int m)
 {
   currParm.mode[m] = true;
@@ -1217,7 +1247,7 @@ void TEmuVt102::setMode(int m)
     case MODE_Mouse1001:
     case MODE_Mouse1002:
     case MODE_Mouse1003:
- 	if (connected) gui->setMouseMarks(false);
+ 	if (connected) setViewMouseMarks(false);
     break;
 
     case MODE_AppScreen : screen[1]->clearSelection();
@@ -1240,7 +1270,7 @@ void TEmuVt102::resetMode(int m)
     case MODE_Mouse1001 :
     case MODE_Mouse1002 :
     case MODE_Mouse1003 :
-	    if (connected) gui->setMouseMarks(true);
+	    if (connected) setViewMouseMarks(true);
     break;
 
     case MODE_AppScreen : screen[0]->clearSelection();
@@ -1272,9 +1302,12 @@ bool TEmuVt102::getMode(int m)
 void TEmuVt102::setConnect(bool c)
 {
   TEmulation::setConnect(c);
-  if (gui)
+
+  QListIterator< QPointer<TEWidget> > viewIter(_views);
+  
+  while (viewIter.hasNext())
   {
-    QObject::disconnect(gui, SIGNAL(sendStringToEmu(const char*)),
+    QObject::disconnect(viewIter.next(), SIGNAL(sendStringToEmu(const char*)),
                         this, SLOT(sendString(const char*)));
   }
   if (c)
@@ -1293,20 +1326,25 @@ void TEmuVt102::setConnect(bool c)
     else
       scrolllock_set_off();
 #endif
-    QObject::connect(gui, SIGNAL(sendStringToEmu(const char*)),
-                     this, SLOT(sendString(const char*)));
+
+    QListIterator< QPointer<TEWidget> > viewIter2(_views);
+
+    while (viewIter2.hasNext())
+    {
+        QObject::connect(viewIter2.next(), SIGNAL(sendStringToEmu(const char*)),
+                         this, SLOT(sendString(const char*)));
+    }
   }
 }
 
 char TEmuVt102::getErase()
 {
   int cmd = CMD_none; 
-  const char* txt; 
-  int len;
+  QByteArray txt; 
   bool metaspecified;
   
-  if (keytrans->findEntry(Qt::Key_Backspace, 0, &cmd, &txt, &len,
-      &metaspecified) && (cmd==CMD_send) && (len == 1))
+  if (keytrans->findEntry(Qt::Key_Backspace, 0, &cmd, txt,
+      &metaspecified) && (cmd==CMD_send) && (txt.length() == 1))
     return txt[0];
     
   return '\b';
@@ -1512,3 +1550,5 @@ static void scrolllock_set_off()
     xkb_set_off();
 }
 #endif // defined(HAVE_XKB)
+
+#include "TEmuVt102.moc"
