@@ -68,26 +68,29 @@
    - evtl. the bulk operations could be made more transparent.
 */
 
-#include "TEmulation.h"
-#include "TEWidget.h"
-#include "TEScreen.h"
-#include "TerminalCharacterDecoder.h"
-
-#include <kdebug.h>
+// System
+#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <QRegExp>
-#include <QClipboard>
+
+// Qt
 #include <QApplication>
 #include <QClipboard>
-//Added by qt3to4:
-#include <QTextStream>
+#include <QClipboard>
 #include <QKeyEvent>
+#include <QRegExp>
+#include <QTextStream>
 
-#include <assert.h>
+// KDE
+#include <kdebug.h>
 
-#include "TEmulation.moc"
+// Konsole
+#include "TEScreen.h"
+#include "TEWidget.h"
+#include "TerminalCharacterDecoder.h"
+
+#include "TEmulation.h"
 
 /* ------------------------------------------------------------------------- */
 /*                                                                           */
@@ -100,8 +103,7 @@
 /*!
 */
 
-TEmulation::TEmulation(TEWidget* w)
-: gui(w),
+TEmulation::TEmulation() :
   scr(0),
   connected(false),
   listenToKeyPress(false),
@@ -111,75 +113,46 @@ TEmulation::TEmulation(TEWidget* w)
   m_findPos(-1)
 {
 
-  screen[0] = new TEScreen(gui->Lines(),gui->Columns());
-  screen[1] = new TEScreen(gui->Lines(),gui->Columns());
+  //initialize screens with a default size
+  screen[0] = new TEScreen(40,80);
+  screen[1] = new TEScreen(40,80);
   scr = screen[0];
 
   QObject::connect(&bulk_timer1, SIGNAL(timeout()), this, SLOT(showBulk()) );
   QObject::connect(&bulk_timer2, SIGNAL(timeout()), this, SLOT(showBulk()) );
-  connectGUI();
+   
   setKeymap(0); // Default keymap
 }
 
 /*!
 */
 
-void TEmulation::connectGUI()
+void TEmulation::connectView(TEWidget* view)
 {
-  QObject::connect(gui,SIGNAL(changedHistoryCursor(int)),
+
+  QObject::connect(view,SIGNAL(changedHistoryCursor(int)),
                    this,SLOT(onHistoryCursorChange(int)));
-  QObject::connect(gui,SIGNAL(keyPressedSignal(QKeyEvent*)),
+  QObject::connect(view,SIGNAL(keyPressedSignal(QKeyEvent*)),
                    this,SLOT(onKeyPress(QKeyEvent*)));
-  QObject::connect(gui,SIGNAL(beginSelectionSignal(const int,const int,const bool)),
+  QObject::connect(view,SIGNAL(beginSelectionSignal(const int,const int,const bool)),
 		   this,SLOT(onSelectionBegin(const int,const int,const bool)) );
-  QObject::connect(gui,SIGNAL(extendSelectionSignal(const int,const int)),
+  QObject::connect(view,SIGNAL(extendSelectionSignal(const int,const int)),
 		   this,SLOT(onSelectionExtend(const int,const int)) );
-  QObject::connect(gui,SIGNAL(endSelectionSignal(const bool)),
+  QObject::connect(view,SIGNAL(endSelectionSignal(const bool)),
 		   this,SLOT(setSelection(const bool)) );
-  QObject::connect(gui,SIGNAL(copySelectionSignal()),
+  QObject::connect(view,SIGNAL(copySelectionSignal()),
 		   this,SLOT(copySelection()) );
-  QObject::connect(gui,SIGNAL(clearSelectionSignal()),
+  QObject::connect(view,SIGNAL(clearSelectionSignal()),
 		   this,SLOT(clearSelection()) );
-  QObject::connect(gui,SIGNAL(isBusySelecting(bool)),
+  QObject::connect(view,SIGNAL(isBusySelecting(bool)),
 		   this,SLOT(isBusySelecting(bool)) );
-  QObject::connect(gui,SIGNAL(testIsSelected(const int, const int, bool &)),
+  QObject::connect(view,SIGNAL(testIsSelected(const int, const int, bool &)),
 		   this,SLOT(testIsSelected(const int, const int, bool &)) );
 }
 
 /*!
 */
 
-void TEmulation::changeGUI(TEWidget* newgui)
-{
-  if (static_cast<TEWidget *>( gui )==newgui) return;
-
-  if ( gui ) {
-    QObject::disconnect(gui,SIGNAL(changedHistoryCursor(int)),
-                     this,SLOT(onHistoryCursorChange(int)));
-    QObject::disconnect(gui,SIGNAL(keyPressedSignal(QKeyEvent*)),
-                     this,SLOT(onKeyPress(QKeyEvent*)));
-    QObject::disconnect(gui,SIGNAL(beginSelectionSignal(const int,const int,const bool)),
-                     this,SLOT(onSelectionBegin(const int,const int,const bool)) );
-    QObject::disconnect(gui,SIGNAL(extendSelectionSignal(const int,const int)),
-                     this,SLOT(onSelectionExtend(const int,const int)) );
-    QObject::disconnect(gui,SIGNAL(endSelectionSignal(const bool)),
-                     this,SLOT(setSelection(const bool)) );
-    QObject::disconnect(gui,SIGNAL(copySelectionSignal()),
-                     this,SLOT(copySelection()) );
-    QObject::disconnect(gui,SIGNAL(clearSelectionSignal()),
-                     this,SLOT(clearSelection()) );
-    QObject::disconnect(gui,SIGNAL(isBusySelecting(bool)),
-                     this,SLOT(isBusySelecting(bool)) );
-    QObject::disconnect(gui,SIGNAL(testIsSelected(const int, const int, bool &)),
-                     this,SLOT(testIsSelected(const int, const int, bool &)) );
-  }
-  gui=newgui;
-  connectGUI();
-}
-
-/*!
-*/
-
 TEmulation::~TEmulation()
 {
   delete screen[0];
@@ -297,11 +270,6 @@ void TEmulation::onKeyPress( QKeyEvent* ev )
     //emit sndBlock(ev->text().toAscii(),ev->text().length());
     emit sndBlock(ev->text().toUtf8(),ev->text().length());
   }
-  else if (ev->text().toAscii().constData()>0)
-  { unsigned char c[1];
-    c[0] = ev->text().toAscii()[0];
-    emit sndBlock((char*)c,1);
-  }
 }
 
 // Unblocking, Byte to Unicode translation --------------------------------- --
@@ -392,20 +360,26 @@ void TEmulation::onRcvBlock(const char* text, int length)
 
 void TEmulation::onSelectionBegin(const int x, const int y, const bool columnmode) {
   if (!connected) return;
-  scr->setSelBeginXY(x,y,columnmode);
+  scr->setSelectionStart(x,y,columnmode);
   showBulk();
 }
 
 void TEmulation::onSelectionExtend(const int x, const int y) {
   if (!connected) return;
-  scr->setSelExtentXY(x,y);
+  scr->setSelectionEnd(x,y);
   showBulk();
 }
 
 void TEmulation::setSelection(const bool preserve_line_breaks) {
   if (!connected) return;
-  QString t = scr->getSelText(preserve_line_breaks);
-  if (!t.isNull()) gui->setSelection(t);
+  QString t = scr->selectedText(preserve_line_breaks);
+  if (!t.isNull()) 
+  {
+    QListIterator< QPointer<TEWidget> > viewIter(_views);
+
+    while (viewIter.hasNext())    
+        viewIter.next()->setSelection(t);
+  }
 }
 
 void TEmulation::isBusySelecting(bool busy)
@@ -417,7 +391,7 @@ void TEmulation::isBusySelecting(bool busy)
 void TEmulation::testIsSelected(const int x, const int y, bool &selected)
 {
   if (!connected) return;
-  selected=scr->testIsSelected(x,y);
+  selected=scr->isSelected(x,y);
 }
 
 void TEmulation::clearSelection() {
@@ -428,12 +402,12 @@ void TEmulation::clearSelection() {
 
 void TEmulation::copySelection() {
   if (!connected) return;
-  QString t = scr->getSelText(true);
+  QString t = scr->selectedText(true);
   QApplication::clipboard()->setText(t);
 }
 
-void TEmulation::streamHistory(QTextStream* stream , TerminalCharacterDecoder* decoder) {
-  scr->streamHistory(stream,decoder);
+void TEmulation::writeToStream(QTextStream* stream , TerminalCharacterDecoder* decoder) {
+  scr->writeToStream(stream,decoder);
 }
 
 void TEmulation::findTextBegin()
@@ -485,7 +459,7 @@ bool TEmulation::findTextNext( const QString &str, bool forward, bool isCaseSens
 	else
 		endLine = qMax(line+delta,lastLine);
 		  
-	scr->streamHistory(&searchStream,&decoder, qMin(endLine,line) , qMax(endLine,line) );
+	scr->writeToStream(&searchStream,&decoder, qMin(endLine,line) , qMax(endLine,line) );
 
 	pos = -1;
 		
@@ -540,12 +514,58 @@ bool TEmulation::findTextNext( const QString &str, bool forward, bool isCaseSens
 /*!
 */
 
+void TEmulation::addView(TEWidget* widget)
+{
+    Q_ASSERT( !_views.contains(widget) );
+    _views << widget;
+
+    connectView(widget);
+}
+
+void TEmulation::removeView(TEWidget* widget)
+{
+    _views.removeAll(widget);
+
+    disconnect(widget);
+}
+
 void TEmulation::showBulk()
 {
   bulk_timer1.stop();
   bulk_timer2.stop();
 
   if (connected)
+  {
+    ca* image = scr->getCookedImage();
+    QVector<LineProperty> lineProperties = scr->getCookedLineProperties();
+
+    QListIterator< QPointer<TEWidget> > viewIter(_views);
+
+    while (viewIter.hasNext())
+    {
+        QPointer<TEWidget> view = viewIter.next();
+
+        QRect scrollRegion;
+        scrollRegion.setTop( scr->topMargin() );
+        scrollRegion.setBottom( scr->bottomMargin() );
+        scrollRegion.setLeft( 0 );
+        scrollRegion.setRight( scr->getColumns() );
+
+        view->scrollImage( - scr->scrolledLines() , scrollRegion );
+    
+        view->setLineProperties( lineProperties );
+	    view->setImage(image,
+                  scr->getLines(),
+                  scr->getColumns());     // actual refresh
+        view->setCursorPos(scr->getCursorX(), scr->getCursorY());	// set XIM position
+	    view->setScroll(scr->getHistCursor(),scr->getHistLines()); 
+    }
+  
+    scr->resetScrolledLines();  
+    free(image);
+  }
+
+  /*if (connected)
   {
     ca* image = scr->getCookedImage();    // get the image
    
@@ -559,7 +579,7 @@ void TEmulation::showBulk()
     free(image);
     
 	gui->setScroll(scr->getHistCursor(),scr->getHistLines());
-  }
+  }*/
 }
 
 void TEmulation::bulkStart()
@@ -603,6 +623,9 @@ void TEmulation::setListenToKeyPress(bool l)
 
 void TEmulation::onImageSizeChange(int lines, int columns)
 {
+  Q_ASSERT( lines > 0 );
+  Q_ASSERT( columns > 0 );
+
    //kDebug(1211)<<"TEmulation::onImageSizeChange()"<<endl;
   screen[0]->resizeImage(lines,columns);
   screen[1]->resizeImage(lines,columns);
@@ -631,3 +654,5 @@ void TEmulation::setColumns(int columns)
   //       Can we put this straight or explain it at least?
   emit changeColumns(columns);
 }
+
+#include "TEmulation.moc"
