@@ -21,6 +21,11 @@
 
 #include "konsole_part.h"
 
+#include "keytrans.h"
+#include "schema.h"
+#include "TESession.h"
+#include "TEWidget.h"
+
 #include <assert.h>
 
 #include <QFile>
@@ -42,7 +47,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <krun.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <QLabel>
 
 #include <QCheckBox>
@@ -55,9 +60,10 @@
 #include <kselectaction.h>
 #include <ktoggleaction.h>
 #include <kauthorized.h>
+#include <kcomponentdata.h>
 
-// We can't use the ARGB32 visual when embedded in another application
-bool argb_visual = false;
+// True transparency is not available in the embedded Konsole
+bool true_transparency = false;
 
 extern "C"
 {
@@ -75,7 +81,7 @@ extern "C"
 /**
  * We need one static instance of the factory for our C 'main' function
  */
-KInstance *konsoleFactory::s_instance = 0L;
+KComponentData *konsoleFactory::s_instance = 0L;
 KAboutData *konsoleFactory::s_aboutData = 0;
 
 konsoleFactory::konsoleFactory()
@@ -103,14 +109,14 @@ KParts::Part *konsoleFactory::createPartObject(QWidget *parentWidget,
   return obj;
 }
 
-KInstance *konsoleFactory::instance()
+const KComponentData &konsoleFactory::componentData()
 {
   if ( !s_instance )
     {
       s_aboutData = new KAboutData("konsole", I18N_NOOP("Konsole"), "1.5");
-      s_instance = new KInstance( s_aboutData );
+      s_instance = new KComponentData( s_aboutData );
     }
-  return s_instance;
+  return *s_instance;
 }
 
 #define DEFAULT_HISTORY_SIZE 1000
@@ -136,7 +142,7 @@ konsolePart::konsolePart(QWidget *_parentWidget, QObject *parent, const char *cl
 ,m_runningShell( false )
 {
   parentWidget=_parentWidget;
-  setInstance(konsoleFactory::instance());
+  setComponentData(konsoleFactory::componentData());
 
   m_extension = new konsoleBrowserExtension(this);
 
@@ -167,7 +173,7 @@ konsolePart::konsolePart(QWidget *_parentWidget, QObject *parent, const char *cl
   // Check to see which config file we use: konsolepartrc or konsolerc
   KConfig* config = new KConfig("konsolepartrc", true);
   config->setDesktopGroup();
-  b_useKonsoleSettings = config->readEntry("use_konsole_settings", QVariant(false)).toBool();
+  b_useKonsoleSettings = config->readEntry("use_konsole_settings", false);
   delete config;
 
   readProperties();
@@ -266,9 +272,9 @@ konsolePart::~konsolePart()
   //te is deleted by the framework
 }
 
-bool konsolePart::openURL( const KUrl & url )
+bool konsolePart::openUrl( const KUrl & url )
 {
-  //kDebug(1211) << "konsolePart::openURL " << url.prettyUrl() << endl;
+  //kDebug(1211) << "konsolePart::openUrl " << url.prettyUrl() << endl;
 
   if (currentURL==url) {
     emit completed();
@@ -331,7 +337,8 @@ void konsolePart::makeGUI()
      m_options = new KMenu((KMainWindow*)parentWidget);
 
      // Scrollbar
-     selectScrollbar = new KSelectAction(i18n("Sc&rollbar"), settingsActions, QString());
+     selectScrollbar = new KSelectAction(i18n("Sc&rollbar"), this);
+     settingsActions->addAction(selectScrollbar->objectName(), selectScrollbar);
      connect( selectScrollbar, SIGNAL( triggered( bool ) ), SLOT(slotSelectScrollbar()) );
 
      QStringList scrollitems;
@@ -341,9 +348,9 @@ void konsolePart::makeGUI()
 
      // Select Bell
      m_options->addSeparator();
-     selectBell = new KSelectAction(i18n("&Bell"), SmallIconSet( "bell"), 0 , this,
-                                 SLOT(slotSelectBell()), settingsActions, "bell");
-
+     selectBell = new KSelectAction(KIcon( "bell" ), i18n("&Bell"), this);
+     settingsActions->addAction("bell", selectBell);
+     connect(selectBell, SIGNAL(triggered(bool)), this, SLOT(slotSelectBell()));
      QStringList bellitems;
      bellitems << i18n("System &Bell")
             << i18n("System &Notification")
@@ -352,32 +359,41 @@ void konsolePart::makeGUI()
      selectBell->setItems(bellitems);
      m_options->addAction(selectBell);
 
-      m_fontsizes = new KActionMenu( KIcon( "text" ), i18n( "Font" ), settingsActions, 0L );
-      KAction * action = new KAction( KIcon( "viewmag+" ), i18n( "&Enlarge Font" ), settingsActions, "enlarge_font" );
-      connect(action, SIGNAL(triggered(bool)), SLOT(biggerFont()));
-      m_fontsizes->addAction( action );
-      action = new KAction( KIcon( "viewmag-" ), i18n( "&Shrink Font" ), settingsActions, "shrink_font" );
-      connect(action, SIGNAL(triggered(bool)), SLOT(smallerFont()));
-      m_fontsizes->addAction( action );
-      action = new KAction( KIcon( "font" ), i18n( "Se&lect..." ), settingsActions, "select_font" );
-      connect(action, SIGNAL(triggered(bool)), SLOT(slotSelectFont()));
-      m_fontsizes->addAction( action );
-      m_options->addAction(m_fontsizes);
+     m_fontsizes = new KActionMenu( KIcon( "text" ), i18n( "Font" ), this );
+     settingsActions->addAction( m_fontsizes->objectName(), m_fontsizes );
+     QAction *action = settingsActions->addAction( "enlarge_font" );
+     action->setIcon( KIcon( "viewmag+" ) );
+     action->setText( i18n( "&Enlarge Font" ) );
+     connect(action, SIGNAL(triggered(bool)), SLOT(biggerFont()));
+     m_fontsizes->addAction( action );
+     action = settingsActions->addAction( "shrink_font" );
+     action->setIcon( KIcon( "viewmag-" ) );
+     action->setText( i18n( "&Shrink Font" ) );
+     connect(action, SIGNAL(triggered(bool)), SLOT(smallerFont()));
+     m_fontsizes->addAction( action );
+     action = settingsActions->addAction( "select_font" );
+     action->setIcon( KIcon( "font" ) );
+     action->setText( i18n( "Se&lect..." ) );
+     connect(action, SIGNAL(triggered(bool)), SLOT(slotSelectFont()));
+     m_fontsizes->addAction( action );
+     m_options->addAction(m_fontsizes);
 
-      // encoding menu, start with default checked !
-      selectSetEncoding = new KSelectAction( i18n( "&Encoding" ), SmallIconSet("charset" ), 0, this, SLOT(slotSetEncoding()), settingsActions, "set_encoding" );
-      QStringList list = KGlobal::charsets()->descriptiveEncodingNames();
-      list.prepend( i18n( "Default" ) );
-      selectSetEncoding->setItems(list);
-      selectSetEncoding->setCurrentItem (0);
-      m_options->addAction( selectSetEncoding );
+     // encoding menu, start with default checked !
+     selectSetEncoding = new KSelectAction( KIcon("charset" ), i18n( "&Encoding" ), this );
+     settingsActions->addAction( "set_encoding", selectSetEncoding );
+     connect(selectSetEncoding, SIGNAL(triggered(bool)), this, SLOT(slotSetEncoding()));
+     QStringList list = KGlobal::charsets()->descriptiveEncodingNames();
+     list.prepend( i18n( "Default" ) );
+     selectSetEncoding->setItems(list);
+     selectSetEncoding->setCurrentItem (0);
+     m_options->addAction( selectSetEncoding );
 
      // Keyboard Options Menu ---------------------------------------------------
      if (KAuthorized::authorizeKAction("keyboard"))
      {
         m_keytab = new KMenu((KMainWindow*)parentWidget);
         connect(m_keytab, SIGNAL(activated(int)), SLOT(keytab_menu_activated(int)));
-        m_options->insertItem( SmallIconSet( "key_bindings" ), i18n( "&Keyboard" ), m_keytab );
+        m_options->insertItem( KIcon( "key_bindings" ), i18n( "&Keyboard" ), m_keytab );
      }
 
      // Schema Options Menu -----------------------------------------------------
@@ -386,19 +402,21 @@ void konsolePart::makeGUI()
         m_schema = new KMenu((KMainWindow*)parentWidget);
         connect(m_schema, SIGNAL(activated(int)), SLOT(schema_menu_activated(int)));
         connect(m_schema, SIGNAL(aboutToShow()), SLOT(schema_menu_check()));
-        m_options->insertItem( SmallIconSet( "colorize" ), i18n( "Sch&ema" ), m_schema);
+        m_options->insertItem( KIcon( "colorize" ), i18n( "Sch&ema" ), m_schema);
      }
 
 
-     KAction *historyType = new KAction(KIcon("history"), i18n("&History..."), settingsActions, "history");
+     QAction *historyType = settingsActions->addAction("history");
+     historyType->setIcon(KIcon("history"));
+     historyType->setText(i18n("&History..."));
      connect(historyType, SIGNAL(triggered(bool)), SLOT(slotHistoryType()));
      m_options->addAction( historyType );
      m_options->addSeparator();
 
      // Select line spacing
-     selectLineSpacing = new KSelectAction(i18n("Li&ne Spacing"),
-        SmallIconSet("leftjust"), 0, this,
-        SLOT(slotSelectLineSpacing()), settingsActions );
+     selectLineSpacing = new KSelectAction(KIcon("leftjust"), i18n("Li&ne Spacing"), this);
+     settingsActions->addAction("linespacing", selectLineSpacing);
+     connect(selectLineSpacing, SIGNAL(triggered(bool)), this, SLOT(slotSelectLineSpacing()));
 
      QStringList lineSpacingList;
      lineSpacingList
@@ -415,30 +433,36 @@ void konsolePart::makeGUI()
      m_options->addAction( selectLineSpacing );
 
      // Blinking Cursor
-     blinkingCursor = new KToggleAction(i18n("Blinking &Cursor"), settingsActions, QString());
+     blinkingCursor = new KToggleAction(i18n("Blinking &Cursor"), this);
+     settingsActions->addAction(blinkingCursor->objectName(), blinkingCursor);
      connect(blinkingCursor, SIGNAL(triggered(bool) ), SLOT(slotBlinkingCursor()));
      m_options->addAction(blinkingCursor);
 
      // Frame on/off
-     showFrame = new KToggleAction(i18n("Show Fr&ame"), settingsActions, QString());
+     showFrame = new KToggleAction(i18n("Show Fr&ame"), this);
+     settingsActions->addAction(showFrame->objectName(), showFrame);
      connect(showFrame, SIGNAL(triggered(bool) ), SLOT(slotToggleFrame()));
-     showFrame->setCheckedState(i18n("Hide Fr&ame"));
+     showFrame->setCheckedState(KGuiItem(i18n("Hide Fr&ame")));
      m_options->addAction(showFrame);
 
      // Word Connectors
-     KAction *WordSeps = new KAction(i18n("Wor&d Connectors..."), settingsActions, 0);
+     KAction *WordSeps = new KAction(i18n("Wor&d Connectors..."), this);
+     settingsActions->addAction(WordSeps->objectName(), WordSeps);
      connect(WordSeps, SIGNAL(triggered(bool) ), SLOT(slotWordSeps()));
      m_options->addAction( WordSeps );
 
      // Use Konsole's Settings
      m_options->addSeparator();
-     m_useKonsoleSettings = new KToggleAction( i18n("&Use Konsole's Settings"), 0, "use_konsole_settings" );
+     m_useKonsoleSettings = new KToggleAction( i18n("&Use Konsole's Settings"), this );
+     settingsActions->addAction( "use_konsole_settings", m_useKonsoleSettings );
      connect(m_useKonsoleSettings, SIGNAL(triggered(bool) ), SLOT(slotUseKonsoleSettings()));
      m_options->addAction(m_useKonsoleSettings);
 
      // Save Settings
      m_options->addSeparator();
-     KAction *saveSettings = new KAction(KIcon("filesave"), i18n("&Save as Default"), actions, "save_default");
+     QAction *saveSettings = actions->addAction("save_default");
+     saveSettings->setIcon(KIcon("filesave"));
+     saveSettings->setText(i18n("&Save as Default"));
      connect(saveSettings, SIGNAL(triggered(bool)), SLOT(saveProperties()));
      m_options->addAction( saveSettings );
      if (KGlobalSettings::insertTearOffHandle())
@@ -447,15 +471,20 @@ void konsolePart::makeGUI()
 
   // Popup Menu -------------------------------------------------------------------
   m_popupMenu = new KMenu((KMainWindow*)parentWidget);
-  KAction *selectionEnd = new KAction(i18n("Set Selection End"), actions, "selection_end");
+  QAction *selectionEnd = actions->addAction("selection_end");
+  selectionEnd->setText(i18n("Set Selection End"));
   connect(selectionEnd, SIGNAL(triggered(bool) ), te, SLOT(setSelectionEnd()));
   m_popupMenu->addAction( selectionEnd );
 
-  KAction *copyClipboard = new KAction(KIcon("editcopy"), i18n("&Copy"), actions, "edit_copy");
+  QAction *copyClipboard = actions->addAction("edit_copy");
+  copyClipboard->setIcon(KIcon("editcopy"));
+  copyClipboard->setText(i18n("&Copy"));
   connect(copyClipboard, SIGNAL(triggered(bool)), te, SLOT(copyClipboard()));
   m_popupMenu->addAction( copyClipboard );
 
-  KAction *pasteClipboard = new KAction(KIcon("editpaste"), i18n("&Paste"), actions, "edit_paste");
+  QAction *pasteClipboard = actions->addAction("edit_paste");
+  pasteClipboard->setIcon(KIcon("editpaste"));
+  pasteClipboard->setText(i18n("&Paste"));
   connect(pasteClipboard, SIGNAL(triggered(bool)), te, SLOT(pasteClipboard()));
   m_popupMenu->addAction( pasteClipboard );
 
@@ -471,7 +500,9 @@ void konsolePart::makeGUI()
      m_popupMenu->addSeparator();
   }
 
-  KAction *closeSession = new KAction(KIcon("fileclose"), i18n("&Close Terminal Emulator"), actions, "close_session");
+  QAction *closeSession = actions->addAction("close_session");
+  closeSession->setIcon(KIcon("fileclose"));
+  closeSession->setText(i18n("&Close Terminal Emulator"));
   connect(closeSession, SIGNAL(triggered(bool)), SLOT(closeCurrentSession()));
   m_popupMenu->addAction( closeSession );
   if (KGlobalSettings::insertTearOffHandle())
@@ -520,7 +551,7 @@ void konsolePart::applyProperties()
    // FIXME:  Move this somewhere else...
    KConfig* config = new KConfig("konsolerc",true);
    config->setGroup("UTMP");
-   se->setAddToUtmp( config->readEntry("AddToUtmp", QVariant(true)).toBool());
+   se->setAddToUtmp( config->readEntry("AddToUtmp", true));
    delete config;
 
    se->widget()->setVTFont( defaultFont );
@@ -530,7 +561,7 @@ void konsolePart::applyProperties()
 
 void konsolePart::setSettingsMenuEnabled( bool enable )
 {
-   foreach ( KAction *a, settingsActions->actions() )
+   foreach ( QAction *a, settingsActions->actions() )
    {
       a->setEnabled( enable );
    }
@@ -552,8 +583,8 @@ void konsolePart::readProperties()
 
   config->setDesktopGroup();
 
-  b_framevis = config->readEntry("has frame", QVariant(false)).toBool();
-  b_histEnabled = config->readEntry("historyenabled", QVariant(true)).toBool();
+  b_framevis = config->readEntry("has frame", false);
+  b_histEnabled = config->readEntry("historyenabled", true);
   n_bell = qMin(config->readEntry("bellmode",uint(TEWidget::BELLSYSTEM)),3u);
   n_keytab=config->readEntry("keytab",0); // act. the keytab for this session
   n_scroll = qMin(config->readEntry("scrollbar",uint(TEWidget::SCRRIGHT)),2u);
@@ -585,7 +616,7 @@ void konsolePart::readProperties()
   }
 
   te->setBellMode(n_bell);
-  te->setBlinkingCursor(config->readEntry("BlinkingCursor", QVariant(false)).toBool());
+  te->setBlinkingCursor(config->readEntry("BlinkingCursor", false));
   te->setFrameStyle( b_framevis?(QFrame::WinPanel|QFrame::Sunken):QFrame::NoFrame );
   te->setLineSpacing( config->readEntry( "LineSpacing", 0 ) );
   te->setScrollbarLocation(n_scroll);
@@ -595,7 +626,7 @@ void konsolePart::readProperties()
 
   config = new KConfig("konsolerc",true);
   config->setDesktopGroup();
-  te->setTerminalSizeHint( config->readEntry("TerminalSizeHint", QVariant(true)).toBool() );
+  te->setTerminalSizeHint( config->readEntry("TerminalSizeHint", true) );
   delete config;
 }
 
@@ -1032,7 +1063,7 @@ konsoleBrowserExtension::~konsoleBrowserExtension()
 
 void konsoleBrowserExtension::emitOpenURLRequest(const KUrl &url)
 {
-  emit openURLRequest(url);
+  emit openUrlRequest(url);
 }
 
 const char* sensibleShell()
@@ -1046,10 +1077,18 @@ void konsolePart::startProgram( const QString& program,
                                 const QStringList& args )
 {
   if ( se ) delete se;
-  se = new TESession(te, program, args, "xterm", parentWidget->winId());
+#ifdef __GNUC__
+#warning "Add setup for TESession"
+#endif
+  se = new TESession();
+  se->setProgram(program);
+  se->setArguments(args);
+  se->addView(te);
+
+//  se = new TESession(te, program, args, "xterm", parentWidget->winId());
   connect( se,SIGNAL(done(TESession*)),
            this,SLOT(doneSession(TESession*)) );
-  connect( se,SIGNAL(openURLRequest(const QString &)),
+  connect( se,SIGNAL(openUrlRequest(const QString &)),
            this,SLOT(emitOpenURLRequest(const QString &)) );
   connect( se, SIGNAL( updateTitle() ),
            this, SLOT( updateTitle() ) );
