@@ -22,17 +22,29 @@
 /* kvt, which is copyright (c) 1996 by Matthias Ettrich <ettrich@kde.org> */
 /*                                                                        */
 
+// Standard Library / Unix
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 
+// Qt
 #include <QDir>
-#include <qsessionmanager.h>
+#include <QSessionManager>
 #include <QWidget>
-
 #include <QStringList>
 
+// X11
+#if defined(Q_WS_X11) && defined(HAVE_XRENDER)
+    #define TRUE_TRANSPARENCY_SUPPORT
+#endif
 
+#ifdef TRUE_TRANSPARENCY_SUPPORT
+    #include <X11/Xlib.h>
+    #include <X11/extensions/Xrender.h>
+    #include <fixx11h.h>
+#endif
+
+// KDE
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -41,30 +53,19 @@
 #include <kglobalsettings.h>
 #include <kio/netaccess.h>
 #include <kmessagebox.h>
-
 #include <config.h>
 #include <kauthorized.h>
+#include <ksimpleconfig.h>
+#include <ksessionmanager.h>
 
+// Konsole
 #include "konsole.h"
+#include "SessionManager.h"
 
-// COMPOSITE disabled by default because the QApplication constructor
-// needed to enable the ARGB32 visual has undesired side effects.
-#if 0
-#if defined(Q_WS_X11) && defined(HAVE_XRENDER) && QT_VERSION >= 0x030300
-# define COMPOSITE
-#endif
-#endif
-
-#ifdef COMPOSITE
-# include <X11/Xlib.h>
-# include <X11/extensions/Xrender.h>
-# include <fixx11h.h>
-#endif
 
 static const char description[] =
-  I18N_NOOP("X terminal for use with KDE.");
+  I18N_NOOP("The KDE Terminal");
 
-//   { "T <title>",      0, 0 },
 static KCmdLineOptions options[] =
 {
    { "name <name>",    I18N_NOOP("Set window class"), 0 },
@@ -79,9 +80,6 @@ static KCmdLineOptions options[] =
    { "noframe",        I18N_NOOP("Do not display frame"), 0 },
    { "noscrollbar",    I18N_NOOP("Do not display scrollbar"), 0 },
    { "noxft",          I18N_NOOP("Do not use Xft (anti-aliasing)"), 0 },
-#ifdef COMPOSITE
-   { "noargb",         I18N_NOOP("Do not use the ARGB32 visual (transparency)"), 0 },
-#endif
    { "vt_sz CCxLL",    I18N_NOOP("Terminal size in columns x lines"), 0 },
    { "noresize",       I18N_NOOP("Terminal size is fixed"), 0 },
    { "type <type>",    I18N_NOOP("Start with given session type"), 0 },
@@ -106,36 +104,34 @@ static bool login_shell = false;
 //static bool full_script = false;
 static bool auto_close = true;
 static bool fixed_size = false;
+bool true_transparency = false;
 
-bool argb_visual = false;
 
-const char *konsole_shell(QStringList &args)
-{
-  const char* shell = getenv("SHELL");
-  if (shell == NULL || *shell == '\0') shell = "/bin/sh";
-  if (login_shell)
-  {
-    char* t = (char*)strrchr(shell,'/');
-    if (t) // see sh(1)
-    {
-      t = strdup(t);
-      *t = '-';
-      args.append(t);
-      free(t);
-    }
-    else
-      args.append(shell);
-  }
-  else
-    args.append(shell);
-  return shell;
-}
+//prototypes
+const char* konsole_shell(QStringList& args);
+
+// Retrieve information about display needed to enable true transparency.  This will
+// search for a display, visual format and colormap which can be passed to the KApplication
+// constructor to enable the use of true transparency in the application.  If compositing
+// support is not available then 'display', 'visual' and 'colormap' will be set to null. 
+// 
+// displayName - The name of the display to use, will use the default display
+//               if this is an empty string.
+// display     - Out parameter. Receives a pointer to the X display to use
+// visual      - Out parameter. Receives a pointer to the X visual to use
+// colormap    - Out parameter. Set to the X colormap to use
+
+#ifdef TRUE_TRANSPARENCY_SUPPORT
+void getDisplayInfo( const QString& displayName , Display*& display , 
+                     Visual*& visual, Colormap& colormap);
+#endif
+
 
 /**
    The goal of this class is to add "--noxft" and "--ls" to the restoreCommand
    if konsole was started with any of those options.
  */
-class KonsoleSessionManaged: public KSessionManaged {
+class KonsoleSessionManager: public KSessionManager {
 public:
     bool saveState( QSessionManager&sm) {
         QStringList restartCommand = sm.restartCommand();
@@ -161,7 +157,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
 {
   setgid(getgid()); setuid(getuid()); // drop privileges
 
-  // deal with shell/command ////////////////////////////
+  // deal with shell/command 
   bool histon = true;
   bool menubaron = true;
   bool tabbaron = true;
@@ -171,71 +167,68 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
   QByteArray wname = PACKAGE;
 
 
-  KAboutData aboutData( "konsole" /*PACKAGE*/, I18N_NOOP("Konsole"),
-    VERSION, description, KAboutData::License_GPL_V2,
-    "Copyright (c) 1997-2006, Konsole Team", 0 , "http://konsole.kde.org");
+  KAboutData aboutData( "konsole" , I18N_NOOP("Konsole") , VERSION , description , 
+                        KAboutData::License_GPL , I18N_NOOP("(C) 1997-2006 , Konsole Developers") );
   aboutData.addAuthor("Robert Knight",I18N_NOOP("Maintainer"), "robertknight@gmail.com");
   aboutData.addAuthor("Lars Doelle",I18N_NOOP("Author"), "lars.doelle@on-line.de");
   aboutData.addCredit("Kurt V. Hindenburg",
-    I18N_NOOP("bug fixing and improvements"), 
-    "kurt.hindenburg@kdemail.net");
+    I18N_NOOP("Bug fixes and general improvements"), 
+    "kurt.hindenburg@gmail.com");
   aboutData.addCredit("Waldo Bastian",
-    I18N_NOOP("bug fixing and improvements"),
+    I18N_NOOP("Bug fixes and general improvements"),
     "bastian@kde.org");
   aboutData.addCredit("Stephan Binner",
-    I18N_NOOP("bug fixing and improvements"),
+    I18N_NOOP("Bug fixes and general improvements"),
     "binner@kde.org");
   aboutData.addCredit("Chris Machemer",
-    I18N_NOOP("bug fixing"),
+    I18N_NOOP("Bug fixes"),
     "machey@ceinetworks.com");
   aboutData.addCredit("Stephan Kulow",
-    I18N_NOOP("Solaris support and work on history"),
+    I18N_NOOP("Solaris support and history"),
     "coolo@kde.org");
   aboutData.addCredit("Alexander Neundorf",
-    I18N_NOOP("faster startup, bug fixing"),
+    I18N_NOOP("Bug fixes and improved startup performance"),
     "neundorf@kde.org");
   aboutData.addCredit("Peter Silva",
-    I18N_NOOP("decent marking"),
+    I18N_NOOP("Marking improvements"),
     "peter.silva@videotron.ca");
   aboutData.addCredit("Lotzi Boloni",
-    I18N_NOOP("partification\n"
+    I18N_NOOP("Embedded Konsole\n"
     "Toolbar and session names"),
     "boloni@cs.purdue.edu");
   aboutData.addCredit("David Faure",
-    I18N_NOOP("partification\n"
-    "overall improvements"),
+    I18N_NOOP("Embedded Konsole\n"
+    "General improvements"),
     "David.Faure@insa-lyon.fr");
   aboutData.addCredit("Antonio Larrosa",
-    I18N_NOOP("transparency"),
+    I18N_NOOP("Visual effects"),
     "larrosa@kde.org");
   aboutData.addCredit("Matthias Ettrich",
-    I18N_NOOP("most of main.C donated via kvt\n"
-    "overall improvements"),
+    I18N_NOOP("Code from the kvt project\n"
+    "General improvements"),
     "ettrich@kde.org");
   aboutData.addCredit("Warwick Allison",
-    I18N_NOOP("schema and selection improvements"),
+    I18N_NOOP("Schema and text selection improvements"),
     "warwick@troll.no");
   aboutData.addCredit("Dan Pilone",
-    I18N_NOOP("SGI Port"),
+    I18N_NOOP("SGI port"),
     "pilone@slac.com");
   aboutData.addCredit("Kevin Street",
     I18N_NOOP("FreeBSD port"),
     "street@iname.com");
   aboutData.addCredit("Sven Fischer",
-    I18N_NOOP("bug fixing"),
+    I18N_NOOP("Bug fixes"),
     "herpes@kawo2.rwth-aachen.de");
   aboutData.addCredit("Dale M. Flaven",
-    I18N_NOOP("bug fixing"),
+    I18N_NOOP("Bug fixes"),
     "dflaven@netport.com");
   aboutData.addCredit("Martin Jones",
-    I18N_NOOP("bug fixing"),
+    I18N_NOOP("Bug fixes"),
     "mjones@powerup.com.au");
   aboutData.addCredit("Lars Knoll",
-    I18N_NOOP("bug fixing"),
+    I18N_NOOP("Bug fixes"),
     "knoll@mpi-hd.mpg.de");
-  aboutData.addCredit("",I18N_NOOP("Thanks to many others.\n"
-    "The above list only reflects the contributors\n"
-    "I managed to keep track of."));
+  aboutData.addCredit("",I18N_NOOP("Thanks to many others.\n"));
 
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
@@ -255,48 +248,22 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
   if( qtargs->isSet("font") )
       kWarning() << "The Qt option -fn, --font has no effect." << endl;
 
-#ifdef COMPOSITE
-  char *display = 0;
-  if ( qtargs->isSet("display"))
-    display = qtargs->getOption( "display" ).data();
+#ifdef TRUE_TRANSPARENCY_SUPPORT
+  Colormap colormap  = 0;
+  Visual*  visual    = 0;
+  Display* display   = 0;
 
-  Display *dpy = XOpenDisplay( display );
-  if ( !dpy ) {
-    kError() << "cannot connect to X server " << display << endl;
-    exit( 1 );
-  }
-
-  int screen = DefaultScreen( dpy );
-  Colormap colormap = 0;
-  Visual *visual = 0;
-  int event_base, error_base;
-
-  if ( args->isSet("argb") && XRenderQueryExtension( dpy, &event_base, &error_base ) )
-  {
-    int nvi;
-    XVisualInfo templ;
-    templ.screen  = screen;
-    templ.depth   = 32;
-    templ.c_class = TrueColor;
-    XVisualInfo *xvi = XGetVisualInfo( dpy, VisualScreenMask | VisualDepthMask
-		  | VisualClassMask, &templ, &nvi );
-
-    for ( int i = 0; i < nvi; i++ ) {
-      XRenderPictFormat *format = XRenderFindVisualFormat( dpy, xvi[i].visual );
-      if ( format->type == PictTypeDirect && format->direct.alphaMask ) {
-        visual = xvi[i].visual;
-        colormap = XCreateColormap( dpy, RootWindow( dpy, screen ), visual, AllocNone );
-        argb_visual = true;
-        break;
-      }
-    }
-  }
-
-  KApplication a( dpy, Qt::HANDLE( visual ), Qt::HANDLE( colormap ) );
+  getDisplayInfo( qtargs->getOption("display") , display , visual , colormap );
+  KApplication a( display , Qt::HANDLE( visual ), Qt::HANDLE( colormap ) );
 #else
   KApplication a;
 #endif
 
+  //create session manager to keep track of available session types
+  //and active terminal sessions
+  SessionManager* sessionManager = new SessionManager();
+  
+  
   QString title;
   if(args->isSet("T")) {
     title = QFile::decodeName(args->getOption("T"));
@@ -324,7 +291,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
        eargs.append( args->arg(i) );
 
      if (title.isEmpty() &&
-         (kapp->caption() == kapp->aboutData()->programName()))
+         (KGlobal::caption() == KGlobal::mainComponent().aboutData()->programName()))
      {
         title = QFile::decodeName(shell);  // program executed in the title bar
      }
@@ -342,7 +309,9 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
 //  full_script = args->isSet("script");
   auto_close = args->isSet("close");
   fixed_size = !args->isSet("resize");
+#ifdef __GNUC__
 #warning "KDE4: Does DBUS have an equivalent function for dcopClient()->setQtBridgeEnabled()?"
+#endif  
 #if 0
   if (!full_script)
 	a.dcopClient()->setQtBridgeEnabled(false);
@@ -353,17 +322,13 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
     type = args->getOption("type");
   }
   if(args->isSet("types")) {
-    QStringList types = KGlobal::dirs()->findAllResources("appdata", "*.desktop", false, true);
-    types.sort();
-    for(QStringList::ConstIterator it = types.begin();
-        it != types.end(); ++it)
+    
+    QListIterator<SessionInfo*> infoIter(sessionManager->availableSessionTypes());
+    while (infoIter.hasNext())
     {
-       QString file = *it;
-       file = file.mid(file.lastIndexOf('/')+1);
-       if (file.endsWith(".desktop"))
-          file = file.left(file.length()-8);
-       printf("%s\n", QFile::encodeName(file).data());
+        printf("%s\n",QFileInfo(infoIter.next()->path()).baseName().toAscii().data());
     }
+    
     return 0;
   }
   if(args->isSet("schemas") || args->isSet("schemata")) {
@@ -415,7 +380,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
   }
   if (args->isSet("profiles"))
   {
-     QStringList profiles = KGlobal::dirs()->findAllResources("data", "konsole/profiles/*", false, true);
+     QStringList profiles = KGlobal::dirs()->findAllResources("data", "konsole/profiles/*", KStandardDirs::NoDuplicates);
      profiles.sort();
      for(QStringList::ConstIterator it = profiles.begin();
          it != profiles.end(); ++it)
@@ -456,7 +421,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
   signal(SIGHUP, SIG_IGN);
 
   putenv((char*)"COLORTERM="); // to trigger mc's color detection
-  KonsoleSessionManaged ksm;
+  KonsoleSessionManager ksm;
 
   if (a.isSessionRestored() || !profile.isEmpty())
   {
@@ -499,10 +464,16 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
         sIcon = sessionconfig->readEntry("Icon0","konsole");
         sCwd = sessionconfig->readPathEntry("Cwd0");
         workDir = sessionconfig->readPathEntry("workdir");
-        n_tabbar = qMin(sessionconfig->readEntry("tabbar", QVariant(Konsole::TabBottom)).toUInt(), 2u);
+        n_tabbar = qMin(sessionconfig->readEntry("tabbar", unsigned(Konsole::TabBottom)), 2u);
         Konsole *m = new Konsole(wname,histon,menubaron,tabbaron,frameon,scrollbaron,0/*type*/,true,n_tabbar, workDir);
 
-        m->newSession(sPgm, eargs, sTerm, sIcon, sTitle, sCwd);
+
+        m->setSessionManager(sessionManager);
+
+        kDebug() << "WARNING:  Not using appropriate properties for new session" << endl;
+        m->newSession( sessionManager->defaultSessionType() );
+        
+        //m->newSession(sPgm, eargs, sTerm, sIcon, sTitle, sCwd);
 
 //        m->enableFullScripting(full_script);
         m->enableFixedSize(fixed_size);
@@ -511,18 +482,15 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
         if (!sessionconfig->hasKey("Pgm0"))
             sessionconfig->setDesktopGroup(); // Backwards compatible
         m->makeGUI();
-        m->setEncoding(sessionconfig->readEntry("Encoding0", QVariant(0)).toInt());
+        m->setEncoding(sessionconfig->readEntry("Encoding0", int(0)));
         m->setSchema(sessionconfig->readEntry("Schema0"));
         // Use konsolerc default as tmpFont instead?
-        QVariant v_defaultFont = sessionconfig->readEntry("SessionFont0", QVariant(KGlobalSettings::fixedFont()));
-        m->initSessionFont( v_defaultFont.value<QFont>() );
+        m->initSessionFont(sessionconfig->readEntry("SessionFont0", KGlobalSettings::fixedFont()));
         m->initSessionKeyTab(sessionconfig->readEntry("KeyTab0"));
-        m->initMonitorActivity(sessionconfig->readEntry("MonitorActivity0", QVariant(false)).toBool());
-        m->initMonitorSilence(sessionconfig->readEntry("MonitorSilence0", QVariant(false)).toBool());
-        m->initMasterMode(sessionconfig->readEntry("MasterMode0", QVariant(false)).toBool());
-        //FIXME: Verify this code when KDE4 supports tab colors... kvh
-        QVariant v_tabColor = sessionconfig->readEntry("TabColor0");
-        m->initTabColor( v_tabColor.value<QColor>() );
+        m->initMonitorActivity(sessionconfig->readEntry("MonitorActivity0", false));
+        m->initMonitorSilence(sessionconfig->readEntry("MonitorSilence0", false));
+        m->initMasterMode(sessionconfig->readEntry("MasterMode0", false));
+        m->initTabColor( sessionconfig->readEntry("TabColor0", QColor()));
         // -1 will be changed to the default history in konsolerc
 //        m->initHistory(sessionconfig->readNumEntry("History0", -1),
 //                       sessionconfig->readBoolEntry("HistoryEnabled0", true));
@@ -550,24 +518,28 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
           sIcon = sessionconfig->readEntry(key,QString("konsole"));
           key = QString("Cwd%1").arg(counter);
           sCwd = sessionconfig->readPathEntry(key);
-          m->newSession(sPgm, eargs, sTerm, sIcon, sTitle, sCwd);
+          
+          //TODO: Make use of command, program type, icon etc. here
+          m->newSession();
+          
+          //m->newSession(sPgm, eargs, sTerm, sIcon, sTitle, sCwd);
+          
           m->setSessionTitle(sTitle);  // Use title as is
           key = QString("Schema%1").arg(counter);
           m->setSchema(sessionconfig->readEntry(key, QString()));
           key = QString("Encoding%1").arg(counter);
-          m->setEncoding(sessionconfig->readEntry(key, QVariant(0)).toInt());
+          m->setEncoding(sessionconfig->readEntry(key, int(0)));
           key = QString("SessionFont%1").arg(counter);
-          QVariant v_defaultFont = sessionconfig->readEntry(key, QVariant(KGlobalSettings::fixedFont()));
-          m->initSessionFont( v_defaultFont.value<QFont>() );
+          m->initSessionFont( sessionconfig->readEntry(key, KGlobalSettings::fixedFont()));
 
           key = QString("KeyTab%1").arg(counter);
           m->initSessionKeyTab(sessionconfig->readEntry(key, QString()));
           key = QString("MonitorActivity%1").arg(counter);
-          m->initMonitorActivity(sessionconfig->readEntry(key, QVariant(false)).toBool());
+          m->initMonitorActivity(sessionconfig->readEntry(key, false));
           key = QString("MonitorSilence%1").arg(counter);
-          m->initMonitorSilence(sessionconfig->readEntry(key, QVariant(false)).toBool());
+          m->initMonitorSilence(sessionconfig->readEntry(key, false));
           key = QString("MasterMode%1").arg(counter);
-          m->initMasterMode(sessionconfig->readEntry(key, QVariant(false)).toBool());
+          m->initMasterMode(sessionconfig->readEntry(key, false));
           key = QString("TabColor%1").arg(counter);
 //          m->initTabColor(sessionconfig->readColorEntry(key));
           //FIXME: Verify this code when KDE4 supports tab colors... kvh
@@ -578,8 +550,8 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
           // -1 will be changed to the default history in konsolerc
           key = QString("History%1").arg(counter);
           QString key2 = QString("HistoryEnabled%1").arg(counter);
-          m->initHistory(sessionconfig->readNumEntry(key, -1),
-                         sessionconfig->readBoolEntry(key2, true));
+          m->initHistory(sessionconfig->readEntry(key, -1),
+                         sessionconfig->readEntry(key2, true));
 */
 
           counter++;
@@ -597,14 +569,21 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
         }
 	// works only for the first one, but there won't be more.
         n++;
-        m->activateSession( sessionconfig->readEntry("ActiveSession", QVariant(0)).toInt() );
+        m->activateSession( sessionconfig->readEntry("ActiveSession", int(0)) );
 	m->setAutoClose(auto_close);
     }
   }
   else
   {
     Konsole*  m = new Konsole(wname,histon,menubaron,tabbaron,frameon,scrollbaron,type, false, 0, workDir);
-    m->newSession((shell ? QFile::decodeName(shell) : QString()), eargs, term, QString(), title, workDir);
+
+   m->setSessionManager(sessionManager);
+
+   kDebug() <<  "* WARNING - Code to create new session not done yet" << endl;
+   //TODO : Make use of session properties
+   m->newSession();
+   
+ //   m->newSession((shell ? QFile::decodeName(shell) : QString()), eargs, term, QString(), title, workDir);
 //    m->enableFullScripting(full_script);
     m->enableFixedSize(fixed_size);
 
@@ -631,3 +610,70 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
 
   return ret;
 }
+
+const char *konsole_shell(QStringList &args)
+{
+  const char* shell = getenv("SHELL");
+  if (shell == NULL || *shell == '\0') shell = "/bin/sh";
+  if (login_shell)
+  {
+    char* t = (char*)strrchr(shell,'/');
+    if (t) // see sh(1)
+    {
+      t = strdup(t);
+      *t = '-';
+      args.append(t);
+      free(t);
+    }
+    else
+      args.append(shell);
+  }
+  else
+    args.append(shell);
+  return shell;
+}
+
+
+#ifdef TRUE_TRANSPARENCY_SUPPORT
+void getDisplayInfo( const QString& displayName , Display*& dpy , Visual*& visual, Colormap& colormap )
+{
+  dpy = 0;
+  visual = 0;
+  colormap = 0;
+
+  char *display = 0;
+
+  if ( !displayName.isEmpty() )
+      display = displayName.toAscii().data();
+
+  dpy = XOpenDisplay( display );
+  if ( !dpy ) {
+    kError() << "cannot connect to X server " << display << endl;
+    exit( 1 );
+  }
+
+  int screen = DefaultScreen( dpy );
+  int event_base, error_base;
+
+  if ( XRenderQueryExtension( dpy, &event_base, &error_base ) )
+  {
+    int nvi;
+    XVisualInfo templ;
+    templ.screen  = screen;
+    templ.depth   = 32;
+    templ.c_class = TrueColor;
+    XVisualInfo *xvi = XGetVisualInfo( dpy, VisualScreenMask | VisualDepthMask
+		  | VisualClassMask, &templ, &nvi );
+
+    for ( int i = 0; i < nvi; i++ ) {
+      XRenderPictFormat *format = XRenderFindVisualFormat( dpy, xvi[i].visual );
+      if ( format->type == PictTypeDirect && format->direct.alphaMask ) {
+        visual = xvi[i].visual;
+        colormap = XCreateColormap( dpy, RootWindow( dpy, screen ), visual, AllocNone );
+        true_transparency = true;
+        break;
+      }
+    }
+  }
+}
+#endif
