@@ -45,6 +45,9 @@
 #include <kmessagebox.h>
 #include <kimageeffect.h>
 #include <QImage>
+#ifdef Q_WS_X11
+#include <kdesktop_background_interface.h>
+#endif
 
 // SchemaListBoxText is a list box text item with schema filename
 class SchemaListBoxText : public Q3ListBoxText
@@ -76,10 +79,17 @@ SchemaEditor::SchemaEditor(QWidget * parent)
     bold.resize(20);
     transparent.resize(20);
     defaultSchema = "";
-
-    QDBusInterface kdesktop("org.kde.kdesktop", "/Background", "org.kde.kdesktop.Background");
-    kdesktop.call( "setExport", 1 );
-
+#ifdef Q_WS_X11
+    int konq_screen_number = KApplication::desktop()->primaryScreen();
+    QByteArray appname;
+    if (konq_screen_number == 0)
+        appname = "org.kde.kdesktop";
+    else
+        appname = "org.kde.kdesktop-screen-" + QByteArray::number( konq_screen_number);
+    org::kde::kdesktop::Background desktop(appname, "/Background", QDBusConnection::sessionBus());
+    desktop.setExport(1);
+    
+#endif
     transparencyCheck->setChecked(true);
     transparencyCheck->setChecked(false);
 
@@ -109,6 +119,7 @@ SchemaEditor::SchemaEditor(QWidget * parent)
 
     connect(defaultSchemaCB, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
     removeButton->setEnabled( schemaList->currentItem() );
+    load();
 }
 
 
@@ -197,10 +208,9 @@ void SchemaEditor::getList()
     }
 }
 
-void SchemaEditor::show()
+void SchemaEditor::load()
 {
     getList();
-    SchemaDialog::show();
 }
 
 
@@ -295,7 +305,7 @@ void SchemaEditor::removeCurrent()
 	int code = KMessageBox::warningContinueCancel(this,
 	    i18n("You are trying to remove a system schema. Are you sure?"),
 	    i18n("Removing System Schema"),
-	    KStdGuiItem::del());
+	    KStandardGuiItem::del());
 	if (code != KMessageBox::Continue)
 	    return;
     }
@@ -483,8 +493,8 @@ void SchemaEditor::querySave()
                          i18n("The schema has been modified.\n"
 			"Do you want to save the changes?"),
 			i18n("Schema Modified"),
-			KStdGuiItem::save(),
-			KStdGuiItem::discard());
+			KStandardGuiItem::save(),
+			KStandardGuiItem::discard());
     if (result == KMessageBox::Yes)
     {
         saveCurrent();
