@@ -29,7 +29,7 @@
 
 #include <kio/netaccess.h>
 
-#include <kaboutapplication.h>
+#include <kaboutapplicationdialog.h>
 #include <kaboutdata.h>
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -50,7 +50,7 @@
 #include <kparts/event.h>
 #include <krecentfilesaction.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <ksqueezedtextlabel.h>
 #include <kstringhandler.h>
 #include <kurl.h>
@@ -96,7 +96,7 @@ KWrite::KWrite (KTextEditor::Document *doc)
     }
 
     doc = editor->createDocument(0);
-  
+
     // enable the modified on disk warning dialogs if any
     if (qobject_cast<KTextEditor::ModificationInterface *>(doc))
       qobject_cast<KTextEditor::ModificationInterface *>(doc)->setModifiedOnDiskWarning (true);
@@ -119,6 +119,7 @@ KWrite::KWrite (KTextEditor::Document *doc)
   connect(m_view->document(), SIGNAL(modifiedChanged(KTextEditor::Document *)), this, SLOT(modifiedChanged()));
   connect(m_view->document(), SIGNAL(modifiedOnDisk(KTextEditor::Document *, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)), this, SLOT(modifiedChanged()) );
   connect(m_view->document(), SIGNAL(documentNameChanged(KTextEditor::Document *)), this, SLOT(documentNameChanged()));
+  connect(m_view->document(),SIGNAL(documentUrlChanged(KTextEditor::Document *)), this, SLOT(urlChanged()));
 
   setAcceptDrops(true);
   connect(m_view,SIGNAL(dropEventPass(QDropEvent *)),this,SLOT(slotDropEvent(QDropEvent *)));
@@ -160,44 +161,57 @@ KWrite::~KWrite()
 
 void KWrite::setupActions()
 {
-  KStdAction::close( this, SLOT(slotFlush()), actionCollection(), "file_close" )->setWhatsThis(i18n("Use this to close the current document"));
+  actionCollection()->addAction( KStandardAction::Close, "file_close", this, SLOT(slotFlush()) )
+    ->setWhatsThis(i18n("Use this to close the current document"));
 
   // setup File menu
-  KStdAction::print(this, SLOT(printDlg()), actionCollection())->setWhatsThis(i18n("Use this command to print the current document"));
-  KStdAction::openNew( this, SLOT(slotNew()), actionCollection(), "file_new" )->setWhatsThis(i18n("Use this command to create a new document"));
-  KStdAction::open( this, SLOT( slotOpen() ), actionCollection(), "file_open" )->setWhatsThis(i18n("Use this command to open an existing document for editing"));
+  actionCollection()->addAction( KStandardAction::Print, this, SLOT(printDlg()) )
+    ->setWhatsThis(i18n("Use this command to print the current document"));
+  actionCollection()->addAction( KStandardAction::New, "file_new", this, SLOT(slotNew()) )
+    ->setWhatsThis(i18n("Use this command to create a new document"));
+  actionCollection()->addAction( KStandardAction::Open, "file_open", this, SLOT(slotOpen()) )
+    ->setWhatsThis(i18n("Use this command to open an existing document for editing"));
 
-  m_recentFiles = KStdAction::openRecent(this, SLOT(slotOpen(const KUrl&)),
-                                         actionCollection());
+  m_recentFiles = KStandardAction::openRecent(this, SLOT(slotOpen(const KUrl&)), this);
+  actionCollection()->addAction(m_recentFiles->objectName(), m_recentFiles);
   m_recentFiles->setWhatsThis(i18n("This lists files which you have opened recently, and allows you to easily open them again."));
 
-  KAction *a = new KAction( KIcon("window_new"), i18n("&New Window"), actionCollection(), "view_new_view" );
+  QAction *a = actionCollection()->addAction( "view_new_view" );
+  a->setIcon( KIcon("window_new") );
+  a->setText( i18n("&New Window") );
   connect( a, SIGNAL(triggered()), this, SLOT(newView()) );
   a->setWhatsThis(i18n("Create another view containing the current document"));
 
-  a = new KAction( i18n("Choose Editor..."), actionCollection(),"settings_choose_editor" );
+  a = actionCollection()->addAction( "settings_choose_editor" );
+  a->setText( i18n("Choose Editor...") );
   connect( a, SIGNAL(triggered()), this, SLOT(changeEditor()) );
   a->setWhatsThis(i18n("Override the system wide setting for the default editing component"));
 
-  KStdAction::quit(this, SLOT(close()), actionCollection())->setWhatsThis(i18n("Close the current document view"));
+  actionCollection()->addAction( KStandardAction::Quit, this, SLOT(close()) )
+    ->setWhatsThis(i18n("Close the current document view"));
 
   // setup Settings menu
   setStandardToolBarMenuEnabled(true);
 
-  m_paShowStatusBar = KStdAction::showStatusbar(this, SLOT(toggleStatusBar()), actionCollection(), "settings_show_statusbar");
+  m_paShowStatusBar = KStandardAction::showStatusbar(this, SLOT(toggleStatusBar()), this);
+  actionCollection()->addAction( "settings_show_statusbar", m_paShowStatusBar);
   m_paShowStatusBar->setWhatsThis(i18n("Use this command to show or hide the view's statusbar"));
 
-  m_paShowPath = new KToggleAction( i18n("Sho&w Path"), actionCollection(), "set_showPath" );
+  m_paShowPath = new KToggleAction( i18n("Sho&w Path"), this );
+  actionCollection()->addAction( "set_showPath", m_paShowPath );
   connect( m_paShowPath, SIGNAL(triggered()), this, SLOT(documentNameChanged()) );
-  m_paShowPath->setCheckedState(i18n("Hide Path"));
+  m_paShowPath->setCheckedState(KGuiItem(i18n("Hide Path")));
   m_paShowPath->setWhatsThis(i18n("Show the complete document path in the window caption"));
-  a=KStdAction::keyBindings(this, SLOT(editKeys()), actionCollection());
+
+  a= actionCollection()->addAction( KStandardAction::KeyBindings, this, SLOT(editKeys()) );
   a->setWhatsThis(i18n("Configure the application's keyboard shortcut assignments."));
 
-  a = KStdAction::configureToolbars(this, SLOT(editToolbars()), actionCollection(), "set_configure_toolbars");
+  a = actionCollection()->addAction( KStandardAction::ConfigureToolbars, "set_configure_toolbars",
+                                     this, SLOT(editToolbars()) );
   a->setWhatsThis(i18n("Configure which items should appear in the toolbar(s)."));
 
-  a = new KAction( i18n("&About Editor Component"), actionCollection(), "help_about_editor" );
+  a = actionCollection()->addAction( "help_about_editor" );
+  a->setText( i18n("&About Editor Component") );
   connect( a, SIGNAL(triggered()), this, SLOT(aboutEditor()) );
 
 }
@@ -236,7 +250,7 @@ void KWrite::setupStatusBar()
 // load on url
 void KWrite::loadURL(const KUrl &url)
 {
-  m_view->document()->openURL(url);
+  m_view->document()->openUrl(url);
 }
 
 // is closing the window wanted by user ?
@@ -263,7 +277,7 @@ void KWrite::changeEditor()
 
 void KWrite::slotFlush ()
 {
-   m_view->document()->closeURL();
+   m_view->document()->closeUrl();
 }
 
 void KWrite::slotNew()
@@ -273,7 +287,7 @@ void KWrite::slotNew()
 
 void KWrite::slotOpen()
 {
-	KEncodingFileDialog::Result r=KEncodingFileDialog::getOpenURLsAndEncoding(m_view->document()->encoding(), m_view->document()->url().url(),QString(),this,i18n("Open File"));
+	KEncodingFileDialog::Result r=KEncodingFileDialog::getOpenUrlsAndEncoding(m_view->document()->encoding(), m_view->document()->url().url(),QString(),this,i18n("Open File"));
 
   for (KUrl::List::Iterator i=r.URLs.begin(); i != r.URLs.end(); ++i)
   {
@@ -305,7 +319,7 @@ void KWrite::slotOpen( const KUrl& url )
   }
 }
 
-void KWrite::slotFileNameChanged()
+void KWrite::urlChanged()
 {
   if ( ! m_view->document()->url().isEmpty() )
     m_recentFiles->addUrl( m_view->document()->url() );
@@ -335,7 +349,7 @@ void KWrite::editKeys()
 
 void KWrite::editToolbars()
 {
-  saveMainWindowSettings( KGlobal::config(), "MainWindow" );
+  saveMainWindowSettings( KGlobal::config().data(), "MainWindow" );
   KEditToolbar *dlg = new KEditToolbar(guiFactory());
 
   connect( dlg, SIGNAL(newToolbarConfig()), this, SLOT(slotNewToolbarConfig()) );
@@ -345,7 +359,7 @@ void KWrite::editToolbars()
 
 void KWrite::slotNewToolbarConfig()
 {
-    applyMainWindowSettings( KGlobal::config(), "MainWindow" );
+    applyMainWindowSettings( KGlobal::config().data(), "MainWindow" );
 }
 
 void KWrite::dragEnterEvent( QDragEnterEvent *event )
@@ -373,9 +387,9 @@ void KWrite::slotDropEvent( QDropEvent *event )
 
 void KWrite::slotEnableActions( bool enable )
 {
-  QList<KAction *> actions = actionCollection()->actions();
-  QList<KAction *>::ConstIterator it = actions.begin();
-  QList<KAction *>::ConstIterator end = actions.end();
+  QList<QAction *> actions = actionCollection()->actions();
+  QList<QAction *>::ConstIterator it = actions.begin();
+  QList<QAction *>::ConstIterator end = actions.end();
 
   for (; it != end; ++it )
       (*it)->setEnabled( enable );
@@ -389,16 +403,16 @@ void KWrite::slotEnableActions( bool enable )
 }
 
 //common config
-void KWrite::readConfig(KConfig *config)
+void KWrite::readConfig(KSharedConfigPtr config)
 {
   config->setGroup("General Options");
 
-  m_paShowStatusBar->setChecked( config->readEntry("ShowStatusBar", QVariant(false)).toBool() );
-  m_paShowPath->setChecked( config->readEntry("ShowPath", QVariant(false)).toBool() );
+  m_paShowStatusBar->setChecked( config->readEntry("ShowStatusBar", false) );
+  m_paShowPath->setChecked( config->readEntry("ShowPath", false) );
 
-  m_recentFiles->loadEntries(config, "Recent Files");
+  m_recentFiles->loadEntries(config.data(), "Recent Files");
 
-  m_view->document()->editor()->readConfig(config);
+  m_view->document()->editor()->readConfig(config.data());
 
   if( m_paShowStatusBar->isChecked() )
     statusBar()->show();
@@ -406,16 +420,16 @@ void KWrite::readConfig(KConfig *config)
     statusBar()->hide();
 }
 
-void KWrite::writeConfig(KConfig *config)
+void KWrite::writeConfig(KSharedConfigPtr config)
 {
   config->setGroup("General Options");
 
   config->writeEntry("ShowStatusBar",m_paShowStatusBar->isChecked());
   config->writeEntry("ShowPath",m_paShowPath->isChecked());
 
-  m_recentFiles->saveEntries(config, "Recent Files");
+  m_recentFiles->saveEntries(config.data(), "Recent Files");
 
-  m_view->document()->editor()->writeConfig(config);
+  m_view->document()->editor()->writeConfig(config.data());
 
   config->sync ();
 }
@@ -423,14 +437,12 @@ void KWrite::writeConfig(KConfig *config)
 //config file
 void KWrite::readConfig()
 {
-  KConfig *config = KGlobal::config();
-  readConfig(config);
+  readConfig(KGlobal::config());
 }
 
 void KWrite::writeConfig()
 {
-  KConfig *config = KGlobal::config();
-  writeConfig(config);
+  writeConfig(KGlobal::config());
 }
 
 // session management
@@ -439,21 +451,21 @@ void KWrite::restore(KConfig *config, int n)
   readPropertiesInternal(config, n);
 }
 
-void KWrite::readProperties(KConfig *config)
+void KWrite::readProperties(KSharedConfigPtr config)
 {
   readConfig(config);
 
   if (KTextEditor::SessionConfigInterface *iface = qobject_cast<KTextEditor::SessionConfigInterface *>(m_view))
-    iface->readSessionConfig(config);
+    iface->readSessionConfig(config.data());
 }
 
-void KWrite::saveProperties(KConfig *config)
+void KWrite::saveProperties(KSharedConfigPtr config)
 {
   writeConfig(config);
   config->writeEntry("DocumentNumber",docList.indexOf(m_view->document()) + 1);
 
   if (KTextEditor::SessionConfigInterface *iface = qobject_cast<KTextEditor::SessionConfigInterface *>(m_view))
-    iface->writeSessionConfig(config);
+    iface->writeSessionConfig(config.data());
 }
 
 void KWrite::saveGlobalProperties(KConfig *config) //save documents
@@ -529,11 +541,8 @@ void KWrite::restore()
 
 void KWrite::aboutEditor()
 {
-  KAboutApplication *ad = new KAboutApplication (m_view->document()->editor()->aboutData(), this);
-
-  ad->exec();
-
-  delete ad;
+  KAboutApplicationDialog dlg(m_view->document()->editor()->aboutData(), this);
+  dlg.exec();
 }
 
 void KWrite::updateStatus ()
@@ -640,18 +649,19 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
   KLocale::setMainCatalog("kate");         //lukas: set this to have the kwritepart translated using kate message catalog
 
   // here we go, construct the KWrite version
-  QString kWriteVersion  = QString ("%1.%2.%3").arg(KDE::versionMajor() + 1).arg(KDE::versionMinor()).arg(KDE::versionRelease());
+  QByteArray kWriteVersion  = QString ("%1.%2.%3").arg(KDE::versionMajor() + 1).arg(KDE::versionMinor()).arg(KDE::versionRelease()).toLatin1();
 
   KAboutData aboutData ( "kwrite",
-                         I18N_NOOP("KWrite"), 
-                         kWriteVersion.toLatin1(),
+                         I18N_NOOP("KWrite"),
+                         kWriteVersion,
                          I18N_NOOP( "KWrite - Text Editor" ), KAboutData::License_LGPL_V2,
-                         I18N_NOOP( "(c) 2000-2005 The Kate Authors" ), 0, "http://kate.kde.org" );
-
+                         I18N_NOOP( "(c) 2000-2005 The Kate Authors" ), 0, "http://www.kate-editor.org" );
+  aboutData.setOrganizationDomain("kde.org");
   aboutData.addAuthor ("Christoph Cullmann", I18N_NOOP("Maintainer"), "cullmann@kde.org", "http://www.babylon2k.de");
   aboutData.addAuthor ("Anders Lund", I18N_NOOP("Core Developer"), "anders@alweb.dk", "http://www.alweb.dk");
   aboutData.addAuthor ("Joseph Wenninger", I18N_NOOP("Core Developer"), "jowenn@kde.org","http://stud3.tuwien.ac.at/~e9925371");
   aboutData.addAuthor ("Hamish Rodda",I18N_NOOP("Core Developer"), "rodda@kde.org");
+  aboutData.addAuthor ("Dominik Haumann", I18N_NOOP("Developer & Highlight wizard"), "dhdev@gmx.de");
   aboutData.addAuthor ("Waldo Bastian", I18N_NOOP( "The cool buffersystem" ), "bastian@kde.org" );
   aboutData.addAuthor ("Charles Samuels", I18N_NOOP("The Editing Commands"), "charles@kde.org");
   aboutData.addAuthor ("Matt Newell", I18N_NOOP("Testing, ..."), "newellm@proaxis.com");
@@ -804,11 +814,11 @@ KWriteEditorChooser::KWriteEditorChooser(QWidget *):
     connect( this, SIGNAL( okClicked() ), SLOT( slotOk() ) );
 }
 
-KWriteEditorChooser::~KWriteEditorChooser() 
+KWriteEditorChooser::~KWriteEditorChooser()
 {
 }
 
-void KWriteEditorChooser::slotOk() 
+void KWriteEditorChooser::slotOk()
 {
     m_chooser->writeAppSetting();
 }
