@@ -26,42 +26,46 @@
 
 #include "katetooltipmenu.h"
 
-#include <kstandarddirs.h>
-#include <klocale.h>
+#include <KStandardDirs>
+#include <KLocale>
 #include <kdebug.h>
-#include <kdirwatch.h>
-#include <kinputdialog.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kcodecs.h>
-#include <kstdguiitem.h>
-#include <kpushbutton.h>
-#include <kmenu.h>
-#include <kactioncollection.h>
-#include <kio/netaccess.h>
+#include <KDirWatch>
+#include <KInputDialog>
+#include <KIconLoader>
+#include <KMessageBox>
+#include <KCodecs>
+#include <KStandardGuiItem>
+#include <KPushButton>
+#include <KMenu>
+#include <KActionCollection>
+#include <KIO/NetAccess>
 
 #include <QDir>
 #include <QLabel>
-#include <QLayout>
 #include <QCheckBox>
-#include <QDateTime>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QStringList>
 #include <QStyle>
+#include <QtAlgorithms>
 
 #include <unistd.h>
 #include <time.h>
 
+// used to sort the session list (qSort)
+bool caseInsensitiveLessThan(const KateSession::Ptr& a, const KateSession::Ptr& b)
+{
+  return a->sessionName().toLower() < b->sessionName().toLower();
+}
 
 KateSession::KateSession (KateSessionManager *manager, const QString &fileName)
-  : m_sessionFileRel (fileName)
-  , m_documents (0)
-  , m_manager (manager)
-  , m_readConfig (0)
-  , m_writeConfig (0)
+    : m_sessionFileRel (fileName)
+    , m_documents (0)
+    , m_manager (manager)
+    , m_readConfig (0)
+    , m_writeConfig (0)
 {
-  m_sessionName=QUrl::fromPercentEncoding(fileName.toLatin1());
+  m_sessionName = QUrl::fromPercentEncoding(fileName.toLatin1());
   m_sessionName.chop(12);//.katesession==12
   init ();
 }
@@ -107,7 +111,7 @@ bool KateSession::create (const QString &name, bool force)
   m_readConfig = 0;
 
   m_sessionName = name;
-  QString oldSessionFileRel=m_sessionFileRel;
+  QString oldSessionFileRel = m_sessionFileRel;
 #if 0
   // get a usable filename
   int s = time(0);
@@ -123,11 +127,12 @@ bool KateSession::create (const QString &name, bool force)
       break;
   }
 #else
-  m_sessionFileRel=QUrl::toPercentEncoding(name, "", ".")+QString(".katesession");
-  if (KGlobal::dirs()->exists(sessionFile ())) {
-  	m_sessionFileRel=oldSessionFileRel;
-	//Q_ASSERT(!KGlobal::dirs()->exists(sessionFile ()));
-	return false;
+  m_sessionFileRel = QUrl::toPercentEncoding(name, "", ".") + QString(".katesession");
+  if (KGlobal::dirs()->exists(sessionFile ()))
+  {
+    m_sessionFileRel = oldSessionFileRel;
+    //Q_ASSERT(!KGlobal::dirs()->exists(sessionFile ()));
+    return false;
   }
 #endif
 
@@ -150,17 +155,19 @@ bool KateSession::rename (const QString &name)
   if (name.isEmpty () || m_sessionFileRel.isEmpty() || m_sessionFileRel == m_manager->defaultSessionFileName())
     return false;
 
-  if (name==m_sessionName) return true;
-  QString oldRel=m_sessionFileRel;
-  QString oldSessionFile=sessionFile();
-  m_sessionFileRel=QUrl::toPercentEncoding(name,"",".")+QString(".katesession");
-  if (KGlobal::dirs()->exists(sessionFile ())) {
-    m_sessionFileRel=oldRel;
+  if (name == m_sessionName) return true;
+  QString oldRel = m_sessionFileRel;
+  QString oldSessionFile = sessionFile();
+  m_sessionFileRel = QUrl::toPercentEncoding(name, "", ".") + QString(".katesession");
+  if (KGlobal::dirs()->exists(sessionFile ()))
+  {
+    m_sessionFileRel = oldRel;
     return false;
   }
-  if (!KIO::NetAccess::file_move(KUrl(QString("file://")+oldSessionFile),KUrl(QString("file://")+sessionFile())) ) {
-  	m_sessionFileRel=oldRel;
-  	return false;
+  if (!KIO::NetAccess::file_move(KUrl(QString("file://") + oldSessionFile), KUrl(QString("file://") + sessionFile())) )
+  {
+    m_sessionFileRel = oldRel;
+    return false;
   }
   m_sessionName = name;
 
@@ -194,10 +201,10 @@ KConfig *KateSession::configWrite ()
 }
 
 KateSessionManager::KateSessionManager (QObject *parent)
- : QObject (parent)
- , m_sessionsDir (KStandardDirs::locateLocal( "data", "kate/sessions"))
- , m_activeSession (new KateSession (this, ""))
- , m_defaultSessionFileName(QUrl::toPercentEncoding(i18n("Default Session"),"",".")+QString(".katesession"))
+    : QObject (parent)
+    , m_sessionsDir (KStandardDirs::locateLocal( "data", "kate/sessions"))
+    , m_activeSession (new KateSession (this, ""))
+    , m_defaultSessionFileName(QUrl::toPercentEncoding(i18n("Default Session"), "", ".") + QString(".katesession"))
 {
   kDebug() << "LOCAL SESSION DIR: " << m_sessionsDir << endl;
 
@@ -206,8 +213,7 @@ KateSessionManager::KateSessionManager (QObject *parent)
 }
 
 KateSessionManager::~KateSessionManager()
-{
-}
+{}
 
 KateSessionManager *KateSessionManager::self()
 {
@@ -227,23 +233,26 @@ void KateSessionManager::updateSessionList ()
   QDir dir (m_sessionsDir, "*.katesession");
 
   bool foundDefault = false;
-  kDebug()<<"default session file name:"<<m_defaultSessionFileName<<endl;
-  for (unsigned int i=0; i < dir.count(); ++i)
+  kDebug() << "default session file name:" << m_defaultSessionFileName << endl;
+  for (unsigned int i = 0; i < dir.count(); ++i)
   {
     KateSession *session = new KateSession (this, dir[i]);
     m_sessionList.append (KateSession::Ptr(session));
 
-    kDebug () << "FOUND SESSION: " << session->sessionName() << " FILE: " << session->sessionFile() << " dir[i];"<<dir[i]<<endl;
+    kDebug () << "FOUND SESSION: " << session->sessionName() << " FILE: " << session->sessionFile() << " dir[i];" << dir[i] << endl;
     if (!foundDefault && (dir[i] == m_defaultSessionFileName))
       foundDefault = true;
   }
 
   // add default session, if not there
-  if (!foundDefault) {
+  if (!foundDefault)
+  {
     KSharedPtr<KateSession> s(new KateSession (this, ""));
     s->create(i18n("Default Session"));
     m_sessionList.append (s);
   }
+
+  qSort(m_sessionList.begin(), m_sessionList.end(), caseInsensitiveLessThan);
 }
 
 void KateSessionManager::activateSession (KateSession::Ptr session, bool closeLast, bool saveLast, bool loadNew)
@@ -264,9 +273,7 @@ void KateSessionManager::activateSession (KateSession::Ptr session, bool closeLa
 
   // really close last
   if (closeLast)
-  {
     KateDocManager::self()->closeAllDocuments ();
-  }
 
   // set the new session
   m_activeSession = session;
@@ -274,13 +281,11 @@ void KateSessionManager::activateSession (KateSession::Ptr session, bool closeLa
   if (loadNew)
   {
     // open the new session
-#ifdef __GNUC__
-#warning fixme later
-#endif
-	  //KTextEditor::Document::setOpenErrorDialogsActivated (false);
-
     KConfig *sc = activeSession()->configRead();
 
+    // load plugin config + plugins
+    KatePluginManager::self()->loadConfig (sc);
+
     if (sc)
       KateApp::self()->documentManager()->restoreDocumentList (sc);
 
@@ -290,10 +295,10 @@ void KateSessionManager::activateSession (KateSession::Ptr session, bool closeLa
       sc = new KSimpleConfig( sessionsDir() + "/default.katesession" );
 
     // window config
-    KConfig *c = KGlobal::config();
+    KSharedConfig::Ptr c = KGlobal::config();
     c->setGroup("General");
 
-    if (c->readEntry("Restore Window Configuration", QVariant(true)).toBool())
+    if (c->readEntry("Restore Window Configuration", true))
     {
       // a new, named session, read settings of the default session.
       if ( ! sc->hasGroup("Open MainWindows") )
@@ -302,7 +307,7 @@ void KateSessionManager::activateSession (KateSession::Ptr session, bool closeLa
       sc->setGroup ("Open MainWindows");
       int wCount = sc->readEntry("Count", 1);
 
-      for (int i=0; i < wCount; ++i)
+      for (int i = 0; i < wCount; ++i)
       {
         if (i >= KateApp::self()->mainWindows())
         {
@@ -315,21 +320,13 @@ void KateSessionManager::activateSession (KateSession::Ptr session, bool closeLa
         }
       }
 
+      // remove mainwindows we need no longer...
       if (wCount > 0)
       {
         while (wCount < KateApp::self()->mainWindows())
-        {
-          KateMainWindow *w = KateApp::self()->mainWindow(KateApp::self()->mainWindows()-1);
-          KateApp::self()->removeMainWindow (w);
-          delete w;
-        }
+          delete KateApp::self()->mainWindow(KateApp::self()->mainWindows() - 1);
       }
     }
-
-#ifdef __GNUC__
-#warning fixme later
-#endif
-	//KTextEditor::Document::setOpenErrorDialogsActivated (true);
   }
 }
 
@@ -340,7 +337,7 @@ KateSession::Ptr KateSessionManager::giveSession (const QString &name)
 
   updateSessionList();
 
-  for (int i=0; i < m_sessionList.count(); ++i)
+  for (int i = 0; i < m_sessionList.count(); ++i)
   {
     if (m_sessionList[i]->sessionName() == name)
       return m_sessionList[i];
@@ -356,7 +353,7 @@ bool KateSessionManager::saveActiveSession (bool tryAsk, bool rememberAsLast)
   if (tryAsk)
   {
     // app config
-    KConfig *c = KGlobal::config();
+    KSharedConfig::Ptr c = KGlobal::config();
     c->setGroup("General");
 
     QString sesExit (c->readEntry ("Session Exit", "save"));
@@ -374,8 +371,8 @@ bool KateSessionManager::saveActiveSession (bool tryAsk, bool rememberAsLast)
 
       bool dontAgain = false;
       int res = KMessageBox::createKMessageBox(dlg, QMessageBox::Question,
-                              i18n("Save current session?"), QStringList(),
-                              i18n("Do not ask again"), &dontAgain, KMessageBox::Notify);
+                i18n("Save current session?"), QStringList(),
+                i18n("Do not ask again"), &dontAgain, KMessageBox::Notify);
 
       // remember to not ask again with right setting
       if (dontAgain)
@@ -398,26 +395,27 @@ bool KateSessionManager::saveActiveSession (bool tryAsk, bool rememberAsLast)
   if (!sc)
     return false;
 
+  // save plugin configs and which plugins to load
+  KatePluginManager::self()->writeConfig(sc);
+
+  // save document configs + which documents to load
   KateDocManager::self()->saveDocumentList (sc);
 
   sc->setGroup ("Open MainWindows");
   sc->writeEntry ("Count", KateApp::self()->mainWindows ());
 
-  KatePluginManager::self()->storeGeneralConfig(sc);
-
   // save config for all windows around ;)
-  for (int i=0; i < KateApp::self()->mainWindows (); ++i )
+  for (int i = 0; i < KateApp::self()->mainWindows (); ++i )
   {
     sc->setGroup(QString ("MainWindow%1").arg(i));
     KateApp::self()->mainWindow(i)->saveProperties (sc);
-    KatePluginManager::self()->storeViewConfig(sc,i);
   }
 
   sc->sync();
 
   if (rememberAsLast)
   {
-    KConfig *c = KGlobal::config();
+    KSharedConfig::Ptr c = KGlobal::config();
     c->setGroup("General");
     c->writeEntry ("Last Session", activeSession()->sessionFileRelative());
     c->sync ();
@@ -431,7 +429,7 @@ bool KateSessionManager::chooseSession ()
   bool success = true;
 
   // app config
-  KConfig *c = KGlobal::config();
+  KSharedConfig::Ptr c = KGlobal::config();
   c->setGroup("General");
 
   // get last used session, default to default session
@@ -453,10 +451,10 @@ bool KateSessionManager::chooseSession ()
   }
 
   QList<KateSessionChooserTemplate> templates;
-  templates.append(KateSessionChooserTemplate("Profile 1 (default)","blah.desktop","<img source=\"/home/jowenn/development/kde/binary/share/icons/hicolor/32x32/actions/show_side_panel.png\"><b>Test 1</b> adfafsdfdsf<br>asdfasdfsdfsdf adsfad adf asdf df<br> adfasdf jasdlfjö"));
-  templates.append(KateSessionChooserTemplate("Profile 2","blah.desktop"," Test 2"));
-  templates.append(KateSessionChooserTemplate("Profile 3","blah.desktop"," Test 3"));
-  KateSessionChooser *chooser = new KateSessionChooser (0, lastSession,templates);
+  templates.append(KateSessionChooserTemplate("Profile 1 (default)", "blah.desktop", "<img source=\"/home/jowenn/development/kde/binary/share/icons/hicolor/32x32/actions/show_side_panel.png\"><b>Test 1</b> adfafsdfdsf<br>asdfasdfsdfsdf adsfad adf asdf df<br> adfasdf jasdlfjö"));
+  templates.append(KateSessionChooserTemplate("Profile 2", "blah.desktop", " Test 2"));
+  templates.append(KateSessionChooserTemplate("Profile 3", "blah.desktop", " Test 3"));
+  KateSessionChooser *chooser = new KateSessionChooser (0, lastSession, templates);
 
   bool retry = true;
   int res = 0;
@@ -467,28 +465,28 @@ bool KateSessionManager::chooseSession ()
     switch (res)
     {
       case KateSessionChooser::resultOpen:
-      {
-        KateSession::Ptr s = chooser->selectedSession ();
-
-        if (!s)
         {
-          KMessageBox::error (chooser, i18n("No session selected to open."), i18n ("No Session Selected"));
+          KateSession::Ptr s = chooser->selectedSession ();
+
+          if (!s)
+          {
+            KMessageBox::error (chooser, i18n("No session selected to open."), i18n ("No Session Selected"));
+            break;
+          }
+
+          activateSession (s, false, false);
+          retry = false;
           break;
         }
 
-        activateSession (s, false, false);
-        retry = false;
-        break;
-      }
-
-      // exit the app lateron
+        // exit the app lateron
       case KateSessionChooser::resultQuit:
         success = false;
         retry = false;
         break;
 
       default:
-        activateSession (KateSession::Ptr(new KateSession (this, "")), false, false)	;
+        activateSession (KateSession::Ptr(new KateSession (this, "")), false, false) ;
         retry = false;
         break;
     }
@@ -548,15 +546,15 @@ void KateSessionManager::sessionSave ()
 
 void KateSessionManager::sessionSaveAs ()
 {
-  bool loop=false;
+  bool loop = false;
   QString name;
   do
   {
     bool ok = false;
     name = KInputDialog::getText (
-	i18n("Specify New Name for Current Session"),
-	loop?i18n("There is already an existing session with your chosen name.\nPlease choose a different one\nSession name:"):i18n("Session name:")
-	, name, &ok);
+             i18n("Specify New Name for Current Session"),
+             loop ? i18n("There is already an existing session with your chosen name.\nPlease choose a different one\nSession name:") : i18n("Session name:")
+             , name, &ok);
 
     if (!ok)
       return;
@@ -566,8 +564,9 @@ void KateSessionManager::sessionSaveAs ()
       KMessageBox::sorry (0, i18n("To save a session, you must specify a name."), i18n ("Missing Session Name"));
       return;
     }
-    loop=true;
-  } while (!activeSession()->create (name, true));
+    loop = true;
+  }
+  while (!activeSession()->create (name, true));
   saveActiveSession ();
 }
 
@@ -587,8 +586,8 @@ class KateSessionChooserItem : public QTreeWidgetItem
 {
   public:
     KateSessionChooserItem (QTreeWidget *tw, KateSession::Ptr s)
-     : QTreeWidgetItem (tw, QStringList(s->sessionName()))
-     , session (s)
+        : QTreeWidgetItem (tw, QStringList(s->sessionName()))
+        , session (s)
     {
       QString docs;
       docs.setNum (s->documents());
@@ -598,25 +597,21 @@ class KateSessionChooserItem : public QTreeWidgetItem
     KateSession::Ptr session;
 };
 
-KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSession,const QList<KateSessionChooserTemplate> &templates)
- : KDialog (  parent )
-   ,m_templates(templates)
+KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSession, const QList<KateSessionChooserTemplate> &templates)
+    : KDialog (  parent )
+    , m_templates(templates)
 {
   setCaption( i18n ("Session Chooser") );
   setButtons( User1 | User2 | User3 );
-  setButtonGuiItem( User1, KStdGuiItem::quit() );
+  setButtonGuiItem( User1, KStandardGuiItem::quit() );
   setButtonGuiItem( User2, KGuiItem (i18n ("Open Session"), "fileopen") );
-  setButtonGuiItem( User3, KGuiItem ((templates.count()>1)?i18n ("New Session (hold down for template)"):i18n ("New Session"), "filenew") );
+  setButtonGuiItem( User3, KGuiItem ((templates.count() > 1) ? i18n ("New Session (hold down for template)") : i18n ("New Session"), "filenew") );
 
   setDefaultButton(KDialog::User2);
   setEscapeButton(KDialog::User1);
   //showButtonSeparator(true);
-  m_delayTimer=new QTimer(this);
-  m_delayTimer->setSingleShot(true);
-  int delay=style()->styleHint(QStyle::SH_ToolButton_PopupDelay, 0, this);
-  m_delayTimer->setInterval((delay<=0) ? 150:delay);
   QFrame *page = new QFrame (this);
-  QHBoxLayout *tll=new QHBoxLayout(page);
+  QHBoxLayout *tll = new QHBoxLayout(page);
   page->setMinimumSize (400, 200);
   setMainWidget(page);
 
@@ -639,13 +634,15 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
   header << i18n("Session Name");
   header << i18nc("The number of open documents", "Open Documents");
   m_sessions->setHeaderLabels(header);
+  m_sessions->setRootIsDecorated( false );
+  m_sessions->setItemsExpandable( false );
   m_sessions->setSelectionBehavior(QAbstractItemView::SelectItems);
   m_sessions->setSelectionMode (QAbstractItemView::SingleSelection);
 
   connect (m_sessions, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(selectionChanged(QTreeWidgetItem *, QTreeWidgetItem *)));
 
   KateSessionList &slist (KateSessionManager::self()->sessionList());
-  for (int i=0; i < slist.count(); ++i)
+  for (int i = 0; i < slist.count(); ++i)
   {
     KateSessionChooserItem *item = new KateSessionChooserItem (m_sessions, slist[i]);
 
@@ -658,35 +655,34 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
 
   setResult (resultNone);
 
-  connect(this,SIGNAL(user3Clicked()),m_delayTimer,SLOT(start()));
-  connect(m_delayTimer,SIGNAL(timeout()),this,SLOT(slotProfilePopup()));
   // trigger action update
   selectionChanged (NULL, NULL);
-  connect(this,SIGNAL(user1Clicked()),this,SLOT(slotUser1()));
-  connect(this,SIGNAL(user2Clicked()),this,SLOT(slotUser2()));
-  connect(this,SIGNAL(user3Clicked()),this,SLOT(slotUser3()));
+  connect(this, SIGNAL(user1Clicked()), this, SLOT(slotUser1()));
+  connect(this, SIGNAL(user2Clicked()), this, SLOT(slotUser2()));
+  connect(m_sessions, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotUser2()));
+  connect(this, SIGNAL(user3Clicked()), this, SLOT(slotUser3()));
+  enableButton (KDialog::User2, true);
+  m_popup = new KateToolTipMenu(this);
+  connect(m_popup, SIGNAL(aboutToShow()), this, SLOT(slotProfilePopup()));
+  connect(m_popup, SIGNAL(triggered(QAction *)), this, SLOT(slotTemplateAction(QAction*)));
+  setButtonMenu(KDialog::User3, m_popup, KDialog::DelayedPopup);
 }
 
 KateSessionChooser::~KateSessionChooser ()
-{
-}
+{}
 
-void KateSessionChooser::slotProfilePopup() {
- KateToolTipMenu popup;
- bool defaultA=true;
- foreach(const KateSessionChooserTemplate &t,m_templates) {
-   QAction *a=popup.addAction(t.displayName);
-   if (defaultA) popup.setDefaultAction(a);
-   defaultA=false;
-   a->setToolTip(t.toolTip);
-   a->setData(t.configFileName);
- }
- connect(&popup,SIGNAL(triggered(QAction *)),this,SLOT(slotTemplateAction(QAction*)));
-/* port me later (tokoe)
- actionButton(KDialog::User3)->setMenu(&popup);
- actionButton(KDialog::User3)->showMenu();
- actionButton(KDialog::User3)->setMenu(0);
-*/
+void KateSessionChooser::slotProfilePopup()
+{
+  m_popup->clear();
+  bool defaultA = true;
+  foreach(const KateSessionChooserTemplate &t, m_templates)
+  {
+    QAction *a = m_popup->addAction(t.displayName);
+    if (defaultA) m_popup->setDefaultAction(a);
+    defaultA = false;
+    a->setToolTip(t.toolTip);
+    a->setData(t.configFileName);
+  }
 }
 
 
@@ -712,13 +708,12 @@ void KateSessionChooser::slotUser2 ()
 
 void KateSessionChooser::slotUser3 ()
 {
-  m_delayTimer->stop();
-  if (m_templates.count()>0) m_selectedTemplate=m_templates[0].configFileName;
+  if (m_templates.count() > 0) m_selectedTemplate = m_templates[0].configFileName;
   done (resultNew);
 }
 void KateSessionChooser::slotTemplateAction(QAction* a)
 {
-  m_selectedTemplate=a->data().toString();
+  m_selectedTemplate = a->data().toString();
   done (resultNew);
 }
 
@@ -737,13 +732,13 @@ void KateSessionChooser::selectionChanged(QTreeWidgetItem *current, QTreeWidgetI
 //BEGIN OPEN DIALOG
 
 KateSessionOpenDialog::KateSessionOpenDialog (QWidget *parent)
- : KDialog (  parent )
+    : KDialog (  parent )
 
 {
   setCaption( i18n ("Open Session") );
   setButtons( User1 | User2 );
-  setButtonGuiItem( User1, KStdGuiItem::cancel() );
-  setButtonGuiItem( User2, KStdGuiItem::open() );
+  setButtonGuiItem( User1, KStandardGuiItem::cancel() );
+  setButtonGuiItem( User2, KStandardGuiItem::open() );
   setDefaultButton(KDialog::User2);
   //showButtonSeparator(true);
   /*QFrame *page = new QFrame (this);
@@ -755,31 +750,33 @@ KateSessionOpenDialog::KateSessionOpenDialog (QWidget *parent)
   QVBoxLayout *vb = new QVBoxLayout ();
   hb->addItem(vb);*/
   m_sessions = new QTreeWidget (this);
-  m_sessions->setMinimumSize(400,200);
+  m_sessions->setMinimumSize(400, 200);
   setMainWidget(m_sessions);
   //vb->addWidget(m_sessions);
   QStringList header;
   header << i18n("Session Name");
   header << i18nc("The number of open documents", "Open Documents");
   m_sessions->setHeaderLabels(header);
+  m_sessions->setRootIsDecorated( false );
+  m_sessions->setItemsExpandable( false );
   m_sessions->setSelectionBehavior(QAbstractItemView::SelectItems);
   m_sessions->setSelectionMode (QAbstractItemView::SingleSelection);
 
   KateSessionList &slist (KateSessionManager::self()->sessionList());
-  for (int i=0; i < slist.count(); ++i)
+  for (int i = 0; i < slist.count(); ++i)
   {
     new KateSessionChooserItem (m_sessions, slist[i]);
   }
 
   setResult (resultCancel);
-  connect(this,SIGNAL(user1Clicked()),this,SLOT(slotUser1()));
-  connect(this,SIGNAL(user2Clicked()),this,SLOT(slotUser2()));
+  connect(this, SIGNAL(user1Clicked()), this, SLOT(slotUser1()));
+  connect(this, SIGNAL(user2Clicked()), this, SLOT(slotUser2()));
+  connect(m_sessions, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotUser2()));
 
 }
 
 KateSessionOpenDialog::~KateSessionOpenDialog ()
-{
-}
+{}
 
 KateSession::Ptr KateSessionOpenDialog::selectedSession ()
 {
@@ -806,11 +803,11 @@ void KateSessionOpenDialog::slotUser2 ()
 //BEGIN MANAGE DIALOG
 
 KateSessionManageDialog::KateSessionManageDialog (QWidget *parent)
- : KDialog ( parent )
+    : KDialog ( parent )
 {
   setCaption( i18n ("Manage Sessions") );
   setButtons( User1 );
-  setButtonGuiItem( User1, KStdGuiItem::close() );
+  setButtonGuiItem( User1, KStandardGuiItem::close() );
 
   setDefaultButton(KDialog::User1);
   QFrame *page = new QFrame (this);
@@ -827,6 +824,7 @@ KateSessionManageDialog::KateSessionManageDialog (QWidget *parent)
   header << i18n("Session Name");
   header << i18nc("The number of open documents", "Open Documents");
   m_sessions->setHeaderLabels(header);
+  m_sessions->setRootIsDecorated( false );
   m_sessions->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_sessions->setSelectionMode (QAbstractItemView::SingleSelection);
 
@@ -842,7 +840,7 @@ KateSessionManageDialog::KateSessionManageDialog (QWidget *parent)
   connect (m_rename, SIGNAL(clicked()), this, SLOT(rename()));
   vb->addWidget (m_rename);
 
-  m_del = new KPushButton (KStdGuiItem::del (), page);
+  m_del = new KPushButton (KStandardGuiItem::del (), page);
   connect (m_del, SIGNAL(clicked()), this, SLOT(del()));
   vb->addWidget (m_del);
 
@@ -850,13 +848,12 @@ KateSessionManageDialog::KateSessionManageDialog (QWidget *parent)
 
   // trigger action update
   selectionChanged (NULL, NULL);
-  connect(this,SIGNAL(user1Clicked()),this,SLOT(slotUser1()));
+  connect(this, SIGNAL(user1Clicked()), this, SLOT(slotUser1()));
 
 }
 
 KateSessionManageDialog::~KateSessionManageDialog ()
-{
-}
+{}
 
 void KateSessionManageDialog::slotUser1 ()
 {
@@ -867,7 +864,7 @@ void KateSessionManageDialog::selectionChanged (QTreeWidgetItem *current, QTreeW
 {
   KateSessionChooserItem *item = (KateSessionChooserItem *) current;
 
-  QString defFileName=KateSessionManager::self()->defaultSessionFileName();
+  QString defFileName = KateSessionManager::self()->defaultSessionFileName();
   m_rename->setEnabled (item && item->session->sessionFileRelative() != defFileName);
   m_del->setEnabled (item && item->session->sessionFileRelative() != defFileName);
 }
@@ -894,7 +891,7 @@ void KateSessionManageDialog::rename ()
   if (item->session->rename (name))
     updateSessionList ();
   else
-    KMessageBox::sorry(this,i18n("The session could not be renamed to \"%1\", there already exists another session with the same name", name),i18n("Session Renaming"));
+    KMessageBox::sorry(this, i18n("The session could not be renamed to \"%1\", there already exists another session with the same name", name), i18n("Session Renaming"));
 
 }
 
@@ -915,7 +912,7 @@ void KateSessionManageDialog::updateSessionList ()
   m_sessions->clear ();
 
   KateSessionList &slist (KateSessionManager::self()->sessionList());
-  for (int i=0; i < slist.count(); ++i)
+  for (int i = 0; i < slist.count(); ++i)
   {
     new KateSessionChooserItem (m_sessions, slist[i]);
   }
@@ -924,10 +921,10 @@ void KateSessionManageDialog::updateSessionList ()
 //END MANAGE DIALOG
 
 
-KateSessionsAction::KateSessionsAction(const QString& text, KActionCollection* parent, const char* name )
-  : KActionMenu(text, parent, name)
+KateSessionsAction::KateSessionsAction(const QString& text, QObject* parent)
+    : KActionMenu(text, parent)
 {
-  connect(menu(),SIGNAL(aboutToShow()),this,SLOT(slotAboutToShow()));
+  connect(menu(), SIGNAL(aboutToShow()), this, SLOT(slotAboutToShow()));
 
   sessionsGroup = new QActionGroup( menu() );
   connect(sessionsGroup, SIGNAL( triggered(QAction *) ), this, SLOT( openSession(QAction *)));
@@ -938,11 +935,11 @@ void KateSessionsAction::slotAboutToShow()
   qDeleteAll( sessionsGroup->actions() );
 
   KateSessionList &slist (KateSessionManager::self()->sessionList());
-  for (int i=0; i < slist.count(); ++i)
+  for (int i = 0; i < slist.count(); ++i)
   {
-      QAction *action = new QAction( slist[i]->sessionName(), sessionsGroup );
-      action->setData(QVariant(i));
-      menu()->addAction (action);
+    QAction *action = new QAction( slist[i]->sessionName(), sessionsGroup );
+    action->setData(QVariant(i));
+    menu()->addAction (action);
   }
 }
 
@@ -950,7 +947,7 @@ void KateSessionsAction::openSession (QAction *action)
 {
   KateSessionList &slist (KateSessionManager::self()->sessionList());
 
-	int i = action->data().toInt();
+  int i = action->data().toInt();
   if (i >= slist.count())
     return;
 
