@@ -2,16 +2,16 @@
    Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
    Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
-
+ 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
-
+ 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
-
+ 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
@@ -71,116 +71,122 @@
 #include <kurlcompletion.h>
 #include <kate/interfaces/mainwindow.h>
 #include <ktexteditor/view.h>
+#include <kconfiggroup.h>
 //END Includes
 
 
-K_EXPORT_COMPONENT_FACTORY( katefilebrowserplugin, KGenericFactory<Kate::Private::Plugin::KateFileSelectorPlugin>( "katefilebrowserplugin" ) )
-
-using namespace Kate::Private::Plugin;
+K_EXPORT_COMPONENT_FACTORY( katefilebrowserplugin, KGenericFactory<KateFileSelectorPlugin>( "katefilebrowserplugin" ) )
 
 KateFileSelectorPlugin::KateFileSelectorPlugin( QObject* parent, const QStringList&):
-  Kate::Plugin ( (Kate::Application*)parent ) {
+    Kate::Plugin ( (Kate::Application*)parent )
+{}
+
+Kate::PluginView *KateFileSelectorPlugin::createView (Kate::MainWindow *mainWindow)
+{
+  return new KateFileSelectorPluginView (mainWindow);
 }
 
-void KateFileSelectorPlugin::addView(Kate::MainWindow *win) {
-    QWidget *toolview=win->createToolView ("kate_private_plugin_katefileselectorplugin", MainWindow::Left, SmallIcon("fileopen"), i18n("Filesystem Browser"));
-    m_views.append(new KateFileSelector(win,toolview));
+KateFileSelectorPluginView::KateFileSelectorPluginView (Kate::MainWindow *mainWindow)
+    : Kate::PluginView (mainWindow)
+{
+  // init console
+  QWidget *toolview = mainWindow->createToolView ("kate_private_plugin_katefileselectorplugin", Kate::MainWindow::Left, SmallIcon("fileopen"), i18n("Filesystem Browser"));
+  m_fileSelector = new KateFileSelector(mainWindow, toolview);
 }
 
-void KateFileSelectorPlugin::removeView(Kate::MainWindow *win) {
-  for(QLinkedList<KateFileSelector*>::iterator it=m_views.begin();it!=m_views.end();++it) {
-    if ((*it)->mainWindow()==win) {
-      QWidget *pw=(*it)->parentWidget();
-      delete *it;
-      delete pw;
-      m_views.erase(it);
-      break;
-    }
-  }
+KateFileSelectorPluginView::~KateFileSelectorPluginView ()
+{
+  // cleanup, kill toolview + console
+  QWidget *toolview = m_fileSelector->parentWidget();
+  delete m_fileSelector;
+  delete toolview;
 }
 
-void KateFileSelectorPlugin::loadViewConfig(KConfig* config,Kate::MainWindow *win,const QString& group) {
-  for(QLinkedList<KateFileSelector*>::iterator it=m_views.begin();it!=m_views.end();++it) {
-    if ((*it)->mainWindow()==win) {
-      (*it)->readConfig(config,group);
-      break;
-    }
-  }
+void KateFileSelectorPluginView::readSessionConfig(KConfig* config, const QString& group)
+{
+  m_fileSelector->readConfig(config, group);
 }
 
-
 uint KateFileSelectorPlugin::configPages() const
 {
-  return 1;
+  return 0;
 }
 
 Kate::PluginConfigPage *KateFileSelectorPlugin::configPage (uint number, QWidget *parent, const char *name)
 {
-  if (number!=0) return 0;
-  return new KFSConfigPage(parent,name,*(m_views.begin()));
+  if (number != 0) return 0;
+  //return new KFSConfigPage(parent,name,*(m_views.begin()));
+  return 0;
 }
 
-QString KateFileSelectorPlugin::configPageName (uint number) const {
-  if (number!=0) return QString();
-  kDebug()<<"Returning a config page name"<<endl;
+QString KateFileSelectorPlugin::configPageName (uint number) const
+{
+  if (number != 0) return QString();
+  kDebug() << "Returning a config page name" << endl;
   return i18n("File Selector");
 }
 
-QString KateFileSelectorPlugin::configPageFullName (uint number) const {
-  if (number!=0) return QString();
+QString KateFileSelectorPlugin::configPageFullName (uint number) const
+{
+  if (number != 0) return QString();
   return i18n("File Selector Settings");
 }
 
-KIcon KateFileSelectorPlugin::configPageIcon (uint number) const {
-  if (number!=0) return KIcon();
+KIcon KateFileSelectorPlugin::configPageIcon (uint number) const
+{
+  if (number != 0) return KIcon();
   return KIcon("fileopen");
 }
 
 //BEGIN Toolbar
- // from kfiledialog.cpp - avoid qt warning in STDERR (~/.xsessionerrors)
-static void silenceQToolBar(QtMsgType, const char *){}
+// from kfiledialog.cpp - avoid qt warning in STDERR (~/.xsessionerrors)
+static void silenceQToolBar(QtMsgType, const char *)
+{}
 
 // helper classes to be able to have a toolbar without move handle
 KateFileSelectorToolBar::KateFileSelectorToolBar(QWidget *parent)
-  : KToolBar( parent, "Kate FileSelector Toolbar", true )
+    : KToolBar( parent, "Kate FileSelector Toolbar", true )
 {
-	setMinimumWidth(10);
+  setMinimumWidth(10);
 }
 
-KateFileSelectorToolBar::~KateFileSelectorToolBar(){}
+KateFileSelectorToolBar::~KateFileSelectorToolBar()
+{}
 
 KateFileSelectorToolBarParent::KateFileSelectorToolBarParent(QWidget *parent)
-	:QFrame(parent),m_tb(0){}
-KateFileSelectorToolBarParent::~KateFileSelectorToolBarParent(){}
+    : QFrame(parent), m_tb(0)
+{}
+KateFileSelectorToolBarParent::~KateFileSelectorToolBarParent()
+{}
 void KateFileSelectorToolBarParent::setToolBar(KateFileSelectorToolBar *tb)
 {
-	m_tb=tb;
+  m_tb = tb;
 }
 
 void KateFileSelectorToolBarParent::resizeEvent ( QResizeEvent * )
 {
-	if (m_tb)
-	{
-		setMinimumHeight(m_tb->sizeHint().height());
-		m_tb->resize(width(),height());
-	}
+  if (m_tb)
+  {
+    setMinimumHeight(m_tb->sizeHint().height());
+    m_tb->resize(width(), height());
+  }
 }
 //END
 
 //BEGIN Constructor/destructor
 
-Kate::Private::Plugin::KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
-                                    QWidget * parent, const char * name )
+::KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
+                                      QWidget * parent, const char * name )
     : KVBox (parent),
-      mainwin(mainWindow),
-      autoSyncEvents(0)
+    mainwin(mainWindow),
+    autoSyncEvents(0)
 {
   setObjectName(name);
   mActionCollection = new KActionCollection( this );
 
   QtMsgHandler oldHandler = qInstallMsgHandler( silenceQToolBar );
 
-  KateFileSelectorToolBarParent *tbp=new KateFileSelectorToolBarParent(this);
+  KateFileSelectorToolBarParent *tbp = new KateFileSelectorToolBarParent(this);
   toolbar = new KateFileSelectorToolBar(tbp);
   tbp->setToolBar(toolbar);
   toolbar->setMovable(false);
@@ -203,23 +209,23 @@ Kate::Private::Plugin::KateFileSelector::KateFileSelector( Kate::MainWindow *mai
 
   KActionCollection *coll = dir->actionCollection();
   // some shortcuts of diroperator that clashes with Kate
-  coll->action( "delete" )->setShortcut( KShortcut( Qt::ALT + Qt::Key_Delete ) );
-  coll->action( "reload" )->setShortcut( KShortcut( Qt::ALT + Qt::Key_F5 ) );
-  coll->action( "back" )->setShortcut( KShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Left ) );
-  coll->action( "forward" )->setShortcut( KShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Right ) );
+  coll->action( "delete" )->setShortcut( Qt::ALT + Qt::Key_Delete );
+  coll->action( "reload" )->setShortcut( Qt::ALT + Qt::Key_F5 );
+  coll->action( "back" )->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Left );
+  coll->action( "forward" )->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Right );
   // some consistency - reset up for dir too
-  coll->action( "up" )->setShortcut( KShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Up ) );
-  coll->action( "home" )->setShortcut( KShortcut( Qt::CTRL + Qt::ALT + Qt::Key_Home ) );
+  coll->action( "up" )->setShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_Up );
+  coll->action( "home" )->setShortcut( Qt::CTRL + Qt::ALT + Qt::Key_Home );
 
   // bookmarks action!
-  KActionMenu *acmBookmarks = new KActionMenu( KIcon("bookmark"), i18n("Bookmarks"),
-        mActionCollection, "bookmarks" );
+  KActionMenu *acmBookmarks = new KActionMenu( KIcon("bookmark"), i18n("Bookmarks"), this );
+  mActionCollection->addAction( "bookmarks", acmBookmarks );
   acmBookmarks->setDelayed( false );
   bookmarkHandler = new KBookmarkHandler( this, acmBookmarks->menu() );
   KHBox* filterBox = new KHBox(this);
 
   btnFilter = new QToolButton( filterBox );
-  btnFilter->setIcon( SmallIconSet("filter" ) );
+  btnFilter->setIcon( KIcon("filter" ) );
   btnFilter->setCheckable( true );
   filter = new KHistoryCombo( true, filterBox);
   filter->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ));
@@ -227,61 +233,62 @@ Kate::Private::Plugin::KateFileSelector::KateFileSelector( Kate::MainWindow *mai
   connect( btnFilter, SIGNAL( clicked() ), this, SLOT( btnFilterClick() ) );
 
   connect( filter, SIGNAL( activated(const QString&) ),
-                   SLOT( slotFilterChange(const QString&) ) );
+           SLOT( slotFilterChange(const QString&) ) );
   connect( filter, SIGNAL( returnPressed(const QString&) ),
            filter, SLOT( addToHistory(const QString&) ) );
 
   // kaction for the dir sync method
-  acSyncDir = new KAction( KIcon("curfiledir"), i18n("Current Document Folder"), mActionCollection, "sync_dir" );
+  acSyncDir = mActionCollection->addAction( "sync_dir" );
+  acSyncDir->setIcon( KIcon("curfiledir") );
+  acSyncDir->setText( i18n("Current Document Folder") );
   connect( acSyncDir, SIGNAL( triggered() ), this, SLOT( setActiveDocumentDir() ) );
   toolbar->setToolButtonStyle( Qt::ToolButtonIconOnly );
   toolbar->setIconDimensions( 16 );
   toolbar->setContextMenuEnabled( false );
 
   connect( cmbPath, SIGNAL( urlActivated( const KUrl&  )),
-             this, SLOT( cmbPathActivated( const KUrl& ) ));
+           this, SLOT( cmbPathActivated( const KUrl& ) ));
   connect( cmbPath, SIGNAL( returnPressed( const QString&  )),
-             this, SLOT( cmbPathReturnPressed( const QString& ) ));
+           this, SLOT( cmbPathReturnPressed( const QString& ) ));
   connect(dir, SIGNAL(urlEntered(const KUrl&)),
-             this, SLOT(dirUrlEntered(const KUrl&)) );
+          this, SLOT(dirUrlEntered(const KUrl&)) );
 
   connect(dir, SIGNAL(finishedLoading()),
-             this, SLOT(dirFinishedLoading()) );
+          this, SLOT(dirFinishedLoading()) );
 
   // enable dir sync button if current doc has a valid URL
   connect ( mainwin, SIGNAL( viewChanged() ),
-              this, SLOT( kateViewChanged() ) );
+            this, SLOT( kateViewChanged() ) );
 
   // Connect the bookmark handler
-  connect( bookmarkHandler, SIGNAL( openURL( const QString& )),
+  connect( bookmarkHandler, SIGNAL( openUrl( const QString& )),
            this, SLOT( setDir( const QString& ) ) );
 
   waitingUrl.clear();
 
   // whatsthis help
   cmbPath->setWhatsThis(       i18n("<p>Here you can enter a path for a folder to display."
-            "<p>To go to a folder previously entered, press the arrow on "
-            "the right and choose one. <p>The entry has folder "
-            "completion. Right-click to choose how completion should behave.") );
+                                    "<p>To go to a folder previously entered, press the arrow on "
+                                    "the right and choose one. <p>The entry has folder "
+                                    "completion. Right-click to choose how completion should behave.") );
   filter->setWhatsThis(        i18n("<p>Here you can enter a name filter to limit which files are displayed."
-             "<p>To clear the filter, toggle off the filter button to the left."
-             "<p>To reapply the last filter used, toggle on the filter button." ) );
+                                    "<p>To clear the filter, toggle off the filter button to the left."
+                                    "<p>To reapply the last filter used, toggle on the filter button." ) );
   btnFilter->setWhatsThis(        i18n("<p>This button clears the name filter when toggled off, or "
-             "reapplies the last filter used when toggled on.") );
+                                       "reapplies the last filter used when toggled on.") );
 
-  connect(dir,SIGNAL(fileSelected(const KFileItem*)),this,SLOT(fileSelected(const KFileItem*)));
+  connect(dir, SIGNAL(fileSelected(const KFileItem*)), this, SLOT(fileSelected(const KFileItem*)));
 }
 
-Kate::Private::Plugin::KateFileSelector::~KateFileSelector()
-{
-}
+::KateFileSelector::~KateFileSelector()
+{}
 //END Constroctor/Destrctor
 
 //BEGIN Public Methods
 
-void Kate::Private::Plugin::KateFileSelector::readConfig(KConfig *config, const QString & name)
+void ::KateFileSelector::readConfig(KConfig *config, const QString & name)
 {
-  kDebug()<<"===================================================================Kate::Private::Plugin::KateFileSelector::readConfig"<<endl;
+  kDebug() << "===================================================================::KateFileSelector::readConfig" << endl;
 #ifdef __GNUC__
 #warning THIS WILL CRASH - setViewConfig keeps the pointer to the KConfigGroup! That API needs to be revised.
 #endif
@@ -297,11 +304,13 @@ void Kate::Private::Plugin::KateFileSelector::readConfig(KConfig *config, const
   setupToolbar( config );
 
   cmbPath->setMaxItems( config->readEntry( "pathcombo history len", 9 ) );
-  cmbPath->setURLs( config->readPathListEntry( "dir history" ) );
+  cmbPath->setUrls( config->readPathListEntry( "dir history" ) );
   // if we restore history
-  if ( config->readEntry( "restore location", QVariant(true )).toBool() || qApp->isSessionRestored() ) {
+  if ( config->readEntry( "restore location", true) || qApp->isSessionRestored() )
+  {
     QString loc( config->readPathEntry( "location" ) );
-    if ( ! loc.isEmpty() ) {
+    if ( ! loc.isEmpty() )
+    {
 //       waitingDir = loc;
 //       QTimer::singleShot(0, this, SLOT(initialDirChangeHack()));
       setDir( loc );
@@ -311,7 +320,7 @@ void Kate::Private::Plugin::KateFileSelector::readConfig(KConfig *config, const
   // else is automatic, as cmpPath->setURL is called when a location is entered.
 
   filter->setMaxCount( config->readEntry( "filter history len", 9 ) );
-  filter->setHistoryItems( config->readEntry("filter history",QStringList()), true );
+  filter->setHistoryItems( config->readEntry("filter history", QStringList()), true );
   lastFilter = config->readEntry( "last filter" );
   QString flt("");
   if ( config->readEntry( "restore last filter", true ) || qApp->isSessionRestored() )
@@ -322,23 +331,25 @@ void Kate::Private::Plugin::KateFileSelector::readConfig(KConfig *config, const
   autoSyncEvents = config->readEntry( "AutoSyncEvents", 0 );
 }
 
-void Kate::Private::Plugin::KateFileSelector::initialDirChangeHack()
+void ::KateFileSelector::initialDirChangeHack()
 {
   setDir( waitingDir );
 }
 
-void Kate::Private::Plugin::KateFileSelector::setupToolbar( KConfig *config )
+void ::KateFileSelector::setupToolbar( KConfig *config )
 {
   toolbar->clear();
-  QStringList tbactions = config->readEntry( "toolbar actions", QStringList(),',' );
-  if ( tbactions.isEmpty() ) {
+  QStringList tbactions = config->readEntry( "toolbar actions", QStringList(), ',' );
+  if ( tbactions.isEmpty() )
+  {
     // reasonable collection for default toolbar
     tbactions << "up" << "back" << "forward" << "home" <<
-                "short view" << "detailed view" <<
-                "bookmarks" << "sync_dir";
+    "short view" << "detailed view" <<
+    "bookmarks" << "sync_dir";
   }
-  KAction *ac;
-  for ( QStringList::Iterator it=tbactions.begin(); it != tbactions.end(); ++it ) {
+  QAction *ac;
+  for ( QStringList::Iterator it = tbactions.begin(); it != tbactions.end(); ++it )
+  {
     if ( *it == "bookmarks" || *it == "sync_dir" )
       ac = mActionCollection->action( (*it).toLatin1().constData() );
     else
@@ -348,15 +359,16 @@ void Kate::Private::Plugin::KateFileSelector::setupToolbar( KConfig *config )
   }
 }
 
-void Kate::Private::Plugin::KateFileSelector::writeConfig(KConfig *config, const QString & name)
+void ::KateFileSelector::writeConfig(KConfig *config, const QString & name)
 {
-  KConfigGroup confGroup(config,name + ":dir");
+  KConfigGroup confGroup(config, name + ":dir");
   dir->writeConfig(&confGroup);
 
   config->setGroup( name );
   config->writeEntry( "pathcombo history len", cmbPath->maxItems() );
   QStringList l;
-  for (int i = 0; i < cmbPath->count(); i++) {
+  for (int i = 0; i < cmbPath->count(); i++)
+  {
     l.append( cmbPath->itemText( i ) );
   }
   config->writePathEntry( "dir history", l );
@@ -369,7 +381,7 @@ void Kate::Private::Plugin::KateFileSelector::writeConfig(KConfig *config, const
   config->writeEntry( "AutoSyncEvents", autoSyncEvents );
 }
 
-void Kate::Private::Plugin::KateFileSelector::setView(KFile::FileView view)
+void ::KateFileSelector::setView(KFile::FileView view)
 {
   dir->setView(view);
   dir->view()->setSelectionMode(KFile::Multi);
@@ -379,17 +391,19 @@ void Kate::Private::Plugin::KateFileSelector::setView(KFile::FileView view)
 
 //BEGIN Public Slots
 
-void Kate::Private::Plugin::KateFileSelector::slotFilterChange( const QString & nf )
+void ::KateFileSelector::slotFilterChange( const QString & nf )
 {
   QString f = nf.trimmed();
   bool empty = f.isEmpty() || f == "*";
-  if ( empty ) {
+  if ( empty )
+  {
     dir->clearFilter();
     filter->lineEdit()->setText( QString() );
     btnFilter->setToolTip(
-        i18n("Apply last filter (\"%1\")", lastFilter )) ;
+      i18n("Apply last filter (\"%1\")", lastFilter )) ;
   }
-  else {
+  else
+  {
     dir->setNameFilter( f );
     lastFilter = f;
     btnFilter->setToolTip( i18n("Clear filter") );
@@ -410,7 +424,7 @@ bool kateFileSelectorIsReadable ( const KUrl& url )
   return dir.exists ();
 }
 
-void Kate::Private::Plugin::KateFileSelector::setDir( KUrl u )
+void ::KateFileSelector::setDir( KUrl u )
 {
   KUrl newurl;
 
@@ -426,18 +440,18 @@ void Kate::Private::Plugin::KateFileSelector::setDir( KUrl u )
     newurl.cd(QString::fromLatin1(".."));
 
   if ( !kateFileSelectorIsReadable (newurl) )
-     newurl.setPath( QDir::homePath() );
+    newurl.setPath( QDir::homePath() );
 
-  dir->setURL(newurl, true);
+  dir->setUrl(newurl, true);
 }
 
 //END Public Slots
 
 //BEGIN Private Slots
 
-void Kate::Private::Plugin::KateFileSelector::fileSelected(const KFileItem * /*file*/)
+void ::KateFileSelector::fileSelected(const KFileItem * /*file*/)
 {
-  const KFileItemList *list=dir->selectedItems();
+  const KFileItemList *list = dir->selectedItems();
 
   KFileItem *tmp;
   KFileItemList::const_iterator it = list->begin();
@@ -445,20 +459,20 @@ void Kate::Private::Plugin::KateFileSelector::fileSelected(const KFileItem * /*f
   for ( ; it != end; ++it )
   {
     tmp = (*it);
-	mainwin->openURL(tmp->url());
-    dir->view()->setSelected(tmp,false);
+    mainwin->openUrl(tmp->url());
+    dir->view()->setSelected(tmp, false);
   }
 }
 
 
 
 
-void Kate::Private::Plugin::KateFileSelector::cmbPathActivated( const KUrl& u )
+void ::KateFileSelector::cmbPathActivated( const KUrl& u )
 {
-   cmbPathReturnPressed( u.url() );
+  cmbPathReturnPressed( u.url() );
 }
 
-void Kate::Private::Plugin::KateFileSelector::cmbPathReturnPressed( const QString& u )
+void ::KateFileSelector::cmbPathReturnPressed( const QString& u )
 {
   KUrl typedURL( u );
   if ( typedURL.hasPass() )
@@ -467,19 +481,18 @@ void Kate::Private::Plugin::KateFileSelector::cmbPathReturnPressed( const QStrin
   QStringList urls = cmbPath->urls();
   urls.removeAll( typedURL.url() );
   urls.prepend( typedURL.url() );
-  cmbPath->setURLs( urls, KUrlComboBox::RemoveBottom );
+  cmbPath->setUrls( urls, KUrlComboBox::RemoveBottom );
   dir->setFocus();
-  dir->setURL( KUrl(u), true );
+  dir->setUrl( KUrl(u), true );
 }
 
-void Kate::Private::Plugin::KateFileSelector::dirUrlEntered( const KUrl& u )
+void ::KateFileSelector::dirUrlEntered( const KUrl& u )
 {
-  cmbPath->setURL( u );
+  cmbPath->setUrl( u );
 }
 
-void Kate::Private::Plugin::KateFileSelector::dirFinishedLoading()
-{
-}
+void ::KateFileSelector::dirFinishedLoading()
+{}
 
 
 /*
@@ -489,19 +502,21 @@ void Kate::Private::Plugin::KateFileSelector::dirFinishedLoading()
    If on:
    Set last filter.
 */
-void Kate::Private::Plugin::KateFileSelector::btnFilterClick()
+void ::KateFileSelector::btnFilterClick()
 {
-  if ( !btnFilter->isChecked() ) {
+  if ( !btnFilter->isChecked() )
+  {
     slotFilterChange( QString() );
   }
-  else {
+  else
+  {
     filter->lineEdit()->setText( lastFilter );
     slotFilterChange( lastFilter );
   }
 }
 
 //FIXME crash on shutdown
-void Kate::Private::Plugin::KateFileSelector::setActiveDocumentDir()
+void ::KateFileSelector::setActiveDocumentDir()
 {
 //   kDebug(13001)<<"KateFileSelector::setActiveDocumentDir()"<<endl;
   KUrl u = activeDocumentUrl();
@@ -511,18 +526,20 @@ void Kate::Private::Plugin::KateFileSelector::setActiveDocumentDir()
 //   kDebug(13001)<<"... setActiveDocumentDir() DONE!"<<endl;
 }
 
-void Kate::Private::Plugin::KateFileSelector::kateViewChanged()
+void ::KateFileSelector::kateViewChanged()
 {
   if ( autoSyncEvents & DocumentChanged )
   {
 //     kDebug(13001)<<"KateFileSelector::do a sync ()"<<endl;
     // if visible, sync
-    if ( isVisible() ) {
+    if ( isVisible() )
+    {
       setActiveDocumentDir();
       waitingUrl.clear();
     }
     // else set waiting url
-    else {
+    else
+    {
       KUrl u = activeDocumentUrl();
       if (!u.isEmpty())
         waitingUrl = u.directory();
@@ -538,34 +555,37 @@ void Kate::Private::Plugin::KateFileSelector::kateViewChanged()
 
 //BEGIN Protected
 
-KUrl Kate::Private::Plugin::KateFileSelector::activeDocumentUrl() {
+KUrl KateFileSelector::activeDocumentUrl()
+{
   KTextEditor::View *v = mainwin->activeView();
   if ( v )
     return v->document()->url();
   return KUrl();
 }
 
-void Kate::Private::Plugin::KateFileSelector::focusInEvent( QFocusEvent * )
+void KateFileSelector::focusInEvent( QFocusEvent * )
 {
-   dir->setFocus();
+  dir->setFocus();
 }
 
-void Kate::Private::Plugin::KateFileSelector::showEvent( QShowEvent * )
+void KateFileSelector::showEvent( QShowEvent * )
 {
-    // sync if we should
-    if ( autoSyncEvents & GotVisible ) {
+  // sync if we should
+  if ( autoSyncEvents & GotVisible )
+  {
 //     kDebug(13001)<<"syncing fs on show"<<endl;
-      setActiveDocumentDir();
-      waitingUrl.clear();
-    }
-    // else, if we have a waiting URL set it
-    else if ( ! waitingUrl.isEmpty() ) {
-      setDir( waitingUrl );
-      waitingUrl.clear();
-   }
+    setActiveDocumentDir();
+    waitingUrl.clear();
+  }
+  // else, if we have a waiting URL set it
+  else if ( ! waitingUrl.isEmpty() )
+  {
+    setDir( waitingUrl );
+    waitingUrl.clear();
+  }
 }
 
-bool Kate::Private::Plugin::KateFileSelector::eventFilter( QObject* o, QEvent *e )
+bool KateFileSelector::eventFilter( QObject* o, QEvent *e )
 {
   /*
       This is rather unfortunate, but:
@@ -574,16 +594,16 @@ bool Kate::Private::Plugin::KateFileSelector::eventFilter( QObject* o, QEvent *e
       satisfying result, something is wrong with the handling of the sizehint.
       And the popup is rather useless, if the paths are only partly visible.
   */
-/* FIXME Q3ListBox *lb = cmbPath->listBox();
-  if ( o == lb && e->type() == QEvent::Show ) {
-    int add = lb->height() < lb->contentsHeight() ? lb->verticalScrollBar()->width() : 0;
-    int w = qMin( mainwin->width(), lb->contentsWidth() + add );
-    lb->resize( w, lb->height() );
-    // TODO - move the listbox to a suitable place if necessary
-    // TODO - decide if it is worth caching the size while untill the contents
-    //        are changed.
-  }
-  */// TODO - same thing for the completion popup?
+  /* FIXME QListWidget *lb = cmbPath->listBox();
+    if ( o == lb && e->type() == QEvent::Show ) {
+      int add = lb->height() < lb->contentsHeight() ? lb->verticalScrollBar()->width() : 0;
+      int w = qMin( mainwin->width(), lb->contentsWidth() + add );
+      lb->resize( w, lb->height() );
+      // TODO - move the listbox to a suitable place if necessary
+      // TODO - decide if it is worth caching the size while untill the contents
+      //        are changed.
+    }
+    */// TODO - same thing for the completion popup?
   return QWidget::eventFilter( o, e );
 }
 
@@ -594,15 +614,20 @@ bool Kate::Private::Plugin::KateFileSelector::eventFilter( QObject* o, QEvent *e
    QListboxItem that can store and return a string,
    used for the toolbar action selector.
 */
-class ActionLBItem : public QListWidgetItem {
+class ActionLBItem : public QListWidgetItem
+{
   public:
-  ActionLBItem( QListWidget *lb=0,
-                const QIcon &pm = QIcon(),
-                const QString &text=QString::null,
-                const QString &str=QString::null ) :
-    QListWidgetItem(pm, text,lb,0 ),
-    _str(str) {};
-  QString idstring() { return _str; };
+    ActionLBItem( QListWidget *lb = 0,
+                  const QIcon &pm = QIcon(),
+                  const QString &text = QString::null,
+                  const QString &str = QString::null ) :
+        QListWidgetItem(pm, text, lb, 0 ),
+        _str(str)
+    {};
+    QString idstring()
+    {
+      return _str;
+    };
   private:
     QString _str;
 };
@@ -613,7 +638,7 @@ class ActionLBItem : public QListWidgetItem {
 // KFSConfigPage implementation
 ////////////////////////////////////////////////////////////////////////////////
 KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *kfs )
-  : Kate::PluginConfigPage( parent ),
+    : Kate::PluginConfigPage( parent ),
     fileSelector( kfs ),
     m_changed( false )
 {
@@ -678,35 +703,35 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
         "move the selected action.") );
   */
   QString lhwt( i18n(
-        "<p>Decides how many locations to keep in the history of the location "
-        "combo box.") );
+                  "<p>Decides how many locations to keep in the history of the location "
+                  "combo box.") );
   lbPathHist->setWhatsThis(lhwt );
   sbPathHistLength->setWhatsThis(lhwt );
   QString fhwt( i18n(
-        "<p>Decides how many filters to keep in the history of the filter "
-        "combo box.") );
+                  "<p>Decides how many filters to keep in the history of the filter "
+                  "combo box.") );
   lbFilterHist->setWhatsThis(fhwt );
   sbFilterHistLength->setWhatsThis(fhwt );
   QString synwt( i18n(
-        "<p>These options allow you to have the File Selector automatically "
-        "change location to the folder of the active document on certain "
-        "events."
-        "<p>Auto synchronization is <em>lazy</em>, meaning it will not take "
-        "effect until the file selector is visible."
-        "<p>None of these are enabled by default, but you can always sync the "
-        "location by pressing the sync button in the toolbar.") );
+                   "<p>These options allow you to have the File Selector automatically "
+                   "change location to the folder of the active document on certain "
+                   "events."
+                   "<p>Auto synchronization is <em>lazy</em>, meaning it will not take "
+                   "effect until the file selector is visible."
+                   "<p>None of these are enabled by default, but you can always sync the "
+                   "location by pressing the sync button in the toolbar.") );
   gbSync->setWhatsThis(synwt );
   cbSesLocation->setWhatsThis(i18n(
-        "<p>If this option is enabled (default), the location will be restored "
-        "when you start Kate.<p><strong>Note</strong> that if the session is "
-        "handled by the KDE session manager, the location is always restored.") );
+                                "<p>If this option is enabled (default), the location will be restored "
+                                "when you start Kate.<p><strong>Note</strong> that if the session is "
+                                "handled by the KDE session manager, the location is always restored.") );
   cbSesFilter->setWhatsThis(i18n(
-        "<p>If this option is enabled (default), the current filter will be "
-        "restored when you start Kate.<p><strong>Note</strong> that if the "
-        "session is handled by the KDE session manager, the filter is always "
-        "restored."
-        "<p><strong>Note</strong> that some of the autosync settings may "
-        "override the restored location if on.") );
+                              "<p>If this option is enabled (default), the current filter will be "
+                              "restored when you start Kate.<p><strong>Note</strong> that if the "
+                              "session is handled by the KDE session manager, the filter is always "
+                              "restored."
+                              "<p><strong>Note</strong> that some of the autosync settings may "
+                              "override the restored location if on.") );
 
   init();
 
@@ -719,7 +744,7 @@ void KFSConfigPage::apply()
 
   m_changed = false;
 
-  KConfig *config = KGlobal::config();
+  KSharedConfig::Ptr config = KGlobal::config();
   config->setGroup( "fileselector" );
   // toolbar
   QStringList l;
@@ -728,10 +753,10 @@ void KFSConfigPage::apply()
   foreach(QListWidgetItem *item, list)
   {
     aItem = (ActionLBItem*)item;
-      l << aItem->idstring();
+    l << aItem->idstring();
   }
   config->writeEntry( "toolbar actions", l );
-  fileSelector->setupToolbar( config );
+  fileSelector->setupToolbar(config.data());
   // sync
   int s = 0;
   if ( cbSyncActive->isChecked() )
@@ -757,26 +782,27 @@ void KFSConfigPage::reset()
 }
 void KFSConfigPage::init()
 {
-  KConfig *config = KGlobal::config();
+  KSharedConfig::Ptr config = KGlobal::config();
   config->setGroup( "fileselector" );
   // toolbar
-  QStringList l = config->readEntry( "toolbar actions", QStringList(),',' );
+  QStringList l = config->readEntry( "toolbar actions", QStringList(), ',' );
   if ( l.isEmpty() ) // default toolbar
     l << "up" << "back" << "forward" << "home" <<
-                "short view" << "detailed view" <<
-                "bookmarks" << "sync_dir";
+    "short view" << "detailed view" <<
+    "bookmarks" << "sync_dir";
 
   // actions from diroperator + two of our own
   QStringList allActions;
   allActions << "up" << "back" << "forward" << "home" <<
-                "reload" << "mkdir" << "delete" <<
-                "short view" << "detailed view" /*<< "view menu" <<
-                "show hidden" << "properties"*/ <<
-                "bookmarks" << "sync_dir";
+  "reload" << "mkdir" << "delete" <<
+  "short view" << "detailed view" /*<< "view menu" <<
+                  "show hidden" << "properties"*/ <<
+  "bookmarks" << "sync_dir";
   QRegExp re("&(?=[^&])");
-  KAction *ac;
+  QAction *ac;
   QListWidget *lb;
-  for ( QStringList::Iterator it=allActions.begin(); it != allActions.end(); ++it ) {
+  for ( QStringList::Iterator it = allActions.begin(); it != allActions.end(); ++it )
+  {
     lb = l.contains( *it ) ? acSel->selectedListWidget() : acSel->availableListWidget();
     if ( *it == "bookmarks" || *it == "sync_dir" )
       ac = fileSelector->actionCollection()->action( (*it).toLatin1().constData() );
@@ -794,8 +820,8 @@ void KFSConfigPage::init()
   sbPathHistLength->setValue( fileSelector->cmbPath->maxItems() );
   sbFilterHistLength->setValue( fileSelector->filter->maxCount() );
   // session
-  cbSesLocation->setChecked( config->readEntry( "restore location", QVariant(true )).toBool() );
-  cbSesFilter->setChecked( config->readEntry( "restore last filter", QVariant(true )).toBool() );
+  cbSesLocation->setChecked( config->readEntry( "restore location", true) );
+  cbSesFilter->setChecked( config->readEntry( "restore last filter", true) );
 }
 
 void KFSConfigPage::slotMyChanged()
