@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwddlg.h 501548 2006-01-23 11:07:16Z mlaurent $
+ * $Id: passwddlg.h 621085 2007-01-08 09:22:45Z ogoffart $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -10,6 +10,7 @@
 #define __PasswdDlg_h_Incluced__
 
 #include <kpassworddialog.h>
+#include <knewpassworddialog.h>
 #include <QByteArray>
 
 class KDEpasswd1Dialog
@@ -23,13 +24,12 @@ public:
 
     static int getPassword(QByteArray &password);
 
-protected:
-    bool checkPassword(const char *password);
+    void accept();
 };
     
 
 class KDEpasswd2Dialog
-    : public KPasswordDialog
+    : public KNewPasswordDialog
 {
     Q_OBJECT
 
@@ -37,6 +37,9 @@ public:
     KDEpasswd2Dialog(const char *oldpass, QByteArray user);
     ~KDEpasswd2Dialog();
 
+    void accept();
+
+
 protected:
     bool checkPassword(const char *password);
     
