@@ -36,12 +36,12 @@
 #include <QDateTimeEdit>
 
 #include <kapplication.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <kmenubar.h>
 #include <ktoolbar.h>
 #include <kaction.h>
 #include <kactioncollection.h>
-#include <klistbox.h>
+#include <klistwidget.h>
 #include <k3listview.h>
 #include <q3header.h>
 #include <klocale.h>
@@ -56,11 +56,11 @@
 #include <kstatusbar.h>
 #include <ksqueezedtextlabel.h>
 #include <krun.h>
-#include <kopenwith.h>
 #include <kpushbutton.h>
 #include <kurl.h>
 #include <kdebug.h>
 #include <kxmlguifactory.h>
+
 KdeprintFax::KdeprintFax(QWidget *parent, const char *name)
 : KMainWindow(parent)
 {
@@ -73,15 +73,15 @@ KdeprintFax::KdeprintFax(QWidget *parent, const char *name)
 
 	QWidget	*mainw = new QWidget(this);
 	setCentralWidget(mainw);
-	m_files = new KListBox(mainw);
-	connect( m_files, SIGNAL( currentChanged( Q3ListBoxItem* ) ), SLOT( slotCurrentChanged() ) );
+	m_files = new KListWidget(mainw);
+	connect( m_files, SIGNAL( currentChanged( QListWidgetItem* ) ), SLOT( slotCurrentChanged() ) );
 	m_upbtn = new KPushButton( mainw );
-	m_upbtn->setIcon( SmallIconSet( "up" ) );
+	m_upbtn->setIcon( KIcon( "up" ) );
 	m_upbtn->setToolTip( i18n( "Move up" ) );
 	connect( m_upbtn, SIGNAL( clicked() ), SLOT( slotMoveUp() ) );
 	m_upbtn->setEnabled( false );
 	m_downbtn = new KPushButton( mainw );
-	m_downbtn->setIcon( SmallIconSet( "down" ) );
+	m_downbtn->setIcon( KIcon( "down" ) );
 	m_downbtn->setToolTip( i18n( "Move down" ) );
 	connect( m_downbtn, SIGNAL( clicked() ), SLOT( slotMoveDown() ) );
 	m_downbtn->setEnabled( false );
@@ -106,7 +106,7 @@ KdeprintFax::KdeprintFax(QWidget *parent, const char *name)
 	m_abbtn->setToolTip( i18n( "Add fax number from addressbook" ) );
 	connect( m_abbtn, SIGNAL( clicked() ), SLOT( slotKab() ) );
 	m_delbtn = new KPushButton( mainw );
-	m_delbtn->setIcon( SmallIconSet( "edittrash" ) );
+	m_delbtn->setIcon( KIcon( "edittrash" ) );
 	m_delbtn->setToolTip( i18n( "Remove fax number" ) );
 	m_delbtn->setEnabled( false );
 	connect( m_delbtn, SIGNAL( clicked() ), SLOT( slotFaxRemove() ) );
@@ -200,61 +200,75 @@ KdeprintFax::~KdeprintFax()
 
 void KdeprintFax::initActions()
 {
-  KAction *action = 0;
+  QAction *action = 0;
 
-  action = new KAction(i18n("&Add File..."), actionCollection(), "file_add");
+  action = actionCollection()->addAction("file_add");
+  action->setText( i18n("&Add File...") );
   action->setIcon( KIcon( "filenew" ) );
   action->setShortcut( Qt::Key_Insert );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotAdd()) );
 
-  action = new KAction(i18n("&Remove File"), actionCollection(), "file_remove");
+  action = actionCollection()->addAction("file_remove");
+  action->setText( i18n("&Remove File") );
   action->setIcon( KIcon( "remove" ) );
   action->setShortcut( Qt::Key_Delete );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotRemove()) );
 
-  action = new KAction(i18n("&Send Fax"), actionCollection(), "fax_send");
+  action = actionCollection()->addAction("fax_send");
+  action->setText( i18n("&Send Fax") );
   action->setIcon( KIcon( "connect_established" ) );
   action->setShortcut( Qt::Key_Return );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotFax()) );
 
-  action = new KAction(i18n("A&bort"), actionCollection(), "fax_stop");
+  action = actionCollection()->addAction("fax_stop");
+  action->setText( i18n("A&bort") );
   action->setIcon( KIcon( "stop" ) );
   action->setShortcut( Qt::Key_Escape );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotAbort()) );
 
-  action = new KAction(i18n("A&ddress Book"), actionCollection(), "fax_ab");
+  action = actionCollection()->addAction("fax_ab");
+  action->setText( i18n("A&ddress Book") );
   action->setIcon( KIcon( "kaddressbook" ) );
   action->setShortcut( Qt::CTRL+Qt::Key_A );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotKab()) );
 
-  action = new KAction(i18n("V&iew Log"), actionCollection(), "fax_log");
+  action = actionCollection()->addAction("fax_log");
+  action->setText( i18n("V&iew Log") );
   action->setIcon( KIcon( "contents" ) );
   action->setShortcut( Qt::CTRL+Qt::Key_L );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotViewLog()) );
 
-  action = new KAction(i18n("Vi&ew File"), actionCollection(), "file_view");
+  action = actionCollection()->addAction("file_view");
+  action->setText( i18n("Vi&ew File") );
   action->setIcon( KIcon( "filefind" ) );
   action->setShortcut( Qt::CTRL+Qt::Key_O );
   connect( action, SIGNAL( triggered() ), this, SLOT(slotView()) );
 
-  action = new KAction( i18n( "&New Fax Recipient..." ), actionCollection(), "fax_add" );
+  action = actionCollection()->addAction("fax_add" );
+  action->setText(  i18n( "&New Fax Recipient..." ) );
   action->setIcon( KIcon( "edit" ) );
   action->setShortcut( Qt::CTRL+Qt::Key_N );
   connect( action, SIGNAL( triggered() ), this, SLOT( slotFaxAdd() ) );
 
-	KStdAction::quit(this, SLOT(slotQuit()), actionCollection());
-	setStandardToolBarMenuEnabled(true);
-	KStdAction::showMenubar(this, SLOT(slotToggleMenuBar()), actionCollection());
-	KStdAction::preferences(this, SLOT(slotConfigure()), actionCollection());
-        KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
-actionCollection());
-	actionCollection()->action("fax_stop")->setEnabled(false);
-	connect(actionCollection()->action("file_remove"), SIGNAL(enabled(bool)), actionCollection()->action("file_view"), SLOT(setEnabled(bool)));
-	actionCollection()->action("file_remove")->setEnabled(false);
-
-	createGUI();
+  KStandardAction::quit(this, SLOT(slotQuit()), actionCollection());
+  setStandardToolBarMenuEnabled(true);
+  KStandardAction::showMenubar(this, SLOT(slotToggleMenuBar()), actionCollection());
+  KStandardAction::preferences(this, SLOT(slotConfigure()), actionCollection());
+  KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
+                               actionCollection());
+  actionCollection()->action("fax_stop")->setEnabled(false);
+  connect(this,SIGNAL(changeStateFileViewAction(bool)), SLOT(slotChangeStateFileViewAction(bool)));
+  actionCollection()->action("file_remove")->setEnabled(false);
+  emit changeStateFileViewAction(false);
+  createGUI();
 }
 
+void KdeprintFax::slotChangeStateFileViewAction(bool _b)
+{
+  actionCollection()->action("file_view")->setEnabled(_b);
+}
+
+
 void KdeprintFax::slotToggleMenuBar()
 {
 	if (menuBar()->isVisible()) menuBar()->hide();
@@ -270,17 +284,20 @@ void KdeprintFax::slotAdd()
 
 void KdeprintFax::slotRemove()
 {
-	if (m_files->currentItem() >= 0)
-		m_files->removeItem(m_files->currentItem());
+	if (m_files->currentItem())
+		delete m_files->takeItem(m_files->currentRow());
 	if (m_files->count() == 0)
+	{
 		actionCollection()->action("file_remove")->setEnabled(false);
+		emit changeStateFileViewAction(false);
+	}
 }
 
 void KdeprintFax::slotView()
 {
-	if (m_files->currentItem() >= 0)
+	if (m_files->currentItem())
 	{
-		new KRun(KUrl( m_files->currentText() ),this);
+		new KRun(KUrl( m_files->currentItem()->text() ),this);
 	}
 }
 
@@ -321,9 +338,10 @@ void KdeprintFax::addURL(KUrl url)
 	QString	target;
 	if (KIO::NetAccess::download(url,target,this))
 	{
-    QPixmap pm = KIcon( KMimeType::iconNameForURL(url) ).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize) );
-		m_files->insertItem(pm, target);
+	        QPixmap pm = KIcon( KMimeType::iconNameForUrl(url) ).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize) );
+		new QListWidgetItem(pm,target,m_files);
 		actionCollection()->action("file_remove")->setEnabled(true);
+		emit changeStateFileViewAction(true);
 		slotCurrentChanged();
 	}
 	else
@@ -363,8 +381,8 @@ void KdeprintFax::dropEvent(QDropEvent *e)
 QStringList KdeprintFax::files()
 {
 	QStringList	l;
-	for (uint i=0; i<m_files->count(); i++)
-		l.append(m_files->text(i));
+	for (int i=0; i<m_files->count(); i++)
+		l.append(m_files->item(i)->text());
 	return l;
 }
 
@@ -514,31 +532,31 @@ QString KdeprintFax::time() const
 
 void KdeprintFax::slotMoveUp()
 {
-	int index = m_files->currentItem();
+	int index = m_files->currentRow();
 	if ( index > 0 )
 	{
-		Q3ListBoxItem *item = m_files->item( index );
-		m_files->takeItem( item );
-		m_files->insertItem( item, index-1 );
-		m_files->setCurrentItem( index-1 );
+		QListWidgetItem *item = m_files->item( index );
+		m_files->takeItem( index );
+		m_files->insertItem( index-1 , item );
+		m_files->setCurrentRow( index-1 );
 	}
 }
 
 void KdeprintFax::slotMoveDown()
 {
-	int index = m_files->currentItem();
+	int index = m_files->currentRow();
 	if ( index >= 0 && index < ( int )m_files->count()-1 )
 	{
-		Q3ListBoxItem *item = m_files->item( index );
-		m_files->takeItem( item );
-		m_files->insertItem( item, index+1 );
-		m_files->setCurrentItem( index+1 );
+		QListWidgetItem *item = m_files->item( index );
+		m_files->takeItem( index );
+		m_files->insertItem( index + 1 , item );
+		m_files->setCurrentRow( index+1 );
 	}
 }
 
 void KdeprintFax::slotCurrentChanged()
 {
-	int index = m_files->currentItem();
+	int index = m_files->currentRow();
 	m_upbtn->setEnabled( index > 0 );
 	m_downbtn->setEnabled( index >=0 && index < ( int )m_files->count()-1 );
 }
