@@ -28,7 +28,7 @@
 #include <QTextStream>
 #include <klocale.h>
 #include <kdebug.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kio/global.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
@@ -38,7 +38,7 @@
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kprocess.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <QFile>
 #include <qdom.h>
 #include <Q3PtrListIterator>
@@ -124,7 +124,7 @@ QString buildGroupTable(DrGroup *grp, bool showHeader = true)
 
 int kdemain(int argc, char **argv)
 {
-	KInstance  instance("kio_print");
+        KComponentData componentData("kio_print");
 
 	PRINT_DEBUG << "starting ioslave" << endl;
 	if (argc != 4)
@@ -774,7 +774,7 @@ void KIO_Print::showData(const QString& pathname)
 	if (f.exists() && f.open(QIODevice::ReadOnly))
 	{
 		QByteArray	arr(f.readAll());
-		mimeType(KMimeType::findByURL(KUrl(pathname), 0, true, true)->name());
+		mimeType(KMimeType::findByUrl(KUrl(pathname), 0, true, true)->name());
 		data(arr);
 		finished();
 	}
@@ -794,7 +794,7 @@ QString KIO_Print::locateData(const QString& item)
 {
 	QString	path = KStandardDirs::locate("data", "kdeprint/template/"+item);
 	if (path.isEmpty())
-		path = KGlobal::iconLoader()->iconPath(item, K3Icon::Desktop, true);
+		path = KIconLoader::global()->iconPath(item, K3Icon::Desktop, true);
 	return path;
 }
 
