@@ -22,7 +22,7 @@
 
 K_EXPORT_COMPONENT_FACTORY( konq_aboutpage, KonqAboutPageFactory )
 
-KInstance *KonqAboutPageFactory::s_instance = 0;
+KComponentData *KonqAboutPageFactory::s_instance = 0;
 QString *KonqAboutPageFactory::s_launch_html = 0;
 QString *KonqAboutPageFactory::s_intro_html = 0;
 QString *KonqAboutPageFactory::s_specs_html = 0;
@@ -32,7 +32,7 @@ QString *KonqAboutPageFactory::s_plugins_html = 0;
 KonqAboutPageFactory::KonqAboutPageFactory( QObject *parent )
     : KParts::Factory( parent )
 {
-    s_instance = new KInstance( "konqaboutpage" );
+    s_instance = new KComponentData("konqaboutpage");
 }
 
 KonqAboutPageFactory::~KonqAboutPageFactory()
@@ -94,7 +94,7 @@ QString KonqAboutPageFactory::launch()
   if ( res.isEmpty() )
     return res;
 
-  KIconLoader *iconloader = KGlobal::iconLoader();
+  KIconLoader *iconloader = KIconLoader::global();
   int iconSize = iconloader->currentSize(K3Icon::Desktop);
   QString home_icon_path = iconloader->iconPath("folder_home", K3Icon::Desktop );
   QString storage_icon_path = iconloader->iconPath("system", K3Icon::Desktop );
@@ -165,7 +165,7 @@ QString KonqAboutPageFactory::intro()
     if ( res.isEmpty() )
 	return res;
 
-    KIconLoader *iconloader = KGlobal::iconLoader();
+    KIconLoader *iconloader = KIconLoader::global();
     QString back_icon_path = QApplication::isRightToLeft()?iconloader->iconPath("forward", K3Icon::Small ):iconloader->iconPath("back", K3Icon::Small );
     QString gohome_icon_path = iconloader->iconPath("gohome", K3Icon::Small );
     QString continue_icon_path = QApplication::isRightToLeft()?iconloader->iconPath("1leftarrow", K3Icon::Small ):iconloader->iconPath("1rightarrow", K3Icon::Small );
@@ -219,7 +219,7 @@ QString KonqAboutPageFactory::specs()
     if ( s_specs_html )
         return *s_specs_html;
 
-    KIconLoader *iconloader = KGlobal::iconLoader();
+    KIconLoader *iconloader = KIconLoader::global();
     QString res = loadFile( KStandardDirs::locate( "data", "konqueror/about/specs.html" ));
     QString continue_icon_path = QApplication::isRightToLeft()?iconloader->iconPath("1leftarrow", K3Icon::Small ):iconloader->iconPath("1rightarrow", K3Icon::Small );
     if ( res.isEmpty() )
@@ -305,7 +305,7 @@ QString KonqAboutPageFactory::tips()
     if ( res.isEmpty() )
 	return res;
 
-    KIconLoader *iconloader = KGlobal::iconLoader();
+    KIconLoader *iconloader = KIconLoader::global();
     QString viewmag_icon_path =
 	    iconloader->iconPath("viewmag", K3Icon::Small );
     QString history_icon_path =
@@ -412,7 +412,7 @@ KonqAboutPage::KonqAboutPage( //KonqMainWindow *
     else
 	setCharset("iso-8859-1", true);
     // about:blah isn't a kioslave -> disable View source
-    KAction * act = actionCollection()->action("viewDocumentSource");
+    QAction * act = actionCollection()->action("viewDocumentSource");
     if ( act )
       act->setEnabled( false );
 }
@@ -421,7 +421,7 @@ KonqAboutPage::~KonqAboutPage()
 {
 }
 
-bool KonqAboutPage::openURL( const KUrl &u )
+bool KonqAboutPage::openUrl( const KUrl &u )
 {
     if (u.url() == "about:plugins")
        serve( KonqAboutPageFactory::plugins(), "plugins" );
@@ -470,25 +470,25 @@ void KonqAboutPage::urlSelected( const QString &url, int button, int state, cons
 
     if ( url == QLatin1String("launch.html") )
     {
-        emit browserExtension()->openURLNotify();
+        emit browserExtension()->openUrlNotify();
 	serve( KonqAboutPageFactory::launch(), "konqueror" );
         return;
     }
     else if ( url == QLatin1String("intro.html") )
     {
-        emit browserExtension()->openURLNotify();
+        emit browserExtension()->openUrlNotify();
         serve( KonqAboutPageFactory::intro(), "konqueror" );
         return;
     }
     else if ( url == QLatin1String("specs.html") )
     {
-        emit browserExtension()->openURLNotify();
+        emit browserExtension()->openUrlNotify();
 	serve( KonqAboutPageFactory::specs(), "konqueror" );
         return;
     }
     else if ( url == QLatin1String("tips.html") )
     {
-        emit browserExtension()->openURLNotify();
+        emit browserExtension()->openUrlNotify();
         serve( KonqAboutPageFactory::tips(), "konqueror" );
         return;
     }
@@ -498,16 +498,16 @@ void KonqAboutPage::urlSelected( const QString &url, int button, int state, cons
 	if ( KMessageBox::questionYesNo( widget(),
 					 i18n("Do you want to disable showing "
 					      "the introduction in the webbrowsing profile?"),
-					 i18n("Faster Startup?"),i18n("Disable"),i18n("Keep") )
+					 i18n("Faster Startup?"),KGuiItem(i18n("Disable")),KGuiItem(i18n("Keep")) )
 	     == KMessageBox::Yes )
 	{
 	    QString profile = KStandardDirs::locateLocal("data", "konqueror/profiles/webbrowsing");
 	    KSaveFile file( profile );
-	    if ( file.status() == 0 ) {
+	    if ( file.open() ) {
+		QTextStream stream(&file);
 		QByteArray content = "[Profile]\n"
 			           "Name=Web-Browser";
-		fputs( content.data(), file.fstream() );
-		file.close();
+		stream << content.data();
 	    }
 	}
 	return;
