@@ -32,7 +32,7 @@
 #include <kdebug.h>
 #include <kservice.h>
 #include <krun.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kstaticdeleter.h>
 
 #include <konq_mainwindow_interface.h>
@@ -60,8 +60,7 @@ QByteArray ClientApp::startup_id_str;
 bool ClientApp::m_ok = true;
 bool s_interactive = true;
 
-static KInstance* s_instance = 0;
-static KStaticDeleter<KInstance> s_instanceSd;
+K_GLOBAL_STATIC(KComponentData, s_instance)
 
 static const KCmdLineOptions options[] =
 {
@@ -112,9 +111,8 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
 // Call needInstance before any use of KConfig
 static void needInstance()
 {
-    if ( !s_instance ) {
-        s_instanceSd.setObject( s_instance, new KInstance( appName ) );
-    }
+    KComponentData *tmp = s_instance; // inits the global static if referenced for the first time
+    Q_UNUSED(tmp);
 }
 
 /*
@@ -187,7 +185,7 @@ static bool startNewKonqueror( QString url, QString mimetype, const QString& pro
 	mimetype = QLatin1String( "" );
     }
     if( mimetype.isEmpty())
-	mimetype = KMimeType::findByURL( KUrl( url ) )->name();
+	mimetype = KMimeType::findByUrl( KUrl( url ) )->name();
     KService::List offers = KMimeTypeTrader::self()->query( mimetype, QLatin1String( "KParts/ReadOnlyPart" ) );
     KService::Ptr serv;
     if( offers.count() > 0 )
@@ -219,7 +217,7 @@ static void needDBus()
     if ( !s_dbus_initialized ) {
         extern void qDBusBindToApplication();
         qDBusBindToApplication();
-        if (!QDBus::sessionBus().isConnected())
+        if (!QDBusConnection::sessionBus().isConnected())
             kFatal(101) << "Session bus not found" << endl;
         s_dbus_initialized = true;
     }
@@ -235,7 +233,7 @@ static QString getPreloadedKonqy()
     if( cfg.readEntry( "MaxPreloadCount", 1 ) == 0 )
         return QString();
     needDBus();
-    QDBusInterface ref( "org.kde.kded", "/modules/konqy_preloader", "org.kde.konqueror.Preloader", QDBus::sessionBus() );
+    QDBusInterface ref( "org.kde.kded", "/modules/konqy_preloader", "org.kde.konqueror.Preloader", QDBusConnection::sessionBus() );
     // ## used to have NoEventLoop and 3s timeout with dcop
     QDBusReply<QString> reply = ref.call( "getPreloadedKonqy", currentScreen() );
     if ( reply.isValid() )
@@ -252,7 +250,7 @@ static QString konqyToReuse( const QString& url, const QString& mimetype, const
     if( startNewKonqueror( url, mimetype, profile ))
         return QString();
     needDBus();
-    QDBusConnection dbus = QDBus::sessionBus();
+    QDBusConnection dbus = QDBusConnection::sessionBus();
     QDBusReply<QStringList> reply = dbus.interface()->registeredServiceNames();
     if ( !reply.isValid() )
         return QString();
@@ -319,7 +317,7 @@ bool ClientApp::createNewWindow(const KUrl & url, bool newTab, bool tempFile, co
     }
 
     needDBus();
-    QDBusConnection dbus = QDBus::sessionBus();
+    QDBusConnection dbus = QDBusConnection::sessionBus();
     KConfig cfg( QLatin1String( "konquerorrc" ), true );
     cfg.setGroup( "FMSettings" );
     if ( newTab || cfg.readEntry( "KonquerorTabforExternalURL", false) ) {
@@ -336,7 +334,7 @@ bool ClientApp::createNewWindow(const KUrl & url, bool newTab, bool tempFile, co
                     QDBusReply<QDBusObjectPath> windowReply = konq.windowForTab();
                     if ( windowReply.isValid() ) {
                         QDBusObjectPath path = windowReply;
-                        if ( !path.value.isEmpty() ) {
+                        if ( !path.path().isEmpty() ) {
                             foundApp = service;
                             foundObj = path;
                         }
@@ -346,7 +344,7 @@ bool ClientApp::createNewWindow(const KUrl & url, bool newTab, bool tempFile, co
         }
 
         if ( !foundApp.isEmpty() ) {
-            org::kde::Konqueror::MainWindow konqWindow( foundApp, foundObj.value, dbus );
+            org::kde::Konqueror::MainWindow konqWindow( foundApp, foundObj.path(), dbus );
             QDBusReply<void> newTabReply = konqWindow.newTabASN( url.url(), startup_id_str, tempFile );
             if ( newTabReply.isValid() ) {
                 sendASNChange();
@@ -419,7 +417,7 @@ bool ClientApp::openProfile( const QString & profileName, const QString & url, c
       ::exit( 0 );
   }
   needDBus();
-  org::kde::Konqueror::Main konqy( appId, "/KonqMain", QDBus::sessionBus() );
+  org::kde::Konqueror::Main konqy( appId, "/KonqMain", QDBusConnection::sessionBus() );
   if ( url.isEmpty() )
       konqy.createBrowserWindowFromProfile( profile, profileName, startup_id_str );
   else if ( mimetype.isEmpty() )
