@@ -40,9 +40,8 @@
 #include <kmessagebox.h>
 #include <konq_settings.h>
 #include <kpropertiesdialog.h>
-#include <kseparatoraction.h>
 #include <kstaticdeleter.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <kparts/factory.h>
 #include <kservicetypetrader.h>
 #include <ktoggleaction.h>
@@ -83,27 +82,27 @@ public:
       return obj;
    }
 
-   static KInstance *instance()
+   static const KComponentData &componentData()
    {
       if ( !s_instance )
-         s_instance = new KInstance( "konqiconview" );
-      return s_instance;
+         s_instance = new KComponentData("konqiconview");
+      return *s_instance;
    }
 
    static KonqPropsView *defaultViewProps()
    {
       if ( !s_defaultViewProps )
-         s_defaultViewProps = new KonqPropsView( instance(), 0L );
+         s_defaultViewProps = new KonqPropsView( componentData(), 0L );
 
       return s_defaultViewProps;
    }
 
    private:
-      static KInstance *s_instance;
+      static KComponentData *s_instance;
       static KonqPropsView *s_defaultViewProps;
 };
 
-KInstance *KonqIconViewFactory::s_instance = 0;
+KComponentData *KonqIconViewFactory::s_instance = 0;
 KonqPropsView *KonqIconViewFactory::s_defaultViewProps = 0;
 
 
@@ -145,7 +144,7 @@ void IconViewBrowserExtension::trash()
 
 void IconViewBrowserExtension::properties()
 {
-    (void) new KPropertiesDialog( m_iconView->iconViewWidget()->selectedFileItems() );
+    KPropertiesDialog::showDialog( m_iconView->iconViewWidget()->selectedFileItems(), m_iconView->iconViewWidget(), true /*modal*/ );
 }
 
 void IconViewBrowserExtension::editMimeType()
@@ -178,7 +177,7 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     setBrowserExtension( new IconViewBrowserExtension( this ) );
 
     // Create a properties instance for this view
-    m_pProps = new KonqPropsView( KonqIconViewFactory::instance(), KonqIconViewFactory::defaultViewProps() );
+    m_pProps = new KonqPropsView( KonqIconViewFactory::componentData(), KonqIconViewFactory::defaultViewProps() );
 
     m_pIconView = new KonqIconViewWidget( parentWidget );
     m_pIconView->initConfig( true );
@@ -201,31 +200,37 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     connect( this, SIGNAL( findClosed( KonqDirPart * ) ), SLOT( slotKFindClosed() ) );
 
     setWidget( m_pIconView );
-    m_mimeTypeResolver = new KMimeTypeResolver<KFileIVI,KonqKfmIconView>(this);
+    m_mimeTypeResolver = new K3MimeTypeResolver<KFileIVI,KonqKfmIconView>(this);
 
-    setInstance( KonqIconViewFactory::instance() );
+    setComponentData( KonqIconViewFactory::componentData() );
 
     setXMLFile( "konq_iconview.rc" );
 
     // Don't repaint on configuration changes during construction
     m_bInit = true;
 
-    m_paDotFiles = new KToggleAction( i18n( "Show &Hidden Files" ), actionCollection(), "show_dot" );
+    m_paDotFiles = new KToggleAction( i18n( "Show &Hidden Files" ), this );
+    actionCollection()->addAction( "show_dot", m_paDotFiles );
     connect(m_paDotFiles, SIGNAL(triggered(bool) ), SLOT( slotShowDot() ));
 //    m_paDotFiles->setCheckedState(i18n("Hide &Hidden Files"));
     m_paDotFiles->setToolTip( i18n( "Toggle displaying of hidden dot files" ) );
 
-    m_paDirectoryOverlays = new KToggleAction( i18n( "&Folder Icons Reflect Contents" ), actionCollection(), "show_directory_overlays" );
+    m_paDirectoryOverlays = new KToggleAction( i18n( "&Folder Icons Reflect Contents" ), this );
+    actionCollection()->addAction( "show_directory_overlays", m_paDirectoryOverlays );
     connect(m_paDirectoryOverlays, SIGNAL(triggered(bool) ), SLOT( slotShowDirectoryOverlays() ));
 
-    m_pamPreview = new KActionMenu( i18n( "&Preview" ), actionCollection(), "iconview_preview" );
+    m_pamPreview = new KActionMenu( i18n( "&Preview" ), this );
+    actionCollection()->addAction( "iconview_preview", m_pamPreview );
 
-    m_paEnablePreviews = new KToggleAction( i18n("Enable Previews"), actionCollection(), "iconview_preview_all" );
-    m_paEnablePreviews->setCheckedState( i18n("Disable Previews") );
+    m_paEnablePreviews = new KToggleAction( i18n("Enable Previews"), this );
+    actionCollection()->addAction( "iconview_preview_all", m_paEnablePreviews );
+    m_paEnablePreviews->setCheckedState( KGuiItem(i18n("Disable Previews")) );
     connect( m_paEnablePreviews, SIGNAL( toggled( bool ) ), this, SLOT( slotPreview( bool ) ) );
     m_paEnablePreviews->setIcon(KIcon("thumbnail"));
     m_pamPreview->addAction( m_paEnablePreviews );
-    m_pamPreview->addAction( new KSeparatorAction(actionCollection()) );
+    QAction *sep_act = new QAction(this);
+    sep_act->setSeparator(true);
+    m_pamPreview->addAction(sep_act);
 
     KService::List plugins = KServiceTypeTrader::self()->query( "ThumbCreator" );
     QMap< QString, KToggleAction* > previewActions;
@@ -236,24 +241,31 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
             preview->QAction::setObjectName( QByteArray( preview->name() ) + ',' + ( *it )->desktopEntryName().toLatin1() );
         else
         {
-            preview = new KToggleAction( (*it)->name(), actionCollection(), (*it)->desktopEntryName().toLatin1() );
+            preview = new KToggleAction( (*it)->name(), this );
+            actionCollection()->addAction( (*it)->desktopEntryName().toLatin1(), preview );
             connect( preview, SIGNAL( toggled( bool ) ), this, SLOT( slotPreview( bool ) ) );
             m_pamPreview->addAction( preview );
             m_paPreviewPlugins.append( preview );
         }
     }
-    KToggleAction *soundPreview = new KToggleAction( i18n("Sound Files"), actionCollection(), "audio/" );
+    KToggleAction *soundPreview = new KToggleAction( i18n("Sound Files"), this );
+    actionCollection()->addAction( "audio/", soundPreview );
     connect( soundPreview, SIGNAL( toggled( bool ) ), this, SLOT( slotPreview( bool ) ) );
     m_pamPreview->addAction( soundPreview );
     m_paPreviewPlugins.append( soundPreview );
 
     //    m_pamSort = new KActionMenu( i18n( "Sort..." ), actionCollection(), "sort" );
 
-    KToggleAction *aSortByNameCS = new KToggleAction( i18n( "By Name (Case Sensitive)" ), actionCollection(), "sort_nc" );
-    KToggleAction *aSortByNameCI = new KToggleAction( i18n( "By Name (Case Insensitive)" ), actionCollection(), "sort_nci" );
-    KToggleAction *aSortBySize = new KToggleAction( i18n( "By Size" ), actionCollection(), "sort_size" );
-    KToggleAction *aSortByType = new KToggleAction( i18n( "By Type" ), actionCollection(), "sort_type" );
-    KToggleAction *aSortByDate = new KToggleAction( i18n( "By Date" ), actionCollection(), "sort_date" );
+    KToggleAction *aSortByNameCS = new KToggleAction( i18n( "By Name (Case Sensitive)" ), this );
+    actionCollection()->addAction( "sort_nc", aSortByNameCS );
+    KToggleAction *aSortByNameCI = new KToggleAction( i18n( "By Name (Case Insensitive)" ), this );
+    actionCollection()->addAction( "sort_nci", aSortByNameCI );
+    KToggleAction *aSortBySize = new KToggleAction( i18n( "By Size" ), this );
+    actionCollection()->addAction( "sort_size", aSortBySize );
+    KToggleAction *aSortByType = new KToggleAction( i18n( "By Type" ), this );
+    actionCollection()->addAction( "sort_type", aSortByType );
+    KToggleAction *aSortByDate = new KToggleAction( i18n( "By Date" ), this );
+    actionCollection()->addAction( "sort_date", aSortByDate );
 
     QActionGroup* sorting = new QActionGroup(this);
     sorting->setExclusive(true);
@@ -280,8 +292,10 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     KToggleAction *sort_action = dynamic_cast<KToggleAction *>(actionCollection()->action(sortcrit.toLatin1().constData()));
     if(sort_action!=NULL) sort_action->trigger();
 
-    m_paSortDirsFirst = new KToggleAction( i18n( "Folders First" ), actionCollection(), "sort_directoriesfirst" );
-    KToggleAction *aSortDescending = new KToggleAction( i18n( "Descending" ), actionCollection(), "sort_descend" );
+    m_paSortDirsFirst = new KToggleAction( i18n( "Folders First" ), this );
+    actionCollection()->addAction( "sort_directoriesfirst", m_paSortDirsFirst );
+    KToggleAction *aSortDescending = new KToggleAction( i18n( "Descending" ), this );
+    actionCollection()->addAction( "sort_descend", aSortDescending );
 
     m_paSortDirsFirst->setChecked( KonqIconViewFactory::defaultViewProps()->isDirsFirst() );
 
@@ -306,17 +320,22 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
 
     m_pamSort->insert( aSortDescending );
     */
-    m_paSelect = new KAction( i18n( "Se&lect..." ), actionCollection(), "select" );
+    m_paSelect = actionCollection()->addAction("select");
+    m_paSelect->setText( i18n( "Se&lect..." ) );
     connect(m_paSelect, SIGNAL(triggered(bool) ), SLOT( slotSelect() ));
     m_paSelect->setShortcut(Qt::CTRL+Qt::Key_Plus);
-    m_paUnselect = new KAction( i18n( "Unselect..." ), actionCollection(), "unselect" );
+    m_paUnselect = actionCollection()->addAction("unselect");
+    m_paUnselect->setText( i18n( "Unselect..." ) );
     connect(m_paUnselect, SIGNAL(triggered(bool) ), SLOT( slotUnselect() ));
     m_paUnselect->setShortcut(Qt::CTRL+Qt::Key_Minus);
-    m_paSelectAll = KStdAction::selectAll( this, SLOT( slotSelectAll() ), actionCollection(), "selectall" );
-    m_paUnselectAll = new KAction( i18n( "Unselect All" ), actionCollection(), "unselectall" );
+    m_paSelectAll = KStandardAction::selectAll( this, SLOT( slotSelectAll() ), this );
+    actionCollection()->addAction( "selectall", m_paSelectAll );
+    m_paUnselectAll = actionCollection()->addAction("unselectall");
+    m_paUnselectAll->setText( i18n( "Unselect All" ) );
     connect(m_paUnselectAll, SIGNAL(triggered(bool) ), SLOT( slotUnselectAll() ));
     m_paUnselectAll->setShortcut(Qt::CTRL+Qt::Key_U);
-    m_paInvertSelection = new KAction( i18n( "&Invert Selection" ), actionCollection(), "invertselection" );
+    m_paInvertSelection = actionCollection()->addAction("invertselection");
+    m_paInvertSelection->setText( i18n( "&Invert Selection" ) );
     connect(m_paInvertSelection, SIGNAL(triggered(bool) ), SLOT( slotInvertSelection() ));
     m_paInvertSelection->setShortcut(Qt::CTRL+Qt::Key_Asterisk);
 
@@ -364,7 +383,8 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
              this, SLOT( slotDragFinished() ) );
 
     // Create the directory lister
-    m_dirLister = new KDirLister( true );
+    m_dirLister = new KDirLister;
+    m_dirLister->setDelayedMimeTypes( true );
     setDirLister( m_dirLister );
     m_dirLister->setMainWindow(m_pIconView->topLevelWidget());
 
@@ -845,7 +865,7 @@ void KonqKfmIconView::slotMouseButtonClicked(int _button, Q3IconViewItem* _item,
 
 void KonqKfmIconView::slotStarted()
 {
-    // Only emit started if this comes after openURL, i.e. it's not for an update.
+    // Only emit started if this comes after openUrl, i.e. it's not for an update.
     // We don't want to start a spinning wheel during updates.
     if ( m_bLoading )
         emit started( 0 );
@@ -864,7 +884,7 @@ void KonqKfmIconView::slotCanceled()
 void KonqKfmIconView::slotCanceled( const KUrl& url )
 {
     // Check if this canceled() signal is about the URL we're listing.
-    // It could be about the URL we were listing, and openURL() aborted it.
+    // It could be about the URL we were listing, and openUrl() aborted it.
     if ( m_bLoading && url.equals( m_pIconView->url(), KUrl::CompareWithoutTrailingSlash ) )
     {
         emit canceled( QString() );
@@ -1025,6 +1045,10 @@ void KonqKfmIconView::slotNewItems( const KFileItemList& entries )
 
 void KonqKfmIconView::slotDeleteItem( KFileItem * _fileitem )
 {
+    KFileItemList list;
+    list.append(_fileitem);
+    emit m_extension->itemsRemoved(list);
+
     if ( _fileitem == m_dirLister->rootItem() )
     {
         m_pIconView->stopImagePreview();
@@ -1184,9 +1208,9 @@ void KonqKfmIconView::slotClear()
 void KonqKfmIconView::slotRedirection( const KUrl & url )
 {
     const QString prettyURL = url.pathOrUrl();
-    emit m_extension->setLocationBarURL( prettyURL );
+    emit m_extension->setLocationBarUrl( prettyURL );
     emit setWindowCaption( prettyURL );
-    m_pIconView->setURL( url );
+    m_pIconView->setUrl( url );
     m_url = url;
 }
 
@@ -1258,7 +1282,7 @@ void KonqKfmIconView::slotRefreshViewport()
 bool KonqKfmIconView::doOpenURL( const KUrl & url )
 {
     // Store url in the icon view
-    m_pIconView->setURL( url );
+    m_pIconView->setUrl( url );
 
     m_bLoading = true;
     m_bNeedSetCurrentItem = true;
@@ -1272,14 +1296,14 @@ bool KonqKfmIconView::doOpenURL( const KUrl & url )
 
     m_dirLister->setMimeFilter( mimeFilter() );
 
-    // This *must* happen before m_dirLister->openURL because it emits
+    // This *must* happen before m_dirLister->openUrl because it emits
     // clear() and Q3IconView::clear() calls setContentsPos(0,0)!
     KParts::URLArgs args = m_extension->urlArgs();
     if ( args.reload )
     {
         args.xOffset = m_pIconView->contentsX();
         args.yOffset = m_pIconView->contentsY();
-        m_extension->setURLArgs( args );
+        m_extension->setUrlArgs( args );
 
         m_filesToSelect.clear();
         const KFileItemList selItems = selectedFileItems();
@@ -1299,7 +1323,7 @@ bool KonqKfmIconView::doOpenURL( const KUrl & url )
     m_paOutstandingOverlays.clear();
 
     // Start the directory lister !
-    m_dirLister->openURL( url, false, args.reload );
+    m_dirLister->openUrl( url, false, args.reload );
 
     // View properties (icon size, background, ..) will be applied into slotClear()
     // if m_bDirPropertiesChanged is set. If so, here we update preview actions.
@@ -1486,10 +1510,10 @@ void SpringLoadingManager::springLoadTrigger(KonqKfmIconView *view,
     args.trustedSource = true;
 
     // Open the folder URL, we don't want to modify the browser
-    // history, hence the use of openURL and setLocationBarURL
-    view->openURL(url);
+    // history, hence the use of openUrl and setLocationBarURL
+    view->openUrl(url);
     const QString prettyURL = url.pathOrUrl();
-    emit view->extension()->setLocationBarURL( prettyURL );
+    emit view->extension()->setLocationBarUrl( prettyURL );
 }
 
 void SpringLoadingManager::dragLeft(KonqKfmIconView */*view*/)
@@ -1531,9 +1555,9 @@ void SpringLoadingManager::finished()
     m_startPart = 0L;
 
     KonqKfmIconView *view = static_cast<KonqKfmIconView*>(part);
-    view->openURL(url);
+    view->openUrl(url);
     const QString prettyURL = url.pathOrUrl();
-    emit view->extension()->setLocationBarURL( prettyURL );
+    emit view->extension()->setLocationBarUrl( prettyURL );
 
     deleteLater();
     s_self = 0L;
