@@ -53,10 +53,12 @@
 #include <ktogglefullscreenaction.h>
 
 class QFile;
+class QAction;
 class KAction;
 class KActionCollection;
 class KActionMenu;
 class KBookmarkMenu;
+class KonqBookmarkActionMenu;
 class KCMultiDialog;
 class KHistoryCombo;
 class KNewMenu;
@@ -115,24 +117,24 @@ public:
 
 
   /**
-   * Filters the URL and calls the main openURL method.
+   * Filters the URL and calls the main openUrl method.
    */
   void openFilteredUrl( const QString & _url, KonqOpenURLRequest& _req);
 
   /**
-   * Filters the URL and calls the main openURL method.
+   * Filters the URL and calls the main openUrl method.
    */
   void openFilteredUrl( const QString &_url, bool inNewTab = false, bool tempFile = false );
 
   /**
-   * The main openURL method.
+   * The main openUrl method.
    */
-  void openURL( KonqView * view, const KUrl & url,
+  void openUrl( KonqView * view, const KUrl & url,
                 const QString &serviceType = QString(),
                 KonqOpenURLRequest & req = KonqOpenURLRequest::null, bool trustedSource = false );
 
   /**
-   * Called by openURL when it knows the service type (either directly,
+   * Called by openUrl when it knows the service type (either directly,
    * or using KonqRun)
    */
   bool openView( QString serviceType, const KUrl &_url, KonqView *childView,
@@ -297,7 +299,7 @@ public:
   void setTitle( const QString &title , QWidget* sender);
   void setTabIcon( const KUrl &url, QWidget* sender );
 
-  QWidget* widget();
+  QWidget* asQWidget();
 
   void listViews( ChildViewList *viewList );
   QByteArray frameType();
@@ -327,17 +329,17 @@ public:
 
   QStringList configModules() const;
 
+  void saveWindowSize() const;
+  void restoreWindowSize();
+
 Q_SIGNALS:
   void viewAdded( KonqView *view );
   void viewRemoved( KonqView *view );
+  void popupItemsDisturbed();
 
 public Q_SLOTS:
   void slotCtrlTabPressed();
 
-  // for KBookmarkMenu and KBookmarkBar
-  void slotFillContextMenu( const KBookmark &, QMenu * );
-  void slotOpenBookmarkUrl( const QString & url, Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers );
-
   void slotPopupMenu( const QPoint &_global, const KUrl &_url, const QString &_mimeType, mode_t mode );
   void slotPopupMenu( KXMLGUIClient *client, const QPoint &_global, const KUrl &_url, const QString &_mimeType, mode_t mode );
   void slotPopupMenu( KXMLGUIClient *client, const QPoint &_global, const KUrl &_url, const KParts::URLArgs &_args, KParts::BrowserExtension::PopupFlags f, mode_t mode );
@@ -354,7 +356,7 @@ public Q_SLOTS:
    */
   void slotOpenURLRequest( const KUrl &url, const KParts::URLArgs &args );
 
-  void openURL( KonqView *childView, const KUrl &url, const KParts::URLArgs &args );
+  void openUrl( KonqView *childView, const KUrl &url, const KParts::URLArgs &args );
 
   void slotCreateNewWindow( const KUrl &url, const KParts::URLArgs &args );
   void slotCreateNewWindow( const KUrl &url, const KParts::URLArgs &args,
@@ -423,6 +425,8 @@ public Q_SLOTS:
   void slotGoHistoryActivated( int steps, Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers );
 
   void slotAddTab();
+  void slotSplitViewHorizontal();
+  void slotSplitViewVertical();
 
 protected Q_SLOTS:
   void slotViewCompleted( KonqView * view );
@@ -432,8 +436,6 @@ protected Q_SLOTS:
   void slotFileNewAboutToShow();
   void slotLocationLabelActivated();
 
-  void slotSplitViewHorizontal();
-  void slotSplitViewVertical();
   void slotDuplicateTab();
   void slotDuplicateTabPopup();
 
@@ -444,7 +446,6 @@ protected Q_SLOTS:
   void slotPopupNewWindow();
   void slotPopupThisWindow();
   void slotPopupNewTab();
-  void slotPopupNewTabRight();
   void slotPopupPasteTo();
   void slotRemoveView();
 
@@ -545,6 +546,7 @@ private Q_SLOTS:
 
   void slotRequesterClicked( KUrlRequester * );
   void slotIntro();
+  void slotItemsRemoved(const KFileItemList &);
   /**
    * Loads the url displayed currently in the lineedit of the locationbar, by
    * emulating a enter key press event.
@@ -607,60 +609,62 @@ private:
 
   QObject* lastFrame( KonqView *view );
 
+private: // members
+
   KNewMenu * m_pMenuNew;
 
-  KAction *m_paPrint;
+  QAction *m_paPrint;
 
-  KActionMenu *m_pamBookmarks;
+  KonqBookmarkActionMenu *m_pamBookmarks;
 
   KToolBarPopupAction *m_paUp;
   KToolBarPopupAction *m_paBack;
   KToolBarPopupAction *m_paForward;
-  KAction *m_paHome;
+  QAction *m_paHome;
 
   KonqBidiHistoryAction *m_paHistory;
 
-  KAction *m_paSaveViewProfile;
+  QAction *m_paSaveViewProfile;
   KToggleAction *m_paSaveViewPropertiesLocally;
-  KAction *m_paRemoveLocalProperties;
+  QAction *m_paRemoveLocalProperties;
 
-  KAction *m_paSplitViewHor;
-  KAction *m_paSplitViewVer;
-  KAction *m_paAddTab;
-  KAction *m_paDuplicateTab;
-  KAction *m_paBreakOffTab;
-  KAction *m_paRemoveView;
-  KAction *m_paRemoveTab;
-  KAction *m_paRemoveOtherTabs;
-  KAction *m_paActivateNextTab;
-  KAction *m_paActivatePrevTab;
+  QAction *m_paSplitViewHor;
+  QAction *m_paSplitViewVer;
+  QAction *m_paAddTab;
+  QAction *m_paDuplicateTab;
+  QAction *m_paBreakOffTab;
+  QAction *m_paRemoveView;
+  QAction *m_paRemoveTab;
+  QAction *m_paRemoveOtherTabs;
+  QAction *m_paActivateNextTab;
+  QAction *m_paActivatePrevTab;
 
-  KAction *m_paSaveRemoveViewProfile;
+  QAction *m_paSaveRemoveViewProfile;
   KActionMenu *m_pamLoadViewProfile;
 
   KToggleAction *m_paLockView;
   KToggleAction *m_paLinkView;
-  KAction *m_paReload;
-  KAction *m_paReloadAllTabs;
-  KAction *m_paUndo;
-  KAction *m_paCut;
-  KAction *m_paCopy;
-  KAction *m_paPaste;
-  KAction *m_paStop;
-  KAction *m_paRename;
+  QAction *m_paReload;
+  QAction *m_paReloadAllTabs;
+  QAction *m_paUndo;
+  QAction *m_paCut;
+  QAction *m_paCopy;
+  QAction *m_paPaste;
+  QAction *m_paStop;
+  QAction *m_paRename;
 
-  KAction *m_paTrash;
-  KAction *m_paDelete;
+  QAction *m_paTrash;
+  QAction *m_paDelete;
 
-  KAction *m_paCopyFiles;
-  KAction *m_paMoveFiles;
-  KAction *m_paNewDir;
+  QAction *m_paCopyFiles;
+  QAction *m_paMoveFiles;
+  QAction *m_paNewDir;
 
-  KAction *m_paMoveTabLeft;
-  KAction *m_paMoveTabRight;
+  QAction *m_paMoveTabLeft;
+  QAction *m_paMoveTabRight;
 
-  KAction *m_paConfigureExtensions;
-  KAction *m_paConfigureSpellChecking;
+  QAction *m_paConfigureExtensions;
+  QAction *m_paConfigureSpellChecking;
 
   KonqLogoAction *m_paAnimatedLogo;
 
@@ -674,14 +678,16 @@ private:
 
   KToggleFullScreenAction *m_ptaFullScreen;
 
-  uint m_bLocationBarConnected:1;
-  uint m_bURLEnterLock:1;
+  bool m_bLocationBarConnected:1;
+  bool m_bURLEnterLock:1;
   // Global settings
-  uint m_bSaveViewPropertiesLocally:1;
-  uint m_bHTMLAllowed:1;
+  bool m_bSaveViewPropertiesLocally:1;
+  bool m_bHTMLAllowed:1;
   // Set in constructor, used in slotRunFinished
-  uint m_bNeedApplyKonqMainWindowSettings:1;
-  uint m_bViewModeToggled:1;
+  bool m_bNeedApplyKonqMainWindowSettings:1;
+  bool m_bViewModeToggled:1;
+  bool m_urlCompletionStarted:1;
+  bool m_prevMenuBarVisible:1;
 
   int m_goBuffer;
   Qt::MouseButtons m_goMouseState;
@@ -694,7 +700,7 @@ private:
   KBookmarkMenu* m_pBookmarkMenu;
   KonqExtendedBookmarkOwner *m_pBookmarksOwner;
   KActionCollection* m_bookmarksActionCollection;
-  KActionCollection* m_bookmarkBarActionCollection;
+  bool m_bookmarkBarInitialized;
 
   KonqViewManager *m_pViewManager;
   KonqFrameBase* m_pChildFrame;
@@ -732,10 +738,10 @@ private:
 
   QString m_initialFrameName;
 
-  QList<KAction *> m_openWithActions;
+  QList<QAction *> m_openWithActions;
   KActionMenu *m_viewModeMenu;
   QActionGroup* m_viewModesGroup;
-  QList<KAction*> m_toolBarViewModeActions; // basically holds three KonqViewActions, one of
+  QList<QAction*> m_toolBarViewModeActions; // basically holds three KonqViewActions, one of
                                               // iconview, one for listview, and one for externals
   QActionGroup* m_toolBarViewModesGroup;
   QList<KToggleAction *> m_viewModeActions;
@@ -751,8 +757,6 @@ private:
 
   QString m_currentDir; // stores current dir for relative URLs whenever applicable
 
-  bool m_urlCompletionStarted;
-
   static bool s_preloaded;
   static KonqMainWindow* s_preloadedWindow;
   static int s_initialMemoryUsage;
