@@ -30,6 +30,7 @@
 #include <QDragMoveEvent>
 #include <QDropEvent>
 
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -43,7 +44,7 @@
 
 #include <kacceleratormanager.h>
 #include <konq_pixmapprovider.h>
-#include <kstdaccel.h>
+#include <kstandardshortcut.h>
 #include <qtabbar.h>
 
 #include <QStyle>
@@ -85,13 +86,13 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
                             m_pViewManager->mainWindow(),
                             SLOT( slotAddTab() ),
                             m_pViewManager->mainWindow()->action("newtab")->shortcut() );
-  m_pPopupMenu->insertItem( SmallIconSet( "tab_duplicate" ),
+  m_pPopupMenu->insertItem( KIcon( "tab_duplicate" ),
                             i18n("&Duplicate Tab"),
                             m_pViewManager->mainWindow(),
                             SLOT( slotDuplicateTabPopup() ),
                             m_pViewManager->mainWindow()->action("duplicatecurrenttab")->shortcut(),
                             DUPLICATE_ID );
-  m_pPopupMenu->insertItem( SmallIconSet( "reload" ),
+  m_pPopupMenu->insertItem( KIcon( "reload" ),
                             i18n( "&Reload Tab" ),
                             m_pViewManager->mainWindow(),
                             SLOT( slotReloadPopup() ),
@@ -102,14 +103,14 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
   connect( m_pSubPopupMenuTab, SIGNAL( activated ( int ) ),
            this, SLOT( slotSubPopupMenuTabActivated( int ) ) );
   m_pPopupMenu->addSeparator();
-  m_pPopupMenu->insertItem( SmallIconSet( "tab_breakoff" ),
+  m_pPopupMenu->insertItem( KIcon( "tab_breakoff" ),
                             i18n("D&etach Tab"),
                             m_pViewManager->mainWindow(),
                             SLOT( slotBreakOffTabPopup() ),
                             m_pViewManager->mainWindow()->action("breakoffcurrenttab")->shortcut(),
                             BREAKOFF_ID );
   m_pPopupMenu->addSeparator();
-  m_pPopupMenu->insertItem( SmallIconSet( "tab_remove" ),
+  m_pPopupMenu->insertItem( KIcon( "tab_remove" ),
                             i18n("&Close Tab"),
                             m_pViewManager->mainWindow(),
                             SLOT( slotRemoveTabPopup() ),
@@ -149,7 +150,7 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
     m_rightWidget = new QToolButton( this );
     connect( m_rightWidget, SIGNAL( clicked() ),
              m_pViewManager->mainWindow(), SLOT( slotRemoveTab() ) );
-    m_rightWidget->setIcon( SmallIconSet( "tab_remove" ) );
+    m_rightWidget->setIcon( KIcon( "tab_remove" ) );
     m_rightWidget->adjustSize();
     m_rightWidget->setToolTip( i18n("Close the current tab"));
     setCornerWidget( m_rightWidget, Qt::TopRightCorner );
@@ -269,16 +270,16 @@ void KonqFrameTabs::setTabIcon( const KUrl &url, QWidget* sender )
   if (m_permanentCloseButtons)
     iconSet =  SmallIcon( "fileclose" );
   else
-    iconSet =  SmallIconSet( KonqPixmapProvider::self()->iconNameFor( url ) );
-  if (tabIconSet( sender ).pixmap().serialNumber() != iconSet.pixmap().serialNumber())
-    setTabIconSet( sender, iconSet );
+    iconSet =  KIcon( KonqPixmapProvider::self()->iconNameFor( url ) );
+  if (tabIcon( indexOf( sender ) ).pixmap().serialNumber() != iconSet.pixmap().serialNumber())
+    KTabWidget::setTabIcon( indexOf( sender ), iconSet );
 }
 
 void KonqFrameTabs::activateChild()
 {
   if (m_pActiveChild)
     {
-      showPage( m_pActiveChild->widget() );
+      setCurrentIndex( indexOf( m_pActiveChild->asQWidget() ) );
       m_pActiveChild->activateChild();
     }
 }
@@ -291,7 +292,7 @@ void KonqFrameTabs::insertChildFrame( KonqFrameBase* frame, int index )
     {
       //kDebug(1202) << "Adding frame" << endl;
       bool showTabBar = (count() == 1);
-      insertTab(frame->widget(),"", index);
+      insertTab(index, frame->asQWidget(), "");
       frame->setParentContainer(this);
       if (index == -1) m_pChildFrameList->append(frame);
       else m_pChildFrameList->insert(index, frame);
@@ -315,7 +316,7 @@ void KonqFrameTabs::removeChildFrame( KonqFrameBase * frame )
 {
   //kDebug(1202) << "KonqFrameTabs::RemoveChildFrame " << this << ". Child " << frame << " removed" << endl;
   if (frame) {
-    removePage(frame->widget());
+    removePage(frame->asQWidget());
     m_pChildFrameList->removeAll(frame);
     if (m_rightWidget)
       m_rightWidget->setEnabled( m_pChildFrameList->count()>1 );
@@ -426,7 +427,7 @@ void KonqFrameTabs::refreshSubPopupMenuTab()
     }
     m_pSubPopupMenuTab->addSeparator();
     m_closeOtherTabsId =
-      m_pSubPopupMenuTab->insertItem( SmallIconSet( "tab_remove" ),
+      m_pSubPopupMenuTab->insertItem( KIcon( "tab_remove" ),
 				      i18n( "Close &Other Tabs" ),
 				      m_pViewManager->mainWindow(),
 				      SLOT( slotRemoveOtherTabsPopup() ),
@@ -453,7 +454,7 @@ void KonqFrameTabs::slotMouseMiddleClick()
   if ( !filteredURL.isEmpty() ) {
     KonqView* newView = m_pViewManager->addTab(QString(), QString(), false, false);
     if (newView == 0L) return;
-    m_pViewManager->mainWindow()->openURL( newView, filteredURL, QString() );
+    m_pViewManager->mainWindow()->openUrl( newView, filteredURL, QString() );
     m_pViewManager->showTab( newView );
     m_pViewManager->mainWindow()->focusLocationBar();
   }
@@ -473,7 +474,7 @@ void KonqFrameTabs::slotMouseMiddleClick( QWidget *w )
   if ( !filteredURL.isEmpty() ) {
     KonqFrameBase* frame = dynamic_cast<KonqFrameBase*>(w);
     if (frame) {
-      m_pViewManager->mainWindow()->openURL( frame->activeChildView(), filteredURL );
+      m_pViewManager->mainWindow()->openUrl( frame->activeChildView(), filteredURL );
     }
   }
   }
@@ -490,7 +491,7 @@ void KonqFrameTabs::slotReceivedDropEvent( QDropEvent *e )
   if ( lstDragURLs.count() ) {
     KonqView* newView = m_pViewManager->addTab(QString(), QString(), false, false);
     if (newView == 0L) return;
-    m_pViewManager->mainWindow()->openURL( newView, lstDragURLs.first(), QString() );
+    m_pViewManager->mainWindow()->openUrl( newView, lstDragURLs.first(), QString() );
     m_pViewManager->showTab( newView );
     m_pViewManager->mainWindow()->focusLocationBar();
   }
@@ -503,7 +504,7 @@ void KonqFrameTabs::slotReceivedDropEvent( QWidget *w, QDropEvent *e )
   if ( lstDragURLs.count() && frame ) {
     KUrl lstDragURL = lstDragURLs.first();
     if ( lstDragURL != frame->activeChildView()->url() )
-      m_pViewManager->mainWindow()->openURL( frame->activeChildView(), lstDragURL );
+      m_pViewManager->mainWindow()->openUrl( frame->activeChildView(), lstDragURL );
   }
 }
 
@@ -515,9 +516,9 @@ void KonqFrameTabs::slotInitiateDrag( QWidget *w )
     QMimeData* md = new QMimeData();
     frame->activeChildView()->url().populateMimeData(md);
     d->setMimeData( md );
-    QString iconName = KMimeType::iconNameForURL(frame->activeChildView()->url());
-    d->setPixmap(KGlobal::iconLoader()->loadIcon(iconName, K3Icon::Small, 0));
-    //d->setPixmap( KGlobal::iconLoader()->loadMimeTypeIcon(KMimeType::pixmapForURL( frame->activeChildView()->url(), 0), K3Icon::Small ) );
+    QString iconName = KMimeType::iconNameForUrl(frame->activeChildView()->url());
+    d->setPixmap(KIconLoader::global()->loadIcon(iconName, K3Icon::Small, 0));
+    //d->setPixmap( KIconLoader::global()->loadMimeTypeIcon(KMimeType::pixmapForURL( frame->activeChildView()->url(), 0), K3Icon::Small ) );
     d->start();
   }
 }
