@@ -138,10 +138,10 @@ KonqView::~KonqView()
   //kDebug(1202) << "KonqView::~KonqView " << this << " done" << endl;
 }
 
-void KonqView::openURL( const KUrl &url, const QString & locationBarURL,
+void KonqView::openUrl( const KUrl &url, const QString & locationBarURL,
                         const QString & nameFilter, bool tempFile )
 {
-  kDebug(1202) << "KonqView::openURL url=" << url << " locationBarURL=" << locationBarURL << endl;
+  kDebug(1202) << "KonqView::openUrl url=" << url << " locationBarURL=" << locationBarURL << endl;
   setServiceTypeInExtension();
 
   if (KonqMainWindow::s_crashlog_file) {
@@ -175,7 +175,7 @@ void KonqView::openURL( const KUrl &url, const QString & locationBarURL,
     if ( !prepareReload( args ) )
       return;
     if ( ext )
-      ext->setURLArgs( args );
+      ext->setUrlArgs( args );
   }
 
 #ifdef DEBUG_HISTORY
@@ -222,7 +222,7 @@ void KonqView::openURL( const KUrl &url, const QString & locationBarURL,
 
   aboutToOpenURL( url, args );
 
-  m_pPart->openURL( url );
+  m_pPart->openUrl( url );
 
   updateHistoryEntry(false /* don't save location bar URL yet */);
   // add pending history entry
@@ -391,7 +391,7 @@ void KonqView::connectPart(  )
   {
       ext->setBrowserInterface( m_browserIface );
 
-      connect( ext, SIGNAL( openURLRequestDelayed( const KUrl &, const KParts::URLArgs &) ),
+      connect( ext, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::URLArgs &) ),
                m_pMainWindow, SLOT( slotOpenURLRequest( const KUrl &, const KParts::URLArgs & ) ) );
 
       if ( m_bPopupMenuEnabled )
@@ -400,10 +400,10 @@ void KonqView::connectPart(  )
           enablePopupMenu( true );
       }
 
-      connect( ext, SIGNAL( setLocationBarURL( const QString & ) ),
+      connect( ext, SIGNAL( setLocationBarUrl( const QString & ) ),
                this, SLOT( setLocationBarURL( const QString & ) ) );
 
-      connect( ext, SIGNAL( setIconURL( const KUrl & ) ),
+      connect( ext, SIGNAL( setIconUrl( const KUrl & ) ),
                this, SLOT( setIconURL( const KUrl & ) ) );
 
       connect( ext, SIGNAL( setPageSecurity( int ) ),
@@ -427,7 +427,7 @@ void KonqView::connectPart(  )
       connect( ext, SIGNAL( mouseOverInfo( const KFileItem * ) ),
                this, SLOT( slotMouseOverInfo( const KFileItem * ) ) );
 
-      connect( ext, SIGNAL( openURLNotify() ),
+      connect( ext, SIGNAL( openUrlNotify() ),
                this, SLOT( slotOpenURLNotify() ) );
 
       connect( ext, SIGNAL( enableAction( const char *, bool ) ),
@@ -532,7 +532,7 @@ void KonqView::slotStarted( KIO::Job * job )
       job->ui()->setWindow (m_pMainWindow->topLevelWidget ());
 
       connect( job, SIGNAL( percent( KJob *, unsigned long ) ), this, SLOT( slotPercent( KJob *, unsigned long ) ) );
-      connect( job, SIGNAL( speed( KIO::Job *, unsigned long ) ), this, SLOT( slotSpeed( KIO::Job *, unsigned long ) ) );
+      connect( job, SIGNAL( speed( KJob *, unsigned long ) ), this, SLOT( slotSpeed( KJob *, unsigned long ) ) );
       connect( job, SIGNAL( infoMessage( KJob *, const QString &, const QString & ) ), this, SLOT( slotInfoMessage( KJob *, const QString & ) ) );
   }
 }
@@ -558,7 +558,7 @@ void KonqView::slotPercent( KJob *, unsigned long percent )
   m_pKonqFrame->statusbar()->slotLoadingProgress( percent );
 }
 
-void KonqView::slotSpeed( KIO::Job *, unsigned long bytesPerSecond )
+void KonqView::slotSpeed( KJob *, unsigned long bytesPerSecond )
 {
   m_pKonqFrame->statusbar()->slotSpeedProgress( bytesPerSecond );
 }
@@ -844,7 +844,7 @@ void KonqView::restoreHistory()
     m_pageReferrer = h.pageReferrer;
   }
   else
-    m_pPart->openURL( h.url );
+    m_pPart->openUrl( h.url );
 
   if ( m_pMainWindow->currentView() == this )
     m_pMainWindow->updateToolBarActions();
@@ -914,8 +914,8 @@ void KonqView::stop()
     // we decided to keep it :)
     KonqHistoryManager::kself()->confirmPending( url(), m_sTypedURL );
 
-    //kDebug(1202) << "m_pPart->closeURL()" << endl;
-    m_pPart->closeURL();
+    //kDebug(1202) << "m_pPart->closeUrl()" << endl;
+    m_pPart->closeUrl();
     m_bAborted = true;
     m_pKonqFrame->statusbar()->slotLoadingProgress( -1 );
     setLoading( false, false );
@@ -1001,7 +1001,7 @@ void KonqView::setServiceTypeInExtension()
 
   KParts::URLArgs args( ext->urlArgs() );
   args.serviceType = m_serviceType;
-  ext->setURLArgs( args );
+  ext->setUrlArgs( args );
 }
 
 QStringList KonqView::frameNames() const
@@ -1216,7 +1216,7 @@ QString KonqView::dbusObjectPath()
     if ( m_dbusObjectPath.isEmpty() ) {
         m_dbusObjectPath = '/' + m_pMainWindow->objectName() + '/' + QString::number( ++s_viewNumber );
         new KonqViewAdaptor( this );
-        QDBus::sessionBus().registerObject( m_dbusObjectPath, this );
+        QDBusConnection::sessionBus().registerObject( m_dbusObjectPath, this );
     }
     return m_dbusObjectPath;
 }
@@ -1259,7 +1259,7 @@ bool KonqView::eventFilter( QObject *obj, QEvent *e )
         KUrl::List lstDragURLs = KUrl::List::fromMimeData( ev->mimeData() );
         KParts::BrowserExtension *ext = browserExtension();
         if ( !lstDragURLs.isEmpty() && ext && lstDragURLs.first().isValid() )
-            emit ext->openURLRequest( lstDragURLs.first() ); // this will call m_pMainWindow::slotOpenURLRequest delayed
+            emit ext->openUrlRequest( lstDragURLs.first() ); // this will call m_pMainWindow::slotOpenURLRequest delayed
     }
 
     if ( m_bBackRightClick )
@@ -1307,17 +1307,17 @@ bool KonqView::eventFilter( QObject *obj, QEvent *e )
 
     if ( e->type() == QEvent::FocusIn )
     {
-        setActiveInstance();
+        setActiveComponent();
     }
     return false;
 }
 
-void KonqView::setActiveInstance()
+void KonqView::setActiveComponent()
 {
-  if ( m_bBuiltinView || !m_pPart->instance() /*never!*/)
-      KGlobal::setActiveInstance( KGlobal::instance() );
+  if ( m_bBuiltinView || !m_pPart->componentData().isValid() /*never!*/)
+      KGlobal::setActiveComponent( KGlobal::mainComponent() );
   else
-      KGlobal::setActiveInstance( m_pPart->instance() );
+      KGlobal::setActiveComponent( m_pPart->componentData() );
 }
 
 bool KonqView::prepareReload( KParts::URLArgs& args )
@@ -1329,7 +1329,7 @@ bool KonqView::prepareReload( KParts::URLArgs& args )
         if ( KMessageBox::warningContinueCancel( 0, i18n(
             "The page you are trying to view is the result of posted form data. "
             "If you resend the data, any action the form carried out (such as search or online purchase) will be repeated. "),
-            i18n( "Warning" ), i18n( "Resend" ) ) == KMessageBox::Continue )
+            i18n( "Warning" ), KGuiItem(i18n( "Resend" )) ) == KMessageBox::Continue )
         {
             args.setDoPost( true );
             args.setContentType( m_postContentType );
