@@ -27,6 +27,8 @@
 #include "konq_settingsxt.h"
 
 #include <QFileInfo>
+#include <QDBusMessage>
+#include <QDBusConnection>
 
 #include <kaccelgen.h>
 #include <kactionmenu.h>
@@ -34,7 +36,7 @@
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kglobalsettings.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -61,7 +63,7 @@ KonqViewManager::KonqViewManager( KonqMainWindow *mainWindow )
 
 KonqView* KonqViewManager::Initialize( const QString &serviceType, const QString &serviceName )
 {
-  //kDebug(1202) << "KonqViewManager::Initialize()" << endl;
+  //kDebug(1202) << "KonqViewManager::Initialize() " << serviceName << endl;
   KService::Ptr service;
   KService::List partServiceOffers, appServiceOffers;
   KonqViewFactory newViewFactory = createView( serviceType, serviceName, service, partServiceOffers, appServiceOffers, true /*forceAutoEmbed*/ );
@@ -80,7 +82,7 @@ KonqView* KonqViewManager::Initialize( const QString &serviceType, const QString
   static_cast<KonqFrameTabs*>( m_pDocContainer )->setAlwaysTabbedMode(
       KonqSettings::alwaysTabbedMode() );
 
-  m_pDocContainer->widget()->show();
+  m_pDocContainer->asQWidget()->show();
   return childView;
 }
 
@@ -120,37 +122,37 @@ KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
   int index= -1;
 
   if (parentContainer->frameType()=="Container") {
-    moveNewContainer = (static_cast<KonqFrameContainer*>(parentContainer)->idAfter( splitFrame->widget() ) != 0);
+    moveNewContainer = static_cast<KonqFrameContainer*>(parentContainer)->hasWidgetAfter( splitFrame->asQWidget() );
     splitterSizes = static_cast<KonqFrameContainer*>(parentContainer)->sizes();
   }
   else if (parentContainer->frameType()=="Tabs")
-    index = static_cast<KonqFrameTabs*>(parentContainer)->indexOf( splitFrame->widget() );
+    index = static_cast<KonqFrameTabs*>(parentContainer)->indexOf( splitFrame->asQWidget() );
 
 #ifndef NDEBUG
   //printSizeInfo( splitFrame, parentContainer, "before split");
 #endif
 
-  parentContainer->widget()->setUpdatesEnabled( false );
+  parentContainer->asQWidget()->setUpdatesEnabled( false );
 
   //kDebug(1202) << "Move out child" << endl;
-  QPoint pos = splitFrame->widget()->pos();
+  QPoint pos = splitFrame->asQWidget()->pos();
   parentContainer->removeChildFrame( splitFrame );
-  splitFrame->widget()->setParent( m_pMainWindow );
-  splitFrame->widget()->move( pos );
+  splitFrame->asQWidget()->setParent( m_pMainWindow );
+  splitFrame->asQWidget()->move( pos );
 
   //kDebug(1202) << "Create new Container" << endl;
-  KonqFrameContainer *newContainer = new KonqFrameContainer( orientation, parentContainer->widget(), parentContainer );
+  KonqFrameContainer *newContainer = new KonqFrameContainer( orientation, parentContainer->asQWidget(), parentContainer );
   connect(newContainer,SIGNAL(ctrlTabPressed()),m_pMainWindow,SLOT(slotCtrlTabPressed()));
 
   parentContainer->insertChildFrame( newContainer, index );
   if ( moveNewContainer ) {
-    static_cast<KonqFrameContainer*>(parentContainer)->moveToFirst( newContainer );
+    static_cast<KonqFrameContainer*>(parentContainer)->insertWidget( 0, newContainer );
     static_cast<KonqFrameContainer*>(parentContainer)->swapChildren();
   }
 
   //kDebug(1202) << "Move in child" << endl;
-  splitFrame->widget()->setParent( newContainer );
-  splitFrame->widget()->move( pos );
+  splitFrame->asQWidget()->setParent( newContainer );
+  splitFrame->asQWidget()->move( pos );
   newContainer->insertChildFrame( splitFrame );
 
 #ifndef NDEBUG
@@ -166,7 +168,7 @@ KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
 
   if ( newOneFirst )
   {
-    newContainer->moveToLast( splitFrame->widget() );
+    newContainer->addWidget( splitFrame->asQWidget() );
     newContainer->swapChildren();
   }
 
@@ -177,14 +179,16 @@ KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
   if (parentContainer->frameType()=="Container") {
     static_cast<KonqFrameContainer*>(parentContainer)->setSizes( splitterSizes );
   }
-  else if (parentContainer->frameType()=="Tabs")
-    static_cast<KonqFrameTabs*>(parentContainer)->showPage( newContainer );
+  else if (parentContainer->frameType()=="Tabs") {
+    KonqFrameTabs* pc = static_cast<KonqFrameTabs*>(parentContainer);
+    pc->setCurrentIndex( pc->indexOf( newContainer ) );
+  }
 
   splitFrame->show();
   //newView->frame()->show();
   newContainer->show();
 
-  parentContainer->widget()->setUpdatesEnabled( true );
+  parentContainer->asQWidget()->setUpdatesEnabled( true );
 
   if (m_pDocContainer == splitFrame) m_pDocContainer = newContainer;
 
@@ -226,10 +230,10 @@ KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation,
 
   KonqFrameBase* mainFrame = m_pMainWindow->childFrame();
 
-  mainFrame->widget()->setUpdatesEnabled( false );
+  mainFrame->asQWidget()->setUpdatesEnabled( false );
 
   //kDebug(1202) << "Move out child" << endl;
-  QPoint pos = mainFrame->widget()->pos();
+  QPoint pos = mainFrame->asQWidget()->pos();
   m_pMainWindow->removeChildFrame( mainFrame );
 
   KonqFrameContainer *newContainer = new KonqFrameContainer( orientation, m_pMainWindow, 0L);
@@ -238,22 +242,22 @@ KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation,
   m_pMainWindow->insertChildFrame( newContainer );
 
   newContainer->insertChildFrame( mainFrame );
-  mainFrame->widget()->setParent( newContainer );
-  mainFrame->widget()->move( pos );
+  mainFrame->asQWidget()->setParent( newContainer );
+  mainFrame->asQWidget()->move( pos );
 
   KonqView* childView = setupView( newContainer, newViewFactory, service, partServiceOffers, appServiceOffers, serviceType, true );
 
   if( newOneFirst ) {
-      static_cast<KonqFrameContainer*>(newContainer)->moveToFirst( childView->frame() );
-      static_cast<KonqFrameContainer*>(newContainer)->swapChildren();
+    newContainer->insertWidget( 0, childView->frame() );
+    newContainer->swapChildren();
   }
 
   newContainer->show();
-  mainFrame->widget()->show();
+  mainFrame->asQWidget()->show();
 
-  mainFrame->widget()->setUpdatesEnabled( true );
+  mainFrame->asQWidget()->setUpdatesEnabled( true );
 
-  childView->openURL( url, locationBarURL );
+  childView->openUrl( url, locationBarURL );
 
   newContainer->setActiveChild( mainFrame );
 
@@ -276,36 +280,38 @@ void KonqViewManager::convertDocContainer()
   bool moveNewContainer = false;
   QList<int> splitterSizes;
   if (parentContainer->frameType()=="Container") {
-    moveNewContainer = (static_cast<KonqFrameContainer*>(parentContainer)->idAfter( m_pDocContainer->widget() ) != 0);
+    moveNewContainer = static_cast<KonqFrameContainer*>(parentContainer)->hasWidgetAfter( m_pDocContainer->asQWidget() );
     splitterSizes = static_cast<KonqFrameContainer*>(parentContainer)->sizes();
   }
 
-  parentContainer->widget()->setUpdatesEnabled( false );
+  parentContainer->asQWidget()->setUpdatesEnabled( false );
 
   //kDebug(1202) << "Move out child" << endl;
-  QPoint pos = m_pDocContainer->widget()->pos();
+  QPoint pos = m_pDocContainer->asQWidget()->pos();
   parentContainer->removeChildFrame( m_pDocContainer );
-  m_pDocContainer->widget()->setParent( m_pMainWindow );
-  m_pDocContainer->widget()->move( pos );
+  m_pDocContainer->asQWidget()->setParent( m_pMainWindow );
+  m_pDocContainer->asQWidget()->move( pos );
 
-  KonqFrameTabs* newContainer = new KonqFrameTabs( parentContainer->widget() , parentContainer, this);
+  KonqFrameTabs* newContainer = new KonqFrameTabs( parentContainer->asQWidget() , parentContainer, this);
   parentContainer->insertChildFrame( newContainer );
   connect( newContainer, SIGNAL(ctrlTabPressed()), m_pMainWindow, SLOT(slotCtrlTabPressed()) );
 
-  m_pDocContainer->widget()->setParent( newContainer );
-  m_pDocContainer->widget()->move( pos );
+  m_pDocContainer->asQWidget()->setParent( newContainer );
+  m_pDocContainer->asQWidget()->move( pos );
   newContainer->insertChildFrame( m_pDocContainer );
 
   if ( moveNewContainer ) {
-    static_cast<KonqFrameContainer*>(parentContainer)->moveToFirst( newContainer );
+    static_cast<KonqFrameContainer*>(parentContainer)->insertWidget( 0, newContainer );
     static_cast<KonqFrameContainer*>(parentContainer)->swapChildren();
   }
-  if (parentContainer->frameType()=="Container")
+  if (parentContainer->frameType()=="Container") {
+    kDebug() << k_funcinfo << "convertDocContainer: setting sizes " << splitterSizes << endl;
     static_cast<KonqFrameContainer*>(parentContainer)->setSizes( splitterSizes );
+  }
 
   newContainer->show();
 
-  parentContainer->widget()->setUpdatesEnabled( true );
+  parentContainer->asQWidget()->setUpdatesEnabled( true );
 
   m_pDocContainer = newContainer;
 }
@@ -421,9 +427,9 @@ void KonqViewManager::duplicateTab( KonqFrameBase* tab, bool openAfterCurrentPag
     return;
   }
 
-  KTempFile tempFile;
-  tempFile.setAutoDelete( true );
-  KConfig config( tempFile.name() );
+  KTemporaryFile tempFile;
+  tempFile.open();
+  KConfig config( tempFile.fileName() );
   config.setGroup( "View Profile" );
 
   QString prefix = QString::fromLatin1( currentFrame->frameType() ) + QString::number(0);
@@ -450,7 +456,7 @@ void KonqViewManager::duplicateTab( KonqFrameBase* tab, bool openAfterCurrentPag
   m_pMainWindow->viewCountChanged();
 
   if (openAfterCurrentPage)
-    tabContainer->setCurrentIndex( tabContainer->currentPageIndex () + 1 );
+    tabContainer->setCurrentIndex( tabContainer->currentIndex () + 1 );
   else
     tabContainer->setCurrentIndex( tabContainer->count() - 1 );
 
@@ -491,9 +497,9 @@ void KonqViewManager::breakOffTab( KonqFrameBase* tab )
     return;
   }
 
-  KTempFile tempFile;
-  tempFile.setAutoDelete( true );
-  KConfig config( tempFile.name() );
+  KTemporaryFile tempFile;
+  tempFile.open();
+  KConfig config( tempFile.fileName() );
   config.setGroup( "View Profile" );
 
   QString prefix = QString::fromLatin1( currentFrame->frameType() ) + QString::number(0);
@@ -565,7 +571,7 @@ void KonqViewManager::removeTab( KonqFrameBase* tab )
   if ( tabContainer->count() == 1 )
     return;
 
-  if (currentFrame->widget() == tabContainer->currentWidget())
+  if (currentFrame->asQWidget() == tabContainer->currentWidget())
     setActivePart( 0L, true );
 
   tabContainer->removeChildFrame(currentFrame);
@@ -604,7 +610,7 @@ void KonqViewManager::reloadAllTabs( )
       if ( frame && frame->activeChildView())
       {
           if( !frame->activeChildView()->locationBarURL().isEmpty())
-              frame->activeChildView()->openURL( frame->activeChildView()->url(), frame->activeChildView()->locationBarURL());
+              frame->activeChildView()->openUrl( frame->activeChildView()->url(), frame->activeChildView()->locationBarURL());
       }
   }
 }
@@ -711,7 +717,7 @@ void KonqViewManager::showTab( KonqView *view )
   KonqFrameTabs *tabContainer = static_cast<KonqFrameTabs*>( docContainer() );
   if (tabContainer->currentWidget() != view->frame())
   {
-    tabContainer->showPage( view->frame() );
+    tabContainer->setCurrentIndex( tabContainer->indexOf( view->frame() ) );
     emitActivePartChanged();
   }
 }
@@ -760,10 +766,10 @@ void KonqViewManager::removeView( KonqView *view )
     bool moveOtherChild = false;
 
     if (grandParentContainer->frameType()=="Tabs")
-      index = static_cast<KonqFrameTabs*>(grandParentContainer)->indexOf( parentContainer->widget() );
+      index = static_cast<KonqFrameTabs*>(grandParentContainer)->indexOf( parentContainer->asQWidget() );
     else if (grandParentContainer->frameType()=="Container")
     {
-      moveOtherChild = (static_cast<KonqFrameContainer*>(grandParentContainer)->idAfter( parentContainer->widget() ) != 0);
+      moveOtherChild = static_cast<KonqFrameContainer*>(grandParentContainer)->hasWidgetAfter( parentContainer->asQWidget() );
       splitterSizes = static_cast<KonqFrameContainer*>(grandParentContainer)->sizes();
     }
 
@@ -778,11 +784,11 @@ void KonqViewManager::removeView( KonqView *view )
 
     if (m_pDocContainer == parentContainer) m_pDocContainer = otherFrame;
 
-    grandParentContainer->widget()->setUpdatesEnabled( false );
+    grandParentContainer->asQWidget()->setUpdatesEnabled( false );
     static_cast<KonqFrameContainer*>(parentContainer)->setAboutToBeDeleted();
 
     //kDebug(1202) << "--- Reparenting otherFrame to m_pMainWindow " << m_pMainWindow << endl;
-    QPoint pos = otherFrame->widget()->pos();
+    QPoint pos = otherFrame->asQWidget()->pos();
     otherFrame->reparentFrame( m_pMainWindow, pos );
 
     //kDebug(1202) << "--- Removing otherFrame from parentContainer" << endl;
@@ -797,30 +803,30 @@ void KonqViewManager::removeView( KonqView *view )
     delete view; // This deletes the view, which deletes the part, which deletes its widget
 
     //kDebug(1202) << "--- Deleting parentContainer " << parentContainer
-    //              << ". Its parent is " << parentContainer->widget()->parent() << endl;
+    //              << ". Its parent is " << parentContainer->asQWidget()->parent() << endl;
     delete parentContainer;
 
     //kDebug(1202) << "--- Reparenting otherFrame to grandParentContainer" << grandParentContainer << endl;
-    otherFrame->reparentFrame( grandParentContainer->widget(), pos );
+    otherFrame->reparentFrame( grandParentContainer->asQWidget(), pos );
 
     //kDebug(1202) << "--- Inserting otherFrame into grandParentContainer" << grandParentContainer << endl;
     grandParentContainer->insertChildFrame( otherFrame, index );
 
     if( moveOtherChild )
     {
-      static_cast<KonqFrameContainer*>(grandParentContainer)->moveToFirst( otherFrame->widget() );
+      static_cast<KonqFrameContainer*>(grandParentContainer)->insertWidget( 0, otherFrame->asQWidget() );
       static_cast<KonqFrameContainer*>(grandParentContainer)->swapChildren();
     }
 
     if (grandParentContainer->frameType()=="Container")
       static_cast<KonqFrameContainer*>(grandParentContainer)->setSizes( splitterSizes );
 
-    otherFrame->widget()->show();
+    otherFrame->asQWidget()->show();
 
     grandParentContainer->setActiveChild( otherFrame );
     grandParentContainer->activateChild();
 
-    grandParentContainer->widget()->setUpdatesEnabled( true );
+    grandParentContainer->asQWidget()->setUpdatesEnabled( true );
   }
   else if (parentContainer->frameType()=="Tabs") {
     kDebug(1202) << "parentContainer " << parentContainer << " is a KonqFrameTabs" << endl;
@@ -981,7 +987,7 @@ KonqViewFactory KonqViewManager::createView( const QString &serviceType,
                                           KService::List &appServiceOffers,
                                           bool forceAutoEmbed )
 {
-  kDebug(1202) << "KonqViewManager::createView" << endl;
+  kDebug(1202) << "KonqViewManager::createView " << serviceName << endl;
   KonqViewFactory viewFactory;
 
   if( serviceType.isEmpty() && m_pMainWindow->currentView() ) {
@@ -1025,7 +1031,7 @@ KonqView *KonqViewManager::setupView( KonqFrameContainerBase *parentContainer,
     sType = m_pMainWindow->currentView()->serviceType();
 
   //kDebug(1202) << "KonqViewManager::setupView creating KonqFrame with parent=" << parentContainer << endl;
-  KonqFrame* newViewFrame = new KonqFrame( parentContainer->widget(), parentContainer, "KonqFrame" );
+  KonqFrame* newViewFrame = new KonqFrame( parentContainer->asQWidget(), parentContainer );
   newViewFrame->setGeometry( 0, 0, m_pMainWindow->width(), m_pMainWindow->height() );
 
   //kDebug(1202) << "Creating KonqView" << endl;
@@ -1071,7 +1077,7 @@ void KonqViewManager::saveViewProfile( const QString & fileName, const QString &
 {
 
   QString path = KStandardDirs::locateLocal( "data", QString::fromLatin1( "konqueror/profiles/" ) +
-                                          fileName, KGlobal::instance() );
+                                          fileName, KGlobal::mainComponent() );
 
   if ( QFile::exists( path ) )
     QFile::remove( path );
@@ -1117,17 +1123,17 @@ void KonqViewManager::saveViewProfile( KConfig & cfg, bool saveURLs, bool saveWi
 
 void KonqViewManager::loadViewProfile( const QString & path, const QString & filename,
                                        const KUrl & forcedURL, const KonqOpenURLRequest &req,
-                                       bool resetWindow, bool openURL )
+                                       bool resetWindow, bool openUrl )
 {
   KConfig cfg( path, true );
   cfg.setDollarExpansion( true );
   cfg.setGroup( "Profile" );
-  loadViewProfile( cfg, filename, forcedURL, req, resetWindow, openURL );
+  loadViewProfile( cfg, filename, forcedURL, req, resetWindow, openUrl );
 }
 
 void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
                                        const KUrl & forcedURL, const KonqOpenURLRequest &req,
-                                       bool resetWindow, bool openURL )
+                                       bool resetWindow, bool openUrl )
 {
   if ( docContainer() && docContainer()->frameType()=="Tabs" )
   {
@@ -1138,7 +1144,7 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
                   i18n("You have multiple tabs open in this window.\n"
                         "Loading a view profile will close them."),
                   i18n("Confirmation"),
-                  i18n("Load View Profile"),
+                  KGuiItem(i18n("Load View Profile")),
                   "LoadProfileTabsConfirm" ) == KMessageBox::Cancel )
               return;
       }
@@ -1153,7 +1159,8 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
                 showTab( view );
                 if ( KMessageBox::warningContinueCancel( 0,
                    i18n("This tab contains changes that have not been submitted.\nLoading a profile will discard these changes."),
-                   i18n("Discard Changes?"), i18n("&Discard Changes"), "discardchangesloadprofile") != KMessageBox::Continue )
+                   i18n("Discard Changes?"), KGuiItem(i18n("&Discard Changes")), "discardchangesloadprofile") != KMessageBox::Continue )
+			/* WE: maybe KStandardGuiItem(Discard) here? */
                 {
                     showTab( originalView );
                     return;
@@ -1171,7 +1178,7 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
         if (prop.isValid() && prop.toBool())
             if ( KMessageBox::warningContinueCancel( 0,
                i18n("This page contains changes that have not been submitted.\nLoading a profile will discard these changes."),
-	       i18n("Discard Changes?"), i18n("&Discard Changes"), "discardchangesloadprofile") != KMessageBox::Continue )
+	       i18n("Discard Changes?"), KGuiItem(i18n("&Discard Changes")), "discardchangesloadprofile") != KMessageBox::Continue )
             return;
       }
   }
@@ -1191,7 +1198,8 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
 
   QString rootItem = cfg.readEntry( "RootItem", "empty" );
 
-  //kDebug(1202) << "KonqViewManager::loadViewProfile : loading RootItem " << rootItem << endl;
+  //kDebug(1202) << "KonqViewManager::loadViewProfile : loading RootItem " << rootItem <<
+  //" forcedURL " << forcedURL.url() << endl;
 
   if ( forcedURL.url() != "about:blank" )
   {
@@ -1199,7 +1207,7 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
     // from profile loading (e.g. in switchView)
     m_bLoadingProfile = true;
 
-    loadItem( cfg, m_pMainWindow, rootItem, defaultURL, openURL && forcedURL.isEmpty() );
+    loadItem( cfg, m_pMainWindow, rootItem, defaultURL, openUrl && forcedURL.isEmpty() );
 
     m_bLoadingProfile = false;
 
@@ -1215,6 +1223,8 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
     m_pMainWindow->action( "clear_location" )->trigger();
   }
 
+  //kDebug(1202) << "KonqViewManager::loadViewProfile : after loadItem " << endl;
+
   if (m_pDocContainer == 0L)
   {
     if (m_pMainWindow->currentView() &&
@@ -1227,7 +1237,7 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
   }
 
 
-    if ( m_pDocContainer->frameType() != "Tabs")
+  if ( m_pDocContainer->frameType() != "Tabs")
     convertDocContainer();
 
   static_cast<KonqFrameTabs*>( m_pDocContainer )->setAlwaysTabbedMode( alwaysTabbedMode );
@@ -1244,13 +1254,13 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
       nextChildView->setViewName( req.args.frameName );
   }
 
-  if ( openURL && !forcedURL.isEmpty())
+  if ( openUrl && !forcedURL.isEmpty())
   {
       KonqOpenURLRequest _req(req);
       _req.openAfterCurrentPage = KonqSettings::openAfterCurrentPage();
       _req.forceAutoEmbed = true; // it's a new window, let's use it
 
-      m_pMainWindow->openURL( nextChildView /* can be 0 for an empty profile */,
+      m_pMainWindow->openUrl( nextChildView /* can be 0 for an empty profile */,
                               forcedURL, _req.args.serviceType, _req, _req.args.trustedSource );
 
       // TODO choose a linked view if any (instead of just the first one),
@@ -1279,14 +1289,14 @@ void KonqViewManager::loadViewProfile( KConfig &cfg, const QString & filename,
          QSize size = readConfigSize( cfg, m_pMainWindow );
          if ( size.isValid() )
              m_pMainWindow->resize( size );
-         else if( resetWindow )
-             m_pMainWindow->resize( 700, 480 ); // size from KonqMainWindow ctor
+         else  // no size in the profile; use last known size
+             m_pMainWindow->restoreWindowSize();
      }
   }
 
   if( resetWindow )
   { // force default settings for the GUI
-     m_pMainWindow->applyMainWindowSettings( KGlobal::config(), "KonqMainWindow", true );
+     m_pMainWindow->applyMainWindowSettings( KGlobal::config().data(), "KonqMainWindow", true );
   }
 
   // Apply menu/toolbar settings saved in profile. Read from a separate group
@@ -1434,13 +1444,13 @@ QSize KonqViewManager::readConfigSize( KConfig &cfg, QWidget *widget )
 }
 
 void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
-                                const QString &name, const KUrl & defaultURL, bool openURL, bool openAfterCurrentPage )
+                                const QString &name, const KUrl & defaultURL, bool openUrl, bool openAfterCurrentPage )
 {
   QString prefix;
   if( name != "InitialView" )
     prefix = name + QLatin1Char( '_' );
 
-  //kDebug(1202) << "begin loadItem: " << name << endl;
+  //kDebug(1202) << "KonqViewManager::loadItem: begin name " << name << " openUrl " << openUrl << endl;
 
   if( name.startsWith("View") || name == "empty" ) {
     //load view config
@@ -1455,7 +1465,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
         serviceType = cfg.readEntry( QString::fromLatin1( "ServiceType" ).prepend( prefix ), QString("inode/directory"));
         serviceName = cfg.readEntry( QString::fromLatin1( "ServiceName" ).prepend( prefix ), QString() );
     }
-    //kDebug(1202) << "ServiceType: " << serviceType << " " << serviceName << endl;
+    kDebug(1202) << "KonqViewManager::loadItem: ServiceType " << serviceType << " " << serviceName << endl;
 
     KService::Ptr service;
     KService::List partServiceOffers, appServiceOffers;
@@ -1469,7 +1479,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
 
     bool passiveMode = cfg.readEntry( QString::fromLatin1( "PassiveMode" ).prepend( prefix ), false );
 
-    //kDebug(1202) << "Creating View Stuff" << endl;
+    //kDebug(1202) << "KonqViewManager::loadItem: Creating View Stuff" << endl;
     KonqView *childView = setupView( parent, viewFactory, service, partServiceOffers, appServiceOffers, serviceType, passiveMode, openAfterCurrentPage );
 
     if (!childView->isFollowActive()) childView->setLinkedView( cfg.readEntry( QString::fromLatin1( "LinkedView" ).prepend( prefix ), false ) );
@@ -1524,10 +1534,11 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
     childView->frame()->show();
 
     QString key = QString::fromLatin1( "URL" ).prepend( prefix );
-    if ( openURL )
+    if ( openUrl )
     {
       KUrl url;
 
+      //kDebug(1202) << "KonqViewManager::loadItem: key " << key << endl;
       if ( cfg.hasKey( key ) )
       {
         QString u = cfg.readPathEntry( key );
@@ -1535,36 +1546,39 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
           u = QString::fromLatin1("about:blank");
         url = u;
       }
+      else if(key == "empty_URL")
+        url = QString::fromLatin1("about:blank");
       else
         url = defaultURL;
 
       if ( !url.isEmpty() )
       {
-        //kDebug(1202) << "loadItem: calling openURL " << url.prettyUrl() << endl;
-        //childView->openURL( url, url.prettyUrl() );
+        //kDebug(1202) << "KonqViewManager::loadItem: calling openUrl " << url.prettyURL() << endl;
+        //childView->openUrl( url, url.prettyUrl() );
         // We need view-follows-view (for the dirtree, for instance)
         KonqOpenURLRequest req;
         if (url.protocol() != "about")
           req.typedUrl = url.prettyUrl();
         m_pMainWindow->openView( serviceType, url, childView, req );
       }
+      //else kDebug(1202) << "KonqViewManager::loadItem: url is empty" << endl;
     }
     // Do this after opening the URL, so that it's actually possible to open it :)
     childView->setLockedLocation( cfg.readEntry( QString::fromLatin1( "LockedLocation" ).prepend( prefix ), false ) );
   }
   else if( name.startsWith("Container") ) {
-    //kDebug(1202) << "Item is Container" << endl;
+    //kDebug(1202) << "KonqViewManager::loadItem Item is Container" << endl;
 
     //load container config
     QString ostr = cfg.readEntry( QString::fromLatin1( "Orientation" ).prepend( prefix ), QString() );
-    //kDebug(1202) << "Orientation: " << ostr << endl;
+    //kDebug(1202) << "KonqViewManager::loadItem Orientation: " << ostr << endl;
     Qt::Orientation o;
     if( ostr == "Vertical" )
       o = Qt::Vertical;
     else if( ostr == "Horizontal" )
       o = Qt::Horizontal;
     else {
-        kWarning() << "Profile Loading Error: No orientation specified in " << name << endl;
+      kWarning() << "Profile Loading Error: No orientation specified in " << name << endl;
       o = Qt::Horizontal;
     }
 
@@ -1578,11 +1592,11 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
     {
       kWarning() << "Profile Loading Error: Less than two children in " << name << endl;
       // fallback to defaults
-      loadItem( cfg, parent, "InitialView", defaultURL, openURL );
+      loadItem( cfg, parent, "InitialView", defaultURL, openUrl );
     }
     else
     {
-      KonqFrameContainer *newContainer = new KonqFrameContainer( o, parent->widget(), parent );
+      KonqFrameContainer *newContainer = new KonqFrameContainer( o, parent->asQWidget(), parent );
       connect(newContainer,SIGNAL(ctrlTabPressed()),m_pMainWindow,SLOT(slotCtrlTabPressed()));
 
       int tabindex = -1;
@@ -1594,9 +1608,10 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
       if (cfg.readEntry( QString::fromLatin1( "docContainer" ).prepend( prefix ), false ))
         m_pDocContainer = newContainer;
 
-      loadItem( cfg, newContainer, childList.at(0), defaultURL, openURL );
-      loadItem( cfg, newContainer, childList.at(1), defaultURL, openURL );
+      loadItem( cfg, newContainer, childList.at(0), defaultURL, openUrl );
+      loadItem( cfg, newContainer, childList.at(1), defaultURL, openUrl );
 
+      //kDebug(1202) << "loadItem: setSizes " << sizes << endl;
       newContainer->setSizes( sizes );
 
       if (index == 1)
@@ -1609,9 +1624,9 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
   }
   else if( name.startsWith("Tabs") )
   {
-    //kDebug(1202) << "Item is a Tabs" << endl;
+    //kDebug(1202) << "KonqViewManager::loadItem Item is a Tabs" << endl;
 
-    KonqFrameTabs *newContainer = new KonqFrameTabs( parent->widget(), parent, this );
+    KonqFrameTabs *newContainer = new KonqFrameTabs( parent->asQWidget(), parent, this );
     connect(newContainer,SIGNAL(ctrlTabPressed()),m_pMainWindow,SLOT(slotCtrlTabPressed()));
 
     parent->insertChildFrame( newContainer );
@@ -1622,7 +1637,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
     QStringList childList = cfg.readEntry( QString::fromLatin1( "Children" ).prepend( prefix ),QStringList() );
     for ( QStringList::Iterator it = childList.begin(); it != childList.end(); ++it )
     {
-        loadItem( cfg, newContainer, *it, defaultURL, openURL );
+        loadItem( cfg, newContainer, *it, defaultURL, openUrl );
         QWidget* currentPage = newContainer->currentWidget();
         if (currentPage != 0L) {
           KonqView* activeChildView = dynamic_cast<KonqFrameBase*>(currentPage)->activeChildView();
@@ -1633,7 +1648,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
         }
     }
 
-    newContainer->setActiveChild( dynamic_cast<KonqFrameBase*>(newContainer->page(index)) );
+    newContainer->setActiveChild( dynamic_cast<KonqFrameBase*>(newContainer->widget(index)) );
     newContainer->setCurrentIndex( index );
 
     newContainer->show();
@@ -1641,7 +1656,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
   else
       kWarning() << "Profile Loading Error: Unknown item " << name;
 
-  //kDebug(1202) << "end loadItem: " << name << endl;
+  //kDebug(1202) << "KonqViewManager::loadItem: end " << name << endl;
 }
 
 void KonqViewManager::setProfiles( KActionMenu *profiles )
@@ -1650,7 +1665,7 @@ void KonqViewManager::setProfiles( KActionMenu *profiles )
 
   if ( m_pamProfiles )
   {
-    connect( m_pamProfiles->popupMenu(), SIGNAL( activated( int ) ),
+    connect( m_pamProfiles->menu(), SIGNAL( activated( int ) ),
              this, SLOT( slotProfileActivated( int ) ) ); connect( m_pamProfiles->menu(), SIGNAL( aboutToShow() ),
              this, SLOT( slotProfileListAboutToShow() ) );
   }
@@ -1678,17 +1693,18 @@ void KonqViewManager::profileListDirty( bool broadcast )
     m_bProfileListDirty = true;
 #if 0
   // There's always one profile at least, now...
-  QStringList profiles = KonqFactory::instance()->dirs()->findAllResources( "data", "konqueror/profiles/*", false, true );
+  QStringList profiles = KonqFactory::componentData().dirs()->findAllResources( "data", "konqueror/profiles/*", false, true );
   if ( m_pamProfiles )
       m_pamProfiles->setEnabled( profiles.count() > 0 );
 #endif
     return;
   }
 
-#ifdef __GNUC__
-#warning port to DBUS signal updateProfileList
-#endif
-//  kapp->dcopClient()->send( "konqueror*", "KonquerorIface", "updateProfileList()", QByteArray() );
+    // Send signal to all konqueror instances
+    QDBusMessage message =
+        QDBusMessage::createSignal("/KonqMain", "org.kde.Konqueror.Main", "updateAllProfileList");
+    QDBusConnection::sessionBus().send(message);
+
 }
 
 void KonqViewManager::slotProfileActivated( int id )
@@ -1785,7 +1801,7 @@ void KonqViewManager::printSizeInfo( KonqFrameBase* frame,
                                      const char* msg )
 {
   QRect r;
-  r = frame->widget()->geometry();
+  r = frame->asQWidget()->geometry();
   qDebug("Child size %s : x: %d, y: %d, w: %d, h: %d", msg, r.x(),r.y(),r.width(),r.height() );
 
   if ( parent->frameType() == "Container" )
