@@ -88,7 +88,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
    : K3ListView(parentWidget)
    ,sortedByColumn(0)
    ,m_pBrowserView(parent)
-   ,m_dirLister(new KDirLister( true /*m_showIcons==false*/))
+   ,m_dirLister(new KDirLister())
    ,m_dragOverItem(0)
    ,m_activeItem(0)
    ,m_selected(0)
@@ -108,6 +108,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
    kDebug(1202) << "+KonqBaseListViewWidget" << endl;
 
    m_dirLister->setMainWindow(topLevelWidget());
+   m_dirLister->setDelayedMimeTypes(true);
 
    m_bTopLevelComplete  = true;
 
@@ -534,7 +535,9 @@ void KonqBaseListViewWidget::drawRubber()
 
    QPainter p;
    p.begin( viewport() );
+#ifdef __GNUC__
    #warning FIXME NotROP is not available in qt4
+#endif
 	//Using black with .5 alpha for now
 	//p.setRasterOp( NotROP );
    QColor c( 0, 0, 0, 127 );
@@ -543,7 +546,9 @@ void KonqBaseListViewWidget::drawRubber()
 
    QPoint pt( m_rubber->x(), m_rubber->y() );
    pt = contentsToViewport( pt );
+#ifdef __GNUC__
 #warning PE_FocusRect is gone, using PE_FrameFocusRect
+#endif
    QStyleOptionFocusRect fr;
    fr.backgroundColor = c;
    fr.rect = QRect( pt.x(), pt.y(), m_rubber->width(), m_rubber->height() );
@@ -737,7 +742,9 @@ void KonqBaseListViewWidget::viewportDropEvent( QDropEvent *ev  )
       setSelected( m_dragOverItem, false );
    m_dragOverItem = 0L;
 
-   ev->accept();
+   ev->acceptProposedAction();
+   ev->acceptAction();
+   kDebug() << ev->dropAction() << endl;
 
    // We dropped on an item only if we dropped on the Name column.
    KonqBaseListViewItem *item =
@@ -764,21 +771,23 @@ void KonqBaseListViewWidget::startDrag()
    if (( urls.count() > 1 ) || (pixmap0Invalid))
    {
       int iconSize = m_pBrowserView->m_pProps->iconSize();
-      iconSize = iconSize ? iconSize : KGlobal::iconLoader()->currentSize( K3Icon::Small ); // Default = small
+      iconSize = iconSize ? iconSize : KIconLoader::global()->currentSize( K3Icon::Small ); // Default = small
       pixmap2 = DesktopIcon( "kmultiple", iconSize );
       if ( pixmap2.isNull() )
           kWarning(1202) << "Could not find multiple pixmap" << endl;
    }
 
    QDrag* drag = new QDrag( viewport() );
-   KonqMimeData::populateMimeData( drag->mimeData(), urls, selectedUrls(true) );
+   QMimeData* md = new QMimeData();
+   KonqMimeData::populateMimeData( md, urls, selectedUrls(true) );
+   drag->setMimeData( md );
 
    if ( !pixmap2.isNull() )
       drag->setPixmap( pixmap2 );
    else if ( !pixmap0Invalid )
       drag->setPixmap( *m_pressedItem->pixmap( 0 ) );
 
-   drag->start();
+   drag->start(Qt::CopyAction|Qt::MoveAction|Qt::LinkAction);
 }
 
 void KonqBaseListViewWidget::slotItemRenamed( Q3ListViewItem *item, const QString &name, int col )
@@ -884,7 +893,7 @@ KUrl::List KonqBaseListViewWidget::selectedUrls( bool mostLocal )
    iterator it = begin();
    for ( ; it != end(); it++ )
       if ( it->isSelected() )
-         list.append( mostLocal ? it->item()->mostLocalURL( dummy ) : it->item()->url() );
+         list.append( mostLocal ? it->item()->mostLocalUrl( dummy ) : it->item()->url() );
    return list;
 }
 
@@ -903,7 +912,9 @@ void KonqBaseListViewWidget::slotReturnPressed( Q3ListViewItem *_item )
 
    KUrl url = fileItem->url();
    url.cleanPath();
+#ifdef __GNUC__
 #warning hardcoded protocol: find a better way to determine if a url is a trash url.
+#endif
    bool isIntoTrash = url.protocol() == "trash";
    if ( !isIntoTrash || (isIntoTrash && fileItem->isDir()) )
       m_pBrowserView->lmbClicked( fileItem );
@@ -969,7 +980,7 @@ void KonqBaseListViewWidget::updateListContents()
       it->updateContents();
 }
 
-bool KonqBaseListViewWidget::openURL( const KUrl &url )
+bool KonqBaseListViewWidget::openUrl( const KUrl &url )
 {
    kDebug(1202) << k_funcinfo << "protocol: " << url.protocol()
                                << " url: " << url.path() << endl;
@@ -1001,7 +1012,7 @@ bool KonqBaseListViewWidget::openURL( const KUrl &url )
    {
       args.xOffset = contentsX();
       args.yOffset = contentsY();
-      m_pBrowserView->extension()->setURLArgs( args );
+      m_pBrowserView->extension()->setUrlArgs( args );
 
       if ( currentItem() && itemRect( currentItem() ).isValid() )
          m_itemToGoTo = currentItem()->text(0);
@@ -1024,7 +1035,7 @@ bool KonqBaseListViewWidget::openURL( const KUrl &url )
    m_bUpdateContentsPosAfterListing = true;
 
    // Start the directory lister !
-   m_dirLister->openURL( url, false /* new url */, args.reload );
+   m_dirLister->openUrl( url, false /* new url */, args.reload );
 
    // Apply properties and reflect them on the actions
    // do it after starting the dir lister to avoid changing the properties
@@ -1035,7 +1046,7 @@ bool KonqBaseListViewWidget::openURL( const KUrl &url )
       m_pBrowserView->m_paShowDot->setChecked( m_pBrowserView->m_pProps->isShowingDotFiles() );
       if ( m_pBrowserView->m_paCaseInsensitive->isChecked() != m_pBrowserView->m_pProps->isCaseInsensitiveSort() ) {
           m_pBrowserView->m_paCaseInsensitive->setChecked( m_pBrowserView->m_pProps->isCaseInsensitiveSort() );
-          // This is in case openURL returned all items synchronously.
+          // This is in case openUrl returned all items synchronously.
           sort();
       }
 
@@ -1171,6 +1182,10 @@ void KonqBaseListViewWidget::slotNewItems( const KFileItemList & entries )
 
 void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
 {
+  KFileItemList list;
+  list.append(_fileitem);
+  emit m_pBrowserView->extension()->itemsRemoved(list);
+
   iterator it = begin();
   for( ; it != end(); ++it )
     if ( (*it).item() == _fileitem )
@@ -1236,7 +1251,7 @@ void KonqBaseListViewWidget::slotRedirection( const KUrl & url )
       createColumns();
    }
    const QString prettyURL = url.pathOrUrl();
-   emit m_pBrowserView->extension()->setLocationBarURL( prettyURL );
+   emit m_pBrowserView->extension()->setLocationBarUrl( prettyURL );
    emit m_pBrowserView->setWindowCaption( prettyURL );
    m_pBrowserView->m_url = url;
    m_url = url;
