@@ -26,27 +26,27 @@
 #define __MAIN_H__
 
 #include <kcmodule.h>
-//Added by qt3to4:
-#include <Q3PtrList>
+#include <QList>
 
-class KURIFilter;
+class KUriFilter;
 
 class KURIFilterModule : public KCModule {
     Q_OBJECT
 
 public:
     KURIFilterModule(QWidget *parent, const QStringList &);
+    ~KURIFilterModule();
 
     void load();
     void save();
     void defaults();
 
 private:
-    KURIFilter *filter;
+    KUriFilter *filter;
 
     QWidget *widget;
     FilterOptions *opts;
-    Q3PtrList<KCModule> modules;
+    QList<KCModule *> modules;
 };
 
 #endif
