@@ -29,6 +29,7 @@
 #include <QPushButton>
 #include <q3buttongroup.h>
 #include <QTabWidget>
+#include <QDBusInterface>
 
 //Added by qt3to4:
 #include <QVBoxLayout>
@@ -43,15 +44,18 @@
 #include <kapplication.h>
 #include <kcustommenueditor.h>
 #include <konq_defaults.h> // include default values directly from libkonq
-#include <kipc.h>
 #include <kprotocolinfo.h>
 #include "konqkcmfactory.h"
 
+#ifdef Q_WS_X11
+#include "kdesktop_interface.h"
+#endif
+
 typedef KonqKcmFactory<DesktopBehaviorModule> DesktopBehaviorModuleFactory;
 K_EXPORT_COMPONENT_FACTORY(dbehavior, DesktopBehaviorModuleFactory)
 
 DesktopBehaviorModule::DesktopBehaviorModule(QWidget *parent, const QStringList &)
-    : KCModule( _globalInstance(), parent )
+    : KCModule( KonqKcmFactory<DesktopBehaviorModule>::componentData(), parent )
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig(_desktopConfigName(), false, false);
     QVBoxLayout* layout = new QVBoxLayout(this);
@@ -117,8 +121,8 @@ private:
 static const int choiceCount=7;
 static const char * s_choices[7] = { "", "WindowListMenu", "DesktopMenu", "AppMenu", "BookmarksMenu", "CustomMenu1", "CustomMenu2" };
 
-DesktopBehavior::DesktopBehavior(KSharedConfig::Ptr config, QWidget *parent, const char * )
-    : DesktopBehaviorBase( parent, "kcmkonq" ), g_pConfig(config)
+DesktopBehavior::DesktopBehavior(KSharedConfig::Ptr config, QWidget *parent )
+    : DesktopBehaviorBase( parent ), g_pConfig(config)
 {
   QString strMouseButton1, strMouseButton3, strButtonTxt1, strButtonTxt3;
 
@@ -377,7 +381,7 @@ void DesktopBehavior::save()
     {
         config->writeEntry( "macStyle", globalMenuBar, KConfigBase::Normal | KConfigBase::Global );
         config->sync();
-        KIPC::sendMessageAll(KIPC::ToolbarStyleChanged);
+        KGlobalSettings::self()->emitChange(KGlobalSettings::ToolbarStyleChanged);
     }
     g_pConfig->setGroup( "Mouse Buttons" );
     g_pConfig->writeEntry("Left", s_choices[ leftComboBox->currentIndex() ] );
@@ -391,23 +395,29 @@ void DesktopBehavior::save()
 
     saveMediaListView();
     g_pConfig->sync();
-
+#ifdef Q_WS_X11
     // Tell kdesktop about the new config file
     int konq_screen_number = KApplication::desktop()->primaryScreen();
     QByteArray appname;
     if (konq_screen_number == 0)
-        appname = "kdesktop";
+        appname = "org.kde.kdesktop";
     else
-        appname = "kdesktop-screen-"+QByteArray::number( konq_screen_number);
+        appname = "org.kde.kdesktop-screen-"+QByteArray::number( konq_screen_number);
+    org::kde::kdesktop::Desktop desktop(appname, "/Desktop", QDBusConnection::sessionBus());
+    desktop.configure();    
+ 
+    // Send signal to all kwin instances
+    QDBusMessage message =
+        QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig");
+    QDBusConnection::sessionBus().send(message);
+#endif
 #ifdef __GNUC__
-#warning Emit DBus signal, and commit kicker/kwin/kdesktop/plasma/whatever to it
+#warning Emit DBus signal, and commit kicker/plasma/whatever to it
 #endif
 #if 0
-    kapp->dcopClient()->send( appname, "KDesktopIface", "configure()", data );
     // for the standalone menubar setting
     kapp->dcopClient()->send( "menuapplet*", "menuapplet", "configure()", data );
     kapp->dcopClient()->send( "kicker", "kicker", "configureMenubar()", data );
-    kapp->dcopClient()->send( "kwin*", "", "reconfigure()", data );
 #endif
 }
 
