@@ -14,6 +14,8 @@
 #include <QSlider>
 #include <q3groupbox.h>
 #include <QTextStream>
+#include <QDBusMessage>
+#include <QDBusConnection>
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -49,14 +51,12 @@ typedef KGenericFactory<KPluginOptions, QWidget> KPluginOptionsFactory;
 K_EXPORT_COMPONENT_FACTORY( khtml_plugins, KPluginOptionsFactory("kcmkonqhtml") )
 
 KPluginOptions::KPluginOptions( QWidget *parent, const QStringList& )
-    : KCModule( KPluginOptionsFactory::instance(), parent ),
+    : KCModule( KPluginOptionsFactory::componentData(), parent ),
       m_pConfig( KSharedConfig::openConfig( "konquerorrc", false, false ) ),
       m_groupname( "Java/JavaScript Settings" ),
       global_policies(m_pConfig,m_groupname,true)
 {
     QVBoxLayout* toplevel = new QVBoxLayout( this );
-    toplevel->setSpacing( 0 /* KDialog::spacingHint() */ );
-    toplevel->setMargin(0);
 
     /**************************************************************************
      ******************** Global Settings *************************************
@@ -214,15 +214,15 @@ void KPluginOptions::load()
   KSharedConfig::Ptr config = KSharedConfig::openConfig("kcmnspluginrc", true);
 
   config->setGroup("Misc");
-  m_widget->scanAtStartup->setChecked( config->readEntry( "startkdeScan", QVariant(false )).toBool() );
+  m_widget->scanAtStartup->setChecked( config->readEntry( "startkdeScan", false) );
 
   m_widget->dirEdit->setUrl(KUrl());
   m_widget->dirEdit->setEnabled( false );
   m_widget->dirRemove->setEnabled( false );
   m_widget->dirUp->setEnabled( false );
   m_widget->dirDown->setEnabled( false );
-  enableHTTPOnly->setChecked( config->readEntry("HTTP URLs Only", QVariant(false)).toBool() );
-  enableUserDemand->setChecked( config->readEntry("demandLoad", QVariant(false)).toBool() );
+  enableHTTPOnly->setChecked( config->readEntry("HTTP URLs Only", false) );
+  enableUserDemand->setChecked( config->readEntry("demandLoad", false) );
   priority->setValue(100 - qBound(0, config->readEntry("Nice Level", 0), 19) * 5);
   updatePLabel(priority->value());
 
@@ -250,7 +250,7 @@ void KPluginOptions::defaults()
     m_widget->dirEdit->setEnabled( false );
     m_widget->dirRemove->setEnabled( false );
 
-    dirLoad( config );
+    dirLoad( config, true );
     pluginLoad( config );
 
     change();
@@ -264,10 +264,11 @@ void KPluginOptions::save()
 
     m_pConfig->sync();	// I need a sync here, otherwise "apply" won't work
     			// instantly
-#warning "kde4: port to dbus call konqueror*"
-#if 0
-  kapp->dcopClient()->send( "konqueror*", "KonquerorIface", "reparseConfiguration()", data );
-#endif
+    // Send signal to all konqueror instances
+    QDBusMessage message =
+        QDBusMessage::createSignal("/KonqMain", "org.kde.Konqueror.Main", "reparseConfiguration");
+    QDBusConnection::sessionBus().send(message);
+
 /*****************************************************************************/
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig("kcmnspluginrc", false);
@@ -315,7 +316,7 @@ void KPluginOptions::scan()
         int ret = KMessageBox::warningYesNoCancel( this,
                                                     i18n("Do you want to apply your changes "
                                                          "before the scan? Otherwise the "
-                                                         "changes will be lost."), QString(), KStdGuiItem::save(), KStdGuiItem::discard() );
+                                                         "changes will be lost."), QString(), KStandardGuiItem::save(), KStandardGuiItem::discard() );
         if ( ret==KMessageBox::Cancel ) {
             m_widget->scanButton->setEnabled(true);
             return;
@@ -326,7 +327,6 @@ void KPluginOptions::scan()
 
     KProcIO* nspluginscan = new KProcIO;
     QString scanExe = KGlobal::dirs()->findExe("nspluginscan");
-#warning !QString? i guess that meant isEmpty?
     if (scanExe.isEmpty()) {
         kDebug() << "can't find nspluginviewer" << endl;
         delete nspluginscan;
@@ -395,27 +395,28 @@ void KPluginOptions::dirInit()
              SLOT(dirEdited(const QString &)) );
 
     connect( m_widget->dirList,
-             SIGNAL(executed(Q3ListBoxItem*)),
-             SLOT(dirSelect(Q3ListBoxItem*)) );
+             SIGNAL(executed(QListWidgetItem*)),
+             SLOT(dirSelect(QListWidgetItem*)) );
 
     connect( m_widget->dirList,
-             SIGNAL(selectionChanged(Q3ListBoxItem*)),
-             SLOT(dirSelect(Q3ListBoxItem*)) );
+             SIGNAL(selectionChanged(QListWidgetItem*)),
+             SLOT(dirSelect(QListWidgetItem*)) );
 }
 
 
-void KPluginOptions::dirLoad( KSharedConfig::Ptr config )
+void KPluginOptions::dirLoad( KSharedConfig::Ptr config, bool useDefault )
 {
     QStringList paths;
 
     // read search paths
 
     config->setGroup("Misc");
-    if ( config->hasKey( "scanPaths" ) )
+    if ( config->hasKey( "scanPaths" ) && !useDefault )
         paths = config->readEntry( "scanPaths" , QStringList() );
     else {//keep sync with kdebase/nsplugins/pluginscan
         paths.append("$HOME/.mozilla/plugins");
         paths.append("$HOME/.netscape/plugins");
+	paths.append("/usr/lib/firefox/plugins");
         paths.append("/usr/lib64/browser-plugins");
         paths.append("/usr/lib/browser-plugins");
         paths.append("/usr/local/netscape/plugins");
@@ -434,10 +435,10 @@ void KPluginOptions::dirLoad( KSharedConfig::Ptr config )
 
     // fill list
     m_widget->dirList->clear();
-    m_widget->dirList->insertStringList( paths );
+    m_widget->dirList->addItems( paths );
 
     // setup other widgets
-    bool useArtsdsp = config->readEntry( "useArtsdsp", QVariant(false )).toBool();
+    bool useArtsdsp = config->readEntry( "useArtsdsp", false);
     m_widget->useArtsdsp->setChecked( useArtsdsp );
 }
 
@@ -446,10 +447,11 @@ void KPluginOptions::dirSave( KSharedConfig::Ptr config )
 {
     // create stringlist
     QStringList paths;
-    Q3ListBoxItem *item = m_widget->dirList->firstItem();
-    for ( ; item!=0; item=item->next() )
-        if ( !item->text().isEmpty() )
-            paths << item->text();
+    
+    for ( int rowIndex = 0 ; rowIndex < m_widget->dirList->count() ; rowIndex++ ) {
+        if ( !m_widget->dirList->item(rowIndex)->text().isEmpty() )
+            paths << m_widget->dirList->item(rowIndex)->text();
+    }
 
     // write entry
     config->setGroup( "Misc" );
@@ -458,12 +460,12 @@ void KPluginOptions::dirSave( KSharedConfig::Ptr config )
 }
 
 
-void KPluginOptions::dirSelect( Q3ListBoxItem *item )
+void KPluginOptions::dirSelect( QListWidgetItem *item )
 {
     m_widget->dirEdit->setEnabled( item!=0 );
     m_widget->dirRemove->setEnabled( item!=0 );
 
-    unsigned cur = m_widget->dirList->index(m_widget->dirList->selectedItem());
+    int cur = m_widget->dirList->currentRow();
     m_widget->dirDown->setEnabled( item!=0 && cur<m_widget->dirList->count()-1 );
     m_widget->dirUp->setEnabled( item!=0 && cur>0 );
     m_widget->dirEdit->setUrl( item!=0 ? item->text() : QString() );
@@ -472,9 +474,9 @@ void KPluginOptions::dirSelect( Q3ListBoxItem *item )
 
 void KPluginOptions::dirNew()
 {
-    m_widget->dirList->insertItem( QString(), 0 );
-    m_widget->dirList->setCurrentItem( 0 );
-    dirSelect( m_widget->dirList->selectedItem() );
+    m_widget->dirList->insertItem( 0 , QString() );
+    m_widget->dirList->setCurrentRow( 0 );
+    dirSelect( m_widget->dirList->currentItem() );
     m_widget->dirEdit->setUrl(QString());
     m_widget->dirEdit->setFocus();
     change();
@@ -484,7 +486,7 @@ void KPluginOptions::dirNew()
 void KPluginOptions::dirRemove()
 {
     m_widget->dirEdit->setUrl(QString());
-    delete m_widget->dirList->selectedItem();
+    delete m_widget->dirList->currentItem();
     m_widget->dirRemove->setEnabled( false );
     m_widget->dirUp->setEnabled( false );
     m_widget->dirDown->setEnabled( false );
@@ -495,11 +497,11 @@ void KPluginOptions::dirRemove()
 
 void KPluginOptions::dirUp()
 {
-    unsigned cur = m_widget->dirList->index(m_widget->dirList->selectedItem());
+    int cur = m_widget->dirList->currentRow();
     if ( cur>0 ) {
-        QString txt = m_widget->dirList->text(cur-1);
-        m_widget->dirList->removeItem( cur-1 );
-        m_widget->dirList->insertItem( txt, cur );
+        QString txt = m_widget->dirList->item(cur-1)->text();
+        delete m_widget->dirList->takeItem( cur-1 );
+        m_widget->dirList->insertItem( cur , txt );
 
         m_widget->dirUp->setEnabled( cur-1>0 );
         m_widget->dirDown->setEnabled( true );
@@ -510,11 +512,11 @@ void KPluginOptions::dirUp()
 
 void KPluginOptions::dirDown()
 {
-    unsigned cur = m_widget->dirList->index(m_widget->dirList->selectedItem());
+    int cur = m_widget->dirList->currentRow();
     if ( cur < m_widget->dirList->count()-1 ) {
-        QString txt = m_widget->dirList->text(cur+1);
-        m_widget->dirList->removeItem( cur+1 );
-        m_widget->dirList->insertItem( txt, cur );
+        QString txt = m_widget->dirList->item(cur+1)->text();
+        delete m_widget->dirList->takeItem( cur+1 );
+        m_widget->dirList->insertItem( cur , txt );
 
         m_widget->dirUp->setEnabled( true );
         m_widget->dirDown->setEnabled( cur+1<m_widget->dirList->count()-1 );
@@ -525,9 +527,9 @@ void KPluginOptions::dirDown()
 
 void KPluginOptions::dirEdited(const QString &txt )
 {
-    if ( m_widget->dirList->currentText() != txt ) {
+    if ( m_widget->dirList->currentItem()->text() != txt ) {
         m_widget->dirList->blockSignals(true);
-        m_widget->dirList->changeItem( txt, m_widget->dirList->currentItem() );
+        m_widget->dirList->currentItem()->setText(txt);
         m_widget->dirList->blockSignals(false);
         change();
     }
@@ -644,7 +646,7 @@ PluginDomainDialog::PluginDomainDialog(QWidget *parent) :
   hl->setMargin(0);
   hl->addStretch(10);
 
-  QPushButton *closePB = new KPushButton(KStdGuiItem::close(),this);
+  QPushButton *closePB = new KPushButton(KStandardGuiItem::close(),this);
   connect(closePB,SIGNAL(clicked()),SLOT(slotClose()));
   hl->addWidget(closePB);
   thisLayout->addLayout(hl);
