@@ -23,7 +23,7 @@
 #include <QLayout>
 #include <QStringList>
 #include <QSplitter>
-#include <Q3PopupMenu>
+#include <QMenu>
 
 #include <klocale.h>
 #include <ksimpleconfig.h>
@@ -38,7 +38,7 @@
 #include <kio/netaccess.h>
 #include <kmenu.h>
 #include <kprocess.h>
-#include <kurlrequesterdlg.h>
+#include <kurlrequesterdialog.h>
 #include <kinputdialog.h>
 #include <kfiledialog.h>
 #include <kdesktopfile.h>
@@ -65,7 +65,9 @@ void addBackEnd::aboutToShowAddMenu()
 	if (!menu)
 		return;
 	KStandardDirs *dirs = KGlobal::dirs();
-	QStringList list = dirs->findAllResources("data","konqsidebartng/add/*.desktop",true,true);
+	QStringList list = dirs->findAllResources("data","konqsidebartng/add/*.desktop",
+						KStandardDirs::Recursive |
+						KStandardDirs::NoDuplicates);
 	menu->clear();
 	int i = 0;
 
@@ -261,9 +263,11 @@ Sidebar_Widget::Sidebar_Widget(QWidget *parent, KParts::ReadOnlyPart *par, bool
 	m_buttonBar->showActiveTabTexts(true);
 
 	// Ported to QMenu already, just needs to have KMultiTabBar fixed
+#ifdef __GNUC__
 #warning switch to QMenu when KMultiTabBar ported
-	m_menu = new Q3PopupMenu(this);
-	m_menu->setIcon(SmallIconSet("configure"));
+#endif	
+	m_menu = new QMenu(this);
+	m_menu->setIcon(KIcon("configure"));
 	m_menu->setTitle(i18n("Configure Navigation Panel"));
 
 	QMenu *addMenu = m_menu->addMenu(i18n("Add New"));
@@ -273,7 +277,7 @@ Sidebar_Widget::Sidebar_Widget(QWidget *parent, KParts::ReadOnlyPart *par, bool
 	m_menu->addAction(i18n("Show Configuration Button"), this, SLOT(slotShowConfigurationButton()));
 	if (!m_universalMode) {
 		m_menu->addSeparator();
-		m_menu->addAction(SmallIconSet("remove"), i18n("Close Navigation Panel"),
+		m_menu->addAction(KIcon("remove"), i18n("Close Navigation Panel"),
 				par, SLOT(deleteLater()));
 	}
         connect(m_menu, SIGNAL(aboutToShow()),
@@ -489,19 +493,19 @@ void Sidebar_Widget::slotSetName( )
 
 void Sidebar_Widget::slotSetURL( )
 {
-	KUrlRequesterDlg dlg( m_currentButton->URL, i18n("Enter a URL:"), this );
+	KUrlRequesterDialog dlg( m_currentButton->URL, i18n("Enter a URL:"), this );
 	dlg.fileDialog()->setMode( KFile::Directory );
 	if (dlg.exec())
 	{
 		KSimpleConfig ksc(m_path+m_currentButton->file);
 		ksc.setGroup("Desktop Entry");
-		if ( !dlg.selectedURL().isValid())
+		if ( !dlg.selectedUrl().isValid())
 		{
-			KMessageBox::error(this, i18n("<qt><b>%1</b> does not exist</qt>", dlg.selectedURL().url()));
+			KMessageBox::error(this, i18n("<qt><b>%1</b> does not exist</qt>", dlg.selectedUrl().url()));
 		}
 		else
 		{
-			QString newurl= dlg.selectedURL().prettyUrl();
+			QString newurl= dlg.selectedUrl().prettyUrl();
 			//If we are going to set the name by 'set name', we don't set it here.
 			//ksc.writeEntry("Name",newurl);
 			ksc.writePathEntry("URL",newurl);
@@ -529,7 +533,7 @@ void Sidebar_Widget::slotSetIcon( )
 void Sidebar_Widget::slotRemove()
 {
 	if (KMessageBox::warningContinueCancel(this,i18n("<qt>Do you really want to remove the <b>%1</b> tab?</qt>", m_currentButton->displayName),
-		QString(),KStdGuiItem::del())==KMessageBox::Continue)
+		QString(),KStandardGuiItem::del())==KMessageBox::Continue)
 	{
 		QFile f(m_path+m_currentButton->file);
 		if (!f.remove())
@@ -612,10 +616,10 @@ void Sidebar_Widget::slotShowConfigurationButton( )
 }
 void Sidebar_Widget::readConfig()
 {
-	m_singleWidgetMode = m_config->readEntry("SingleWidgetMode", QVariant(true)).toBool();
-	m_showExtraButtons = m_config->readEntry("ShowExtraButtons", QVariant(false)).toBool();
-	m_showTabsLeft = m_config->readEntry("ShowTabsLeft", QVariant(true)).toBool();
-	m_hideTabs = m_config->readEntry("HideTabs", QVariant(false)).toBool();
+	m_singleWidgetMode = m_config->readEntry("SingleWidgetMode", true);
+	m_showExtraButtons = m_config->readEntry("ShowExtraButtons", false);
+	m_showTabsLeft = m_config->readEntry("ShowTabsLeft", true);
+	m_hideTabs = m_config->readEntry("HideTabs", false);
 	if (m_initial) {
 		m_openViews = m_config->readEntry("OpenViews",QStringList());
 		m_savedWidth = m_config->readEntry("SavedWidth",200);
@@ -716,7 +720,7 @@ void Sidebar_Widget::createButtons()
         m_noUpdate=false;
 }
 
-bool Sidebar_Widget::openURL(const class KUrl &url)
+bool Sidebar_Widget::openUrl(const class KUrl &url)
 {
 	if (url.protocol()=="sidebar")
 	{
@@ -742,7 +746,7 @@ bool Sidebar_Widget::openURL(const class KUrl &url)
 			if ((button->dock->isVisibleTo(this)) && (button->module))
 			{
 				ret = true;
-				button->module->openURL(url);
+				button->module->openUrl(url);
 			}
 		}
 	}
@@ -814,11 +818,11 @@ bool Sidebar_Widget::eventFilter(QObject *obj, QEvent *ev)
 				{
 					m_buttonPopup=new KMenu(this);
 					m_buttonPopupTitle = m_buttonPopup->addTitle(SmallIcon("unknown"), "");
-					m_buttonPopup->addAction(SmallIconSet("text"), i18n("Set Name..."), this, SLOT(slotSetName())); // Item to open a dialog to change the name of the sidebar item (by Pupeno)
-					m_buttonPopup->addAction(SmallIconSet("www"), i18n("Set URL..."), this, SLOT(slotSetURL()));
-					m_buttonPopup->addAction(SmallIconSet("icons"), i18n("Set Icon..."), this, SLOT(slotSetIcon()));
+					m_buttonPopup->addAction(KIcon("text"), i18n("Set Name..."), this, SLOT(slotSetName())); // Item to open a dialog to change the name of the sidebar item (by Pupeno)
+					m_buttonPopup->addAction(KIcon("www"), i18n("Set URL..."), this, SLOT(slotSetURL()));
+					m_buttonPopup->addAction(KIcon("icons"), i18n("Set Icon..."), this, SLOT(slotSetIcon()));
 					m_buttonPopup->addSeparator();
-					m_buttonPopup->addAction(SmallIconSet("editdelete"), i18n("Remove"), this, SLOT(slotRemove()));
+					m_buttonPopup->addAction(KIcon("editdelete"), i18n("Remove"), this, SLOT(slotRemove()));
 					m_buttonPopup->addSeparator();
 					m_buttonPopup->addMenu(m_menu);
 				}
@@ -856,8 +860,8 @@ KonqSidebarPlugin *Sidebar_Widget::loadModule(QWidget *par,QString &desktopName,
 		{
 			// create the module
 
-			KonqSidebarPlugin* (*func)(KInstance*,QObject *, QWidget*, QString&, const char *);
-			func = (KonqSidebarPlugin* (*)(KInstance*,QObject *, QWidget *, QString&, const char *)) create;
+			KonqSidebarPlugin* (*func)(const KComponentData &,QObject *, QWidget*, QString&, const char *);
+			func = (KonqSidebarPlugin* (*)(const KComponentData &,QObject *, QWidget *, QString&, const char *)) create;
 			QString fullPath(m_path+desktopName);
 			return  (KonqSidebarPlugin*)func(getInstance(),bi,par,fullPath,0);
 		}
@@ -950,7 +954,7 @@ void Sidebar_Widget::showHidePage(int page)
 			info->dock->show();
 
 			if (m_hasStoredUrl)
-				info->module->openURL(m_storedUrl);
+				info->module->openUrl(m_storedUrl);
 			m_visibleViews<<info->file;
 			m_latestViewed=page;
 		}
@@ -974,7 +978,7 @@ void Sidebar_Widget::showHidePage(int page)
 			info->dock->show();
 			m_latestViewed = page;
 			if (m_hasStoredUrl)
-				info->module->openURL(m_storedUrl);
+				info->module->openUrl(m_storedUrl);
 			m_visibleViews << info->file;
 			m_buttonBar->setTab(page,true);
 		} else {
@@ -1037,7 +1041,7 @@ void Sidebar_Widget::dockWidgetHasUndocked(K3DockWidget* wid)
 	}
 }
 
-KInstance  *Sidebar_Widget::getInstance()
+const KComponentData &Sidebar_Widget::getInstance()
 {
 	return ((KonqSidebar*)m_partParent)->getInstance();
 }
@@ -1055,12 +1059,12 @@ KParts::URLArgs args;
 	args.postData = formData;
 	args.setDoPost(QByteArray(action).toLower() == "post");
 	// boundary?
-	emit getExtension()->openURLRequest(KUrl( url ), args);
+	emit getExtension()->openUrlRequest(KUrl( url ), args);
 }
 
-void Sidebar_Widget::openURLRequest( const KUrl &url, const KParts::URLArgs &args)
+void Sidebar_Widget::openUrlRequest( const KUrl &url, const KParts::URLArgs &args)
 {
-	getExtension()->openURLRequest(url,args);
+	getExtension()->openUrlRequest(url,args);
 }
 
 void Sidebar_Widget::createNewWindow( const KUrl &url, const KParts::URLArgs &args)
@@ -1174,9 +1178,9 @@ void Sidebar_Widget::connectModule(QObject *mod)
 			this,SLOT(popupMenu( const QPoint &, const KFileItemList & )));
 	}
 
-	if (mod->metaObject()->indexOfSignal("openURLRequest(KUrl,KParts::URLArgs)") != -1) {
-		connect(mod,SIGNAL(openURLRequest( const KUrl &, const KParts::URLArgs &)),
-			this,SLOT(openURLRequest( const KUrl &, const KParts::URLArgs &)));
+	if (mod->metaObject()->indexOfSignal("openUrlRequest(KUrl,KParts::URLArgs)") != -1) {
+		connect(mod,SIGNAL(openUrlRequest( const KUrl &, const KParts::URLArgs &)),
+			this,SLOT(openUrlRequest( const KUrl &, const KParts::URLArgs &)));
 	}
 
 	if (mod->metaObject()->indexOfSignal("submitFormRequest(const char*,QString,QByteArray,QString,QString,QString)") != -1) {
