@@ -44,7 +44,7 @@ KonqSidebarDirTreeModule::KonqSidebarDirTreeModule( KonqSidebarTree * parentTree
 
     KConfig * config = new KConfig( universalMode ? "konqsidebartng_kicker.rc" : "konqsidebartng.rc" );
     config->setGroup("");
-    m_showArchivesAsFolders = config->readEntry("ShowArchivesAsFolders", QVariant(true)).toBool();
+    m_showArchivesAsFolders = config->readEntry("ShowArchivesAsFolders", true);
     delete config;
 }
 
@@ -85,7 +85,7 @@ void KonqSidebarDirTreeModule::addTopLevelItem( KonqSidebarTreeTopLevelItem * it
 
     if ( cfg.hasLinkType() )
     {
-        targetURL = cfg.readURL();
+        targetURL = cfg.readUrl();
 		// some services might want to make their URL configurable in kcontrol
 		QString configured = cfg.readEntry("X-KDE-ConfiguredURL");
 		if (!configured.isEmpty()) {
@@ -301,7 +301,8 @@ void KonqSidebarDirTreeModule::openSubFolder( KonqSidebarTreeItem *item )
 
     if ( !m_dirLister ) // created on demand
     {
-        m_dirLister = new KDirLister( true );
+        m_dirLister = new KDirLister();
+        //m_dirLister->setDelayedMimeTypes( true ); // this was set, but it's wrong, without a KMimeTypeResolver...
         //m_dirLister->setDirOnlyMode( true );
 //	QStringList mimetypes;
 //	mimetypes<<QString("inode/directory");
@@ -325,7 +326,7 @@ void KonqSidebarDirTreeModule::openSubFolder( KonqSidebarTreeItem *item )
     if ( !item->isTopLevelItem() &&
          static_cast<KonqSidebarDirTreeItem *>(item)->hasStandardIcon() )
     {
-        int size = KGlobal::iconLoader()->currentSize( K3Icon::Small );
+        int size = KIconLoader::global()->currentSize( K3Icon::Small );
         QPixmap pix = DesktopIcon( "folder_open", size );
         m_pTree->startAnimation( item, "kde", 6, &pix );
     }
@@ -358,7 +359,7 @@ void KonqSidebarDirTreeModule::listDirectory( KonqSidebarTreeItem *item )
     {
        // We have this directory listed already, just copy the entries as we
        // can't use the dirlister, it would invalidate the old entries
-       int size = KGlobal::iconLoader()->currentSize( K3Icon::Small );
+       int size = KIconLoader::global()->currentSize( K3Icon::Small );
        KonqSidebarTreeItem * parentItem = item;
        KonqSidebarDirTreeItem *oldItem = static_cast<KonqSidebarDirTreeItem *> (openItem->firstChild());
        while(oldItem)
@@ -394,7 +395,7 @@ void KonqSidebarDirTreeModule::listDirectory( KonqSidebarTreeItem *item )
     if (tree()->isOpeningFirstChild()) m_dirLister->setAutoErrorHandlingEnabled(false,0);
 	else m_dirLister->setAutoErrorHandlingEnabled(true,tree());
 
-    m_dirLister->openURL( url, true /*keep*/ );
+    m_dirLister->openUrl( url, true /*keep*/ );
 }
 
 void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
@@ -426,7 +427,7 @@ void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
     }
 
     kDebug()<<"number of additional parent items:"<< (parentItemList?parentItemList->count():0)<<endl;
-    int size = KGlobal::iconLoader()->currentSize( K3Icon::Small );
+    int size = KIconLoader::global()->currentSize( K3Icon::Small );
     do
     {
     	kDebug()<<"Parent Item URL:"<<parentItem->externalURL()<<endl;
@@ -462,7 +463,7 @@ void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
 
 void KonqSidebarDirTreeModule::slotRefreshItems( const KFileItemList &entries )
 {
-    int size = KGlobal::iconLoader()->currentSize( K3Icon::Small );
+    int size = KIconLoader::global()->currentSize( K3Icon::Small );
 
     kDebug(1201) << "KonqSidebarDirTreeModule::slotRefreshItems " << entries.count() << " entries. First: " << entries.first()->url().url() << endl;
 
