@@ -95,7 +95,7 @@ void KonqSidebarTree::loadModuleFactories()
   pluginFactories.clear();
   pluginInfo.clear();
   KStandardDirs *dirs=KGlobal::dirs();
-  QStringList list=dirs->findAllResources("data","konqsidebartng/dirtree/*.desktop",false,true);
+  QStringList list=dirs->findAllResources("data","konqsidebartng/dirtree/*.desktop",KStandardDirs::NoDuplicates);
 
 
   for (QStringList::ConstIterator it=list.begin();it!=list.end();++it)
@@ -198,7 +198,7 @@ KonqSidebarTree::KonqSidebarTree( KonqSidebar_Tree *parent, QWidget *parentWidge
 
     setFrameStyle( QFrame::ToolBarPanel | QFrame::Raised );
 
-    OrgKdeKDirNotifyInterface *kdirnotify = new OrgKdeKDirNotifyInterface(QString(), QString(), QDBus::sessionBus());
+    OrgKdeKDirNotifyInterface *kdirnotify = new OrgKdeKDirNotifyInterface(QString(), QString(), QDBusConnection::sessionBus());
     kdirnotify->setParent(this);
     connect(kdirnotify, SIGNAL(FilesAdded(QString)), SLOT(slotFilesAdded(QString)));
     connect(kdirnotify, SIGNAL(FilesChanged(QStringList)), SLOT(slotFilesChanged(QStringList)));
@@ -392,7 +392,7 @@ void KonqSidebarTree::addUrl(KonqSidebarTreeTopLevelItem* item, const KUrl & url
     {
        QString filename = findUniqueFilename(path, url.fileName());
        destUrl.setPath(filename);
-       KIO::NetAccess::copy(url, destUrl, this);
+       KIO::NetAccess::file_copy(url, destUrl, this);
     }
     else
     {
@@ -408,7 +408,7 @@ void KonqSidebarTree::addUrl(KonqSidebarTreeTopLevelItem* item, const KUrl & url
        cfg.writeEntry("URL", url.url());
        QString icon = "folder";
        if (!url.isLocalFile())
-          icon = KMimeType::favIconForURL(url);
+          icon = KMimeType::favIconForUrl(url);
        if (icon.isEmpty())
           icon = KProtocolInfo::icon( url.protocol() );
        cfg.writeEntry("Icon", icon);
@@ -496,7 +496,7 @@ void KonqSidebarTree::slotExecuted( Q3ListViewItem *item )
     args.trustedSource = true;
     KUrl externalURL = dItem->externalURL();
     if ( !externalURL.isEmpty() )
-	openURLRequest( externalURL, args );
+	openUrlRequest( externalURL, args );
 }
 
 void KonqSidebarTree::slotMouseButtonPressed( int _button, Q3ListViewItem* _item, const QPoint&, int col )
@@ -702,7 +702,7 @@ void KonqSidebarTree::scanDir( KonqSidebarTreeItem *parent, const QString &path,
         QString filePath = QString( *eIt ).prepend( path );
         KUrl u;
         u.setPath( filePath );
-        if ( KMimeType::findByURL( u, 0, true )->name() == "application/x-desktop" )
+        if ( KMimeType::findByUrl( u, 0, true )->name() == "application/x-desktop" )
             loadTopLevelItem( parent, filePath );
     }
 
@@ -739,7 +739,7 @@ void KonqSidebarTree::loadTopLevelGroup( KonqSidebarTreeItem *parent, const QStr
         name = cfg.readEntry( "Name", name );
         icon = cfg.readEntry( "Icon", icon );
         //stripIcon( icon );
-        open = cfg.readEntry( "Open", QVariant(open )).toBool();
+        open = cfg.readEntry( "Open", open);
     }
 
     KonqSidebarTreeTopLevelItem *item;
@@ -816,7 +816,7 @@ void KonqSidebarTree::loadTopLevelItem( KonqSidebarTreeItem *parent, const QStri
     m_topLevelItems.append( item );
     m_lstModules.append( module );
 
-    bool open = cfg.readEntry( "Open", QVariant(false )).toBool();
+    bool open = cfg.readEntry( "Open", false);
     if ( open && item->isExpandable() )
         item->setOpen( true );
 }
@@ -928,22 +928,30 @@ void KonqSidebarTree::showToplevelContextMenu()
     if (!m_collection)
     {
         m_collection = new KActionCollection( this);
-	    m_collection->setObjectName("bookmark actions");
-        KAction *action = new KAction(KIcon("folder_new"),  i18n("&Create New Folder..."), m_collection, "create_folder");
+        m_collection->setObjectName("bookmark actions");
+        QAction *action = new KAction(KIcon("folder_new"),  i18n("&Create New Folder..."), this);
+        m_collection->addAction("create_folder", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotCreateFolder() ));
-        action = new KAction(KIcon("editdelete"),  i18n("Delete Folder"), m_collection, "delete_folder");
+        action = new KAction(KIcon("editdelete"),  i18n("Delete Folder"), this);
+        m_collection->addAction("delete_folder", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotDelete() ));
-        action = new KAction( i18n("Rename"), m_collection, "rename");
+        action = new KAction(i18n("Rename"), this);
+        m_collection->addAction("rename", action);
         connect(action, SIGNAL(triggered(bool) ), SLOT( slotRename() ));
-        action = new KAction(KIcon("editdelete"),  i18n("Delete Link"), m_collection, "delete_link");
+        action = new KAction(KIcon("editdelete"),  i18n("Delete Link"), this);
+        m_collection->addAction("delete_link", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotDelete() ));
-        action = new KAction(KIcon("edit"),  i18n("Properties"), m_collection, "item_properties");
+        action = new KAction(KIcon("edit"),  i18n("Properties"), this);
+        m_collection->addAction("item_properties", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotProperties() ));
-        action = new KAction(KIcon("window_new"),  i18n("Open in New Window"), m_collection, "open_window");
+        action = new KAction(KIcon("window_new"),  i18n("Open in New Window"), this);
+        m_collection->addAction("open_window", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotOpenNewWindow() ));
-        action = new KAction(KIcon("tab_new"),  i18n("Open in New Tab"), m_collection, "open_tab");
+        action = new KAction(KIcon("tab_new"),  i18n("Open in New Tab"), this);
+        m_collection->addAction("open_tab", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotOpenTab() ));
-        action = new KAction(KIcon("editcopy"),  i18n("Copy Link Address"), m_collection, "copy_location");
+        action = new KAction(KIcon("editcopy"),  i18n("Copy Link Address"), this);
+        m_collection->addAction("copy_location", action);
         connect(action, SIGNAL(triggered(bool)), SLOT( slotCopyLocation() ));
     }
 
@@ -1030,10 +1038,9 @@ void KonqSidebarTree::slotProperties()
     KUrl url;
     url.setPath(m_currentTopLevelItem->path());
 
-    KPropertiesDialog *dlg = new KPropertiesDialog( url );
+    KPropertiesDialog *dlg = new KPropertiesDialog( url, this );
     dlg->setFileNameReadOnly(true);
     dlg->exec();
-    delete dlg;
 }
 
 void KonqSidebarTree::slotOpenNewWindow()
@@ -1064,8 +1071,9 @@ void KonqSidebarTree::slotCopyLocation()
 
 ///////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////
-
+#ifdef __GNUC__
 #warning KonqSidebarTreeToolTip removed, must implemented in event() function
+#endif
 /*
 void KonqSidebarTreeToolTip::maybeTip( const QPoint &point )
 {
