@@ -26,6 +26,7 @@
 #include <kio/paste.h>
 #include <kapplication.h>
 #include <kaction.h>
+#include <kactioncollection.h>
 #include <kdebug.h>
 #include <kdirlister.h>
 #include <kicon.h>
@@ -40,6 +41,8 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QFile>
+#include <QPointer>
+
 //Added by qt3to4:
 #include <assert.h>
 
@@ -50,8 +53,8 @@ class KonqDirPart::KonqDirPartPrivate
 public:
     KonqDirPartPrivate() : dirLister( 0 ) {}
     QStringList mimeFilters;
-    KAction *aEnormousIcons;
-    KAction *aSmallMediumIcons;
+    QAction *aEnormousIcons;
+    QAction *aSmallMediumIcons;
     QVector<int> iconSize;
 
     KDirLister* dirLister;
@@ -64,7 +67,7 @@ public:
 
 void KonqDirPart::KonqDirPartPrivate::findAvailableIconSizes(void)
 {
-    KIconTheme *root = KGlobal::instance()->iconLoader()->theme();
+    KIconTheme *root = KIconLoader::global()->theme();
     iconSize.resize(1);
     if (root) {
 	QList<int> avSizes = root->querySizes(K3Icon::Desktop);
@@ -106,7 +109,7 @@ void KonqDirPart::KonqDirPartPrivate::findAvailableIconSizes(void)
 int KonqDirPart::KonqDirPartPrivate::findNearestIconSize(int preferred)
 {
     int s1 = iconSize[1];
-    if (preferred == 0) return KGlobal::iconLoader()->currentSize(K3Icon::Desktop);
+    if (preferred == 0) return KIconLoader::global()->currentSize(K3Icon::Desktop);
     if (preferred <= s1) return s1;
     for (int i = 2; i <= iconSize.count(); i++) {
         if (preferred <= iconSize[i]) {
@@ -135,19 +138,30 @@ KonqDirPart::KonqDirPart( QObject *parent )
 
     connect( QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(slotClipboardDataChanged()) );
 
-    m_paIncIconSize = new KAction( KIcon( "viewmag+" ), i18n( "Enlarge Icons" ), actionCollection(), "incIconSize" );
+    m_paIncIconSize = actionCollection()->addAction( "incIconSize" );
+    m_paIncIconSize->setIcon( KIcon( "viewmag+" ) );
+    m_paIncIconSize->setText( i18n( "Enlarge Icons" ) );
     connect( m_paIncIconSize, SIGNAL( triggered() ), this, SLOT( slotIncIconSize() ) );
-    m_paDecIconSize = new KAction( KIcon( "viewmag-" ), i18n( "Shrink Icons" ), actionCollection(), "decIconSize" );
+    m_paDecIconSize = actionCollection()->addAction( "decIconSize" );
+    m_paDecIconSize->setIcon( KIcon( "viewmag-" ) );
+    m_paDecIconSize->setText( i18n( "Shrink Icons" ) );
     connect( m_paDecIconSize, SIGNAL( triggered() ), this, SLOT( slotDecIconSize() ) );
 
 
-    m_paDefaultIcons = new KAction( i18n( "&Default Size" ), actionCollection(), "modedefault" );
-    d->aEnormousIcons = new KAction( i18n( "&Huge" ), actionCollection(), "modeenormous" );
-    m_paHugeIcons = new KAction( i18n( "&Very Large" ), actionCollection(), "modehuge" );
-    m_paLargeIcons = new KAction( i18n( "&Large" ), actionCollection(), "modelarge" );
-    m_paMediumIcons = new KAction( i18n( "&Medium" ), actionCollection(), "modemedium" );
-    d->aSmallMediumIcons = new KAction( i18n( "&Small" ), actionCollection(), "modesmallmedium" );
-    m_paSmallIcons = new KAction( i18n( "&Tiny" ), actionCollection(), "modesmall" );
+    m_paDefaultIcons = actionCollection()->addAction( "modedefault" );
+    m_paDefaultIcons->setText( i18n( "&Default Size" ) );
+    d->aEnormousIcons = actionCollection()->addAction( "modeenormous" );
+    d->aEnormousIcons->setText( i18n( "&Huge" ) );
+    m_paHugeIcons = actionCollection()->addAction( "modehuge" );
+    m_paHugeIcons->setText( i18n( "&Very Large" ) );
+    m_paLargeIcons = actionCollection()->addAction( "modelarge" );
+    m_paLargeIcons->setText( i18n( "&Large" ) );
+    m_paMediumIcons = actionCollection()->addAction( "modemedium" );
+    m_paMediumIcons->setText( i18n( "&Medium" ) );
+    d->aSmallMediumIcons = actionCollection()->addAction( "modesmallmedium" );
+    d->aSmallMediumIcons->setText( i18n( "&Small" ) );
+    m_paSmallIcons = actionCollection()->addAction( "modesmall" );
+    m_paSmallIcons->setText( i18n( "&Tiny" ) );
 
     QActionGroup* viewModeGroup = new QActionGroup(this);
     viewModeGroup->setExclusive(true);
@@ -169,7 +183,7 @@ KonqDirPart::KonqDirPart( QObject *parent )
 	    this, SLOT( slotIconSizeToggled( bool ) ) );
     connect( m_paSmallIcons, SIGNAL( toggled( bool ) ), this, SLOT( slotIconSizeToggled( bool ) ) );
 
-    connect( kapp, SIGNAL(iconChanged(int)), SLOT(slotIconChanged(int)) );
+    connect( KGlobalSettings::self(), SIGNAL(iconChanged(int)), SLOT(slotIconChanged(int)) );
 #if 0
     // Extract 6 icon sizes from the icon theme.
     // Use 16,22,32,48,64,128 as default.
@@ -184,7 +198,7 @@ KonqDirPart::KonqDirPart( QObject *parent )
     d->iconSize[6] = K3Icon::SizeEnormous; // 128
     d->iconSize[7] = 192;
     d->iconSize[8] = 256;
-    KIconTheme *root = KGlobal::instance()->iconLoader()->theme();
+    KIconTheme *root = KIconLoader::global()->theme();
     if (root)
     {
       QList<int> avSizes = root->querySizes(K3Icon::Desktop);
@@ -212,7 +226,9 @@ KonqDirPart::KonqDirPart( QObject *parent )
     adjustIconSizes();
 #endif
 
-    KAction *a = new KAction( KIcon( "background" ), i18n( "Configure Background..." ), actionCollection(), "bgsettings" );
+    QAction *a = actionCollection()->addAction( "bgsettings" );
+    a->setIcon( KIcon( "background" ) );
+    a->setText( i18n( "Configure Background..." ) );
     connect( a, SIGNAL( triggered() ), this, SLOT( slotBackgroundSettings() ) );
 
     a->setToolTip( i18n( "Allows choosing of background settings for this view" ) );
@@ -223,6 +239,7 @@ KonqDirPart::~KonqDirPart()
     // Close the find part with us
     delete m_findPart;
     delete d;
+    d = 0;
 }
 
 void KonqDirPart::adjustIconSizes()
@@ -273,22 +290,30 @@ void KonqDirPart::slotBackgroundSettings()
 {
     QColor bgndColor = m_pProps->bgColor( widget() );
     QColor defaultColor = KGlobalSettings::baseColor();
-    KonqBgndDialog dlg( widget(), m_pProps->bgPixmapFile(), bgndColor, defaultColor );
-    if ( dlg.exec() == KonqBgndDialog::Accepted )
+    // dlg must be created on the heap as widget() can get deleted while dlg.exec(),
+    // trying to delete dlg as its child then (#124210) - Frank Osterfeld
+    QPointer<KonqBgndDialog> dlg = new KonqBgndDialog( widget(),
+                                              m_pProps->bgPixmapFile(),
+                                              bgndColor,
+                                              defaultColor );
+
+    if ( dlg->exec() == KonqBgndDialog::Accepted )
     {
-        if ( dlg.color().isValid() )
+        if ( dlg->color().isValid() )
         {
-            m_pProps->setBgColor( dlg.color() );
+            m_pProps->setBgColor( dlg->color() );
         m_pProps->setBgPixmapFile( "" );
     }
         else
     {
             m_pProps->setBgColor( defaultColor );
-        m_pProps->setBgPixmapFile( dlg.pixmapFile() );
+        m_pProps->setBgPixmapFile( dlg->pixmapFile() );
         }
         m_pProps->applyColors( scrollWidget()->viewport() );
         scrollWidget()->viewport()->repaint();
     }
+
+    delete dlg;
 }
 
 void KonqDirPart::lmbClicked( KFileItem * fileItem )
@@ -325,8 +350,8 @@ void KonqDirPart::lmbClicked( KFileItem * fileItem )
     }
     else
     {
-        kDebug() << "emit m_extension->openURLRequest( " << url.url() << "," << args.serviceType << ")" << endl;
-        emit m_extension->openURLRequest( url, args );
+        kDebug() << "emit m_extension->openUrlRequest( " << url.url() << "," << args.serviceType << ")" << endl;
+        emit m_extension->openUrlRequest( url, args );
     }
 }
 
@@ -553,7 +578,7 @@ void KonqDirPart::slotIconSizeToggled( bool toggleOn )
 void KonqDirPart::slotIncIconSize()
 {
     int s = m_pProps->iconSize();
-    s = s ? s : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    s = s ? s : KIconLoader::global()->currentSize( K3Icon::Desktop );
     int sizeIndex = 0;
     for ( int idx = 1; idx < d->iconSize.count() ; ++idx )
         if (s == d->iconSize[idx]) {
@@ -569,7 +594,7 @@ void KonqDirPart::slotIncIconSize()
 void KonqDirPart::slotDecIconSize()
 {
     int s = m_pProps->iconSize();
-    s = s ? s : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    s = s ? s : KIconLoader::global()->currentSize( K3Icon::Desktop );
     uint sizeIndex = 0;
     for ( int idx = 1; idx < d->iconSize.count() ; ++idx )
         if (s == d->iconSize[idx]) {
@@ -585,7 +610,7 @@ void KonqDirPart::slotDecIconSize()
 // Only updates Actions, a GUI update is done in the views by reimplementing this
 void KonqDirPart::newIconSize( int size /*0=default, or 16,32,48....*/ )
 {
-    int realSize = (size==0) ? KGlobal::iconLoader()->currentSize( K3Icon::Desktop ) : size;
+    int realSize = (size==0) ? KIconLoader::global()->currentSize( K3Icon::Desktop ) : size;
     m_paDecIconSize->setEnabled(realSize > d->iconSize[1]);
     m_paIncIconSize->setEnabled(realSize < d->iconSize.back());
 
@@ -606,17 +631,17 @@ void KonqDirPart::setIconSize( int size )
     newIconSize( size );
 }
 
-bool KonqDirPart::closeURL()
+bool KonqDirPart::closeUrl()
 {
     // Tell all the childern objects to clean themselves up for dinner :)
     return doCloseURL();
 }
 
-bool KonqDirPart::openURL(const KUrl& url)
+bool KonqDirPart::openUrl(const KUrl& url)
 {
     if ( m_findPart )
     {
-        kDebug(1203) << "KonqDirPart::openURL -> emit findClosed " << this << endl;
+        kDebug(1203) << "KonqDirPart::openUrl -> emit findClosed " << this << endl;
         delete m_findPart;
         m_findPart = 0L;
         emit findClosed( this );
@@ -655,7 +680,7 @@ void KonqDirPart::setFindPart( KParts::ReadOnlyPart * part )
     emit findOpened( this );
 
     // set the initial URL in the find part
-    m_findPart->openURL( url() );
+    m_findPart->openUrl( url() );
 }
 
 void KonqDirPart::slotFindClosed()
@@ -665,7 +690,7 @@ void KonqDirPart::slotFindClosed()
     m_findPart = 0L;
     emit findClosed( this );
     // reload where we were before
-    openURL( url() );
+    openUrl( url() );
 }
 
 void KonqDirPart::slotIconChanged( int group )
@@ -704,7 +729,7 @@ void KonqDirPartBrowserExtension::restoreState( QDataStream &stream )
     stream >> hasFindPart;
     assert( ! ( hasFindPart && !strcmp(m_dirPart->metaObject()->className(), "KFindPart") ) );
     if ( !hasFindPart )
-        // This calls openURL, that's why we don't want to call it in case of a find part
+        // This calls openUrl, that's why we don't want to call it in case of a find part
         KParts::BrowserExtension::restoreState( stream );
     else {
         m_dirPart->restoreFindState( stream );
