@@ -18,7 +18,7 @@
 */
 
 #include "konq_historymgr.h"
-#include "konq_historymgr_adaptor.h"
+#include "konqhistorymanageradaptor.h"
 #include "konqbookmarkmanager.h"
 
 #include <QtDBus/QtDBus>
@@ -30,9 +30,10 @@
 #include <kcompletion.h>
 
 #include <zlib.h> // for crc32
+#include <kconfiggroup.h>
 
 
-const int KonqHistoryManager::s_historyVersion = 3;
+const int KonqHistoryManager::s_historyVersion = 4;
 
 KonqHistoryManager::KonqHistoryManager( QObject *parent )
     : KParts::HistoryProvider( parent )
@@ -40,7 +41,7 @@ KonqHistoryManager::KonqHistoryManager( QObject *parent )
     m_updateTimer = new QTimer( this );
 
     // defaults
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup cs( config, "HistorySettings" );
     m_maxCount = cs.readEntry( "Maximum of History entries", 500 );
     m_maxCount = qMax( 1, m_maxCount );
@@ -62,7 +63,7 @@ KonqHistoryManager::KonqHistoryManager( QObject *parent )
     const QString dbusPath = "/KonqHistoryManager";
     const QString dbusInterface = "org.kde.libkonq.KonqHistoryManager";
 
-    QDBusConnection dbus = QDBus::sessionBus();
+    QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.registerObject( dbusPath, this );
     dbus.connect(QString(), dbusPath, dbusInterface, "notifyClear", this, SLOT(slotNotifyClear(QDBusMessage)));
     dbus.connect(QString(), dbusPath, dbusInterface, "notifyHistoryEntry", this, SLOT(slotNotifyHistoryEntry(QByteArray,QDBusMessage)));
@@ -81,7 +82,7 @@ KonqHistoryManager::~KonqHistoryManager()
 
 static QString dbusService()
 {
-    return QDBus::sessionBus().baseService();
+    return QDBusConnection::sessionBus().baseService();
 }
 
 bool KonqHistoryManager::isSenderOfSignal( const QDBusMessage& msg )
@@ -130,9 +131,10 @@ bool KonqHistoryManager::loadHistory()
             stream = &crcStream; // pick up the right stream
         }
 
-	if ( version == 3 )
-	{
-	    //Use KUrl marshalling for V3 format.
+        // We can't read v3 history anymore, because operator<<(KURL) disappeared.
+        if ( version == 4)
+        {
+            // Use QUrl marshalling for V4 format.
 	    KonqHistoryEntry::marshalURLAsStrings = false;
 	}
 
@@ -211,18 +213,18 @@ bool KonqHistoryManager::loadHistory()
 bool KonqHistoryManager::saveHistory()
 {
     KSaveFile file( m_filename );
-    if ( file.status() != 0 ) {
-	kWarning() << "Can't open " << file.name() << endl;
-	return false;
+    if ( !file.open() ) {
+        kWarning() << "Can't open " << file.fileName() << endl;
+        return false;
     }
 
-    QDataStream *fileStream = file.dataStream();
-    *fileStream << s_historyVersion;
+    QDataStream fileStream ( &file );
+    fileStream << s_historyVersion;
 
     QByteArray data;
     QDataStream stream( &data, QIODevice::WriteOnly );
 
-    //We use KUrl for marshalling URLs in entries in the V3
+    //We use QUrl for marshalling URLs in entries in the V4
     //file format
     KonqHistoryEntry::marshalURLAsStrings = false;
     QListIterator<KonqHistoryEntry> it( m_history );
@@ -234,9 +236,9 @@ bool KonqHistoryManager::saveHistory()
     KonqHistoryEntry::marshalURLAsStrings = true;
 
     quint32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
-    *fileStream << crc << data;
+    fileStream << crc << data;
 
-    file.close();
+    file.finalize(); //check for error here?
 
     return true;
 }
@@ -500,7 +502,7 @@ void KonqHistoryManager::slotNotifyMaxCount( int count, const QDBusMessage& msg
     clearPending();
     adjustSize();
 
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup cs( config, "HistorySettings" );
     cs.writeEntry( "Maximum of History entries", m_maxCount );
 
@@ -516,7 +518,7 @@ void KonqHistoryManager::slotNotifyMaxAge( int days, const QDBusMessage& msg  )
     clearPending();
     adjustSize();
 
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup cs( config, "HistorySettings" );
     cs.writeEntry( "Maximum age of History entries", m_maxAgeDays );
 
