@@ -46,7 +46,6 @@
 #include <QPixmap>
 #include <QBuffer>
 
-#include <kapplication.h>
 #include <kdebug.h>
 #include <kio/previewjob.h>
 #include <kfileivi.h>
@@ -54,7 +53,6 @@
 #include <konqmimedata.h>
 #include <kglobalsettings.h>
 #include <kpropertiesdialog.h>
-#include <kipc.h>
 #include <kicontheme.h>
 #include <kiconeffect.h>
 #include <kstandarddirs.h>
@@ -64,6 +62,7 @@
 #include <assert.h>
 #include <unistd.h>
 #include <klocale.h>
+#include <kconfiggroup.h>
 
 
 struct KonqIconViewWidgetPrivate
@@ -140,8 +139,7 @@ KonqIconViewWidget::KonqIconViewWidget( QWidget * parent, const char * name, Qt:
     connect( this, SIGNAL( selectionChanged() ),
              this, SLOT( slotSelectionChanged() ) );
 
-    kapp->addKipcEventMask( KIPC::IconChanged );
-    connect( kapp, SIGNAL(iconChanged(int)), SLOT(slotIconChanged(int)) );
+    connect( KGlobalSettings::self(), SIGNAL(iconChanged(int)), SLOT(slotIconChanged(int)) );
     connect( this, SIGNAL(onItem(Q3IconViewItem *)), SLOT(slotOnItem(Q3IconViewItem *)) );
     connect( this, SIGNAL(onViewport()), SLOT(slotOnViewport()) );
     connect( this, SIGNAL(itemRenamed(Q3IconViewItem *, const QString &)), SLOT(slotItemRenamed(Q3IconViewItem *, const QString &)) );
@@ -241,7 +239,7 @@ void KonqIconViewWidget::slotIconChanged( int group )
 void KonqIconViewWidget::readAnimatedIconsConfig()
 {
     KConfigGroup cfgGroup( KGlobal::config(), "DesktopIcons" );
-    d->doAnimations = cfgGroup.readEntry( "Animated", QVariant(true /*default*/ )).toBool();
+    d->doAnimations = cfgGroup.readEntry( "Animated", true /*default*/);
 }
 
 void KonqIconViewWidget::slotOnItem( Q3IconViewItem *_item )
@@ -298,7 +296,7 @@ void KonqIconViewWidget::slotOnItem( Q3IconViewItem *_item )
                 else
                 {
                     delete d->m_movie;
-                    d->m_movie = KGlobal::iconLoader()->loadMovie( d->pActiveItem->mouseOverAnimation(), K3Icon::Desktop, d->pActiveItem->iconSize() );
+                    d->m_movie = KIconLoader::global()->loadMovie( d->pActiveItem->mouseOverAnimation(), K3Icon::Desktop, d->pActiveItem->iconSize() );
 #if 0
                     if ( d->m_movie && d->m_movie->isValid() )
                     {
@@ -351,10 +349,11 @@ void KonqIconViewWidget::slotOnItem( Q3IconViewItem *_item )
     }
 
     // ## shouldn't this be disabled during rectangular selection too ?
+    //kDebug(1203) << "about to start sound preview: bSoundPreviews=" << d->bSoundPreviews << ", pSoundPlayer=" << d->pSoundPlayer << ", isMimeTypeKnown=" << d->pSoundPlayer->isMimeTypeKnown(item->item()->mimetype()) << ", showFilePreview=" << KGlobalSettings::showFilePreview(item->item()->url()) << ", activeWindow=" << (window() == qApp->activeWindow()) << endl;
     if (d->bSoundPreviews && d->pSoundPlayer &&
         d->pSoundPlayer->isMimeTypeKnown(item->item()->mimetype())
         && KGlobalSettings::showFilePreview(item->item()->url())
-        && window() == kapp->activeWindow())
+        && window() == qApp->activeWindow())
     {
         d->pSoundItem = item;
         d->bSoundItemClicked = false;
@@ -452,7 +451,7 @@ void KonqIconViewWidget::slotMovieUpdate( const QRect& rect )
         // This can happen if the icon was scaled to the desired size, so KIconLoader
         // will happily return a movie with different dimensions than the icon
         int iconSize=d->pActiveItem->iconSize();
-        if (iconSize==0) iconSize = KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+        if (iconSize==0) iconSize = KIconLoader::global()->currentSize( K3Icon::Desktop );
         if ( frame.width() != iconSize || frame.height() != iconSize ) {
             d->pActiveItem->setAnimated( false );
             d->m_movie->setPaused(true);
@@ -592,7 +591,7 @@ bool KonqIconViewWidget::boostPreview() const
     if ( m_bDesktop ) return false;
 
     KConfigGroup group( KGlobal::config(), "PreviewSettings" );
-    return group.readEntry( "BoostSize", QVariant(false )).toBool();
+    return group.readEntry( "BoostSize", false);
 }
 
 void KonqIconViewWidget::disableSoundPreviews()
@@ -615,7 +614,7 @@ void KonqIconViewWidget::setIcons( int size, const QStringList& stopImagePreview
 
     if ( sizeChanged || previewSizeChanged )
     {
-        int realSize = size ? size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+        int realSize = size ? size : KIconLoader::global()->currentSize( K3Icon::Desktop );
         // choose spacing depending on font, but min 5 (due to KFileIVI  move limit)
         setSpacing( ( m_bDesktop || ( realSize > K3Icon::SizeSmall ) ) ?
                     qMax( 5, QFontMetrics(font()).width('n') ) : 0 );
@@ -678,7 +677,7 @@ bool KonqIconViewWidget::mimeTypeMatch( const QString& mimeType, const QStringLi
 void KonqIconViewWidget::setItemTextPos( ItemTextPos pos )
 {
     // can't call gridXValue() because this already would need the new itemTextPos()
-    int sz = m_size ? m_size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int sz = m_size ? m_size : KIconLoader::global()->currentSize( K3Icon::Desktop );
 
     if ( m_bSetGridX )
         if ( pos == Q3IconView::Bottom )
@@ -696,7 +695,7 @@ void KonqIconViewWidget::gridValues( int* x, int* y, int* dx, int* dy,
                                      int* nx, int* ny )
 {
     int previewSize = previewIconSize( m_size );
-    int iconSize = m_size ? m_size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int iconSize = m_size ? m_size : KIconLoader::global()->currentSize( K3Icon::Desktop );
 
     // Grid size
     // as KFileIVI limits to move an icon to x >= 5, y >= 5, we define a grid cell as:
@@ -757,7 +756,7 @@ void KonqIconViewWidget::calculateGridX()
 int KonqIconViewWidget::gridXValue() const
 {
     // this method is only used in konqi as filemanager (not desktop)
-    int sz = m_size ? m_size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int sz = m_size ? m_size : KIconLoader::global()->currentSize( K3Icon::Desktop );
     int newGridX;
 
     if ( itemTextPos() == Q3IconView::Bottom )
@@ -777,7 +776,7 @@ void KonqIconViewWidget::refreshMimeTypes()
     setIcons( m_size );
 }
 
-void KonqIconViewWidget::setURL( const KUrl &kurl )
+void KonqIconViewWidget::setUrl( const KUrl &kurl )
 {
     stopImagePreview();
     m_url = kurl;
@@ -831,7 +830,7 @@ void KonqIconViewWidget::startImagePreview( const QStringList &, bool force )
         return; // don't start the preview job if not really necessary
     }
 
-    int iconSize = m_size ? m_size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int iconSize = m_size ? m_size : KIconLoader::global()->currentSize( K3Icon::Desktop );
     int size;
 
     d->bBoostPreview = boostPreview();
@@ -884,7 +883,7 @@ void KonqIconViewWidget::slotDropped( QDropEvent *ev, const QList<Q3IconDragItem
     KUrl dirURL = url();
     if ( m_rootItem ) {
         bool dummy;
-        dirURL = m_rootItem->mostLocalURL(dummy);
+        dirURL = m_rootItem->mostLocalUrl(dummy);
     }
     KonqOperations::doDrop( m_rootItem /* may be 0L */, dirURL, ev, this );
 }
@@ -963,7 +962,7 @@ QMimeData * KonqIconViewWidget::konqMimeData(bool moveSelection)
 			KFileItem* fileItem = static_cast<KFileIVI *>(it)->item();
 			urls.append(fileItem->url());
 			bool dummy;
-			mostLocalUrls.append(fileItem->mostLocalURL(dummy));
+			mostLocalUrls.append(fileItem->mostLocalUrl(dummy));
 #ifdef __GNUC__
 #warning how much of the q3icondragitem stuff do we have to duplicate here.... (TODO: jowenn)
 #endif
@@ -1162,7 +1161,7 @@ KUrl::List KonqIconViewWidget::selectedUrls( UrlFlags flags ) const
     for ( Q3IconViewItem *it = firstItem(); it; it = it->nextItem() )
         if ( it->isSelected() ) {
             KFileItem* item = (static_cast<KFileIVI *>( it ))->item();
-            lstURLs.append( flags == MostLocalUrls ? item->mostLocalURL( dummy ) : item->url() );
+            lstURLs.append( flags == MostLocalUrls ? item->mostLocalUrl( dummy ) : item->url() );
         }
     return lstURLs;
 }
@@ -1551,7 +1550,7 @@ void KonqIconViewWidget::lineupIcons()
         return;
     }
 
-    int iconSize = m_size ? m_size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int iconSize = m_size ? m_size : KIconLoader::global()->currentSize( K3Icon::Desktop );
 
     typedef QList<Q3IconViewItem*> Bin;
     Bin*** bins = new Bin**[nx];
@@ -1723,7 +1722,7 @@ void KonqIconViewWidget::lineupIcons()
     else {
         // Repaint only repaintRegion...
         QVector<QRect> rects = repaintRegion.rects();
-        for ( uint l = 0; l < rects.count(); l++ ) {
+        for ( int l = 0; l < rects.count(); l++ ) {
             kDebug( 1203 ) << "Repainting (" << rects[l].x() << ","
                             << rects[l].y() << ")\n";
             repaintContents( rects[l], false );
@@ -1796,7 +1795,7 @@ void KonqIconViewWidget::lineupIcons( Q3IconView::Arrangement arrangement )
 
 int KonqIconViewWidget::largestPreviewIconSize( int size ) const
 {
-    int iconSize = size ? size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int iconSize = size ? size : KIconLoader::global()->currentSize( K3Icon::Desktop );
 
     if (iconSize < 28)
         return 48;
@@ -1812,7 +1811,7 @@ int KonqIconViewWidget::largestPreviewIconSize( int size ) const
 
 int KonqIconViewWidget::previewIconSize( int size ) const
 {
-    int iconSize = size ? size : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+    int iconSize = size ? size : KIconLoader::global()->currentSize( K3Icon::Desktop );
 
     if (!d->bBoostPreview)
         return iconSize;
@@ -1865,7 +1864,7 @@ void KonqIconViewWidget::setNewURL( const QString& url )
         u.setPath( url );
     else
         u = url;
-    setURL( u );
+    setUrl( u );
 }
 
 void KonqIconViewWidget::setCaseInsensitiveSort( bool b )
