@@ -44,6 +44,7 @@
 #include <QtDBus/QtDBus>
 #include <QDir>
 #include <QPixmap>
+#include <kconfiggroup.h>
 
 /*
  Test cases:
@@ -182,40 +183,13 @@ ServiceList* PopupServices::selectList( const QString& priority, const QString&
 
 //////////////////
 
-#if 0
-KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
-                              KUrl viewURL,
-                              KActionCollection & actions,
-                              KNewMenu * newMenu,
-                              bool showProperties )
-    : QMenu( 0L ),
-      m_actions( actions ), m_ownActions( static_cast<QWidget *>( 0 ) ),
-		  m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
-{
-    KonqPopupFlags kpf = ( showProperties ? ShowProperties : IsLink ) | ShowNewWindow;
-    init(0, kpf, KParts::BrowserExtension::DefaultPopupItems);
-}
-
-KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
-                              KUrl viewURL,
-                              KActionCollection & actions,
-                              KNewMenu * newMenu,
-                              QWidget * parentWidget,
-                              bool showProperties )
-    : QMenu( parentWidget ), m_actions( actions ), m_ownActions( static_cast<QWidget *>( 0 ) ), m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
-{
-    KonqPopupFlags kpf = ( showProperties ? ShowProperties : IsLink ) | ShowNewWindow;
-    init(parentWidget, kpf, KParts::BrowserExtension::DefaultPopupItems);
-}
-#endif
-
 KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
                               const KUrl& viewURL,
                               KActionCollection & actions,
                               KNewMenu * newMenu,
                               QWidget * parentWidget,
                               KonqPopupFlags kpf,
-                              KParts::BrowserExtension::PopupFlags flags)
+                              KParts::BrowserExtension::PopupFlags flags )
   : QMenu( parentWidget ),
     m_actions( actions ),
     m_ownActions( static_cast<QWidget *>( 0 ) ),
@@ -289,7 +263,8 @@ int KonqPopupMenu::insertServices(const ServiceList& list,
             QString name;
             name.setNum( id );
             name.prepend( isBuiltin ? "builtinservice_" : "userservice_" );
-            KAction* act = new KAction(QString((*it).m_strName).replace('&',"&&"), &m_ownActions, name.toLatin1());
+            QAction* act = m_ownActions.addAction( name.toLatin1() );
+            act->setText( QString((*it).m_strName).replace('&',"&&") );
             connect(act, SIGNAL(triggered()), this, SLOT(slotRunService()));
 
             if ( !(*it).m_strIcon.isEmpty() )
@@ -297,7 +272,7 @@ int KonqPopupMenu::insertServices(const ServiceList& list,
                 act->setIcon( KIcon((*it).m_strIcon) );
             }
 
-            KonqXMLGUIClient::addAction( act, menu ); // Add to toplevel menu
+            KonqXMLGUIClient::addAction( name, menu ); // Add to toplevel menu
 
             m_mapPopupServices[ id++ ] = *it;
             ++count;
@@ -454,13 +429,13 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
 
     //////////////////////////////////////////////////////////////////////////
 
-    KAction * act;
+    QAction * act;
 
     if (!isCurrentTrash)
         addMerge( "konqueror" );
 
     bool isKDesktop = QByteArray( kapp->objectName().toUtf8() ) == "kdesktop";
-    KAction *actNewWindow = 0;
+    QAction *actNewWindow = 0;
 
     if (( kpf & ShowProperties ) && isKDesktop &&
         !KAuthorized::authorizeKAction("editable_desktop_icons"))
@@ -473,7 +448,9 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
     if ( ((kpf & ShowNewWindow) != 0) && sReading )
     {
         QString openStr = isKDesktop ? i18n( "&Open" ) : i18n( "Open in New &Window" );
-        actNewWindow = new KAction( KIcon("window_new"), openStr, &m_ownActions, "newview" );
+        actNewWindow = m_ownActions.addAction( "newview" );
+        actNewWindow->setIcon( KIcon("window_new") );
+        actNewWindow->setText( openStr );
         connect(actNewWindow, SIGNAL(triggered()), this, SLOT(slotPopupNewView()));
     }
 
@@ -495,7 +472,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
             m_pMenuNew->slotCheckUpToDate();
             m_pMenuNew->setPopupFiles( m_lstPopupURLs );
 
-            KonqXMLGUIClient::addAction( m_pMenuNew );
+            KonqXMLGUIClient::addAction( m_pMenuNew->objectName() );
 
             KonqXMLGUIClient::addSeparator();
         }
@@ -503,17 +480,20 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
         {
             if (d->m_itemFlags & KParts::BrowserExtension::ShowCreateDirectory)
             {
-                KAction *actNewDir = new KAction( KIcon("folder_new"), i18n( "Create &Folder..." ), &m_ownActions, "newdir" );
+                QAction *actNewDir = m_ownActions.addAction( "newdir" );
+                actNewDir->setIcon( KIcon("folder_new") );
+                actNewDir->setText( i18n( "Create &Folder..." ) );
                 connect(actNewDir, SIGNAL(triggered()), this, SLOT(slotPopupNewDir()));
-                KonqXMLGUIClient::addAction( actNewDir );
+                KonqXMLGUIClient::addAction( "newdir" );
                 KonqXMLGUIClient::addSeparator();
             }
         }
     } else if ( isIntoTrash ) {
         // Trashed item, offer restoring
-        act = new KAction( i18n( "&Restore" ), &m_ownActions, "restore" );
+        act = m_ownActions.addAction( "restore" );
+        act->setText( i18n( "&Restore" ) );
         connect(act, SIGNAL(triggered()), this, SLOT(slotPopupRestoreTrashedItems()));
-        KonqXMLGUIClient::addAction( act );
+        KonqXMLGUIClient::addAction( "restore" );
     }
 
     if (d->m_itemFlags & KParts::BrowserExtension::ShowNavigationItems)
@@ -530,7 +510,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
     // "open in new window" is either provided by us, or by the tabhandling group
     if (actNewWindow)
     {
-        KonqXMLGUIClient::addAction( actNewWindow );
+        KonqXMLGUIClient::addAction( "newview" );
         KonqXMLGUIClient::addSeparator();
     }
     KonqXMLGUIClient::addGroup( "tabhandling" ); // includes a separator
@@ -570,7 +550,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
                 }
                 else {
                     KConfigGroup configGroup( KGlobal::config(), "KDE" );
-                    if ( configGroup.readEntry( "ShowDeleteCommand", QVariant(false )).toBool() )
+                    if ( configGroup.readEntry( "ShowDeleteCommand", false) )
                         addDel = true;
                 }
             }
@@ -583,9 +563,14 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
     }
     if ( isCurrentTrash )
     {
-        act = new KAction( KIcon("emptytrash"), i18n( "&Empty Trash Bin" ), &m_ownActions, "empytrash" );
+        act = m_ownActions.addAction( "emptytrash" );
+        act->setIcon( KIcon("emptytrash") );
+        act->setText( i18n( "&Empty Trash Bin" ) );
+        KSimpleConfig trashConfig( "trashrc", true );
+        trashConfig.setGroup( "Status" );
+        act->setEnabled( !trashConfig.readEntry( "Empty", true ) );
         connect(act, SIGNAL(triggered()), this, SLOT(slotPopupEmptyTrashBin()));
-        KonqXMLGUIClient::addAction( act );
+        KonqXMLGUIClient::addAction( "emptytrash" );
     }
     KonqXMLGUIClient::addGroup( "editactions" );
 
@@ -614,12 +599,14 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
         else
            caption = i18n("&Bookmark This File");
 
-        act = new KAction( KIcon("bookmark_add"), caption, &m_ownActions, "bookmark_add" );
+        act = m_ownActions.addAction( "bookmark_add" );
+        act->setIcon( KIcon("bookmark_add") );
+        act->setText( caption );
         connect(act, SIGNAL(triggered()), this, SLOT(slotPopupAddToBookmark()));
         if (m_lstItems.count() > 1)
             act->setEnabled(false);
         if (KAuthorized::authorizeKAction("bookmarks"))
-            KonqXMLGUIClient::addAction( act );
+            KonqXMLGUIClient::addAction( "bookmark_add" );
         if (bIsLink)
             KonqXMLGUIClient::addGroup( "linkactions" );
     }
@@ -672,8 +659,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
         // findAllResources() also removes duplicates
         const QStringList entries = KGlobal::dirs()->findAllResources( "data",
                                                                        "konqueror/servicemenus/*.desktop",
-                                                                       false /* recursive */,
-                                                                       true /* unique */ );
+                                                                       KStandardDirs::NoDuplicates );
         QStringList::ConstIterator eIt = entries.begin();
         const QStringList::ConstIterator eEnd = entries.end();
         for (; eIt != eEnd; ++eIt )
@@ -689,7 +675,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
             if ( cfg.hasKey( "X-KDE-ShowIfRunning" ) )
             {
                 const QString app = cfg.readEntry( "X-KDE-ShowIfRunning" );
-                if ( QDBus::sessionBus().interface()->serviceOwner( app ).value().isEmpty() )
+                if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( app ) )
                     continue;
             }
             if ( cfg.hasKey( "X-KDE-ShowIfDBusCall" ) )
@@ -711,8 +697,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
 
                 QDBusMessage reply = QDBusInterface( app, obj, interface ).
                                      call( method, m_lstPopupURLs.toStringList() );
-                if ( reply.count() < 1 || reply.at(0).type() != QVariant::Bool ||
-                     !reply.at(0).toBool() )
+                if ( reply.arguments().count() < 1 || reply.arguments().at(0).type() != QVariant::Bool || !reply.arguments().at(0).toBool() )
                     continue;
 
             }
@@ -810,7 +795,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
 
         if (KAuthorized::authorizeKAction("openwith"))
         {
-            QString constraint = "Type == 'Application' and DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'";
+            QString constraint = "DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'";
             QString subConstraint = " and '%1' in ServiceTypes";
 
             QStringList::ConstIterator it = mimeTypeList.begin();
@@ -823,7 +808,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
                 ++it;
             }
 
-            offers = KMimeTypeTrader::self()->query( first, QString(), constraint );
+            offers = KMimeTypeTrader::self()->query( first, "Application", constraint );
         }
 
         //// Ok, we have everything, now insert
@@ -858,8 +843,24 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
                 for( ; it != offers.end(); it++ )
                 {
                     KService::Ptr service = (*it);
-                    if (service->noDisplay())
-                        continue;
+
+                    // Skip OnlyShowIn=Foo and NotShowIn=KDE entries,
+                    // but still offer NoDisplay=true entries, that's the
+                    // whole point of such desktop files. This is why we don't
+                    // use service->noDisplay() here.
+                    const QString onlyShowIn = service->property("OnlyShowIn", QVariant::String).toString();
+                    if ( !onlyShowIn.isEmpty() ) {
+                        const QStringList aList = QStringList::split(';', onlyShowIn);
+                        if (!aList.contains("KDE"))
+                            continue;
+                    }
+                    const QString notShowIn = service->property("NotShowIn", QVariant::String).toString();
+                    if ( !notShowIn.isEmpty() ) {
+                        const QStringList aList = QStringList::split(';', notShowIn);
+                        if (aList.contains("KDE"))
+                            continue;
+                    }
+
 
                     QByteArray nam;
                     nam.setNum( id );
@@ -868,9 +869,11 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
                     if ( menu == domElement() ) // no submenu -> prefix single offer
                         actionName = i18n( "Open with %1" ,  actionName );
 
-                    act = new KAction( KIcon( service->icon() ), actionName, &m_ownActions, nam.prepend( "appservice_" ) );
+                    act = m_ownActions.addAction( nam.prepend( "appservice_" ) );
+                    act->setIcon( KIcon( service->icon() ) );
+                    act->setText( actionName );
                     connect(act, SIGNAL(triggered()), this, SLOT(slotRunService()));
-                    KonqXMLGUIClient::addAction( act, menu );
+                    KonqXMLGUIClient::addAction( nam.prepend( "appservice_" ).constData(), menu );
 
                     m_mapPopup[ id++ ] = *it;
                 }
@@ -885,15 +888,17 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
                 {
                     openWithActionName = i18n( "&Open With..." );
                 }
-                KAction *openWithAct = new KAction( openWithActionName, &m_ownActions, "openwith" );
+                QAction *openWithAct = m_ownActions.addAction( "openwith" );
+                openWithAct->setText( openWithActionName );
                 connect(openWithAct, SIGNAL(triggered()), this, SLOT(slotPopupOpenWith()));
-                KonqXMLGUIClient::addAction( openWithAct, menu );
+                KonqXMLGUIClient::addAction( "openwith", menu );
             }
             else // no app offers -> Open With...
             {
-                act = new KAction( i18n( "&Open With..." ), &m_ownActions, "openwith" );
+                act = m_ownActions.addAction( "openwith" );
+                act->setText( i18n( "&Open With..." ) );
                 connect(act, SIGNAL(triggered()), this, SLOT(slotPopupOpenWith()));
-                KonqXMLGUIClient::addAction( act );
+                KonqXMLGUIClient::addAction( "openwith" );
             }
 
         }
@@ -946,9 +951,10 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
 
     if ( KPropertiesDialog::canDisplay( m_lstItems ) && (kpf & ShowProperties) )
     {
-        act = new KAction( i18n( "&Properties" ), &m_ownActions, "properties" );
+        act = m_ownActions.addAction( "properties" );
+        act->setText( i18n( "&Properties" ) );
         connect(act, SIGNAL(triggered()), this, SLOT(slotPopupProperties()));
-        KonqXMLGUIClient::addAction( act );
+        KonqXMLGUIClient::addAction( "properties" );
     }
 
     while ( !domElement().lastChild().isNull() &&
@@ -960,9 +966,10 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
         if ( KFileShare::authorization() == KFileShare::Authorized )
         {
             KonqXMLGUIClient::addSeparator();
-            act = new KAction( i18n("Share"), &m_ownActions, "sharefile" );
+            act = m_ownActions.addAction( "sharefile" );
+            act->setText( i18n("Share") );
             connect(act, SIGNAL(triggered()), this, SLOT(slotOpenShareFileDialog()));
-            KonqXMLGUIClient::addAction( act );
+            KonqXMLGUIClient::addAction( "sharefile" );
         }
     }
 
@@ -974,8 +981,9 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
 
 void KonqPopupMenu::slotOpenShareFileDialog()
 {
-    KPropertiesDialog* dlg = showPropertiesDialog();
+    KPropertiesDialog* dlg = new KPropertiesDialog( m_lstItems, d->m_parentWidget );
     dlg->showFileSharingPage();
+    dlg->exec();
 }
 
 KonqPopupMenu::~KonqPopupMenu()
@@ -1008,17 +1016,17 @@ void KonqPopupMenu::slotPopupNewDir()
 
 void KonqPopupMenu::slotPopupEmptyTrashBin()
 {
-  KonqOperations::emptyTrash();
+  KonqOperations::emptyTrash( d->m_parentWidget );
 }
 
 void KonqPopupMenu::slotPopupRestoreTrashedItems()
 {
-  KonqOperations::restoreTrashedItems( m_lstPopupURLs );
+  KonqOperations::restoreTrashedItems( m_lstPopupURLs, d->m_parentWidget );
 }
 
 void KonqPopupMenu::slotPopupOpenWith()
 {
-  KRun::displayOpenWithDialog( m_lstPopupURLs, topLevelWidget() );
+  KRun::displayOpenWithDialog( m_lstPopupURLs, d->m_parentWidget );
 }
 
 void KonqPopupMenu::slotPopupAddToBookmark()
@@ -1069,32 +1077,14 @@ void KonqPopupMenu::slotPopupMimeType()
 
 void KonqPopupMenu::slotPopupProperties()
 {
-    (void)showPropertiesDialog();
+    KPropertiesDialog::showDialog( m_lstItems, d->m_parentWidget );
 }
 
-KPropertiesDialog* KonqPopupMenu::showPropertiesDialog()
-{
-    // It may be that the kfileitem was created by hand
-    // (see KonqKfmIconView::slotMouseButtonPressed)
-    // In that case, we can get more precise info in the properties
-    // (like permissions) if we stat the URL.
-    if ( m_lstItems.count() == 1 )
-    {
-        KFileItem * item = m_lstItems.first();
-        if (item->entry().count() == 0) // this item wasn't listed by a slave
-        {
-            // KPropertiesDialog will use stat to get more info on the file
-            return new KPropertiesDialog( item->url(), d->m_parentWidget );
-        }
-    }
-    return new KPropertiesDialog( m_lstItems, d->m_parentWidget );
-}
-
-KAction *KonqPopupMenu::action( const QDomElement &element ) const
+QAction *KonqPopupMenu::action( const QDomElement &element ) const
 {
   QByteArray name = element.attribute( attrName ).toLatin1();
 
-  KAction *res = m_ownActions.action( name.data() );
+  QAction *res = m_ownActions.action( name.data() );
 
   if ( !res )
     res = m_actions.action( name.data() );
