@@ -30,10 +30,11 @@
 #include <QFile>
 #include <iostream>
 #include <kservicetypetrader.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <assert.h>
 
 #include <ksimpleconfig.h>
+#include <kconfiggroup.h>
 
 static QPixmap wallpaperPixmap( const QString & _wallpaper )
 {
@@ -72,20 +73,20 @@ struct KonqPropsView::Private
    QString sortcriterion;
 };
 
-KonqPropsView::KonqPropsView( KInstance * instance, KonqPropsView * defaultProps )
+KonqPropsView::KonqPropsView(const KComponentData &componentData, KonqPropsView *defaultProps)
     : m_bSaveViewPropertiesLocally( false ), // will be overridden by setSave... anyway
     // if this is the default properties instance, then keep config object for saving
     m_dotDirExists( true ), // HACK so that enterDir returns true initially
-    m_currentConfig( defaultProps ? 0L : instance->config() ),
+    m_currentConfig( defaultProps ? KSharedConfig::Ptr() : componentData.config() ),
     m_defaultProps( defaultProps )
 {
 
-  KConfig *config = instance->config();
+  KSharedConfig::Ptr config = componentData.config();
   KConfigGroup cgs(config, "Settings");
 
   d = new Private;
   d->previewsToShow = 0;
-  d->caseInsensitiveSort=cgs.readEntry( "CaseInsensitiveSort", QVariant(true )).toBool();
+  d->caseInsensitiveSort=cgs.readEntry( "CaseInsensitiveSort", true);
 
   m_iIconSize = cgs.readEntry( "IconSize", 0 );
   m_iItemTextPos = cgs.readEntry( "ItemTextPos", int(Qt::DockBottom) );
@@ -93,7 +94,7 @@ KonqPropsView::KonqPropsView( KInstance * instance, KonqPropsView * defaultProps
   d->dirsfirst = cgs.readEntry( "SortDirsFirst", true );
   d->descending = cgs.readEntry( "SortDescending", false );
   m_bShowDot = cgs.readEntry( "ShowDotFiles", false );
-  m_bShowDirectoryOverlays = cgs.readEntry( "ShowDirectoryOverlays", QVariant(false )).toBool();
+  m_bShowDirectoryOverlays = cgs.readEntry( "ShowDirectoryOverlays", false);
 
   m_dontPreview = cgs.readEntry( "DontPreview" , QStringList() );
   m_dontPreview.removeAll("audio/"); //Use the separate setting.
@@ -101,13 +102,13 @@ KonqPropsView::KonqPropsView( KInstance * instance, KonqPropsView * defaultProps
 
   //The setting for sound previews is stored separately, so we can force
   //the default-to-off bias to propagate up.
-  if (!cgs.readEntry("EnableSoundPreviews", QVariant(false)).toBool())
+  if (!cgs.readEntry("EnableSoundPreviews", false))
   {
     if (!m_dontPreview.contains("audio/"))
       m_dontPreview.append("audio/");
   }
 
-  d->previewsEnabled = cgs.readEntry( "PreviewsEnabled", QVariant(true )).toBool();
+  d->previewsEnabled = cgs.readEntry( "PreviewsEnabled", true);
 
   QColor tc = KonqFMSettings::settings()->normalTextColor();
   m_textColor = cgs.readEntry( "TextColor", tc );
@@ -147,7 +148,7 @@ bool KonqPropsView::isDescending() const
    return d->descending;
 }
 
-KConfigBase * KonqPropsView::currentConfig()
+KSharedConfigPtr KonqPropsView::currentConfig()
 {
     if ( !m_currentConfig )
     {
@@ -156,13 +157,13 @@ KConfigBase * KonqPropsView::currentConfig()
         assert ( !isDefaultProperties() );
 
         if (!dotDirectory.isEmpty())
-            m_currentConfig = new KSimpleConfig( dotDirectory );
+            m_currentConfig = KSharedConfig::openConfig(dotDirectory);
         // the "else" is when we want to save locally but this is a remote URL -> no save
     }
     return m_currentConfig;
 }
 
-KConfigBase * KonqPropsView::currentColorConfig()
+KSharedConfigPtr KonqPropsView::currentColorConfig()
 {
     // Saving locally ?
     if ( m_bSaveViewPropertiesLocally && !isDefaultProperties() )
@@ -217,11 +218,11 @@ bool KonqPropsView::enterDir( const KUrl & dir )
     m_iIconSize = config->readEntry( "IconSize", m_iIconSize );
     m_iItemTextPos = config->readEntry( "ItemTextPos", m_iItemTextPos );
     d->sortcriterion = config->readEntry( "SortingCriterion" , d->sortcriterion );
-    d->dirsfirst = config->readEntry( "SortDirsFirst", QVariant(d->dirsfirst )).toBool();
-    d->descending = config->readEntry( "SortDescending", QVariant(d->descending )).toBool();
-    m_bShowDot = config->readEntry( "ShowDotFiles", QVariant(m_bShowDot )).toBool();
-    d->caseInsensitiveSort=config->readEntry("CaseInsensitiveSort", QVariant(d->caseInsensitiveSort)).toBool();
-    m_bShowDirectoryOverlays = config->readEntry( "ShowDirectoryOverlays", QVariant(m_bShowDirectoryOverlays )).toBool();
+    d->dirsfirst = config->readEntry( "SortDirsFirst", d->dirsfirst);
+    d->descending = config->readEntry( "SortDescending", d->descending);
+    m_bShowDot = config->readEntry( "ShowDotFiles", m_bShowDot);
+    d->caseInsensitiveSort=config->readEntry("CaseInsensitiveSort", d->caseInsensitiveSort);
+    m_bShowDirectoryOverlays = config->readEntry( "ShowDirectoryOverlays", m_bShowDirectoryOverlays);
     if (config->hasKey( "DontPreview" ))
     {
         m_dontPreview = config->readEntry( "DontPreview" , QStringList() );
@@ -233,7 +234,7 @@ bool KonqPropsView::enterDir( const KUrl & dir )
         if (config->hasKey("EnableSoundPreviews"))
         {
 
-            if (!config->readEntry("EnableSoundPreviews", QVariant(false)).toBool())
+            if (!config->readEntry("EnableSoundPreviews", false))
                 if (!m_dontPreview.contains("audio/"))
                     m_dontPreview.append("audio/");
         }
@@ -251,13 +252,13 @@ bool KonqPropsView::enterDir( const KUrl & dir )
     m_bgColor = config->readEntry( "BgColor", m_bgColor );
     m_bgPixmapFile = config->readPathEntry( "BgImage", m_bgPixmapFile );
     //kDebug(1203) << "KonqPropsView::enterDir m_bgPixmapFile=" << m_bgPixmapFile << endl;
-    d->previewsEnabled = config->readEntry( "PreviewsEnabled", QVariant(d->previewsEnabled )).toBool();
+    d->previewsEnabled = config->readEntry( "PreviewsEnabled", d->previewsEnabled);
     delete config;
   }
   //if there is or was a .directory then the settings probably have changed
   bool configChanged=(m_dotDirExists|| dotDirExists);
   m_dotDirExists = dotDirExists;
-  m_currentConfig = 0L; // new dir, not current config for saving yet
+  m_currentConfig.clear(); // new dir, not current config for saving yet
   //kDebug(1203) << "KonqPropsView::enterDir returning " << configChanged << endl;
   return configChanged;
 }
@@ -267,11 +268,8 @@ void KonqPropsView::setSaveViewPropertiesLocally( bool value )
     assert( !isDefaultProperties() );
     //kDebug(1203) << "KonqPropsView::setSaveViewPropertiesLocally " << value << endl;
 
-    if ( m_bSaveViewPropertiesLocally )
-        delete m_currentConfig; // points to a KSimpleConfig
-
+    m_currentConfig.clear();
     m_bSaveViewPropertiesLocally = value;
-    m_currentConfig = 0L; // mark as dirty
 }
 
 void KonqPropsView::setIconSize( int size )
@@ -461,7 +459,7 @@ void KonqPropsView::setBgColor( const QColor & color )
     }
     else
     {
-        KConfigBase * colorConfig = currentColorConfig();
+        KSharedConfig::Ptr colorConfig = currentColorConfig();
         if (colorConfig) // 0L when saving locally but remote URL
         {
             KConfigGroup cgs(colorConfig, currentGroup());
@@ -488,7 +486,7 @@ void KonqPropsView::setTextColor( const QColor & color )
     }
     else
     {
-        KConfigBase * colorConfig = currentColorConfig();
+        KSharedConfig::Ptr colorConfig = currentColorConfig();
         if (colorConfig) // 0L when saving locally but remote URL
         {
             KConfigGroup cgs(colorConfig, currentGroup());
@@ -516,7 +514,7 @@ void KonqPropsView::setBgPixmapFile( const QString & file )
     }
     else
     {
-        KConfigBase * colorConfig = currentColorConfig();
+        KSharedConfig::Ptr colorConfig = currentColorConfig();
         if (colorConfig) // 0L when saving locally but remote URL
         {
             KConfigGroup cgs(colorConfig, currentGroup());
