@@ -386,7 +386,7 @@ void scanDirectory( QString dir, QStringList &mimeInfoList,
               kDebug(1433) << " - type=" << *type << endl;
               name = name.replace( ':', "%3A" );
 
-              QString entry = name + ":" + *type;
+              QString entry = name + ':' + *type;
               if ( !mimeInfoList.contains( entry ) ) {
                   if (!actuallyUsing) {
                       // note the plugin name
@@ -517,7 +517,7 @@ void removeExistingExtensions( QString &extension )
         if ( ext == "*" ) // some plugins have that, but we don't want to associate a mimetype with *.*!
             continue;
 
-        KMimeType::Ptr mime = KMimeType::findByURL( KUrl("file:///foo."+ext ),
+        KMimeType::Ptr mime = KMimeType::findByUrl( KUrl("file:///foo."+ext ),
                                                     0, true, true );
         if( mime->name()=="application/octet-stream" ||
             mime->comment().left(8)=="Netscape" ) {
@@ -679,7 +679,7 @@ int main( int argc, char **argv )
 
     // Tel kded to update sycoca database.
     QDBusInterface kbuildsycoca("org.kde.kded", "/kbuildsycoca",
-                                   "org.kde.kbuildsycoca");
+                                   "org.kde.kded");
     if (kbuildsycoca.isValid())
         kbuildsycoca.call("recreate");
 }
