@@ -25,8 +25,11 @@
 
 #include "nsplugin.h"
 #include "resolve.h"
-#include "dbusadaptors.h"
-#include "callback_proxy.h"
+#include "classadaptor.h"
+#include "instanceadaptor.h"
+#include "vieweradaptor.h"
+
+#include "nsplugins_callback_interface.h"
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -49,7 +52,7 @@
 #include <klocale.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kurl.h>
 #include <QX11Info>
 
@@ -588,7 +591,7 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
     // The object name is the dbus object path
    (void) new InstanceAdaptor( this );
    setObjectName( QString( "/Instance_" ) + QString::number( ++s_instanceCounter ) );
-   QDBus::sessionBus().registerObject( objectName(), this );
+   QDBusConnection::sessionBus().registerObject( objectName(), this );
 
     Q_UNUSED(embed);
    _firstResize = true;
@@ -602,7 +605,7 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
    _tempFiles.setAutoDelete( true );
    _streams.setAutoDelete( true );
    _waitingRequests.setAutoDelete( true );
-   _callback = new org::kde::nsplugins::CallBack( appId, callbackId, QDBus::sessionBus() );
+   _callback = new org::kde::nsplugins::CallBack( appId, callbackId, QDBusConnection::sessionBus() );
 
    KUrl base(src);
    base.setFileName( QString() );
@@ -843,7 +846,7 @@ QString NSPluginInstance::normalizedURL(const QString& url) const {
     KConfig cfg("kcmnspluginrc", true);
     cfg.setGroup("Misc");
 
-    if (!cfg.readEntry("HTTP URLs Only", QVariant(false)).toBool() ||
+    if (!cfg.readEntry("HTTP URLs Only", false) ||
 	inURL.protocol() == "http" ||
         inURL.protocol() == "https" ||
         inURL.protocol() == "javascript") {
@@ -1181,7 +1184,7 @@ void NSPluginInstance::NPURLNotify(QString url, NPReason reason, void *notifyDat
 }
 
 
-void NSPluginInstance::addTempFile(KTempFile *tmpFile)
+void NSPluginInstance::addTempFile(KTemporaryFile *tmpFile)
 {
    _tempFiles.append(tmpFile);
 }
@@ -1207,9 +1210,9 @@ NSPluginViewer::NSPluginViewer( QObject *parent )
    : QObject( parent )
 {
    (void) new ViewerAdaptor( this );
-   QDBus::sessionBus().registerObject( "/Viewer", this );
+   QDBusConnection::sessionBus().registerObject( "/Viewer", this );
 
-    QObject::connect(QDBus::sessionBus().interface(),
+    QObject::connect(QDBusConnection::sessionBus().interface(),
                      SIGNAL(serviceUnregistered(const QString&)),
                      this, SLOT(appUnregistered(const QString&)));
 }
@@ -1249,7 +1252,7 @@ void NSPluginViewer::shutdown()
 }
 
 
-QString NSPluginViewer::newClass( const QString& plugin, const QString& senderId )
+QDBusObjectPath NSPluginViewer::newClass( const QString& plugin, const QString& senderId )
 {
    kDebug(1431) << "NSPluginViewer::NewClass( " << plugin << ")" << endl;
 
@@ -1262,13 +1265,13 @@ QString NSPluginViewer::newClass( const QString& plugin, const QString& senderId
        if ( cls->error() ) {
            kError(1431) << "Can't create plugin class" << endl;
            delete cls;
-           return QString();
+           return QDBusObjectPath();
        }
 
        _classes.insert( plugin, cls );
    }
 
-   return cls->objectName();
+   return QDBusObjectPath(cls->objectName());
 }
 
 
@@ -1283,7 +1286,7 @@ NSPluginClass::NSPluginClass( const QString &library,
     (void) new ClassAdaptor( this );
     // The object name is used to store the dbus object path
     setObjectName( QString( "/Class_" ) + QString::number( ++s_classCounter ) );
-    QDBus::sessionBus().registerObject( objectName(), this );
+    QDBusConnection::sessionBus().registerObject( objectName(), this );
 
     // initialize members
     _handle = KLibLoader::self()->library(QFile::encodeName(library));
@@ -1408,14 +1411,14 @@ void NSPluginClass::shutdown()
 }
 
 
-QString NSPluginClass::newInstance( const QString &url, const QString &mimeType, bool embed,
+QDBusObjectPath NSPluginClass::newInstance( const QString &url, const QString &mimeType, bool embed,
                                     const QStringList &argn, const QStringList &argv,
                                     const QString &appId, const QString &callbackId, bool reload )
 {
    kDebug(1431) << "-> NSPluginClass::NewInstance" << endl;
 
    if ( !_constructed )
-       return QString();
+       return QDBusObjectPath();
 
    // copy parameters over
    unsigned int argc = argn.count();
@@ -1474,7 +1477,7 @@ QString NSPluginClass::newInstance( const QString &url, const QString &mimeType,
       delete inst;
       //delete npp;    double delete!
       kDebug(1431) << "<- PluginClass::NewInstance = 0" << endl;
-      return QString();
+      return QDBusObjectPath();
    }
 
    // create source stream
@@ -1482,7 +1485,7 @@ QString NSPluginClass::newInstance( const QString &url, const QString &mimeType,
       inst->requestURL( src, mimeType, QString(), 0, false, reload );
 
    _instances.append( inst );
-   return inst->objectName();
+   return QDBusObjectPath(inst->objectName());
 }
 
 
@@ -1558,9 +1561,9 @@ void NSPluginStreamBase::inform()
 
                 // stream into temporary file (use lower() in case the
                 // filename as an upper case X in it)
-                _tempFile = new KTempFile;
-                _tempFile->setAutoDelete( TRUE );
-                _fileURL = _tempFile->name();
+                _tempFile = new KTemporaryFile;
+                _tempFile->open();
+                _fileURL = _tempFile->fileName();
                 kDebug() << "saving into " << _fileURL << endl;
             }
         }
@@ -1600,7 +1603,9 @@ bool NSPluginStreamBase::create( const QString& url, const QString& mimeType, vo
 int NSPluginStreamBase::process( const QByteArray &data, int start )
 {
    int32 max, sent, to_sent, len;
+#ifdef __GNUC__
 #warning added a const_cast
+#endif   
    char *d = const_cast<char*>(data.data()) + start;
 
    to_sent = data.size() - start;
@@ -1627,7 +1632,7 @@ int NSPluginStreamBase::process( const QByteArray &data, int start )
       }
 
       if (_tempFile) {
-          _tempFile->dataStream()->writeRawData(d, sent);
+          _tempFile->write(d, sent);
       }
 
       to_sent -= sent;
@@ -1651,7 +1656,7 @@ bool NSPluginStreamBase::pump()
         // handle AS_FILE_ONLY streams
         if ( _onlyAsFile ) {
             if (_tempFile) {
-                _tempFile->dataStream()->writeRawData( _queue, _queue.size() );
+                _tempFile->write( _queue, _queue.size() );
 	    }
             newPos = _queuePos+_queue.size();
         } else {
