@@ -7,26 +7,29 @@
 #ifndef __SuDlg_h_Included__
 #define __SuDlg_h_Included__
 
-#include <kpassworddialog.h>
 #include <QByteArray>
 
+#include <KPasswordDialog>
+#include <kdesu/su.h>
+
 class KDEsuDialog
     : public KPasswordDialog
 {
     Q_OBJECT
 
 public:
-    KDEsuDialog(QByteArray user, QByteArray auth_user, bool enableKeep, const QString& icon , bool withIgnoreButton);
+    KDEsuDialog(QByteArray user, QByteArray authUser, bool enableKeep, const QString& icon , bool withIgnoreButton);
     ~KDEsuDialog();
 
     enum ResultCodes { AsUser = 10 };
 
-protected:
-    bool checkPassword(const char *password);
+private slots:
     void slotUser1();
+protected:
+    bool checkPassword();
 
 private:
-    QByteArray m_User;
+    SuProcess proc;
 };
 
 
