@@ -25,7 +25,7 @@
 */
 
 #include "config.h"
-
+#include "config-fish.h"
 #include <QFile>
 #include <q3socket.h>
 #include <QDateTime>
@@ -62,7 +62,7 @@
 
 #include <kdebug.h>
 #include <kmessagebox.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
@@ -72,7 +72,6 @@
 #include <time.h>
 #include <sys/stat.h>
 #include <kmimetype.h>
-#include <kmimemagic.h>
 #include <fcntl.h>
 #include <sys/socket.h>
 #include <errno.h>
@@ -123,7 +122,7 @@ static void ripper(int)
 int KDE_EXPORT kdemain( int argc, char **argv )
 {
     KLocale::setMainCatalog("kio_fish");
-    KInstance instance("fish");
+    KComponentData componentData("fish");
 
     myDebug( << "*** Starting fish " << endl);
     if (argc != 4) {
@@ -131,6 +130,8 @@ int KDE_EXPORT kdemain( int argc, char **argv )
         exit(-1);
     }
 
+    setenv("TZ", "UTC", true);
+
     struct sigaction act;
     memset(&act,0,sizeof(act));
     act.sa_handler = ripper;
@@ -431,7 +432,7 @@ bool fishProtocol::connectionStart() {
 
         const char *dev = ttyname(0);
         setpgid(0,0);
-        if (dev) close(open(dev, O_WRONLY, 0));
+        if (dev) close(::open(dev, O_WRONLY, 0));
         setpgid(0,0);
 
         if (local) {
@@ -466,7 +467,10 @@ bool fishProtocol::connectionStart() {
         FD_SET(childFd,&rfds);
         FD_ZERO(&wfds);
         if (outBufPos >= 0) FD_SET(childFd,&wfds);
-        rc = select(childFd+1, &rfds, &wfds, NULL, NULL);
+        struct timeval timeout;
+        timeout.tv_sec = 0;
+        timeout.tv_usec = 1000;
+        rc = select(childFd+1, &rfds, &wfds, NULL, &timeout);
         if (rc < 0) {
             if (errno == EINTR)
                 continue;
@@ -474,7 +478,7 @@ bool fishProtocol::connectionStart() {
             return true;
         }
         if (FD_ISSET(childFd,&wfds) && outBufPos >= 0) {
-            if (outBuf > 0) rc = write(childFd,outBuf+outBufPos,outBufLen-outBufPos);
+            if (outBuf) rc = write(childFd,outBuf+outBufPos,outBufLen-outBufPos);
             else rc = 0;
             if (rc >= 0) outBufPos += rc;
             else {
@@ -511,7 +515,7 @@ bool fishProtocol::connectionStart() {
 /**
 writes one chunk of data to stdin of child process
 */
-void fishProtocol::writeChild(const char *buf, int len) {
+void fishProtocol::writeChild(const char *buf, KIO::fileoffset_t len) {
     if (outBufPos >= 0 && outBuf) {
 #if 0
         QString debug;
@@ -528,7 +532,7 @@ void fishProtocol::writeChild(const char *buf, int len) {
 /**
 manages initial communication setup including password queries
 */
-int fishProtocol::establishConnection(char *buffer, int len) {
+int fishProtocol::establishConnection(char *buffer, KIO::fileoffset_t len) {
     QString buf;
     buf.setLatin1(buffer,len);
     int pos=0;
@@ -585,7 +589,7 @@ int fishProtocol::establishConnection(char *buffer, int len) {
                     connectionAuth.caption = i18n("SSH Authorization");
                 if ((!firstLogin || !checkCachedAuthentication(connectionAuth))) {
                     connectionAuth.password.clear(); // don't prefill
-                    if ( !openPassDlg(connectionAuth)) {
+                    if ( !openPasswordDialog(connectionAuth)) {
                         error(ERR_USER_CANCELED,connectionHost);
                         shutdownConnection();
                         return -1;
@@ -804,7 +808,7 @@ void fishProtocol::manageConnection(const QString &l) {
             redirection(url);
             break;
         case FISH_LIST:
-            myDebug( << "listReason: " << listReason << endl);
+            myDebug( << "listReason: " << static_cast<int>(listReason) << endl);
             /* Fall through */
         case FISH_STAT:
             if (line.length() > 0) {
@@ -925,7 +929,9 @@ void fishProtocol::manageConnection(const QString &l) {
                     // By default, the mimetype comes from the extension
                     // We'll use the file(1) result only as fallback [like the rest of KDE does]
                     {
-                      KMimeType::Ptr mime = KMimeType::findByURL( KUrl("fish://host/" + thisFn) );
+                      KUrl kurl("fish://host/");
+                      kurl.setFileName(thisFn);  // properly encode special chars
+                      KMimeType::Ptr mime = KMimeType::findByUrl(kurl);
                       if ( mime->name() != KMimeType::defaultMimeType() )
                           udsMime = mime->name();
                     }
@@ -975,7 +981,7 @@ void fishProtocol::manageConnection(const QString &l) {
                 recvLen = 0;
                 break;
             }
-            recvLen = line.toInt(&isOk);
+            recvLen = line.toLongLong(&isOk);
             if (!isOk) {
                 error(ERR_COULD_NOT_READ,url.prettyUrl());
                 shutdownConnection();
@@ -1054,7 +1060,7 @@ void fishProtocol::manageConnection(const QString &l) {
             error(ERR_CANNOT_ENTER_DIRECTORY,url.prettyUrl());
             break;
         case FISH_LIST:
-            myDebug( << "list error. reason: " << listReason << endl);
+            myDebug( << "list error. reason: " << static_cast<int>(listReason) << endl);
             if (listReason == LIST) error(ERR_CANNOT_ENTER_DIRECTORY,url.prettyUrl());
             else if (listReason == CHECK) {
                 checkExist = false;
@@ -1146,7 +1152,7 @@ void fishProtocol::sent()
 {
     if (rawWrite > 0) {
         myDebug( << "writing raw: " << rawData.size() << "/" << rawWrite << endl);
-        writeChild(rawData.data(),((int)rawWrite > rawData.size()?rawData.size():rawWrite));
+        writeChild(rawData.data(),(rawWrite > rawData.size()?rawData.size():rawWrite));
         rawWrite -= rawData.size();
         if (rawWrite > 0) {
             dataReq();
@@ -1174,7 +1180,7 @@ void fishProtocol::sent()
     }
 }
 
-int fishProtocol::received(const char *buffer, int buflen)
+int fishProtocol::received(const char *buffer, KIO::fileoffset_t buflen)
 {
     int pos = 0;
     do {
@@ -1185,7 +1191,7 @@ int fishProtocol::received(const char *buffer, int buflen)
             int dataSize = (rawRead > buflen?buflen:rawRead);
             if (!mimeTypeSent)
             {
-                int mimeSize = qMin(dataSize, (int)mimeBuffer.size()-dataRead);
+                int mimeSize = qMin(dataSize, (int)(mimeBuffer.size()-dataRead));
                 memcpy(mimeBuffer.data()+dataRead,buffer,mimeSize);
                 dataRead += mimeSize;
                 rawRead -= mimeSize;
@@ -1198,7 +1204,7 @@ int fishProtocol::received(const char *buffer, int buflen)
                     myDebug( << "wait for more" << endl);
                     break;
                 }
-                sendmimeType(KMimeMagic::self()->findBufferFileType(mimeBuffer,url.path())->mimeType());
+                sendmimeType(KMimeType::findByNameAndContent(url.path(), mimeBuffer)->name());
                 mimeTypeSent = true;
                 if (fishCommand != FISH_READ) {
                     totalSize(dataRead + rawRead);
@@ -1278,12 +1284,20 @@ void fishProtocol::put(const KUrl& u, int permissions, bool overwrite, bool /*re
         sendCommand(FISH_PWD);
     } else {
         putPerm = permissions;
+
         checkOverwrite = overwrite;
         checkExist = false;
         putPos = 0;
         listReason = CHECK;
         sendCommand(FISH_LIST,E(url.path()));
         sendCommand(FISH_STOR,"0",E(url.path()));
+
+        const QString mtimeStr = metaData( "modified" );
+        if ( !mtimeStr.isEmpty() ) {
+            QDateTime dt = QDateTime::fromString( mtimeStr, Qt::ISODate );
+            // TODO set modification time on url.path() somehow
+            // see FileProtocol::put if using utime() to do that.
+        }
     }
     run();
 }
@@ -1328,7 +1342,10 @@ void fishProtocol::run() {
             FD_SET(childFd,&rfds);
             FD_ZERO(&wfds);
             if (outBufPos >= 0) FD_SET(childFd,&wfds);
-            rc = select(childFd+1, &rfds, &wfds, NULL, NULL);
+            struct timeval timeout;
+            timeout.tv_sec = 0;
+            timeout.tv_usec = 1000;
+            rc = select(childFd+1, &rfds, &wfds, NULL, &timeout);
             if (rc < 0) {
                 if (errno == EINTR)
                     continue;
