@@ -32,7 +32,7 @@
 #include <QRegExp>
 
 #include <kdebug.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <kprocess.h>
@@ -432,6 +432,19 @@ extern void output_real(const char *insert)
 }
 #endif
 
+static QString text2html(const QString& txt)
+{
+    QString reply = txt;
+
+    reply = reply.replace('&', "&amp;");
+    reply = reply.replace('<', "&lt;");
+    reply = reply.replace('>', "&gt;");
+    reply = reply.replace('"', "&dquot;");
+    reply = reply.replace('\'', "&quot;");
+    return reply;
+}
+
+
 void MANProtocol::get(const KUrl& url )
 {
     kDebug(7107) << "GET " << url.url() << endl;
@@ -466,7 +479,7 @@ void MANProtocol::get(const KUrl& url )
            "Be careful that you must take care about upper case and lower case characters!<br>"
            "If everything looks correct, then perhaps you need to set a better search path "
            "for man pages, be it by the environment variable MANPATH or a matching file "
-           "in the directory /etc .", title));
+           "in the directory /etc .", text2html(title)));
        pageFound=false;
     }
     else if (foundPages.count()>1)
@@ -675,7 +688,7 @@ extern "C"
 
     int KDE_EXPORT kdemain( int argc, char **argv ) {
 
-        KInstance instance("kio_man");
+        KComponentData componentData("kio_man");
 
         kDebug(7107) <<  "STARTING " << getpid() << endl;
 
@@ -1072,7 +1085,9 @@ void MANProtocol::checkManPaths()
 //#define _USE_OLD_CODE
 
 #ifdef _USE_OLD_CODE
+#ifdef __GNUC__
 #warning "using old code"
+#endif
 #else
 
 // Define this, if you want to compile with qsort from stdlib.h
@@ -1130,7 +1145,9 @@ int compare_man_index(const void *s1, const void *s2)
 }
 
 #else /* !_USE_QSORT */
+#ifdef __GNUC__
 #warning using heapsort
+#endif
 // Set up my own man page list,
 // with a special compare function to sort itself
 typedef QList<struct man_index_t*> QManIndexListBase;
