@@ -29,12 +29,11 @@ So we can't connect.
 
 #include <fcntl.h>
 
-#include <q3cstring.h>
-#include <QString>
-#include <QObject>
-#include <q3strlist.h>
-#include <QFile>
-#include <QBuffer>
+#include <QtCore/QBuffer>
+#include <QtCore/QByteArray>
+#include <QtCore/QFile>
+#include <QtCore/QObject>
+#include <QtCore/QString>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -56,14 +55,13 @@ So we can't connect.
 #include <kuser.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kurl.h>
 #include <kio/ioslave_defaults.h>
 #include <kmimetype.h>
-#include <kmimemagic.h>
 #include <kde_file.h>
 #include <kremoteencoding.h>
 
@@ -79,7 +77,7 @@ extern "C"
 {
   int KDE_EXPORT kdemain( int argc, char **argv )
   {
-    KInstance instance( "kio_sftp" );
+    KComponentData componentData( "kio_sftp" );
 
     kDebug(KIO_SFTP_DB) << "*** Starting kio_sftp " << endl;
 
@@ -216,7 +214,7 @@ void sftpProtocol::sftpCopyGet(const KUrl& dest, const KUrl& src, int mode, bool
         return;
 
     KDE_struct_stat buff_orig;
-    Q3CString dest_orig ( QFile::encodeName(dest.path()) );
+    QByteArray dest_orig ( QFile::encodeName(dest.path()) );
     bool origExists = (KDE_lstat( dest_orig.data(), &buff_orig ) != -1);
 
     if (origExists)
@@ -235,11 +233,11 @@ void sftpProtocol::sftpCopyGet(const KUrl& dest, const KUrl& src, int mode, bool
     }
 
     KIO::filesize_t offset = 0;
-    Q3CString dest_part ( dest_orig + ".part" );
+    QByteArray dest_part ( dest_orig + ".part" );
 
     int fd = -1;
     bool partExists = false;
-    bool markPartial = config()->readEntry("MarkPartial", QVariant(true)).toBool();
+    bool markPartial = config()->readEntry("MarkPartial", true);
 
     if (markPartial)
     {
@@ -384,11 +382,10 @@ sftpProtocol::Status sftpProtocol::sftpGet( const KUrl& src, KIO::filesize_t off
 
                 if( mimeBuffer.size() > 1024 ||  offset == fileSize ) {
                     // determine mimetype
-                    KMimeMagicResult* result =
-                        KMimeMagic::self()->findBufferFileType(mimeBuffer, src.fileName());
+                    KMimeType::Ptr mime = KMimeType::findByNameAndContent(src.fileName(), mimeBuffer);
                     kDebug(KIO_SFTP_DB) << "sftpGet(): mimetype is " <<
-                                      result->mimeType() << endl;
-                    mimeType(result->mimeType());
+                                      mime->name() << endl;
+                    mimeType(mime->name());
 
                     // Always send the total size after emitting mime-type...
                     totalSize(fileSize);
@@ -637,9 +634,9 @@ void sftpProtocol::openConnection() {
                                  << ", info.url = " << info.url.prettyUrl() << endl;
 
             if( firstTime )
-                dlgResult = openPassDlg(info);
+                dlgResult = openPasswordDialog(info);
             else
-                dlgResult = openPassDlg(info, i18n("Incorrect username or password"));
+                dlgResult = openPasswordDialog(info, i18n("Incorrect username or password"));
 
             if( dlgResult ) {
                if( info.username.isEmpty() || info.password.isEmpty() ) {
@@ -842,7 +839,7 @@ void sftpProtocol::closeConnection() {
 void sftpProtocol::sftpCopyPut(const KUrl& src, const KUrl& dest, int permissions, bool overwrite) {
 
     KDE_struct_stat buff;
-    Q3CString file (QFile::encodeName(src.path()));
+    QByteArray file (QFile::encodeName(src.path()));
 
     if (KDE_lstat(file.data(), &buff) == -1) {
         error (ERR_DOES_NOT_EXIST, src.prettyUrl());
@@ -917,7 +914,7 @@ void sftpProtocol::sftpPut( const KUrl& dest, int permissions, bool resume, bool
 
     quint64 offset = 0;
     bool partExists = false;
-    bool markPartial = config()->readEntry("MarkPartial", QVariant(true)).toBool();
+    bool markPartial = config()->readEntry("MarkPartial", true);
 
     if( markPartial ) {
 
@@ -1240,7 +1237,7 @@ void sftpProtocol::mkdir(const KUrl&url, int permissions){
     if( !mConnected )
         return;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     sftpFileAttr attr(remoteEncoding());
@@ -1527,7 +1524,7 @@ int sftpProtocol::sftpRealPath(const KUrl& url, KUrl& newUrl){
 
     kDebug(KIO_SFTP_DB) << "sftpRealPath(" << url << ", newUrl)" << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     quint32 id, expectedId;
@@ -1570,7 +1567,7 @@ int sftpProtocol::sftpRealPath(const KUrl& url, KUrl& newUrl){
         return -1;
     }
 
-    Q3CString newPath;
+    QByteArray newPath;
     r >> newPath;
 
     newPath.truncate(newPath.size());
@@ -1631,7 +1628,7 @@ int sftpProtocol::sftpOpenDirectory(const KUrl& url, QByteArray& handle){
 
     kDebug(KIO_SFTP_DB) << "sftpOpenDirectory(" << url << ", handle)" << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     quint32 id, expectedId;
@@ -1724,7 +1721,7 @@ int sftpProtocol::sftpSetStat(const KUrl& url, const sftpFileAttr& attr){
 
     kDebug(KIO_SFTP_DB) << "sftpSetStat(" << url << ", attr)" << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     quint32 id, expectedId;
@@ -1770,7 +1767,7 @@ int sftpProtocol::sftpRemove(const KUrl& url, bool isfile){
 
     kDebug(KIO_SFTP_DB) << "sftpRemove(): " << url << ", isFile ? " << isfile << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     quint32 id, expectedId;
@@ -1814,8 +1811,8 @@ int sftpProtocol::sftpRename(const KUrl& src, const KUrl& dest){
 
     kDebug(KIO_SFTP_DB) << "sftpRename(" << src << " -> " << dest << ")" << endl;
 
-    Q3CString srcPath = remoteEncoding()->encode(src.path());
-    Q3CString destPath = remoteEncoding()->encode(dest.path());
+    QByteArray srcPath = remoteEncoding()->encode(src.path());
+    QByteArray destPath = remoteEncoding()->encode(dest.path());
 
     uint slen = srcPath.length();
     uint dlen = destPath.length();
@@ -1929,7 +1926,7 @@ int sftpProtocol::sftpReadLink(const KUrl& url, QString& target){
 
     kDebug(KIO_SFTP_DB) << "sftpReadLink(): " << url << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     //kDebug(KIO_SFTP_DB) << "sftpReadLink(): Encoded Path: " << path << endl;
@@ -1977,7 +1974,7 @@ int sftpProtocol::sftpReadLink(const KUrl& url, QString& target){
         return -1;
     }
 
-    Q3CString linkAddress;
+    QByteArray linkAddress;
     r >> linkAddress;
 
     linkAddress.truncate(linkAddress.size());
@@ -1990,8 +1987,8 @@ int sftpProtocol::sftpReadLink(const KUrl& url, QString& target){
 
 int sftpProtocol::sftpSymLink(const QString& _target, const KUrl& dest){
 
-    Q3CString destPath = remoteEncoding()->encode(dest.path());
-    Q3CString target = remoteEncoding()->encode(_target);
+    QByteArray destPath = remoteEncoding()->encode(dest.path());
+    QByteArray target = remoteEncoding()->encode(_target);
     uint dlen = destPath.length();
     uint tlen = target.length();
 
@@ -2041,7 +2038,7 @@ int sftpProtocol::sftpStat(const KUrl& url, sftpFileAttr& attr) {
 
     kDebug(KIO_SFTP_DB) << "sftpStat(): " << url << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     quint32 id, expectedId;
@@ -2129,7 +2126,7 @@ int sftpProtocol::sftpOpen(const KUrl& url, const quint32 pflags,
                            const sftpFileAttr& attr, QByteArray& handle) {
     kDebug(KIO_SFTP_DB) << "sftpOpen(" << url << ", handle" << endl;
 
-    Q3CString path = remoteEncoding()->encode(url.path());
+    QByteArray path = remoteEncoding()->encode(url.path());
     uint len = path.length();
 
     quint32 id, expectedId;
