@@ -31,6 +31,7 @@
 #include <kapplication.h>
 #include <kio/netaccess.h>
 #include <kio/job.h>
+#include <kio/copyjob.h>
 #include <kdebug.h>
 #include <kcmdlineargs.h>
 
@@ -45,6 +46,7 @@
 #include <assert.h>
 #include <kfileitem.h>
 #include <kstandarddirs.h>
+#include <kio/chmodjob.h>
 
 static bool check(QString a, QString b)
 {
@@ -101,6 +103,11 @@ QString TestTrash::homeTmpDir() const
     return QDir::homePath() + "/.kde/testtrash/";
 }
 
+QString TestTrash::readOnlyDirPath() const
+{
+    return homeTmpDir() + QString( "readonly" );
+}
+
 QString TestTrash::otherTmpDir() const
 {
     // This one needs to be on another partition
@@ -131,6 +138,24 @@ static void removeDir( const QString& trashDir, const QString& dirName )
     assert( !QDir( trashDir + dirName ).exists() );
 }
 
+static void removeDirRecursive( const QString& dir )
+{
+    if ( QFileInfo( dir ).exists() ) {
+
+        // Make it work even with readonly dirs, like trashReadOnlyDirFromHome() creates
+        KUrl u = KUrl::fromPath( dir );
+        KFileItem fileItem( u, "inode/directory", KFileItem::Unknown );
+        KFileItemList fileItemList;
+        fileItemList.append( &fileItem );
+        KIO::ChmodJob* chmodJob = KIO::chmod( fileItemList, 0200, 0200, QString::null, QString::null, true /*recursive*/, false /*showProgressInfo*/ );
+        KIO::NetAccess::synchronousRun( chmodJob, 0 );
+
+        bool ok = KIO::NetAccess::del( u, 0 );
+        if ( !ok )
+            kFatal() << "Couldn't delete " << dir << endl;
+    }
+}
+
 void TestTrash::setup()
 {
     m_trashDir = KGlobal::dirs()->localxdgdatadir() + "Trash";
@@ -194,8 +219,9 @@ void TestTrash::setup()
         kWarning() << "No writable partition other than $HOME found, some tests will be skipped" << endl;
 
     // Start with a clean base dir
-    KIO::NetAccess::del( KUrl::fromPath( homeTmpDir() ), 0 );
-    KIO::NetAccess::del( KUrl::fromPath( otherTmpDir() ), 0 );
+    removeDirRecursive( homeTmpDir() );
+    removeDirRecursive( otherTmpDir() );
+
     QDir dir; // TT: why not a static method?
     bool ok = dir.mkdir( homeTmpDir() );
     if ( !ok )
@@ -203,46 +229,10 @@ void TestTrash::setup()
     ok = dir.mkdir( otherTmpDir() );
     if ( !ok )
         kFatal() << "Couldn't create " << otherTmpDir() << endl;
-    cleanTrash();
-}
 
-
-void TestTrash::cleanTrash()
-{
-    // Start with a relatively clean trash too
-    removeFile( m_trashDir, "/info/fileFromHome.trashinfo" );
-    removeFile( m_trashDir, "/files/fileFromHome" );
-    removeFile( m_trashDir, "/info/fileFromHome_1.trashinfo" );
-    removeFile( m_trashDir, "/files/fileFromHome_1" );
-    removeFile( m_trashDir, "/info/file%2f.trashinfo" );
-    removeFile( m_trashDir, "/files/file%2f" );
-    removeFile( m_trashDir, "/info/" + utf8FileName() + ".trashinfo" );
-    removeFile( m_trashDir, "/files/" + utf8FileName() );
-    removeFile( m_trashDir, "/info/" + umlautFileName() + ".trashinfo" );
-    removeFile( m_trashDir, "/files/" + umlautFileName() );
-    removeFile( m_trashDir, "/info/fileFromOther.trashinfo" );
-    removeFile( m_trashDir, "/files/fileFromOther" );
-    removeFile( m_trashDir, "/info/symlinkFromHome.trashinfo" );
-    removeFile( m_trashDir, "/files/symlinkFromHome" );
-    removeFile( m_trashDir, "/info/symlinkFromOther.trashinfo" );
-    removeFile( m_trashDir, "/files/symlinkFromOther" );
-    removeFile( m_trashDir, "/info/brokenSymlinkFromHome.trashinfo" );
-    removeFile( m_trashDir, "/files/brokenSymlinkFromHome" );
-    removeFile( m_trashDir, "/info/trashDirFromHome.trashinfo" );
-    removeFile( m_trashDir, "/files/trashDirFromHome/testfile" );
-    removeDir( m_trashDir, "/files/trashDirFromHome" );
-    removeFile( m_trashDir, "/info/trashDirFromHome_1.trashinfo" );
-    removeFile( m_trashDir, "/files/trashDirFromHome_1/testfile" );
-    removeDir( m_trashDir, "/files/trashDirFromHome_1" );
-    removeFile( m_trashDir, "/info/trashDirFromOther.trashinfo" );
-    removeFile( m_trashDir, "/files/trashDirFromOther/testfile" );
-    removeDir( m_trashDir, "/files/trashDirFromOther" );
-    // for trashDirectoryOwnedByRoot
-    KIO::NetAccess::del( KUrl::fromPath( m_trashDir + "/files/cups" ), 0 );
-    KIO::NetAccess::del( KUrl::fromPath( m_trashDir + "/files/boot" ), 0 );
-    KIO::NetAccess::del( KUrl::fromPath( m_trashDir + "/files/etc" ), 0 );
-
-    //system( "find ~/.local-testtrash/share/Trash" );
+    kDebug() << k_funcinfo << endl;
+    // Start with a clean trash too
+    removeDirRecursive( m_trashDir );
 }
 
 void TestTrash::runAll()
@@ -259,6 +249,7 @@ void TestTrash::runAll()
     trashUtf8FileFromHome();
 #endif
     trashUmlautFileFromHome();
+    trashReadOnlyDirFromHome();
     testTrashNotEmpty();
     trashFileFromOther();
     trashFileIntoOtherPartition();
@@ -469,7 +460,7 @@ void TestTrash::testTrashNotEmpty()
     KSimpleConfig cfg( "trashrc", true );
     assert( cfg.hasGroup( "Status" ) );
     cfg.setGroup( "Status" );
-    assert( cfg.readEntry( "Empty", QVariant(true )).toBool() == false );
+    assert( cfg.readEntry( "Empty", true ) == false );
 }
 
 void TestTrash::trashFileFromOther()
@@ -604,14 +595,16 @@ void TestTrash::trashDirectory( const QString& origPath, const QString& fileId )
 {
     kDebug() << k_funcinfo << fileId << endl;
     // setup
-    QDir dir;
-    bool ok = dir.mkdir( origPath );
-    Q_ASSERT( ok );
+    if ( !QFileInfo( origPath ).exists() ) {
+        QDir dir;
+        bool ok = dir.mkdir( origPath );
+        Q_ASSERT( ok );
+    }
     createTestFile( origPath + "/testfile" );
     KUrl u; u.setPath( origPath );
 
     // test
-    ok = KIO::NetAccess::move( u, KUrl("trash:/") );
+    bool ok = KIO::NetAccess::move( u, KUrl("trash:/") );
     assert( ok );
     if ( origPath.startsWith( "/tmp" ) && m_tmpIsWritablePartition ) {
         kDebug() << " TESTS SKIPPED" << endl;
@@ -637,6 +630,23 @@ void TestTrash::trashDirectoryFromHome()
     trashDirectory( homeTmpDir() + dirName, dirName + "_1" );
 }
 
+void TestTrash::trashReadOnlyDirFromHome()
+{
+    kDebug() << k_funcinfo << endl;
+    const QString dirName = readOnlyDirPath();
+    QDir dir;
+    bool ok = dir.mkdir( dirName );
+    Q_ASSERT( ok );
+    // #130780
+    const QString subDirPath = dirName + "/readonly_subdir";
+    ok = dir.mkdir( subDirPath );
+    Q_ASSERT( ok );
+    createTestFile( subDirPath + "/testfile_in_subdir" );
+    ::chmod( QFile::encodeName( subDirPath ), 0500 );
+
+    trashDirectory( dirName, "readonly" );
+}
+
 void TestTrash::trashDirectoryFromOther()
 {
     kDebug() << k_funcinfo << endl;
@@ -1133,9 +1143,9 @@ void TestTrash::emptyTrash()
 #if 0
     kDebug() << k_funcinfo << endl;
     QByteArray packedArgs;
-    QDataStream stream( packedArgs, QIODevice::WriteOnly );
+    QDataStream stream( &packedArgs, QIODevice::WriteOnly );
     stream << (int)1;
-    KIO::Job* job = KIO::special( "trash:/", packedArgs );
+    KIO::Job* job = KIO::special( KUrl( "trash:/" ), packedArgs );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     assert( ok );
 
@@ -1143,6 +1153,10 @@ void TestTrash::emptyTrash()
     assert( cfg.hasGroup( "Status" ) );
     cfg.setGroup( "Status" );
     assert( cfg.readEntry( "Empty", QVariant(false )).toBool() == true );
+
+    assert( !QFile::exists( m_trashDir + "/files/fileFromHome" ) );
+    assert( !QFile::exists( m_trashDir + "/files/readonly" ) );
+    assert( !QFile::exists( m_trashDir + "/info/readonly.trashinfo" ) );
 #else
     kDebug() << k_funcinfo << " : SKIPPED" << endl;
 #endif
@@ -1150,7 +1164,7 @@ void TestTrash::emptyTrash()
 
 static void checkIcon( const KUrl& url, const QString& expectedIcon )
 {
-    QString icon = KMimeType::iconNameForURL( url );
+    QString icon = KMimeType::iconNameForUrl( url );
     COMPARE( icon, expectedIcon );
 }
 
