@@ -21,15 +21,19 @@
 #include <klocale.h>
 #include <kde_file.h>
 #include <kio/global.h>
-#include <kio/renamedlg.h>
+#include <kio/renamedialog.h>
 #include <kio/job.h>
+#include <kio/chmodjob.h>
+#include <kio/copyjob.h>
+#include <kio/deletejob.h>
 #include <kdebug.h>
 #include <kurl.h>
 #include <kdirnotify.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <kglobalsettings.h>
-#include <kmountpoint.h>
+#include <kfileitem.h>
+#include <kconfiggroup.h>
 
 #include <QApplication>
 #include <QEventLoop>
@@ -46,11 +50,14 @@
 #include <stdlib.h>
 #include <errno.h>
 
+#include <solid/devicemanager.h>
+#include <solid/device.h>
+#include <solid/volume.h>
+
 TrashImpl::TrashImpl() :
     QObject(),
     m_lastErrorCode( 0 ),
     m_initStatus( InitToBeDone ),
-    m_lastId( 0 ),
     m_homeDevice( 0 ),
     m_trashDirectoriesScanned( false ),
     // not using kio_trashrc since KIO uses that one already for kio_trash
@@ -68,9 +75,10 @@ TrashImpl::TrashImpl() :
 /**
  * Test if a directory exists, create otherwise
  * @param _name full path of the directory
- * @return true if the dir was created or existed already
+ * @return errorcode, or 0 if the dir was created or existed already
+ * Warning, don't use return value like a bool
  */
-bool TrashImpl::testDir( const QString &_name )
+int TrashImpl::testDir( const QString &_name ) const
 {
   DIR *dp = opendir( QFile::encodeName(_name) );
   if ( dp == NULL )
@@ -92,12 +100,11 @@ bool TrashImpl::testDir( const QString &_name )
                 ok = false;
             }
             if ( !ok ) {
-                error( KIO::ERR_DIR_ALREADY_EXIST, name );
-                return false;
+                return KIO::ERR_DIR_ALREADY_EXIST;
             }
 #if 0
         //} else {
-        //    return false;
+        //    return 0;
         //}
 #endif
     }
@@ -105,8 +112,7 @@ bool TrashImpl::testDir( const QString &_name )
     {
         //KMessageBox::sorry( 0, i18n( "Could not create directory %1. Check for permissions." ).arg( name ) );
         kWarning() << "could not create " << name << endl;
-        error( KIO::ERR_COULD_NOT_MKDIR, name );
-        return false;
+        return KIO::ERR_COULD_NOT_MKDIR;
     } else {
         kDebug() << name << " created." << endl;
     }
@@ -115,7 +121,7 @@ bool TrashImpl::testDir( const QString &_name )
   {
     closedir( dp );
   }
-  return true;
+  return 0; // success
 }
 
 bool TrashImpl::init()
@@ -136,12 +142,19 @@ bool TrashImpl::init()
     }
 
     const QString trashDir = xdgDataDir + "Trash";
-    if ( !testDir( trashDir ) )
+    int err;
+    if ( ( err = testDir( trashDir ) ) ) {
+        error( err, trashDir );
         return false;
-    if ( !testDir( trashDir + "/info" ) )
+    }
+    if ( ( err = testDir( trashDir + "/info" ) ) ) {
+        error( err, trashDir + "/info" );
         return false;
-    if ( !testDir( trashDir + "/files" ) )
+    }
+    if ( ( err = testDir( trashDir + "/files" ) ) ) {
+        error( err, trashDir + "/files" );
         return false;
+    }
     m_trashDirectories.insert( 0, trashDir );
     m_initStatus = InitOK;
     kDebug() << k_funcinfo << "initialization OK, home trash dir: " << trashDir << endl;
@@ -186,7 +199,7 @@ void TrashImpl::migrateOldTrash()
     if ( allOK ) {
         // We need to remove the old one, otherwise the desktop will have two trashcans...
         kDebug() << "Trash migration: all OK, removing old trash directory" << endl;
-        synchronousDel( oldTrashDir, false );
+        synchronousDel( oldTrashDir, false, true );
     }
 }
 
@@ -228,7 +241,7 @@ bool TrashImpl::createInfo( const QString& origPath, int& trashId, QString& file
         fd = ::open( QFile::encodeName( url.path() ), O_WRONLY | O_CREAT | O_EXCL, 0600 );
         if ( fd < 0 ) {
             if ( errno == EEXIST ) {
-                url.setFileName( KIO::RenameDlg::suggestName( baseDirectory, url.fileName() ) );
+                url.setFileName( KIO::RenameDialog::suggestName( baseDirectory, url.fileName() ) );
                 // and try again on the next iteration
             } else {
                 error( KIO::ERR_COULD_NOT_WRITE, url.path() );
@@ -334,7 +347,7 @@ bool TrashImpl::moveToTrash( const QString& origPath, int trashId, const QString
         if ( QFileInfo( dest ).isFile() )
             QFile::remove( dest );
         else
-            synchronousDel( dest, false );
+            synchronousDel( dest, false, true );
         return false;
     }
     fileAdded();
@@ -369,9 +382,7 @@ bool TrashImpl::move( const QString& src, const QString& dest )
     urlDest.setPath( dest );
     kDebug() << k_funcinfo << urlSrc << " -> " << urlDest << endl;
     KIO::CopyJob* job = KIO::moveAs( urlSrc, urlDest, false );
-#ifdef KIO_COPYJOB_HAS_SETINTERACTIVE
     job->setUiDelegate(0);
-#endif
     connect( job, SIGNAL( result(KJob*) ),
              this, SLOT( jobFinished(KJob*) ) );
     enterLoop();
@@ -416,9 +427,7 @@ bool TrashImpl::copy( const QString& src, const QString& dest )
     urlDest.setPath( dest );
     kDebug() << k_funcinfo << "copying " << src << " to " << dest << endl;
     KIO::CopyJob* job = KIO::copyAs( urlSrc, urlDest, false );
-#ifdef KIO_COPYJOB_HAS_SETINTERACTIVE
     job->setUiDelegate(0);
-#endif
     connect( job, SIGNAL( result(KJob*) ),
              this, SLOT( jobFinished(KJob*) ) );
     enterLoop();
@@ -485,20 +494,33 @@ bool TrashImpl::del( int trashId, const QString& fileId )
         return false;
     }
 
-    QFile::remove( info );
-
-    if ( !synchronousDel( file, true ) )
+    if ( !synchronousDel( file, true, QFileInfo(file).isDir() ) )
         return false;
+
+    QFile::remove( info );
     fileRemoved();
     return true;
 }
 
-bool TrashImpl::synchronousDel( const QString& path, bool setLastErrorCode )
+bool TrashImpl::synchronousDel( const QString& path, bool setLastErrorCode, bool isDir )
 {
     const int oldErrorCode = m_lastErrorCode;
     const QString oldErrorMsg = m_lastErrorMessage;
     KUrl url;
     url.setPath( path );
+    // First ensure that all dirs have u+w permissions,
+    // otherwise we won't be able to delete files in them (#130780).
+    if ( isDir ) {
+        kDebug() << k_funcinfo << "chmod'ing " << url << endl;
+        KFileItem fileItem( url, "inode/directory", KFileItem::Unknown );
+        KFileItemList fileItemList;
+        fileItemList.append( &fileItem );
+        KIO::ChmodJob* chmodJob = KIO::chmod( fileItemList, 0200, 0200, QString::null, QString::null, true /*recursive*/, false /*showProgressInfo*/ );
+        connect( chmodJob, SIGNAL( result(KJob *) ),
+                 this, SLOT( jobFinished(KJob *) ) );
+        enterLoop();
+    }
+
     KIO::DeleteJob *job = KIO::del( url, false, false );
     connect( job, SIGNAL( result(KJob*) ),
              this, SLOT( jobFinished(KJob*) ) );
@@ -511,24 +533,28 @@ bool TrashImpl::synchronousDel( const QString& path, bool setLastErrorCode )
     return ok;
 }
 
-void TrashImpl::emptyTrash()
+bool TrashImpl::emptyTrash()
 {
     kDebug() << k_funcinfo << endl;
-    if ( !m_trashDirectoriesScanned )
-        scanTrashDirectories();
-    // For each known trash directory...
-    TrashDirMap::const_iterator it = m_trashDirectories.begin();
-    for ( ; it != m_trashDirectories.end() ; ++it ) {
-        QDir dir;
-        const QString infoPath = it.value() + "/info";
-        // TODO show errors (with warning()), e.g. when permission denied?
-        synchronousDel( infoPath, false );
-        dir.mkdir( infoPath );
-        const QString filesPath = it.value() + "/files";
-        synchronousDel( filesPath, false );
-        dir.mkdir( filesPath );
+    // The naive implementation "delete info and files in every trash directory"
+    // breaks when deleted directories contain files owned by other users.
+    // We need to ensure that the .trashinfo file is only removed when the
+    // corresponding files could indeed be removed.
+
+    const TrashedFileInfoList fileInfoList = list();
+
+    TrashedFileInfoList::const_iterator it = fileInfoList.begin();
+    const TrashedFileInfoList::const_iterator end = fileInfoList.end();
+    for ( ; it != end ; ++it ) {
+        const TrashedFileInfo& info = *it;
+        const QString filesPath = info.physicalPath;
+        if ( synchronousDel( filesPath, true, true ) ) {
+            QFile::remove( infoPath( info.trashId, info.fileId ) );
+        } // else error code is set
     }
     fileRemoved();
+
+    return m_lastErrorCode == 0;
 }
 
 TrashImpl::TrashedFileInfoList TrashImpl::list()
@@ -658,7 +684,7 @@ bool TrashImpl::isEmpty() const
 void TrashImpl::fileAdded()
 {
     m_config.setGroup( "Status" );
-    if ( m_config.readEntry( "Empty", QVariant(true )).toBool() == true ) {
+    if ( m_config.readEntry( "Empty", true) == true ) {
         m_config.writeEntry( "Empty", false );
         m_config.sync();
     }
@@ -679,6 +705,13 @@ void TrashImpl::fileRemoved()
     // which will be done by the job soon after this.
 }
 
+static int idForDevice(const Solid::Device& device)
+{
+    const Solid::Volume* volume = device.as<Solid::Volume>();
+    kDebug() << "major=" << volume->deviceMajor() << " minor=" << volume->deviceMinor() << endl;
+    return volume->deviceMajor()*1000 + volume->deviceMinor();
+}
+
 int TrashImpl::findTrashDirectory( const QString& origPath )
 {
     kDebug() << k_funcinfo << origPath << endl;
@@ -709,33 +742,39 @@ int TrashImpl::findTrashDirectory( const QString& origPath )
     m_topDirectories.insert( m_lastId, mountPoint );
     return m_lastId;
 #endif
-    scanTrashDirectories();
+
+    const Solid::DeviceList lst = Solid::DeviceManager::self().findDevicesFromQuery("Volume.mounted == true AND Volume.mountPoint == '"+mountPoint+"'");
+    // Pretend we got exactly one...
+    const Solid::Device device = lst[0];
+
+    // new trash dir found, register it
+    id = idForDevice( device );
+    m_trashDirectories.insert( id, trashDir );
+    kDebug() << k_funcinfo << "found " << trashDir << " gave it id " << id << endl;
+    if ( !mountPoint.endsWith( "/" ) )
+        mountPoint += '/';
+    m_topDirectories.insert( id, mountPoint );
+
     return idForTrashDirectory( trashDir );
 }
 
 void TrashImpl::scanTrashDirectories() const
 {
-    const KMountPoint::List lst = KMountPoint::currentMountPoints();
-    for ( KMountPoint::List::ConstIterator it = lst.begin() ; it != lst.end() ; ++it ) {
-        const QByteArray str = (*it)->mountType().toLatin1();
-        // Skip pseudo-filesystems, there's no chance we'll find a .Trash on them :)
-        // ## Maybe we should also skip readonly filesystems
-        if ( str != "proc" && str != "devfs" && str != "usbdevfs" &&
-             str != "sysfs" && str != "devpts" && str != "subfs" /* #96259 */ &&
-             str != "autofs" /* #101116 */ ) {
-            QString topdir = (*it)->mountPoint();
-            QString trashDir = trashForMountPoint( topdir, false );
-            if ( !trashDir.isEmpty() ) {
-                // OK, trashDir is a valid trash directory. Ensure it's registered.
-                int trashId = idForTrashDirectory( trashDir );
-                if ( trashId == -1 ) {
-                    // new trash dir found, register it
-                    m_trashDirectories.insert( ++m_lastId, trashDir );
-                    kDebug() << k_funcinfo << "found " << trashDir << " gave it id " << m_lastId << endl;
-                    if ( !topdir.endsWith( "/" ) )
-                        topdir += '/';
-                    m_topDirectories.insert( m_lastId, topdir );
-                }
+    const Solid::DeviceList lst = Solid::DeviceManager::self().findDevicesFromQuery("Volume.mounted == true");
+    for ( Solid::DeviceList::ConstIterator it = lst.begin() ; it != lst.end() ; ++it ) {
+        QString topdir = (*it).as<Solid::Volume>()->mountPoint();
+        QString trashDir = trashForMountPoint( topdir, false );
+        if ( !trashDir.isEmpty() ) {
+            // OK, trashDir is a valid trash directory. Ensure it's registered.
+            int trashId = idForTrashDirectory( trashDir );
+            if ( trashId == -1 ) {
+                // new trash dir found, register it
+                trashId = idForDevice( *it );
+                m_trashDirectories.insert( trashId, trashDir );
+                kDebug() << k_funcinfo << "found " << trashDir << " gave it id " << trashId << endl;
+                if ( !topdir.endsWith( "/" ) )
+                    topdir += '/';
+                m_topDirectories.insert( trashId, topdir );
             }
         }
     }
@@ -800,7 +839,9 @@ QString TrashImpl::trashForMountPoint( const QString& topdir, bool createIfNeede
              && (S_ISDIR(buff.st_mode)) // must be a dir
              && (!S_ISLNK(buff.st_mode)) // not a symlink
              && ((buff.st_mode & 0777) == 0700) ) { // rwx for user, ------ for group and others
-            return trashDir;
+
+            if ( checkTrashSubdirs( trashDir_c ) )
+                return trashDir;
         }
         kDebug() << "Directory " << trashDir << " exists but didn't pass the security checks, can't use it" << endl;
         // Exists, but not useable
@@ -826,8 +867,10 @@ int TrashImpl::idForTrashDirectory( const QString& trashDir ) const
 
 bool TrashImpl::initTrashDirectory( const QByteArray& trashDir_c ) const
 {
+    kDebug() << k_funcinfo << trashDir_c << endl;
     if ( KDE_mkdir( trashDir_c, 0700 ) != 0 )
         return false;
+    kDebug() << k_funcinfo << endl;
     // This trash dir will be useable only if the directory is owned by user.
     // In theory this is the case, but not on e.g. USB keys...
     uid_t uid = getuid();
@@ -837,12 +880,8 @@ bool TrashImpl::initTrashDirectory( const QByteArray& trashDir_c ) const
     if ( (buff.st_uid == uid) // must be owned by user
          && ((buff.st_mode & 0777) == 0700) ) { // rwx for user, --- for group and others
 
-        QByteArray info_c = trashDir_c + "/info";
-        if ( KDE_mkdir( info_c, 0700 ) != 0 )
-            return false;
-        QByteArray files_c = trashDir_c + "/files";
-        if ( KDE_mkdir( files_c, 0700 ) != 0 )
-            return false;
+        return checkTrashSubdirs( trashDir_c );
+
     } else {
         kDebug() << trashDir_c << " just created, by it doesn't have the right permissions, must be a FAT partition. Removing it again." << endl;
         // Not good, e.g. USB key. Delete again.
@@ -856,6 +895,19 @@ bool TrashImpl::initTrashDirectory( const QByteArray& trashDir_c ) const
     return true;
 }
 
+bool TrashImpl::checkTrashSubdirs( const QByteArray& trashDir_c ) const
+{
+    // testDir currently works with a QString - ## optimize
+    QString trashDir = QFile::decodeName( trashDir_c );
+    const QString info = trashDir + "/info";
+    if ( testDir( info ) != 0 )
+        return false;
+    const QString files = trashDir + "/files";
+    if ( testDir( files ) != 0 )
+        return false;
+    return true;
+}
+
 QString TrashImpl::trashDirectoryPath( int trashId ) const
 {
     // Never scanned for trash dirs? (This can happen after killing kio_trash
