@@ -2,7 +2,7 @@
     Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
     Copyright (C) 2000 Yves Arrouye <yves@realnames.com>
     Copyright (C) 2002, 2003 Dawit Alemayehu <adawit@kde.org>
-    
+
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -26,16 +26,14 @@
 
 #include <kurifilter.h>
 
-class KInstance;
-
-class KAutoWebSearch : public KURIFilterPlugin
+class KAutoWebSearch : public KUriFilterPlugin
 {
     Q_OBJECT
 public:
     KAutoWebSearch(QObject *parent = 0, const QStringList &args = QStringList() );
     ~KAutoWebSearch();
 
-    virtual bool filterURI( KURIFilterData& ) const;
+    virtual bool filterUri( KUriFilterData& ) const;
 
 public Q_SLOTS:
     void configure();
