@@ -37,6 +37,7 @@
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kauthorized.h>
+#include <kmimetype.h>
 
 #include "kshorturifilter.h"
 
@@ -58,6 +59,18 @@
 
 typedef QMap<QString,QString> EntryMap;
 
+#if 0
+static QString stringDetails( const QString& str )
+{
+  if ( str.isNull() )
+    return QFL1( "<null>" );
+  else if ( str.isEmpty() )
+    return QFL1( "<empty>" );
+  else
+    return str;
+}
+#endif
+
 static bool isValidShortURL( const QString& cmd, bool verbose = false )
 {
   // Examples of valid short URLs:
@@ -73,6 +86,12 @@ static bool isValidShortURL( const QString& cmd, bool verbose = false )
     if (verbose)
       kDebug() << "KShortURIFilter::isValidShortURL: " << cmd
                 << " matches FQDN_PATTERN" << endl;
+
+    // something like wallpaper.png also matches a the FQDN pattern
+    // but is very unlikely to be meant as such
+    if (KMimeType::findByPath(cmd) != KMimeType::defaultMimeTypePtr())
+        return false;
+
     return true;
   }
 
@@ -127,15 +146,15 @@ static QString removeArgs( const QString& _cmd )
   return cmd;
 }
 
-KShortURIFilter::KShortURIFilter( QObject *parent, const QStringList & /*args*/ )
-                :KURIFilterPlugin( "kshorturifilter", parent, 1.0)
+KShortUriFilter::KShortUriFilter( QObject *parent, const QStringList & /*args*/ )
+                :KUriFilterPlugin( "kshorturifilter", parent )
 {
-    QDBus::sessionBus().connect(QString(), QString(), "org.kde.KUriFilterPlugin",
+    QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.KUriFilterPlugin",
                                 "configure", this, SLOT(configure()));
     configure();
 }
 
-bool KShortURIFilter::filterURI( KURIFilterData& data ) const
+bool KShortUriFilter::filterUri( KUriFilterData& data ) const
 {
  /*
   * Here is a description of how the shortURI deals with the supplied
@@ -165,8 +184,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
   {
      // Handle "encrypted" URLs like: h++p://www.kde.org
      url.setProtocol( QLatin1String("http"));
-     setFilteredURI( data, url);
-     setURIType( data, KURIFilterData::NET_PROTOCOL );
+     setFilteredUri( data, url);
+     setUriType( data, KUriFilterData::NET_PROTOCOL );
      return true;
   }
 
@@ -178,8 +197,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
   const QString starthere_proto = QFL1("start-here:");
   if (cmd.indexOf(starthere_proto) == 0 )
   {
-    setFilteredURI( data, KUrl("system:/") );
-    setURIType( data, KURIFilterData::LOCAL_DIR );
+    setFilteredUri( data, KUrl("system:/") );
+    setUriType( data, KUriFilterData::LOCAL_DIR );
     return true;
   }
 
@@ -198,8 +217,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
     else if ((cmd==info_proto) || (cmd==man_proto))
       cmd+='/';
 
-    setFilteredURI( data, KUrl( cmd ));
-    setURIType( data, KURIFilterData::HELP );
+    setFilteredUri( data, KUrl( cmd ));
+    setUriType( data, KUriFilterData::HELP );
     return true;
   }
 
@@ -209,8 +228,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
     // make sure path is unix style
     cmd.replace('\\', '/');
     cmd.prepend( QLatin1String( "smb:" ) );
-    setFilteredURI( data, KUrl( cmd ));
-    setURIType( data, KURIFilterData::NET_PROTOCOL );
+    setFilteredUri( data, KUrl( cmd ));
+    setUriType( data, KUriFilterData::NET_PROTOCOL );
     return true;
   }
 
@@ -219,6 +238,7 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
   // Expanding shortcut to HOME URL...
   QString path;
   QString ref;
+  //kDebug() << "initially ref is " << stringDetails( ref ) << endl;
   QString query;
   QString nameFilter;
 
@@ -237,6 +257,7 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
       {
         path = url.path();
         ref = url.ref();
+        //kDebug() << "isLocalFile set ref to " << stringDetails( ref ) << endl;
         query = url.query();
         if (path.isEmpty() && url.hasHost())
           path = '/';
@@ -270,7 +291,7 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
         QString msg = dir ? i18n("<qt><b>%1</b> does not have a home folder.</qt>", user) :
                             i18n("<qt>There is no user called <b>%1</b>.</qt>", user);
         setErrorMsg( data, msg );
-        setURIType( data, KURIFilterData::ERROR );
+        setUriType( data, KUriFilterData::ERROR );
         // Always return true for error conditions so
         // that other filters will not be invoked !!
         return true;
@@ -314,7 +335,7 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
 
   // Checking for local resource match...
   // Determine if "uri" is an absolute path to a local resource  OR
-  // A local resource with a supplied absolute path in KURIFilterData
+  // A local resource with a supplied absolute path in KUriFilterData
   const QString abs_path = data.absolutePath();
 
   const bool canBeAbsolute = (protocol.isEmpty() && !abs_path.isEmpty());
@@ -362,7 +383,7 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
            && stat( QFile::encodeName(testPath).data(), &buff ) == 0 )
         {
           nameFilter = fileName;
-          kDebug() << "Setting nameFilter to " << nameFilter << endl;
+          //kDebug() << "Setting nameFilter to " << nameFilter << endl;
           path = testPath;
           exists = true;
         }
@@ -375,15 +396,16 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
   {
     KUrl u;
     u.setPath(path);
+    //kDebug() << "ref=" << stringDetails(ref) << " query=" << stringDetails(query) << endl;
     u.setRef(ref);
     u.setQuery(query);
 
-    if (!KAuthorized::authorizeURLAction( QLatin1String("open"), KUrl(), u))
+    if (!KAuthorized::authorizeUrlAction( QLatin1String("open"), KUrl(), u))
     {
       // No authorisation, we pretend it's a file will get
       // an access denied error later on.
-      setFilteredURI( data, u );
-      setURIType( data, KURIFilterData::LOCAL_FILE );
+      setFilteredUri( data, u );
+      setUriType( data, KUriFilterData::LOCAL_FILE );
       return true;
     }
 
@@ -392,8 +414,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
     if( !isDir && access ( QFile::encodeName(path).data(), X_OK) == 0 )
     {
       //kDebug() << "Abs path to EXECUTABLE" << endl;
-      setFilteredURI( data, u );
-      setURIType( data, KURIFilterData::EXECUTABLE );
+      setFilteredUri( data, u );
+      setUriType( data, KUriFilterData::EXECUTABLE );
       return true;
     }
 
@@ -403,8 +425,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
       //kDebug() << "Abs path as local file or directory" << endl;
       if ( !nameFilter.isEmpty() )
         u.setFileName( nameFilter );
-      setFilteredURI( data, u );
-      setURIType( data, ( isDir ) ? KURIFilterData::LOCAL_DIR : KURIFilterData::LOCAL_FILE );
+      setFilteredUri( data, u );
+      setUriType( data, ( isDir ) ? KUriFilterData::LOCAL_DIR : KUriFilterData::LOCAL_FILE );
       return true;
     }
 
@@ -421,11 +443,11 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
   if( data.checkForExecutables() && !KStandardDirs::findExe( exe ).isNull() )
   {
     //kDebug() << "EXECUTABLE  exe=" << exe << endl;
-    setFilteredURI( data, KUrl::fromPath( exe ));
+    setFilteredUri( data, KUrl::fromPath( exe ));
     // check if we have command line arguments
     if( exe != cmd )
         setArguments(data, cmd.right(cmd.length() - exe.length()));
-    setURIType( data, KURIFilterData::EXECUTABLE );
+    setUriType( data, KUriFilterData::EXECUTABLE );
     return true;
   }
 
@@ -437,11 +459,11 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
     //kDebug() << "looking for protocol " << protocol << endl;
     if ( KProtocolInfo::protocols().contains( protocol ) )
     {
-      setFilteredURI( data, url );
+      setFilteredUri( data, url );
       if ( protocol == QFL1("man") || protocol == QFL1("help") )
-        setURIType( data, KURIFilterData::HELP );
+        setUriType( data, KUriFilterData::HELP );
       else
-        setURIType( data, KURIFilterData::NET_PROTOCOL );
+        setUriType( data, KUriFilterData::NET_PROTOCOL );
       return true;
     }
   }
@@ -459,8 +481,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
       {
         //kDebug() << "match - prepending " << (*it).prepend << endl;
         cmd.prepend( (*it).prepend );
-        setFilteredURI( data, KUrl( cmd ) );
-        setURIType( data, (*it).type );
+        setFilteredUri( data, KUrl( cmd ) );
+        setUriType( data, (*it).type );
         return true;
       }
     }
@@ -474,8 +496,8 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
                   << m_strDefaultProtocol << endl;
 
       cmd.insert( 0, m_strDefaultProtocol );
-      setFilteredURI( data, KUrl( cmd ));
-      setURIType( data, KURIFilterData::NET_PROTOCOL );
+      setFilteredUri( data, KUrl( cmd ));
+      setUriType( data, KUriFilterData::NET_PROTOCOL );
       return true;
     }
   }
@@ -488,17 +510,17 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
     u.setPath(path);
     u.setRef(ref);
 
-    if (!KAuthorized::authorizeURLAction( QLatin1String("open"), KUrl(), u))
+    if (!KAuthorized::authorizeUrlAction( QLatin1String("open"), KUrl(), u))
     {
       // No authorisation, we pretend it exists and will get
       // an access denied error later on.
-      setFilteredURI( data, u );
-      setURIType( data, KURIFilterData::LOCAL_FILE );
+      setFilteredUri( data, u );
+      setUriType( data, KUriFilterData::LOCAL_FILE );
       return true;
     }
     //kDebug() << "fileNotFound -> ERROR" << endl;
     setErrorMsg( data, i18n( "<qt>The file or folder <b>%1</b> does not exist.", data.uri().prettyUrl() ) );
-    setURIType( data, KURIFilterData::ERROR );
+    setUriType( data, KUriFilterData::ERROR );
     return true;
   }
 
@@ -507,23 +529,23 @@ bool KShortURIFilter::filterURI( KURIFilterData& data ) const
   return false;
 }
 
-KCModule* KShortURIFilter::configModule( QWidget*, const char* ) const
+KCModule* KShortUriFilter::configModule( QWidget*, const char* ) const
 {
-    return 0; //new KShortURIOptions( parent, name );
+    return 0; //new KShortUriOptions( parent, name );
 }
 
-QString KShortURIFilter::configName() const
+QString KShortUriFilter::configName() const
 {
     return i18n("&ShortURLs");
 }
 
-void KShortURIFilter::configure()
+void KShortUriFilter::configure()
 {
   KConfig config( name() + QFL1("rc"), false, false );
   m_bVerbose = config.readEntry( "Verbose", false );
 
   if ( m_bVerbose )
-    kDebug() << "KShortURIFilter::configure: Config reload request..." << endl;
+    kDebug() << "KShortUriFilter::configure: Config reload request..." << endl;
 
   m_strDefaultProtocol = config.readEntry( "DefaultProtocol", QString("http://") );
   EntryMap patterns = config.entryMap( QFL1("Pattern") );
@@ -536,8 +558,8 @@ void KShortURIFilter::configure()
     if (!protocol.isEmpty())
     {
       int type = config.readEntry(it.key(), -1);
-      if (type > -1 && type <= KURIFilterData::UNKNOWN)
-        m_urlHints.append( URLHint(it.value(), protocol, static_cast<KURIFilterData::URITypes>(type) ) );
+      if (type > -1 && type <= KUriFilterData::UNKNOWN)
+        m_urlHints.append( URLHint(it.value(), protocol, static_cast<KUriFilterData::UriTypes>(type) ) );
       else
         m_urlHints.append( URLHint(it.value(), protocol) );
     }
@@ -545,6 +567,6 @@ void KShortURIFilter::configure()
 }
 
 K_EXPORT_COMPONENT_FACTORY( libkshorturifilter,
-                            KGenericFactory<KShortURIFilter>( "kcmkurifilt" ) )
+                            KGenericFactory<KShortUriFilter>( "kcmkurifilt" ) )
 
 #include "kshorturifilter.moc"
