@@ -97,28 +97,6 @@ KAccessApp::KAccessApp(bool allowStyles, bool GUIenabled)
   : KUniqueApplication(allowStyles, GUIenabled),
   overlay(0), wm(0, KWinModule::INFO_DESKTOP),_player(Phonon::AccessibilityCategory)
 {
-  // verify the Xlib has matching XKB extension
-  int major = XkbMajorVersion;
-  int minor = XkbMinorVersion;
-  if (!XkbLibraryVersion(&major, &minor))
-    {
-      kError() << "Xlib XKB extension does not match" << endl;
-      exit(-1);
-    }
-  kDebug() << "Xlib XKB extension major=" << major << " minor=" << minor << endl;
-
-  // verify the X server has matching XKB extension
-  // if yes, the XKB extension is initialized
-  int opcode_rtrn;
-  int error_rtrn;
-  if (!XkbQueryExtension(QX11Info::display(), &opcode_rtrn, &xkb_opcode, &error_rtrn,
-			 &major, &minor))
-    {
-      kError() << "X server has not matching XKB extension" << endl;
-      exit(-1);
-    }
-  kDebug() << "X server XKB extension major=" << major << " minor=" << minor << endl;
-
   _activeWindow = wm.activeWindow();
   connect(&wm, SIGNAL(activeWindowChanged(WId)), this, SLOT(activeWindowChanged(WId)));
 
@@ -145,7 +123,7 @@ int KAccessApp::newInstance()
 
 void KAccessApp::readSettings()
 {
-  KConfig *config = KGlobal::config();
+  KSharedConfig::Ptr config = KGlobal::config();
 
   // bell ---------------------------------------------------------------
 
@@ -461,7 +439,9 @@ void KAccessApp::xkbBellNotify(XkbBellNotifyEvent *event)
       if (_visibleBellInvert)
         {
 	  QPixmap screen = QPixmap::grabWindow(id, 0, 0, window.size.width, window.size.height);
+#ifdef __GNUC__
 #warning is this the best way to invert a pixmap?
+#endif	  
 //	  QPixmap invert(window.size.width, window.size.height);
 	  QImage i = screen.toImage();
 	  i.invertPixels();
@@ -587,8 +567,8 @@ void KAccessApp::createDialogContents() {
       dialog = new KDialog( 0 );
       dialog->setCaption( i18n("Warning") );
       dialog->setButtons( KDialog::Yes | KDialog::No );
-      dialog->setButtonGuiItem( KDialog::Yes, KStdGuiItem::yes() );
-      dialog->setButtonGuiItem( KDialog::No, KStdGuiItem::no() );
+      dialog->setButtonGuiItem( KDialog::Yes, KStandardGuiItem::yes() );
+      dialog->setButtonGuiItem( KDialog::No, KStandardGuiItem::no() );
       dialog->setEscapeButton( KDialog::Close );
       dialog->setObjectName( "AccessXWarning" );
       dialog->setModal( true );
@@ -596,7 +576,9 @@ void KAccessApp::createDialogContents() {
 
       KVBox *topcontents = new KVBox (dialog);
       topcontents->setSpacing(KDialog::spacingHint()*2);
+#ifdef __GNUC__
 #warning "kde4 fixme"
+#endif      
 	  //topcontents->setMargin(KDialog::marginHint());
 
       QWidget *contents = new QWidget(topcontents);
@@ -604,7 +586,7 @@ void KAccessApp::createDialogContents() {
       lay->setSpacing(KDialog::spacingHint());
 
       QLabel *label1 = new QLabel( contents);
-      QPixmap pixmap = KApplication::kApplication()->iconLoader()->loadIcon("messagebox_warning", K3Icon::NoGroup, K3Icon::SizeMedium, K3Icon::DefaultState, 0, true);
+      QPixmap pixmap = KIconLoader::global()->loadIcon("messagebox_warning", K3Icon::NoGroup, K3Icon::SizeMedium, K3Icon::DefaultState, 0, true);
       if (pixmap.isNull())
          pixmap = QMessageBox::standardIcon(QMessageBox::Warning);
       label1->setPixmap(pixmap);
@@ -823,7 +805,7 @@ void KAccessApp::applyChanges() {
    unsigned int enabled  = requestedFeatures & ~features;
    unsigned int disabled = features & ~requestedFeatures;
 
-   KConfig *config = KGlobal::config();
+   KSharedConfig::Ptr config = KGlobal::config();
    config->setGroup("Keyboard");
 
    if (enabled & XkbSlowKeysMask)
@@ -856,7 +838,7 @@ void KAccessApp::yesClicked() {
       dialog->deleteLater();
    dialog = 0;
 
-   KConfig *config = KGlobal::config();
+   KSharedConfig::Ptr config = KGlobal::config();
    config->setGroup("Keyboard");
    switch (showModeCombobox->currentIndex()) {
       case 0:
@@ -887,7 +869,7 @@ void KAccessApp::noClicked() {
    dialog = 0;
    requestedFeatures = features;
 
-   KConfig *config = KGlobal::config();
+   KSharedConfig::Ptr config = KGlobal::config();
    config->setGroup("Keyboard");
    switch (showModeCombobox->currentIndex()) {
       case 0:
@@ -917,3 +899,7 @@ void KAccessApp::dialogClosed() {
 
    requestedFeatures = features;
 }
+
+void KAccessApp::setXkbOpcode(int opcode) {
+   xkb_opcode = opcode;
+}
