@@ -65,7 +65,7 @@
 
 #define NR_PREDEF_PATTERNS 6
 
-BGDialog::BGDialog(QWidget* parent, KConfig* _config, bool _multidesktop)
+BGDialog::BGDialog(QWidget* parent, const KSharedConfigPtr &_config, bool _multidesktop)
   : BGDialog_UI(parent, "BGDialog")
 {
    m_pGlobals = new KGlobalBackgroundSettings(_config);
@@ -125,7 +125,7 @@ BGDialog::BGDialog(QWidget* parent, KConfig* _config, bool _multidesktop)
    }
 
    // background image settings
-   QIcon iconSet = SmallIconSet(QLatin1String("fileopen"));
+   QIcon iconSet = KIcon(QLatin1String("fileopen"));
    QPixmap pixMap = iconSet.pixmap( QIcon::Small, QIcon::Normal );
    m_urlWallpaperButton->setIcon( iconSet );
    m_urlWallpaperButton->setFixedSize( pixMap.width()+8, pixMap.height()+8 );
@@ -521,7 +521,7 @@ void BGDialog::loadWallpaperFilesList() {
    QMap<QString, QPair<QString, QString> > papers;
 
    //search for .desktop files before searching for images without .desktop files
-   QStringList lst = m_pDirs->findAllResources("wallpaper", "*desktop", false, true);
+   QStringList lst = m_pDirs->findAllResources("wallpaper", "*desktop", KStandardDirs::NoDuplicates);
    QStringList files;
    for (QStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it)
    {
@@ -538,8 +538,6 @@ void BGDialog::loadWallpaperFilesList() {
          imageCaption = KStringHandler::capwords(imageCaption);
       }
 
-      imageCaption = KStringHandler::rEmSqueeze(imageCaption, m_urlWallpaperBox->fontMetrics(), 11);
-
       // avoid name collisions
       QString rs = imageCaption;
       QString lrs = rs.toLower();
@@ -557,7 +555,7 @@ void BGDialog::loadWallpaperFilesList() {
    }
 
    //now find any wallpapers that don't have a .desktop file
-   lst = m_pDirs->findAllResources("wallpaper", "*", false, true);
+   lst = m_pDirs->findAllResources("wallpaper", "*", KStandardDirs::NoDuplicates);
    for (QStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it)
    {
       if ( !(*it).endsWith(".desktop") && files.filter(*it).empty() ) {
@@ -584,8 +582,6 @@ void BGDialog::loadWallpaperFilesList() {
             imageCaption = KStringHandler::capwords(imageCaption);
          }
 
-         imageCaption = KStringHandler::rEmSqueeze(imageCaption, m_urlWallpaperBox->fontMetrics(), 11);
-
          // avoid name collisions
          QString rs = imageCaption;
          QString lrs = rs.toLower();
@@ -634,7 +630,7 @@ void BGDialog::setWallpaper(const QString &s)
          i--;
          comboWallpaper->removeItem(i);
       }
-      comboWallpaper->addItem(KStringHandler::rEmSqueeze(imageCaption, m_urlWallpaperBox->fontMetrics(), 11));
+      comboWallpaper->addItem(imageCaption);
       m_wallpaper[s] = i;
       comboWallpaper->setCurrentIndex(i);
    }
@@ -1242,7 +1238,7 @@ void BGDialog::slotGetNewStuff()
    //FIXME set this to a server when we get one
    //should really be in a .rc file but could be either
    //kcmshellrc or kcontrolrc
-   KConfig* config = KGlobal::config();
+   KSharedConfig::Ptr config = KGlobal::config();
    config->setGroup("KNewStuff");
    config->writeEntry( "ProvidersUrl", "http://download.kde.org/khotnewstuff/wallpaper-providers.xml" );
    config->writeEntry( "StandardResource", "wallpaper" );
