@@ -7,7 +7,7 @@
  * You can Freely distribute this program under the GNU Library General
  * Public License. See the file "COPYING.LIB" for the exact licensing terms.
  */
-
+#include <fixx11h.h>
 #include <config.h>
 
 #include <time.h>
@@ -23,7 +23,6 @@
 #include <QPaintEngine>
 #include <QHash>
 #include <QDateTime>
-#include <QSvgRenderer>
 #include <QPixmap>
 
 #include <kapplication.h>
@@ -31,9 +30,11 @@
 #include <kstandarddirs.h>
 #include <kimageeffect.h>
 #include <kprocess.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kcursor.h>
-#include <kmimetype.h>
+#include <kfilemetainfo.h>
+#include <kconfig.h>
+#include <ksvgrenderer.h>
 
 #include "bgdefaults.h"
 #include "bgrender.h"
@@ -47,7 +48,7 @@
 /**** KBackgroundRenderer ****/
 
 
-KBackgroundRenderer::KBackgroundRenderer(int desk, int screen, bool drawBackgroundPerScreen, KConfig *config)
+KBackgroundRenderer::KBackgroundRenderer(int desk, int screen, bool drawBackgroundPerScreen, const KSharedConfigPtr &config)
     : KBackgroundSettings(desk, screen, drawBackgroundPerScreen, config)
 {
     m_State = 0;
@@ -104,8 +105,8 @@ void KBackgroundRenderer::tile(QImage& dest, QRect rect, const QImage& src)
     int sw = src.width(), sh = src.height();
 
     for (y=offy; y<offy+h; y++)
-	for (x=offx; x<offx+w; x++)
-	    dest.setPixel(x, y, src.pixel(x%sw, y%sh));
+        for (x=offx; x<offx+w; x++)
+            dest.setPixel(x, y, src.pixel(x%sw, y%sh));
 }
 
 
@@ -125,7 +126,7 @@ QString KBackgroundRenderer::buildCommand()
         cmd = command();
 
     if (cmd.isEmpty())
-	return QString();
+        return QString();
 
     while ((pos = cmd.indexOf('%', pos)) != -1) {
 
@@ -135,8 +136,8 @@ QString KBackgroundRenderer::buildCommand()
         switch (cmd.at(pos+1).toLatin1()) {
         case 'f':
             createTempFile();
-            cmd.replace(pos, 2, KShellProcess::quote(m_Tempfile->name()));
-            pos += m_Tempfile->name().length() - 2;
+            cmd.replace(pos, 2, KShellProcess::quote(m_Tempfile->fileName()));
+            pos += m_Tempfile->fileName().length() - 2;
             break;
 
         case 'x':
@@ -176,8 +177,8 @@ int KBackgroundRenderer::doBackground(bool quit)
       bgmode= Flat;
 
     if (quit) {
-	if (bgmode == Program && m_pProc)
-	    m_pProc->kill();
+        if (bgmode == Program && m_pProc)
+            m_pProc->kill();
         return Done;
     }
 
@@ -200,7 +201,7 @@ int KBackgroundRenderer::doBackground(bool quit)
 
     case Flat:
         // this can be tiled correctly without problems
-	m_Background.create( tileWidth, tileHeight, 32);
+        m_Background = QImage( tileWidth, tileHeight, QImage::Format_RGB32 );
         m_Background.fill(colorA().rgb());
         break;
 
@@ -212,18 +213,18 @@ int KBackgroundRenderer::doBackground(bool quit)
         if (file.isEmpty())
             break;
 
-	m_Background.load(file);
-	if (m_Background.isNull())
-	    break;
-	int w = m_Background.width();
-	int h = m_Background.height();
-	if ((w > m_Size.width()) || (h > m_Size.height())) {
-	    w = qMin(w, m_Size.width());
-	    h = qMin(h, m_Size.height());
-	    m_Background = m_Background.copy(0, 0, w, h);
-	}
-	KImageEffect::flatten(m_Background, colorA(), colorB(), 0);
-	break;
+        m_Background.load(file);
+        if (m_Background.isNull())
+            break;
+        int w = m_Background.width();
+        int h = m_Background.height();
+        if ((w > m_Size.width()) || (h > m_Size.height())) {
+            w = qMin(w, m_Size.width());
+            h = qMin(h, m_Size.height());
+            m_Background = m_Background.copy(0, 0, w, h);
+        }
+        KImageEffect::flatten(m_Background, colorA(), colorB(), 0);
+        break;
     }
     case Program:
         if (m_State & BackgroundStarted)
@@ -231,9 +232,9 @@ int KBackgroundRenderer::doBackground(bool quit)
         m_State |= BackgroundStarted;
         createTempFile();
 
-	file = buildCommand();
-	if (file.isEmpty())
-	    break;
+        file = buildCommand();
+        if (file.isEmpty())
+            break;
 
         delete m_pProc;
         m_pProc = new KShellProcess;
@@ -246,37 +247,37 @@ int KBackgroundRenderer::doBackground(bool quit)
 
     case HorizontalGradient:
     {
-	QSize size = m_Size;
+        QSize size = m_Size;
         // on <16bpp displays the gradient sucks when tiled because of dithering
         if( canTile())
-	    size.setHeight( tileHeight );
-	m_Background = KImageEffect::gradient(size, colorA(), colorB(),
-		KImageEffect::HorizontalGradient, 0);
+            size.setHeight( tileHeight );
+        m_Background = KImageEffect::gradient(size, colorA(), colorB(),
+        KImageEffect::HorizontalGradient, 0);
         break;
     }
     case VerticalGradient:
     {
-	QSize size = m_Size;
+        QSize size = m_Size;
         // on <16bpp displays the gradient sucks when tiled because of dithering
         if( canTile())
-	    size.setWidth( tileWidth );
+            size.setWidth( tileWidth );
         m_Background = KImageEffect::gradient(size, colorA(), colorB(),
-		KImageEffect::VerticalGradient, 0);
+        KImageEffect::VerticalGradient, 0);
         break;
     }
     case PyramidGradient:
         m_Background = KImageEffect::gradient(m_Size, colorA(), colorB(),
-		KImageEffect::PyramidGradient, 0);
+        KImageEffect::PyramidGradient, 0);
         break;
 
     case PipeCrossGradient:
         m_Background = KImageEffect::gradient(m_Size, colorA(), colorB(),
-		KImageEffect::PipeCrossGradient, 0);
+        KImageEffect::PipeCrossGradient, 0);
         break;
 
     case EllipticGradient:
         m_Background = KImageEffect::gradient(m_Size, colorA(), colorB(),
-		KImageEffect::EllipticGradient, 0);
+        KImageEffect::EllipticGradient, 0);
         break;
     }
 
@@ -301,161 +302,187 @@ int KBackgroundRenderer::doWallpaper(bool quit)
     m_Wallpaper = QImage();
     if (wpmode != NoWallpaper) {
 wp_load:
-	if (currentWallpaper().isEmpty()) {
-	    wpmode = NoWallpaper;
-	    goto wp_out;
-	}
-	QString file = m_pDirs->findResource("wallpaper", currentWallpaper());
-	if (file.isEmpty()) {
-	    wpmode = NoWallpaper;
-	    goto wp_out;
-	}
+        if (currentWallpaper().isEmpty()) {
+            wpmode = NoWallpaper;
+            goto wp_out;
+        }
+        QString file = m_pDirs->findResource("wallpaper", currentWallpaper());
+        if (file.isEmpty()) {
+            wpmode = NoWallpaper;
+            goto wp_out;
+        }
 
         // _Don't_ use KMimeType, as it relies on ksycoca which we really
         // don't want in krootimage (kdm context).
         //if ( KMimeType::findByPath( file )->is( "image/svg+xml" ) ) {
         if (file.endsWith(".svg") || file.endsWith(".svgz")) {
 
-	    // Special stuff for SVG icons
-            QSvgRenderer renderer;
+            // Special stuff for SVG icons
 
-	    //FIXME
-	    //ksvgiconloader doesn't seem to let us find out the
-	    //ratio of width to height so for the most part we just
-	    //assume it's a square
-	    int svgWidth;
-	    int svgHeight;
-	    switch (wpmode)
-	    {
-	        case Centred:
-	        case CentredAutoFit:
-		    svgHeight = (int)(m_Size.height() * 0.8);
-		    svgWidth = svgHeight;
-	            break;
-	        case Tiled:
-	        case CenterTiled:
-		    svgHeight = (int)(m_Size.height() * 0.5);
-		    svgWidth = svgHeight;
-	            break;
-	        case Scaled:
-		    svgHeight = m_Size.height();
-		    svgWidth = m_Size.width();
-	            break;
-	        case CentredMaxpect:
-		case ScaleAndCrop:
-	        case TiledMaxpect:
-		    svgHeight = m_Size.height();
-		    svgWidth = svgHeight;
-	            break;
-	        case NoWallpaper:
-	        default:
-	            kWarning() << k_funcinfo << "unknown diagram type" << endl;
-		    svgHeight = m_Size.height();
-		    svgWidth = svgHeight;
-		    break;
-	    }
-	    //FIXME hack due to strangeness with
-	    //background control modules
-	    if ( svgHeight < 200 ) {
-		svgHeight *= 6;
-	        svgWidth *= 6;
-	    }
+            //FIXME
+            //ksvgiconloader doesn't seem to let us find out the
+            //ratio of width to height so for the most part we just
+            //assume it's a square
+            int svgWidth;
+            int svgHeight;
+            switch (wpmode)
+            {
+                case Centred:
+                case CentredAutoFit:
+                    svgHeight = (int)(m_Size.height() * 0.8);
+                    svgWidth = svgHeight;
+                    break;
+                case Tiled:
+                case CenterTiled:
+                    svgHeight = (int)(m_Size.height() * 0.5);
+                    svgWidth = svgHeight;
+                    break;
+                case Scaled:
+                    svgHeight = m_Size.height();
+                    svgWidth = m_Size.width();
+                    break;
+                case CentredMaxpect:
+                case ScaleAndCrop:
+                case TiledMaxpect:
+                    svgHeight = m_Size.height();
+                    svgWidth = svgHeight;
+                    break;
+                case NoWallpaper:
+                default:
+                    kWarning() << k_funcinfo << "unknown diagram type" << endl;
+                    svgHeight = m_Size.height();
+                    svgWidth = svgHeight;
+                    break;
+            }
+            //FIXME hack due to strangeness with
+            //background control modules
+            if ( svgHeight < 200 ) {
+                svgHeight *= 6;
+                svgWidth *= 6;
+            }
 
-            QImage* img = new QImage(svgWidth, svgHeight, QImage::Format_ARGB32_Premultiplied);
-            QPainter p(img);
-
-	    if (renderer.load(file)) {
-                if (renderer.isValid())
-                   renderer.render(&p);
-                p.end();
-		m_Wallpaper = *img;
-	    } else {
-		kWarning() << "failed to load SVG file " << file << endl;
-	    }
-	} else {
-	    m_Wallpaper.load(file);
-	}
-	if (m_Wallpaper.isNull()) {
+            KSvgRenderer renderer(file);
+            if (renderer.isValid()) {
+                m_Wallpaper = QImage(svgWidth, svgHeight, QImage::Format_ARGB32_Premultiplied);
+                m_Wallpaper.fill(0);
+                QPainter p(&m_Wallpaper);
+                renderer.render(&p);
+            }
+        } else {
+            m_Wallpaper.load(file);
+        }
+        if (m_Wallpaper.isNull()) {
+            kWarning() << "failed to load wallpaper " << file << endl;
             if (discardCurrentWallpaper())
                goto wp_load;
-	    wpmode = NoWallpaper;
-	    goto wp_out;
-	}
-	m_Wallpaper = m_Wallpaper.convertDepth(32, Qt::DiffuseAlphaDither);
+            wpmode = NoWallpaper;
+            goto wp_out;
+        }
+        m_Wallpaper = m_Wallpaper.convertToFormat(QImage::Format_ARGB32_Premultiplied, Qt::DiffuseAlphaDither);
 
-	// If we're previewing, scale the wallpaper down to make the preview
-	// look more like the real desktop.
-	if (m_bPreview) {
-	    int xs = m_Wallpaper.width() * m_Size.width() / m_rSize.width();
-	    int ys = m_Wallpaper.height() * m_Size.height() / m_rSize.height();
-	    if ((xs < 1) || (ys < 1))
-	    {
-	       xs = ys = 1;
-	    }
-	    if( m_WallpaperRect.size() != QSize( xs, ys ))
-	        m_Wallpaper = m_Wallpaper.scaled(xs, ys, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-	}
+        // If we're previewing, scale the wallpaper down to make the preview
+        // look more like the real desktop.
+        if (m_bPreview) {
+            int xs = m_Wallpaper.width() * m_Size.width() / m_rSize.width();
+            int ys = m_Wallpaper.height() * m_Size.height() / m_rSize.height();
+            if ((xs < 1) || (ys < 1))
+            {
+                xs = ys = 1;
+            }
+            if( m_WallpaperRect.size() != QSize( xs, ys ))
+                m_Wallpaper = m_Wallpaper.scaled(xs, ys, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        }
+
+        // HACK: Use KFileMetaInfo only when we have a KApplication
+        // KFileMetaInfo needs ksycoca and so on, but this code is
+        // used also in krootimage (which in turn is used by kdm).
+        if (kapp) {
+            KFileMetaInfo metaInfo(file);
+            if (metaInfo.isValid() && metaInfo.item("Orientation").isValid()) {
+                switch (metaInfo.item("Orientation").string().toInt()) {
+                    case 2:
+                        // Flipped horizontally
+                        m_Wallpaper.mirrored(true, false);
+                        break;
+                    case 3:
+                        // Rotated 180 degrees
+                        m_Wallpaper = KImageEffect::rotate(m_Wallpaper, KImageEffect::Rotate180);
+                        break;
+                    case 4:
+                        // Flipped vertically
+                        m_Wallpaper = m_Wallpaper.mirrored(false, true);
+                        break;
+                    case 5:
+                        // Rotated 90 degrees & flipped horizontally
+                        m_Wallpaper = KImageEffect::rotate(m_Wallpaper, KImageEffect::Rotate90).mirrored(true, false);
+                        break;
+                    case 6:
+                        // Rotated 90 degrees
+                        m_Wallpaper = KImageEffect::rotate(m_Wallpaper, KImageEffect::Rotate90);
+                        break;
+                    case 7:
+                        // Rotated 90 degrees & flipped vertically
+                        m_Wallpaper = KImageEffect::rotate(m_Wallpaper, KImageEffect::Rotate90).mirrored(false, true);
+                        break;
+                    case 8:
+                        // Rotated 270 degrees
+                        m_Wallpaper = KImageEffect::rotate(m_Wallpaper, KImageEffect::Rotate270);
+                        break;
+                    case 1:
+                    default:
+                        // Normal or invalid orientation
+                        break;
+                }
+            }
+        }
     }
 wp_out:
 
     if (m_Background.isNull()) {
-	m_Background.create(8, 8, 32);
-	m_Background.fill(colorA().rgb());
+        m_Background = QImage(8, 8, QImage::Format_RGB32);
+        m_Background.fill(colorA().rgb());
     }
 
     int retval = Done;
 
-    int w = m_Size.width();	// desktop width/height
+    // desktop width/height
+    int w = m_Size.width();
     int h = m_Size.height();
 
-    int ww = m_Wallpaper.width();	// wallpaper width/height
+    // wallpaper width/height
+    int ww = m_Wallpaper.width();
     int wh = m_Wallpaper.height();
 
-    m_WallpaperRect = QRect();	// to be filled destination rectangle; may exceed desktop!
+    // to be filled destination rectangle; may exceed desktop!
+    m_WallpaperRect = QRect();
 
     switch (wpmode)
     {
-	case NoWallpaper:
-	    break;
-	case Centred:
-	    m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2, ww, wh);
-	    break;
-	case Tiled:
-	    m_WallpaperRect.setRect(0, 0, w, h);
-	    break;
-	case CenterTiled:
-	    m_WallpaperRect.setCoords(-ww + ((w - ww) / 2) % ww, -wh + ((h - wh) / 2) % wh, w-1, h-1);
-	    break;
-	case Scaled:
-	    ww = w;
-	    wh = h;
-	    if( m_WallpaperRect.size() != QSize( w, h ))
-		m_Wallpaper = m_Wallpaper.scaled( w, h, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
-	    m_WallpaperRect.setRect(0, 0, w, h);
-	    break;
+        case NoWallpaper:
+            break;
+        case Centred:
+            m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2, ww, wh);
+            break;
+        case Tiled:
+            m_WallpaperRect.setRect(0, 0, w, h);
+            break;
+        case CenterTiled:
+            m_WallpaperRect.setCoords(-ww + ((w - ww) / 2) % ww, -wh + ((h - wh) / 2) % wh, w-1, h-1);
+            break;
+        case Scaled:
+            ww = w;
+            wh = h;
+            if( m_WallpaperRect.size() != QSize( w, h ))
+                m_Wallpaper = m_Wallpaper.scaled( w, h, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+            m_WallpaperRect.setRect(0, 0, w, h);
+            break;
         case CentredAutoFit:
             if( ww <= w && wh <= h ) {
-    	        m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2, ww, wh); // like Centred
-	        break;
+                m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2, ww, wh); // like Centred
+                break;
             }
             // fall through
-	case CentredMaxpect:
-            {
-              double sx = (double) w / ww;
-              double sy = (double) h / wh;
-              if (sx > sy) {
-                  ww = (int)(sy * ww);
-                  wh = h;
-              } else {
-                  wh = (int)(sx * wh);
-                  ww = w;
-              }
-	      if( m_WallpaperRect.size() != QSize( ww, wh ))
-                  m_Wallpaper = m_Wallpaper.scaled(ww, wh, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-	      m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2, ww, wh);
-	      break;
-            }
-	case TiledMaxpect:
+        case CentredMaxpect:
             {
               double sx = (double) w / ww;
               double sy = (double) h / wh;
@@ -468,26 +495,42 @@ wp_out:
               }
               if( m_WallpaperRect.size() != QSize( ww, wh ))
                   m_Wallpaper = m_Wallpaper.scaled(ww, wh, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-	      m_WallpaperRect.setRect(0, 0, w, h);
-	      break;
+              m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2, ww, wh);
+              break;
             }
-	 case ScaleAndCrop:
+        case TiledMaxpect:
             {
               double sx = (double) w / ww;
               double sy = (double) h / wh;
               if (sx > sy) {
-	      	  //Case 1: x needs bigger scaling. Lets increase x and leave part of y offscreen
-                  ww = w;
-		  wh=(int)(sx * wh);
+                  ww = (int)(sy * ww);
+                  wh = h;
               } else {
-	          //Case 2: y needs bigger scaling. Lets increase y and leave part of x offscreen
+                  wh = (int)(sx * wh);
+                  ww = w;
+              }
+              if( m_WallpaperRect.size() != QSize( ww, wh ))
+                  m_Wallpaper = m_Wallpaper.scaled(ww, wh, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+              m_WallpaperRect.setRect(0, 0, w, h);
+              break;
+            }
+        case ScaleAndCrop:
+            {
+              double sx = (double) w / ww;
+              double sy = (double) h / wh;
+              if (sx > sy) {
+                  //Case 1: x needs bigger scaling. Lets increase x and leave part of y offscreen
+                  ww = w;
+                  wh=(int)(sx * wh);
+              } else {
+                  //Case 2: y needs bigger scaling. Lets increase y and leave part of x offscreen
                   wh = h;
                   ww = (int)(sy*ww);
               }
               if( m_WallpaperRect.size() != QSize( ww, wh ))
                   m_Wallpaper = m_Wallpaper.scaled(ww, wh, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-	      m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2,w, h);
-	      break;
+              m_WallpaperRect.setRect((w - ww) / 2, (h - wh) / 2,w, h);
+              break;
             }
     }
 
@@ -509,7 +552,7 @@ void KBackgroundRenderer::wallpaperBlend()
     if( !enabled() || wallpaperMode() == NoWallpaper
         || (blendMode() == NoBlending &&
         ( QApplication::desktop()->paintEngine()->hasFeature(QPaintEngine::Antialiasing)
-            || !m_Wallpaper.hasAlphaBuffer()))) {
+            || !m_Wallpaper.hasAlphaChannel()))) {
         fastWallpaperBlend();
     }
     else {
@@ -529,13 +572,13 @@ void KBackgroundRenderer::fastWallpaperBlend()
         m_Pixmap = QPixmap::fromImage( m_Background );
         return;
     }
-    else if( wallpaperMode() == Tiled && !m_Wallpaper.hasAlphaBuffer() && canTile() && !m_bPreview ) {
+    else if( wallpaperMode() == Tiled && !m_Wallpaper.hasAlphaChannel() && canTile() && !m_bPreview ) {
     // tiles will be tiled by X automatically
         m_Pixmap = QPixmap::fromImage( m_Wallpaper );
         return;
     }
     else if( m_WallpaperRect.contains( QRect( QPoint( 0, 0 ), m_Size ))
-        && !m_Wallpaper.hasAlphaBuffer()) // wallpaper covers all and no blending
+        && !m_Wallpaper.hasAlphaChannel()) // wallpaper covers all and no blending
         m_Pixmap = QPixmap( m_Size );
     else if (m_Background.size() == m_Size)
         m_Pixmap = QPixmap::fromImage( m_Background );
@@ -549,13 +592,14 @@ void KBackgroundRenderer::fastWallpaperBlend()
     // paint/alpha-blend wallpaper to destination rectangle of m_pPixmap
     if (m_WallpaperRect.isValid()) {
         QPixmap wp_pixmap = QPixmap::fromImage( m_Wallpaper );
+        QPainter pa( &m_Pixmap );
         int ww = m_Wallpaper.width();
         int wh = m_Wallpaper.height();
         for (int y = m_WallpaperRect.top(); y < m_WallpaperRect.bottom(); y += wh) {
-	    for (int x = m_WallpaperRect.left(); x < m_WallpaperRect.right(); x += ww) {
-		bitBlt( &m_Pixmap, x, y, &wp_pixmap, 0, 0, ww, wh );
-	    }
-	}
+            for (int x = m_WallpaperRect.left(); x < m_WallpaperRect.right(); x += ww) {
+                pa.drawPixmap( x, y, wp_pixmap );
+            }
+        }
     }
 }
 
@@ -563,18 +607,21 @@ void KBackgroundRenderer::fastWallpaperBlend()
 void KBackgroundRenderer::fullWallpaperBlend()
 {
     m_Pixmap = QPixmap();
-    int w = m_Size.width();	// desktop width/height
+
+    // desktop width/height
+    int w = m_Size.width();
     int h = m_Size.height();
+
     // copy background to m_pImage
     if (m_Background.size() == m_Size) {
-	m_Image = m_Background.copy();
-
-	if (m_Image.depth() < 32)
-	    m_Image = m_Image.convertDepth(32, Qt::DiffuseAlphaDither);
+        m_Image = m_Background.copy();
 
+        if (m_Image.depth() < 32) {
+            m_Image = m_Image.convertToFormat(QImage::Format_ARGB32_Premultiplied, Qt::DiffuseAlphaDither);
+        }
     } else {
-	m_Image.create(w, h, 32);
-	tile(m_Image, QRect(0, 0, w, h), m_Background);
+        m_Image = QImage(w, h, QImage::Format_RGB32);
+        tile(m_Image, QRect(0, 0, w, h), m_Background);
     }
 
     // blend wallpaper to destination rectangle of m_pImage
@@ -586,11 +633,11 @@ void KBackgroundRenderer::fullWallpaperBlend()
         int ww = m_Wallpaper.width();
         int wh = m_Wallpaper.height();
         for (int y = m_WallpaperRect.top(); y < m_WallpaperRect.bottom(); y += wh) {
-	    for (int x = m_WallpaperRect.left(); x < m_WallpaperRect.right(); x += ww) {
-		blend(m_Image, QRect(x, y, ww, wh), m_Wallpaper,
-			QPoint(-qMin(x, 0), -qMin(y, 0)), blendFactor);
-	    }
-	}
+            for (int x = m_WallpaperRect.left(); x < m_WallpaperRect.right(); x += ww) {
+                blend(m_Image, QRect(x, y, ww, wh), m_Wallpaper,
+                        QPoint(-qMin(x, 0), -qMin(y, 0)), blendFactor);
+            }
+        }
     }
 
 
@@ -600,58 +647,58 @@ void KBackgroundRenderer::fullWallpaperBlend()
 
       switch( blendMode() ) {
       case HorizontalBlending:
-	KImageEffect::blend( m_Image, m_Background,
-			     KImageEffect::HorizontalGradient,
-			     bal, 100 );
-	break;
+        KImageEffect::blend( m_Image, m_Background,
+                             KImageEffect::HorizontalGradient,
+                             bal, 100 );
+        break;
 
       case VerticalBlending:
-	KImageEffect::blend( m_Image, m_Background,
-			     KImageEffect::VerticalGradient,
-			     100, bal );
-	break;
+        KImageEffect::blend( m_Image, m_Background,
+                             KImageEffect::VerticalGradient,
+                             100, bal );
+        break;
 
       case PyramidBlending:
-	KImageEffect::blend( m_Image, m_Background,
-			     KImageEffect::PyramidGradient,
-			     bal, bal );
-	break;
+        KImageEffect::blend( m_Image, m_Background,
+                             KImageEffect::PyramidGradient,
+                             bal, bal );
+        break;
 
       case PipeCrossBlending:
-	KImageEffect::blend( m_Image, m_Background,
-			     KImageEffect::PipeCrossGradient,
-			     bal, bal );
-	break;
+        KImageEffect::blend( m_Image, m_Background,
+                             KImageEffect::PipeCrossGradient,
+                             bal, bal );
+        break;
 
       case EllipticBlending:
-	KImageEffect::blend( m_Image, m_Background,
-			     KImageEffect::EllipticGradient,
-			     bal, bal );
-	break;
+        KImageEffect::blend( m_Image, m_Background,
+                             KImageEffect::EllipticGradient,
+                             bal, bal );
+        break;
 
       case IntensityBlending:
-	KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
-		    KImageEffect::Intensity, bal, KImageEffect::All );
-	break;
+        KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
+                    KImageEffect::Intensity, bal, KImageEffect::All );
+        break;
 
       case SaturateBlending:
-	KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
-		    KImageEffect::Saturation, bal, KImageEffect::Gray );
-	break;
+        KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
+                    KImageEffect::Saturation, bal, KImageEffect::Gray );
+        break;
 
       case ContrastBlending:
-	KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
-		    KImageEffect::Contrast, bal, KImageEffect::All );
-	break;
+        KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
+                    KImageEffect::Contrast, bal, KImageEffect::All );
+        break;
 
       case HueShiftBlending:
-	KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
-		    KImageEffect::HueShift, bal, KImageEffect::Gray );
-	break;
+        KImageEffect::modulate( m_Image, m_Background, reverseBlending(),
+                    KImageEffect::HueShift, bal, KImageEffect::Gray );
+        break;
 
       case FlatBlending:
         // Already handled
-	break;
+        break;
       }
     }
 }
@@ -666,14 +713,14 @@ void KBackgroundRenderer::blend(QImage& dst, QRect dr, const QImage& src, QPoint
     dr &= dst.rect();
 
     for (y = 0; y < dr.height(); y++) {
-	if (dst.scanLine(dr.y() + y) && src.scanLine(soffs.y() + y)) {
-	    QRgb *b;
+        if (dst.scanLine(dr.y() + y) && src.scanLine(soffs.y() + y)) {
+            QRgb *b;
             const QRgb *d;
-	    for (x = 0; x < dr.width(); x++) {
-		b = reinterpret_cast<QRgb*>(dst.scanLine(dr.y() + y)
-			+ (dr.x() + x) * sizeof(QRgb));
+            for (x = 0; x < dr.width(); x++) {
+                b = reinterpret_cast<QRgb*>(dst.scanLine(dr.y() + y)
+                        + (dr.x() + x) * sizeof(QRgb));
                 d = reinterpret_cast<const QRgb*>(src.scanLine(soffs.y() + y)
-			+ (soffs.x() + x) * sizeof(QRgb));
+                        + (soffs.x() + x) * sizeof(QRgb));
                 a = (qAlpha(*d) * blendFactor) / 100;
                 *b = qRgb(qRed(*b) - (((qRed(*b) - qRed(*d)) * a) >> 8),
                           qGreen(*b) - (((qGreen(*b) - qGreen(*d)) * a) >> 8),
@@ -691,11 +738,10 @@ void KBackgroundRenderer::slotBackgroundDone(KProcess *process)
     m_State |= BackgroundDone;
 
     if (m_pProc->normalExit() && !m_pProc->exitStatus()) {
-        m_Background.load(m_Tempfile->name());
+        m_Background.load(m_Tempfile->fileName());
         m_State |= BackgroundDone;
     }
 
-    m_Tempfile->unlink();
     delete m_Tempfile; m_Tempfile = 0;
     m_pTimer->start(0);
     setBusyCursor(false);
@@ -755,8 +801,8 @@ void KBackgroundRenderer::render()
     if (!(m_State & BackgroundDone)) {
         ret = doBackground();
         if (ret != Wait)
-	    m_pTimer->start(0);
-	return;
+            m_pTimer->start(0);
+        return;
     }
 
     // No async wallpaper
@@ -784,7 +830,6 @@ void KBackgroundRenderer::done()
      } else if(backgroundMode() == Program) {
          emit programSuccess(desk());
      }
-
 }
 
 /*
@@ -811,7 +856,7 @@ void KBackgroundRenderer::setBusyCursor(bool isBusy) {
 void KBackgroundRenderer::stop()
 {
     if (!(m_State & Rendering))
-	return;
+        return;
 
     doBackground(true);
     doWallpaper(true);
@@ -882,8 +927,10 @@ void KBackgroundRenderer::load(int desk, int screen, bool drawBackgroundPerScree
 
 void KBackgroundRenderer::createTempFile()
 {
-   if( !m_Tempfile )
-     m_Tempfile = new KTempFile();
+    if( !m_Tempfile ){
+     m_Tempfile = new KTemporaryFile();
+     m_Tempfile->open();
+    }
 }
 
 QString KBackgroundRenderer::cacheFileName()
@@ -939,7 +986,7 @@ void KBackgroundRenderer::saveCacheFile()
         m_Image.save( f, "PNG" );
         // remove old entries from the cache
         QDir dir( KStandardDirs::locateLocal( "cache", "background/" ));
-        const QFileInfoList list = dir.entryInfoList( "*.png", QDir::Files, QDir::Time | QDir::Reversed );
+        const QFileInfoList list = dir.entryInfoList( QStringList() << "*.png", QDir::Files, QDir::Time | QDir::Reversed );
         if( !list.isEmpty()) {
             int size = 0;
             Q_FOREACH( QFileInfo info, list )
@@ -959,7 +1006,7 @@ void KBackgroundRenderer::saveCacheFile()
 }
 
 //BEGIN class KVirtualBGRenderer
-KVirtualBGRenderer::KVirtualBGRenderer( int desk, KConfig *config )
+KVirtualBGRenderer::KVirtualBGRenderer(int desk, const KSharedConfigPtr &config)
 {
     m_pPixmap = 0l;
     m_desk = desk;
@@ -978,11 +1025,9 @@ KVirtualBGRenderer::KVirtualBGRenderer( int desk, KConfig *config )
         else
             configname.sprintf("kdesktop-screen-%drc", screen_number);
 
-        m_pConfig = new KConfig(configname, false, false);
-        m_bDeleteConfig = true;
+        m_pConfig = KSharedConfig::openConfig(configname, false, false);
     } else {
         m_pConfig = config;
-        m_bDeleteConfig = false;
     }
 
     initRenderers();
@@ -995,9 +1040,6 @@ KVirtualBGRenderer::~KVirtualBGRenderer()
         delete m_renderer[i];
 
     delete m_pPixmap;
-
-    if (m_bDeleteConfig)
-        delete m_pConfig;
 }
 
 
