@@ -19,6 +19,7 @@
 #include <QLayout>
 #include <QPainter>
 #include <QSlider>
+#include <QSplitter>
 #include <q3groupbox.h>
 #include <Q3PtrList>
 
@@ -29,15 +30,16 @@
 #include <kglobalsettings.h>
 #include <kinputdialog.h>
 #include <kio/netaccess.h>
-#include <kipc.h>
 #include <kmessagebox.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
 #include <kaboutdata.h>
-#include <klistbox.h>
-#include "../krdb/krdb.h"
+#include <klistwidget.h>
+#include <kvbox.h>
+#include "../../../runtime/kcontrol/krdb/krdb.h"
 
 #include "colorscm.h"
+#include "kcolortreewidget.h"
 #include <QX11Info>
 
 #if defined Q_WS_X11 && !defined K_WS_QTONLY
@@ -93,7 +95,7 @@ QPixmap mkColorPreview(const WidgetCanvas *cs)
 /**** KColorScheme ****/
 
 KColorScheme::KColorScheme(QWidget *parent, const QStringList &)
-    : KCModule(KolorFactory::instance(), parent)
+    : KCModule(KolorFactory::componentData(), parent)
 {
     nSysSchemes = 2;
 
@@ -118,39 +120,27 @@ KColorScheme::KColorScheme(QWidget *parent, const QStringList &)
     cs = new WidgetCanvas( this );
     cs->setCursor( KCursor::handCursor() );
 
-    // LAYOUT
-
-    QGridLayout *topLayout = new QGridLayout( this );
-    topLayout->setSpacing( KDialog::spacingHint() );
-    topLayout->setRowStretch(0,0);
-    topLayout->setRowStretch(1,0);
-    topLayout->setColumnStretch(0,1);
-    topLayout->setColumnStretch(1,1);
 
     cs->setFixedHeight(160);
     cs->setMinimumWidth(440);
-
     cs->setWhatsThis( i18n("This is a preview of the color settings which"
        " will be applied if you click \"Apply\" or \"OK\". You can click on"
        " different parts of this preview image. The widget name in the"
        " \"Widget color\" box will change to reflect the part of the preview"
        " image you clicked.") );
 
-    connect( cs, SIGNAL( widgetSelected( int ) ),
-         SLOT( slotWidgetColor( int ) ) );
     connect( cs, SIGNAL( colorDropped( int, const QColor&)),
          SLOT( slotColorForWidget( int, const QColor&)));
-    topLayout->addWidget( cs, 0, 0, 1, 2 );
-
-    Q3GroupBox *group = new Q3GroupBox( i18n("Color Scheme"), this );
+    
+    QSplitter *splitter = new QSplitter(this);
+    
+    Q3GroupBox *group = new Q3GroupBox( i18n("Color Scheme"), splitter );
     group->setOrientation( Qt::Horizontal );
     group->setColumns( 1 );
-    topLayout->addWidget( group, 1, 0 );
 
-    sList = new KListBox( group );
+
+    sList = new KListWidget( group );
     mSchemeList = new KColorSchemeList();
-    readSchemeNames();
-    sList->setCurrentItem( 0 );
     connect(sList, SIGNAL(highlighted(int)), SLOT(slotPreviewScheme(int)));
 
     sList->setWhatsThis( i18n("This is a list of predefined color schemes,"
@@ -184,79 +174,50 @@ KColorScheme::KColorScheme(QWidget *parent, const QStringList &)
 		" current user." ));
 
 
-    QBoxLayout *stackLayout = new QVBoxLayout;
-    topLayout->addLayout(stackLayout, 1, 1);
+    
+    KVBox *vb=new KVBox(splitter);
 
-    group = new Q3GroupBox(i18n("&Widget Color"), this);
-    stackLayout->addWidget(group);
-    QBoxLayout *groupLayout = new QVBoxLayout(group);
-    groupLayout->setMargin(10);
-    groupLayout->addSpacing(10);
+        // LAYOUT
+    splitter->addWidget(group);
+    splitter->addWidget(vb);
+    QVBoxLayout *toplayout = new QVBoxLayout(this);
+    toplayout->addWidget(cs);
+    toplayout->addWidget(splitter);
+    setLayout(toplayout);
 
-    wcCombo = new QComboBox(group);
-    wcCombo->setEditable(false);
-    for(int i=0; i < CSM_LAST;i++)
-    {
-       wcCombo->addItem(QString());
-    }
+    mColorTreeWidget = new KColorTreeWidget(vb);
+    connect(mColorTreeWidget , SIGNAL(colorChanged(int, const QColor& )) , 
+            this , SLOT(slotColorChanged( int, const QColor& ) ));
+    
+    setColorName(i18n("Inactive Title Bar") , CSM_Inactive_title_text , CSM_Inactive_title_bar);
+    setColorName(i18n("Inactive Title Blend"), -1 , CSM_Inactive_title_blend);
+    setColorName(i18n("Active Title Bar"), CSM_Active_title_text, CSM_Active_title_bar);
+    setColorName(i18n("Active Title Blend"), -1, CSM_Active_title_blend);
+    setColorName(i18n("Window"), CSM_Text , CSM_Background);
+    setColorName(i18n("Selected"), CSM_Select_text , CSM_Select_background);
+    setColorName(i18n("Standard"), CSM_Standard_text,  CSM_Standard_background);
+    setColorName(i18n("Button"), CSM_Button_text , CSM_Button_background);
+    setColorName(i18n("Active Title Button"), CSM_Active_title_button , -1 );
+    setColorName(i18n("Inactive Title Button"), CSM_Inactive_title_button , -1);
+    setColorName(i18n("Active Window Frame"), CSM_Active_frame , -1);
+    setColorName(i18n("Active Window Handle"), CSM_Active_handle , -1);
+    setColorName(i18n("Inactive Window Frame"), CSM_Inactive_frame , -1);
+    setColorName(i18n("Inactive Window Handle"), CSM_Inactive_handle , -1);
+    setColorName(i18n("Link"), CSM_Link , -1);
+    setColorName(i18n("Followed Link"), CSM_Followed_Link , -1 );
+    setColorName(i18n("Alternate Background in Lists"), -1 , CSM_Alternate_background);
 
-    setColorName(i18n("Inactive Title Bar") , CSM_Inactive_title_bar);
-    setColorName(i18n("Inactive Title Text"), CSM_Inactive_title_text);
-    setColorName(i18n("Inactive Title Blend"), CSM_Inactive_title_blend);
-    setColorName(i18n("Active Title Bar"), CSM_Active_title_bar);
-    setColorName(i18n("Active Title Text"), CSM_Active_title_text);
-    setColorName(i18n("Active Title Blend"), CSM_Active_title_blend);
-    setColorName(i18n("Window Background"), CSM_Background);
-    setColorName(i18n("Window Text"), CSM_Text);
-    setColorName(i18n("Selected Background"), CSM_Select_background);
-    setColorName(i18n("Selected Text"), CSM_Select_text);
-    setColorName(i18n("Standard Background"), CSM_Standard_background);
-    setColorName(i18n("Standard Text"), CSM_Standard_text);
-    setColorName(i18n("Button Background"), CSM_Button_background);
-    setColorName(i18n("Button Text"), CSM_Button_text);
-    setColorName(i18n("Active Title Button"), CSM_Active_title_button);
-    setColorName(i18n("Inactive Title Button"), CSM_Inactive_title_button);
-    setColorName(i18n("Active Window Frame"), CSM_Active_frame);
-    setColorName(i18n("Active Window Handle"), CSM_Active_handle);
-    setColorName(i18n("Inactive Window Frame"), CSM_Inactive_frame);
-    setColorName(i18n("Inactive Window Handle"), CSM_Inactive_handle);
-    setColorName(i18n("Link"), CSM_Link);
-    setColorName(i18n("Followed Link"), CSM_Followed_Link);
-    setColorName(i18n("Alternate Background in Lists"), CSM_Alternate_background);
 
-    wcCombo->adjustSize();
-    connect(wcCombo, SIGNAL(activated(int)), SLOT(slotWidgetColor(int)));
-    groupLayout->addWidget(wcCombo);
-
-    wcCombo->setWhatsThis( i18n("Click here to select an element of"
-       " the KDE desktop whose color you want to change. You may either"
-       " choose the \"widget\" here, or click on the corresponding part"
-       " of the preview image above.") );
-
-    colorButton = new KColorButton( group );
-    connect( colorButton, SIGNAL( changed(const QColor &)),
-             SLOT(slotSelectColor(const QColor &)));
-
-    groupLayout->addWidget( colorButton );
-
-    colorButton->setWhatsThis( i18n("Click here to bring up a dialog"
-       " box where you can choose a color for the \"widget\" selected"
-       " in the above list.") );
-
-    cbShadeList = new QCheckBox(i18n("Shade sorted column in lists"), this);
-    stackLayout->addWidget(cbShadeList);
+    cbShadeList = new QCheckBox(i18n("Shade sorted column in lists"), vb);
     connect(cbShadeList, SIGNAL(toggled(bool)), this, SLOT(slotShadeSortColumnChanged(bool)));
 
     cbShadeList->setWhatsThis(
        i18n("Check this box to show the sorted column in a list with a shaded background"));
 
-    group = new Q3GroupBox(  i18n("Con&trast"), this );
-    stackLayout->addWidget(group);
-
+    group = new Q3GroupBox(  i18n("Con&trast"), vb );
+    
     QVBoxLayout *groupLayout2 = new QVBoxLayout(group);
-    groupLayout2->setMargin(10);
-    groupLayout2->addSpacing(10);
-    groupLayout = new QHBoxLayout;
+    QHBoxLayout *groupLayout = new QHBoxLayout;
     groupLayout2->addLayout(groupLayout);
 
     sb = new QSlider( Qt::Horizontal,group,"Slider" );
@@ -277,11 +238,14 @@ KColorScheme::KColorScheme(QWidget *parent, const QStringList &)
     groupLayout->addWidget( label );
 
     cbExportColors = new QCheckBox(i18n("Apply colors to &non-KDE applications"), this);
-    topLayout->addWidget( cbExportColors, 2, 0, 1, 2 );
+    toplayout->addWidget( cbExportColors );
     connect(cbExportColors, SIGNAL(toggled(bool)), this, SLOT(changed()));
 
     cbExportColors->setWhatsThis( i18n("Check this box to apply the"
        " current color scheme to non-KDE applications."));
+    
+    readSchemeNames();
+    sList->setCurrentItem( 0 );
 
     load();
 
@@ -302,25 +266,19 @@ KColorScheme::~KColorScheme()
     delete mSchemeList;
 }
 
-void KColorScheme::setColorName( const QString &name, int id )
-{
-    wcCombo->setItemText(id, name);
-    cs->addToolTip( id, name );
-}
 
 void KColorScheme::load()
 {
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->setGroup("KDE");
     sCurrentScheme = config->readEntry("colorScheme");
 
-    sList->setCurrentItem(findSchemeByName(sCurrentScheme));
+    sList->setCurrentRow(findSchemeByName(sCurrentScheme));
     readScheme(0);
 
     cbShadeList->setChecked(cs->shadeSortColumn);
 
     cs->drawSampleWidgets();
-    slotWidgetColor(wcCombo->currentIndex());
     sb->blockSignals(true);
     sb->setValue(cs->contrast);
     sb->blockSignals(false);
@@ -336,7 +294,7 @@ void KColorScheme::load()
 
 void KColorScheme::save()
 {
-    KConfig *cfg = KGlobal::config();
+    KSharedConfig::Ptr cfg = KGlobal::config();
     cfg->setGroup( "General" );
     cfg->writeEntry("background", cs->back, KConfigBase::Normal|KConfigBase::Global);
     cfg->writeEntry("selectBackground", cs->select, KConfigBase::Normal|KConfigBase::Global);
@@ -406,18 +364,18 @@ void KColorScheme::save()
     runRdb( flags );	// Save the palette to qtrc for KStyles
 
     // Notify all KDE applications
-    KIPC::sendMessageAll(KIPC::PaletteChanged);
+    KGlobalSettings::self()->emitChange(KGlobalSettings::PaletteChanged);
 
     // Update the "Current Scheme"
     int current = findSchemeByName(sCurrentScheme);
     sList->setCurrentItem(0);
     readScheme(0);
     QPixmap preview = mkColorPreview(cs);
-    sList->changeItem(preview, sList->text(0), 0);
-    sList->setCurrentItem(current);
+    sList->item(0)->setIcon(preview);
+    sList->setCurrentRow(current);
     readScheme(current);
     preview = mkColorPreview(cs);
-    sList->changeItem(preview, sList->text(current), current);
+    sList->item(current)->setIcon(preview);
 
     emit changed(false);
 }
@@ -426,12 +384,11 @@ void KColorScheme::save()
 void KColorScheme::defaults()
 {
     readScheme(1);
-    sList->setCurrentItem(1);
+    sList->setCurrentRow(1);
 
     cbShadeList->setChecked(cs->shadeSortColumn);
 
     cs->drawSampleWidgets();
-    slotWidgetColor(wcCombo->currentIndex());
     sb->blockSignals(true);
     sb->setValue(cs->contrast);
     sb->blockSignals(false);
@@ -454,7 +411,7 @@ void KColorScheme::sliderValueChanged( int val )
 
 void KColorScheme::slotSave( )
 {
-    KColorSchemeEntry *entry = mSchemeList->at(sList->currentItem()-nSysSchemes);
+    KColorSchemeEntry *entry = mSchemeList->at(sList->currentRow()-nSysSchemes);
     if (!entry) return;
     sCurrentScheme = entry->path;
     KSimpleConfig *config = new KSimpleConfig(sCurrentScheme );
@@ -495,7 +452,7 @@ void KColorScheme::slotSave( )
 
 void KColorScheme::slotRemove()
 {
-    uint ind = sList->currentItem();
+    int ind = sList->currentRow();
     KColorSchemeEntry *entry = mSchemeList->at(ind-nSysSchemes);
     if (!entry) return;
 
@@ -507,10 +464,10 @@ void KColorScheme::slotRemove()
         return;
     }
 
-    sList->removeItem(ind);
+    delete sList->takeItem(ind);
     mSchemeList->remove(entry);
 
-    ind = sList->currentItem();
+    ind = sList->currentRow();
     entry = mSchemeList->at(ind-nSysSchemes);
     if (!entry) return;
     removeBt->setEnabled(entry ? entry->local : false);
@@ -523,8 +480,8 @@ void KColorScheme::slotRemove()
 void KColorScheme::slotAdd()
 {
     QString sName;
-    if (sList->currentItem() >= nSysSchemes)
-       sName = sList->currentText();
+    if (sList->currentRow() >= nSysSchemes)
+       sName = sList->currentItem()->text();
 
     QString sFile;
 
@@ -548,14 +505,14 @@ void KColorScheme::slotAdd()
         // Check if it's already there
         for (i=0; i < (int) sList->count(); i++)
         {
-            if (sName == sList->text(i))
+            if (sName == sList->item(i)->text())
             {
                 exists = i;
-                int result = KMessageBox::warningContinueCancel( 0,
+                int result = KMessageBox::warningContinueCancel( this,
                    i18n("A color scheme with the name '%1' already exists.\n"
                         "Do you want to overwrite it?\n", sName),
                    i18n("Save Color Scheme"),
-                   i18n("Overwrite"));
+                   KGuiItem(i18n("Overwrite")));
                 if (result == KMessageBox::Cancel)
                     break;
             }
@@ -570,7 +527,7 @@ void KColorScheme::slotAdd()
     if (exists != -1)
     {
        sList->setFocus();
-       sList->setCurrentItem(exists);
+       sList->setCurrentRow(exists);
     }
     else
     {
@@ -586,8 +543,8 @@ void KColorScheme::slotAdd()
     slotSave();
 
     QPixmap preview = mkColorPreview(cs);
-    int current = sList->currentItem();
-    sList->changeItem(preview, sList->text(current), current);
+    int current = sList->currentRow();
+    sList->item(current)->setIcon(preview);
     connect(sList, SIGNAL(highlighted(int)), SLOT(slotPreviewScheme(int)));
     slotPreviewScheme(current);
 }
@@ -617,8 +574,8 @@ void KColorScheme::slotImport()
 
 		insertEntry(sFile, sName);
 		QPixmap preview = mkColorPreview(cs);
-		int current = sList->currentItem();
-		sList->changeItem(preview, sList->text(current), current);
+		int current = sList->currentRow();
+		sList->item(current)->setIcon(preview);
 		connect(sList, SIGNAL(highlighted(int)), SLOT(slotPreviewScheme(int)));
 		slotPreviewScheme(current);
 	}
@@ -679,58 +636,9 @@ QColor &KColorScheme::color(int index)
     return cs->iaTxt; // Silence compiler
 }
 
-
-void KColorScheme::slotSelectColor(const QColor &col)
-{
-    int selection;
-    selection = wcCombo->currentIndex();
-
-    // Adjust the alternate background color if the standard color changes
-    // Only if the previous alternate color was not a user-configured one
-    // of course
-    if ( selection == CSM_Standard_background &&
-         color(CSM_Alternate_background) ==
-         KGlobalSettings::calculateAlternateBackgroundColor(
-             color(CSM_Standard_background) ) )
-    {
-        color(CSM_Alternate_background) =
-            KGlobalSettings::calculateAlternateBackgroundColor( col );
-    }
-
-    color(selection) = col;
-
-    cs->drawSampleWidgets();
-
-    sCurrentScheme.clear();
-
-    emit changed(true);
-}
-
-
-void KColorScheme::slotWidgetColor(int indx)
-{
-    if (indx < 0)
-        indx = 0;
-    if (wcCombo->currentIndex() != indx)
-        wcCombo->setCurrentIndex( indx );
-
-    // Do not emit KCModule::changed()
-    colorButton->blockSignals( true );
-
-    QColor col = color(indx);
-    colorButton->setColor( col );
-    colorPushColor = col;
-
-    colorButton->blockSignals( false );
-}
-
-
 void KColorScheme::slotColorForWidget(int indx, const QColor& col)
 {
-    if (wcCombo->currentIndex() != indx)
-        wcCombo->setCurrentIndex( indx );
-
-    slotSelectColor(col);
+    mColorTreeWidget->setColor( indx , col );
 }
 
 void KColorScheme::slotShadeSortColumnChanged(bool b)
@@ -748,8 +656,6 @@ void KColorScheme::slotShadeSortColumnChanged(bool b)
  */
 void KColorScheme::readScheme( int index )
 {
-    KConfigBase* config;
-
     QColor widget(239, 239, 239);
     QColor kde34Blue(103,141,178);
     QColor inactiveBackground(157,170,186);
@@ -803,13 +709,14 @@ void KColorScheme::readScheme( int index )
       return;
     }
 
+    KConfigBase *config;
     if (index == 0) {
       // Current scheme
-      config = KGlobal::config();
+      config = KGlobal::config().data();
       config->setGroup("General");
     } else {
       // Open scheme file
-      KColorSchemeEntry *entry = mSchemeList->at(sList->currentItem()-nSysSchemes);
+      KColorSchemeEntry *entry = mSchemeList->at(sList->currentRow()-nSysSchemes);
       if (!entry) return;
       sCurrentScheme = entry->path;
       config = new KSimpleConfig(sCurrentScheme, true);
@@ -861,6 +768,12 @@ void KColorScheme::readScheme( int index )
     cs->contrast = config->readEntry( "contrast", 7 );
     if (index != 0)
       delete config;
+    
+    mColorTreeWidget->blockSignals(true);   //block the colorChanged signal
+    for(int f=0; f< CSM_LAST ; f++)
+        mColorTreeWidget->setColor( f , color(f) );
+    mColorTreeWidget->blockSignals(false);
+    
 }
 
 
@@ -872,13 +785,13 @@ void KColorScheme::readSchemeNames()
     mSchemeList->clear();
     sList->clear();
     // Always a current and a default scheme
-    sList->insertItem( i18n("Current Scheme"), 0 );
-    sList->insertItem( i18n("KDE Default"), 1 );
+    sList->insertItem( 0 , i18n("Current Scheme") );
+    sList->insertItem( 1 , i18n("KDE Default") );
     nSysSchemes = 2;
 
     // Global + local schemes
     QStringList list = KGlobal::dirs()->findAllResources("data",
-            "kdisplay/color-schemes/*.kcsrc", false, true);
+            "kdisplay/color-schemes/*.kcsrc", KStandardDirs::NoDuplicates);
 
     // And add them
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
@@ -898,15 +811,15 @@ void KColorScheme::readSchemeNames()
 
     for(KColorSchemeEntry *entry = mSchemeList->first(); entry; entry = mSchemeList->next())
     {
-       sList->insertItem(entry->name);
+       sList->addItem(entry->name);
     }
 
-    for (uint i = 0; i < (nSysSchemes + mSchemeList->count()); i++)
+    for (int i = 0; i < (nSysSchemes + mSchemeList->count()); i++)
     {
-       sList->setCurrentItem(i);
+       sList->setCurrentRow(i);
        readScheme(i);
        QPixmap preview = mkColorPreview(cs);
-       sList->changeItem(preview, sList->text(i), i);
+       sList->item(i)->setIcon(preview);
     }
 
 }
@@ -953,7 +866,6 @@ void KColorScheme::slotPreviewScheme(int indx)
     sb->blockSignals(true);
     sb->setValue(cs->contrast);
     sb->blockSignals(false);
-    slotWidgetColor(wcCombo->currentIndex());
     if (indx < nSysSchemes)
        removeBt->setEnabled(false);
     else
@@ -990,8 +902,38 @@ void KColorScheme::insertEntry(const QString &sFile, const QString &sName)
        KColorSchemeEntry *newEntry = new KColorSchemeEntry(sFile, sName, true);
        mSchemeList->inSort(newEntry);
        int newIndex = mSchemeList->findRef(newEntry)+nSysSchemes;
-       sList->insertItem(sName, newIndex);
-       sList->setCurrentItem(newIndex);
+       sList->insertItem(newIndex , sName);
+       sList->setCurrentRow(newIndex);
 }
 
+void KColorScheme::setColorName( const QString & name, int id , int id2 )
+{
+    mColorTreeWidget->addRole( id , id2, name );
+}
+
+void KColorScheme::slotColorChanged( int selection , const QColor & col)
+{
+    // Adjust the alternate background color if the standard color changes
+    // Only if the previous alternate color was not a user-configured one
+    // of course
+    if ( selection == CSM_Standard_background &&
+         color(CSM_Alternate_background) ==
+         KGlobalSettings::calculateAlternateBackgroundColor(
+             color(CSM_Standard_background) ) )
+    {
+        color(CSM_Alternate_background) =
+            KGlobalSettings::calculateAlternateBackgroundColor( col );
+    }
+
+    color(selection) = col;
+
+    cs->drawSampleWidgets();
+
+    sCurrentScheme.clear();
+
+    emit changed(true);
+}
+
+
+
 #include "colorscm.moc"
