@@ -25,15 +25,16 @@
 
 #include <kacceleratormanager.h>
 #include <kapplication.h>
+#include <kglobalsettings.h>
 #include <kgenericfactory.h>
-#include <kipc.h>
 #include <kmessagebox.h>
 #include <knuminput.h>
+#include <kprocio.h>
 #include <ksimpleconfig.h>
 #include <kstandarddirs.h>
 #include <stdlib.h>
 
-#include "../krdb/krdb.h"
+#include "../../../runtime/kcontrol/krdb/krdb.h"
 #include "fonts.h"
 #include "fonts.moc"
 
@@ -155,7 +156,7 @@ void FontUseItem::readFont()
 
   bool deleteme = false;
   if (_rcfile.isEmpty())
-    config = KGlobal::config();
+    config = KGlobal::config().data();
   else
   {
     config = new KConfig(_rcfile, true);
@@ -173,7 +174,7 @@ void FontUseItem::writeFont()
   KConfigBase *config;
 
   if (_rcfile.isEmpty()) {
-    config = KGlobal::config();
+    config = KGlobal::config().data();
     config->setGroup(_rcgroup);
     config->writeEntry(_rckey, font(), KConfigBase::Normal|KConfigBase::Global);
   } else {
@@ -495,7 +496,7 @@ static QString desktopConfigName()
 }
 
 KFonts::KFonts(QWidget *parent, const QStringList &args)
-    :   KCModule(FontFactory::instance(), parent, args)
+    :   KCModule(FontFactory::componentData(), parent, args)
 {
   QStringList nameGroupKeyRc;
 
@@ -609,33 +610,46 @@ KFonts::KFonts(QWidget *parent, const QStringList &args)
    layout->addItem(lay);
    lay->setSpacing(KDialog::spacingHint());
    cbAA = new QCheckBox( i18n( "Use a&nti-aliasing for fonts" ), this);
+   cbAA->setTristate( true );
    cbAA->setWhatsThis( i18n("If this option is selected, KDE will smooth the edges of curves in "
                               "fonts."));
-   QPushButton *aaSettingsButton = new QPushButton( i18n( "Configure..." ), this);
+   aaSettingsButton = new QPushButton( i18n( "Configure..." ), this);
    connect(aaSettingsButton, SIGNAL(clicked()), SLOT(slotCfgAa()));
-   connect(cbAA, SIGNAL(toggled(bool)), aaSettingsButton, SLOT(setEnabled(bool)));
    lay->addWidget( cbAA );
    lay->addWidget( aaSettingsButton );
    lay->addStretch();
 
    lay = new QHBoxLayout( layout, KDialog::spacingHint());
-   cbDpi = new QCheckBox( i18n( "Force DPI" ), this );
-   lay->addWidget( cbDpi );
-   comboDpi = new QComboBox( this );
-   comboDpi->addItem( i18n( "Normal fonts (96 DPI)" ));
-   comboDpi->addItem( i18n( "Huge fonts (120 DPI)" ));
-   comboDpi->setDisabled( true );
-   connect( cbDpi, SIGNAL( toggled( bool )), comboDpi, SLOT( setEnabled( bool )));
-   connect( cbDpi, SIGNAL( toggled( bool )), SLOT( changed()));
-   connect( comboDpi, SIGNAL( activated( int )), SLOT( changed()));
-   lay->addWidget( comboDpi );
+   cbForceDpi = new QCheckBox( i18n( "Force fonts DPI" ), this );
+   lay->addWidget( cbForceDpi );
+   comboForceDpi = new QComboBox( this );
+   comboForceDpi->addItem( i18n( "96 DPI" ));
+   comboForceDpi->addItem( i18n( "120 DPI" ));
+   comboForceDpi->setDisabled( true );
+   QString whatsthis = i18n(
+       "<p>This option forces a specific DPI value for fonts. It may be useful"
+       " when the real DPI of the hardware is not detected properly and it"
+       " is also often misused when poor quality fonts are used that do not"
+       " look well with DPI values other than 96 or 120 DPI.</p>"
+       "<p>The use of this option is generally discouraged. For selecting proper DPI"
+       " value a better option is explicitly configuring it for the whole X server if"
+       " possible (e.g. DisplaySize in xorg.conf or adding <i>-dpi value</i> to"
+       " ServerLocalArgs= in $KDEDIR/share/config/kdm/kdmrc). When fonts do not render"
+       " properly with real DPI value better fonts should be used or configuration"
+       " of font hinting should be checked.</p>" );
+   cbForceDpi->setWhatsThis(whatsthis);
+   comboForceDpi->setWhatsThis(whatsthis);
+   connect( cbForceDpi, SIGNAL( toggled( bool )), comboForceDpi, SLOT( setEnabled( bool )));
+   connect( cbForceDpi, SIGNAL( toggled( bool )), SLOT( changed()));
+   connect( comboForceDpi, SIGNAL( activated( int )), SLOT( changed()));
+   lay->addWidget( comboForceDpi );
    lay->addStretch();
 
    layout->addStretch(1);
 
    aaSettings=new FontAASettings(this);
 
-   connect(cbAA, SIGNAL(clicked()), SLOT(slotUseAntiAliasing()));
+   connect(cbAA, SIGNAL(stateChanged(int)), SLOT(slotUseAntiAliasing()));
 
    load();
 }
@@ -656,10 +670,10 @@ void KFonts::defaults()
   for ( int i = 0; i < (int) fontUseList.count(); i++ )
     fontUseList.at( i )->setDefault();
 
-  useAA = true;
-  cbAA->setChecked(useAA);
+  useAA = Qt::PartiallyChecked;
+  cbAA->setNoChange();
   aaSettings->defaults();
-  cbDpi->setChecked(false);
+  cbForceDpi->setChecked(false);
   emit changed(true);
 }
 
@@ -668,16 +682,21 @@ void KFonts::load()
   for ( uint i = 0; i < fontUseList.count(); i++ )
     fontUseList.at( i )->readFont();
 
-  useAA_original = useAA = aaSettings->load();
-  kDebug(1208) << "AA:" << useAA << endl;
-  cbAA->setChecked(useAA);
+  useAA_original = useAA = aaSettings->load() ? Qt::Checked : Qt::Unchecked;
+  kDebug(1208) << "AA:" << ( useAA == Qt::Checked ) << endl;
+  cbAA->setChecked(useAA == Qt::Checked);
 
   KConfig cfgfonts("kcmfonts", true);
   cfgfonts.setGroup("General");
-  int dpi = cfgfonts.readNumEntry( "fontDPI", 0 );
-  cbDpi->setChecked( dpi == 96 || dpi == 120 );
-  comboDpi->setCurrentIndex( dpi == 120 ? 1 : 0 );
+  int dpi = cfgfonts.readEntry( "forceFontDPI", 0 );
+  cbForceDpi->setChecked( dpi == 96 || dpi == 120 );
+  comboForceDpi->setCurrentIndex( dpi == 120 ? 1 : 0 );
   dpi_original = dpi;
+  if( cfgfonts.readEntry( "dontChangeAASettings", true )) {
+      cbAA->setNoChange();
+      useAA_original = useAA = Qt::PartiallyChecked;
+  }
+  aaSettingsButton->setEnabled( cbAA->checkState() == Qt::Checked );
 
   emit changed(false);
 }
@@ -692,12 +711,22 @@ void KFonts::save()
   KConfig cfgfonts("kcmfonts");
   cfgfonts.setGroup("General");
   int dpi;
-  if( !cbDpi->isChecked())
+  if( !cbForceDpi->isChecked())
       dpi = 0;
   else
-      dpi = comboDpi->currentIndex() == 0 ? 96 : 120;
-  cfgfonts.writeEntry( "fontDPI", dpi );
+      dpi = comboForceDpi->currentIndex() == 0 ? 96 : 120;
+  cfgfonts.writeEntry( "forceFontDPI", dpi );
+  cfgfonts.writeEntry( "dontChangeAASettings", cbAA->checkState() == Qt::PartiallyChecked );
   cfgfonts.sync();
+  // if the setting is reset in the module, remove the dpi value,
+  // otherwise don't explicitly remove it and leave any possible system-wide value
+  if( dpi == 0 && dpi_original != 0 ) {
+      KProcIO proc;
+      proc << "xrdb" << "-quiet" << "-remove" << "-nocpp";
+      proc.writeStdin( QString( "Xft.dpi" ), true );
+      proc.closeWhenDone();
+      proc.start( KProcess::Block );
+  }
 
   // KDE-1.x support
   KSimpleConfig* config = new KSimpleConfig( QDir::homePath() + "/.kderc" );
@@ -711,14 +740,21 @@ void KFonts::save()
   config->sync();
   delete config;
 
-  KIPC::sendMessageAll(KIPC::FontChanged);
+  KGlobalSettings::self()->emitChange(KGlobalSettings::FontChanged);
 
   kapp->processEvents(); // Process font change ourselves
 
-  if(aaSettings->save( useAA ) || (useAA != useAA_original) || dpi != dpi_original) {
+  bool aaSave = false;
+  // Don't overwrite global settings unless explicitly asked for - e.g. the system
+  // fontconfig setup may be much more complex than this module can provide.
+  // TODO: With PartiallyChecked the changes already made by this module should be reverted somehow.
+  if( cbAA->checkState() != Qt::PartiallyChecked )
+      aaSave = aaSettings->save( useAA == Qt::Checked );
+
+  if( aaSave || (useAA != useAA_original) || dpi != dpi_original) {
     KMessageBox::information(this,
       i18n(
-        "<p>Some changes such as anti-aliasing or DPI settings will only affect newly started applications.</p>"
+        "<p>Some changes such as anti-aliasing will only affect newly started applications.</p>"
       ), i18n("Font Settings Changed"), "FontSettingsChanged", false);
     useAA_original = useAA;
     dpi_original = dpi;
@@ -746,7 +782,8 @@ void KFonts::slotApplyFontDiff()
 
 void KFonts::slotUseAntiAliasing()
 {
-    useAA = cbAA->isChecked();
+    useAA = cbAA->checkState();
+    aaSettingsButton->setEnabled( cbAA->checkState() == Qt::Checked );
     emit changed(true);
 }
 
