@@ -32,7 +32,7 @@ extern bool GetInfo_OpenGL( Q3ListView *lBox );
 class KInfoListWidget : public KCModule
 {
 public:
-  KInfoListWidget(KInstance *inst,const QString &_title, QWidget *parent, bool _getlistbox (Q3ListView *)=0);
+  KInfoListWidget(const KComponentData &inst,const QString &_title, QWidget *parent, bool _getlistbox (Q3ListView *)=0);
 
   virtual void load();
   virtual QString quickHelp() const;
