@@ -71,7 +71,7 @@
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <kipc.h>
+#include <kglobalsettings.h>
 #include <QX11Info>
 
 #undef Below
@@ -82,7 +82,7 @@ typedef KGenericFactory<MouseConfig> MouseConfigFactory;
 K_EXPORT_COMPONENT_FACTORY(mouse, MouseConfigFactory("kcminput"))
 
 MouseConfig::MouseConfig(QWidget *parent, const QStringList &args)
-  : KCModule(MouseConfigFactory::instance(), parent, args)
+  : KCModule(MouseConfigFactory::componentData(), parent, args)
 {
 
 
@@ -726,7 +726,9 @@ void MouseSettings::load(KConfig *config)
     handed = RIGHT_HANDED;
   else if (key == "LeftHanded")
     handed = LEFT_HANDED;
+#ifdef __GNUC__
 #warning was key == NULL how was this working? is key.isNull() what the coder meant?
+#endif  
   else if (key.isNull())
     handed = h;
   reverseScrollPolarity = config->readEntry( "ReverseScrollPolarity", false);
@@ -863,7 +865,7 @@ void MouseSettings::save(KConfig *config)
   }
 #endif
   config->sync();
-  KIPC::sendMessageAll(KIPC::SettingsChanged, KApplication::SETTINGS_MOUSE);
+  KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged, KGlobalSettings::SETTINGS_MOUSE);
 }
 
 void MouseConfig::slotScrollPolarityChanged()
