@@ -34,7 +34,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 #include <kiconloader.h>
 #include <kio/job.h>
 #include <kio/netaccess.h>
-#include <kipc.h>
 #include <klocale.h>
 #include <kservice.h>
 #include <ksimpleconfig.h>
@@ -43,6 +42,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 #include <kstyle.h>
 #include <QX11Info>
 #include <QtDBus/QtDBus>
+#include <kglobalsettings.h>
+#include "kwin_interface.h"
+#include "kdesktop_background.h"
 
 KTheme::KTheme( QWidget *parent, const QString & xmlFile )
 	: m_parent(parent)
@@ -126,7 +128,7 @@ QString KTheme::createYourself( bool pack )
     // 1. General stuff set by methods setBlah()
 
     // 2. Background theme
-    KConfig * globalConf = KGlobal::config();
+    KSharedConfig::Ptr globalConf = KGlobal::config();
 
     KConfig kwinConf( "kwinrc", true );
     kwinConf.setGroup( "Desktops" );
@@ -304,12 +306,30 @@ QString KTheme::createYourself( bool pack )
     QDomElement transElem = m_dom.createElement( "transparent" );
     transElem.setAttribute( "value", kickerConf.readEntry( "Transparent" , false) );
     panelElem.appendChild( transElem );
+
+    QDomElement posElem = m_dom.createElement( "position" );
+    posElem.setAttribute( "value", kickerConf.readEntry( "Position" ) );
+    panelElem.appendChild( posElem );
+
+
+    QDomElement showLeftHideButtonElem = m_dom.createElement( "showlefthidebutton" );
+    showLeftHideButtonElem.setAttribute( "value", kickerConf.readEntry( "ShowLeftHideButton",true ) );
+    panelElem.appendChild( showLeftHideButtonElem );
+
+    QDomElement showRightHideButtonElem = m_dom.createElement( "showrighthidebutton" );
+    showRightHideButtonElem.setAttribute( "value", kickerConf.readEntry( "ShowRightHideButton",true ) );
+    panelElem.appendChild( showRightHideButtonElem );
+
+
+
     m_root.appendChild( panelElem );
 
     // 10. Widget style
     globalConf->setGroup( "General" );
     QDomElement widgetsElem = m_dom.createElement( "widgets" );
+#ifdef __GNUC__
 #warning "qt4: FIXME KStyle::defaultStyle();";
+#endif    
     widgetsElem.setAttribute( "name", globalConf->readEntry( "widgetStyle"/*,KStyle::defaultStyle()*/  ) );
     m_root.appendChild( widgetsElem );
 
@@ -424,15 +444,16 @@ void KTheme::apply()
 
     desktopConf.sync();         // TODO sync and signal only if <desktop> elem present
     // reconfigure kdesktop. kdesktop will notify all clients
-    QDBusInterface kdesktop( "org.kde.kdesktop", "/Background", "org.kde.kdesktop.Background");
-    kdesktop.call("configure");
+    org::kde::kdesktop::Background desktop("org.kde.kdesktop", "/Background", QDBusConnection::sessionBus());
+    desktop.configure();
+
     // FIXME Xinerama
 
     // 3. Icons
     QDomElement iconElem = m_dom.elementsByTagName( "icons" ).item( 0 ).toElement();
     if ( !iconElem.isNull() )
     {
-        KConfig * iconConf = KGlobal::config();
+        KSharedConfig::Ptr iconConf = KGlobal::config();
         iconConf->setGroup( "Icons" );
         iconConf->writeEntry( "Theme", iconElem.attribute( "name", "crystalsvg" ), KConfigBase::Persistent|KConfigBase::Global);
 
@@ -468,7 +489,7 @@ void KTheme::apply()
         iconConf->sync();
 
         for ( int i = 0; i < K3Icon::LastGroup; i++ )
-            KIPC::sendMessageAll( KIPC::IconChanged, i );
+            KGlobalSettings::self()->emitChange( KGlobalSettings::IconChanged, i );
         KBuildSycocaProgressDialog::rebuildKSycoca( m_parent );
     }
 
@@ -514,7 +535,7 @@ void KTheme::apply()
     if ( !colorsElem.isNull() )
     {
         QDomNodeList colorList = colorsElem.childNodes();
-        KConfig * colorConf = KGlobal::config();
+        KSharedConfig::Ptr colorConf = KGlobal::config();
 
         QString sCurrentScheme = KStandardDirs::locateLocal("data", "kdisplay/color-schemes/thememgr.kcsrc");
         KSimpleConfig *colorScheme = new KSimpleConfig( sCurrentScheme );
@@ -542,7 +563,7 @@ void KTheme::apply()
         colorConf->sync();
         delete colorScheme;
 
-        KIPC::sendMessageAll( KIPC::PaletteChanged );
+        KGlobalSettings::self()->emitChange( KGlobalSettings::PaletteChanged );
     }
 
     // 6.Cursors
@@ -581,9 +602,8 @@ void KTheme::apply()
         kwinConf.writeEntry( "BorderSize", getProperty( wmElem, "border", "size" ) );
 
         kwinConf.sync();
-        QDBusInterface kwin("org.kde.kwin", "/KWin", "org.kde.KWin");
-        if ( kwin.isValid() )
-            kwin.call( "reconfigure" );
+        org::kde::KWin kwin("org.kde.kwin", "/KWin", QDBusConnection::sessionBus());
+        kwin.reconfigure();	
     }
 
     // 8. Konqueror
@@ -599,8 +619,8 @@ void KTheme::apply()
         konqConf.sync();
 
         QDBusMessage message =
-            QDBusMessage::signal("/KonqMain", "org.kde.Konqueror.Main", "reparseConfiguration", QDBus::sessionBus());
-        QDBus::sessionBus().send(message);
+            QDBusMessage::createSignal("/KonqMain", "org.kde.Konqueror.Main", "reparseConfiguration");
+        QDBusConnection::sessionBus().send(message);
     }
 
     // 9. Kicker
@@ -621,6 +641,12 @@ void KTheme::apply()
         kickerConf.writeEntry( "Transparent",
                                static_cast<bool>( getProperty( panelElem, "transparent", "value" ).toUInt() ) );
 
+        kickerConf.writeEntry( "Position", static_cast<int> (getProperty( panelElem, "position", "value" ).toUInt() ));
+
+        kickerConf.writeEntry( "ShowLeftHideButton", static_cast<bool>( getProperty( panelElem, "showlefthidebutton", "value").toInt()));
+
+        kickerConf.writeEntry( "ShowRightHideButton", static_cast<bool>( getProperty( panelElem, "showrighthidebutton", "value").toInt()));
+
         kickerConf.sync();
 		QDBusInterface kicker( "org.kde.kicker", "kicker");
 		kicker.call("configure");
@@ -631,18 +657,18 @@ void KTheme::apply()
 
     if ( !widgetsElem.isNull() )
     {
-        KConfig * widgetConf = KGlobal::config();
+        KSharedConfig::Ptr widgetConf = KGlobal::config();
         widgetConf->setGroup( "General" );
         widgetConf->writeEntry( "widgetStyle", widgetsElem.attribute( "name" ), KConfigBase::Persistent|KConfigBase::Global);
         widgetConf->sync();
-        KIPC::sendMessageAll( KIPC::StyleChanged );
+        KGlobalSettings::self()->emitChange( KGlobalSettings::StyleChanged );
     }
 
     // 12. Fonts
     QDomElement fontsElem = m_dom.elementsByTagName( "fonts" ).item( 0 ).toElement();
     if ( !fontsElem.isNull() )
     {
-        KConfig * fontsConf = KGlobal::config();
+        KSharedConfig::Ptr fontsConf = KGlobal::config();
         KConfig * kde1xConf = new KSimpleConfig( QDir::homePath() + "/.kderc" );
         kde1xConf->setGroup( "General" );
 
@@ -668,7 +694,7 @@ void KTheme::apply()
 
         fontsConf->sync();
         kde1xConf->sync();
-        KIPC::sendMessageAll( KIPC::FontChanged );
+        KGlobalSettings::self()->emitChange( KGlobalSettings::FontChanged );
     }
 
 }
@@ -714,7 +740,7 @@ QString KTheme::getProperty( QDomElement parent, const QString & tag,
 }
 
 void KTheme::createIconElems( const QString & group, const QString & object,
-                              QDomElement parent, KConfig * cfg )
+                              QDomElement parent, KSharedConfigPtr cfg )
 {
     cfg->setGroup( group );
     QStringList elemNames;
@@ -747,7 +773,7 @@ void KTheme::createIconElems( const QString & group, const QString & object,
 }
 
 void KTheme::createColorElem( const QString & name, const QString & object,
-                              QDomElement parent, KConfig * cfg )
+                              QDomElement parent, KSharedConfigPtr cfg )
 {
     QColor color = cfg->readEntry( name,QColor() );
     if ( color.isValid() )
