@@ -1,3 +1,5 @@
+#ifndef XKLAVIER_ADAPTOR_H
+#define XKLAVIER_ADAPTOR_H
 #include <X11/Xlib.h>
 
 #include <QHash>
@@ -10,7 +12,7 @@ public:
 	XKlavierAdaptor();
 	~XKlavierAdaptor();	
 		
-	void xklConfig(Display* dpy);
+	void loadXkbConfig(Display* dpy, bool layoutsOnly);
 
 	QHash<QString, QString> getModels();
 	QHash<QString, QString> getLayouts();
@@ -21,3 +23,5 @@ public:
 private:
 	XKlavierAdaptorPriv* priv;
 };
+#endif
+
