@@ -27,7 +27,6 @@
 #include <kglobal.h>
 #include <kapplication.h>
 #include <kiconloader.h>
-#include <kipc.h>
 #include <qlabel.h>
 #include <QDesktopWidget>
 #include "ktimerdialog.h"
@@ -154,7 +153,7 @@ bool RandRScreen::confirm()
 
 	// FIXME remember to put the dialog on the right screen
 
-	KTimerDialog *acceptDialog = new KTimerDialog(
+	KTimerDialog acceptDialog(
 											15000,
 											KTimerDialog::CountDown,
 											KApplication::kApplication()->mainWidget(),
@@ -164,19 +163,22 @@ bool RandRScreen::confirm()
 											KTimerDialog::Ok|KTimerDialog::Cancel,
 											KTimerDialog::Cancel);
 
-	acceptDialog->setButtonGuiItem(KDialog::Ok, KGuiItem(i18n("&Accept Configuration"), "button_ok"));
-	acceptDialog->setButtonGuiItem(KDialog::Cancel, KGuiItem(i18n("&Return to Previous Configuration"), "button_cancel"));
+	acceptDialog.setButtonGuiItem(KDialog::Ok, KGuiItem(i18n("&Accept Configuration"), "button_ok"));
+	acceptDialog.setButtonGuiItem(KDialog::Cancel, KGuiItem(i18n("&Return to Previous Configuration"), "button_cancel"));
 
-	QLabel *label = new QLabel(i18n("Your screen orientation, size and refresh rate have been changed to the requested settings. Please indicate whether you wish to keep this configuration. In 15 seconds the display will revert to your previous settings."), acceptDialog);
-        acceptDialog->setMainWidget(label);
+	QLabel *label = new QLabel(i18n("Your screen orientation, size and refresh rate have been "
+                    "changed to the requested settings. Please indicate whether you wish to keep "
+                    "this configuration. In 15 seconds the display will revert to your previous "
+                    "settings."), &acceptDialog);
+        acceptDialog.setMainWidget(label);
 
-	KDialog::centerOnScreen(acceptDialog, m_screen);
+	KDialog::centerOnScreen(&acceptDialog, m_screen);
 
-	m_shownDialog = acceptDialog;
+	m_shownDialog = &acceptDialog;
 	connect( m_shownDialog, SIGNAL( destroyed()), this, SLOT( shownDialogDestroyed()));
 	connect( kapp->desktop(), SIGNAL( resized(int)), this, SLOT( desktopResized()));
 
-    return acceptDialog->exec();
+    return acceptDialog.exec();
 }
 
 void RandRScreen::shownDialogDestroyed()
@@ -320,7 +322,7 @@ QString RandRScreen::currentRotationDescription() const
 {
 	QString ret = rotationName(m_currentRotation & RotateMask);
 
-	if (m_currentRotation != m_currentRotation & RotateMask)
+	if (m_currentRotation != (m_currentRotation & RotateMask))
 		if (m_currentRotation & RR_Rotate_0)
 			ret = rotationName(m_currentRotation & (RR_Reflect_X + RR_Reflect_X), true, true);
 		else
@@ -547,8 +549,8 @@ void RandRScreen::save(KConfig& config) const
 	config.writeEntry("height", currentPixelHeight());
 	config.writeEntry("refresh", refreshRateIndexToHz(currentSize(), currentRefreshRate()));
 	config.writeEntry("rotation", rotationIndexToDegree(currentRotation()));
-	config.writeEntry("reflectX", (bool)(currentRotation() & ReflectMask == ReflectX));
-	config.writeEntry("reflectY", (bool)(currentRotation() & ReflectMask == ReflectY));
+	config.writeEntry("reflectX", (bool)(currentRotation() & ReflectMask) == ReflectX);
+	config.writeEntry("reflectY", (bool)(currentRotation() & ReflectMask) == ReflectY);
 }
 
 RandRDisplay::RandRDisplay()
@@ -565,7 +567,7 @@ RandRDisplay::RandRDisplay()
 	int major_version, minor_version;
 	XRRQueryVersion(QX11Info::display(), &major_version, &minor_version);
 
-	m_version = QString("X Resize and Rotate extension version %1.%1").arg(major_version).arg(minor_version);
+	m_version = i18n("X Resize and Rotate extension version %1.%2",major_version,minor_version);
 
 	m_numScreens = ScreenCount(QX11Info::display());
 
@@ -664,7 +666,7 @@ bool RandRDisplay::loadDisplay(KConfig& config, bool loadScreens)
         	RandRScreen* s = m_screens.at(i);
         	s->load(config);
 		}
-    }	
+    }
 	return applyOnStartup(config);
 }
 
