@@ -10,12 +10,18 @@ SaverConfig::SaverConfig()
 bool SaverConfig::read(const QString &file)
 {
     KDesktopFile config(file, true);
+#if 0    
     if( !config.tryExec())
       return false;
+#endif    
     mExec = config.readPathEntry("Exec");
     mName = config.readEntry("Name");
-    mCategory = i18nc("Screen saver category", // Must be same in Makefile.am
-                     config.readEntry("X-KDE-Category").toUtf8());
+    QString categoryName = config.readEntry("X-KDE-Category");
+    if(categoryName.isEmpty())
+	mCategory = categoryName;
+    else	    
+        mCategory = i18nc("Screen saver category", // Must be same in CMakeFiles.txt
+                     categoryName.toUtf8());
 
     if (config.hasActionGroup("Setup"))
     {
