@@ -17,6 +17,8 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 
+#include <kservicetypetrader.h>
+#include <kstandarddirs.h>
 #include <q3buttongroup.h>
 #include <QCheckBox>
 #include <q3header.h>
@@ -57,7 +59,7 @@
 #include "scrnsave.h"
 #include <QX11Info>
 #include <QDesktopWidget>
-
+#include <screensaver_interface.h>
 #include <fixx11h.h>
 
 template class QList<SaverConfig*>;
@@ -83,7 +85,7 @@ static QString findExe(const QString &exe) {
 }
 
 KScreenSaver::KScreenSaver(QWidget *parent, const QStringList&)
-    : KCModule(KSSFactory::instance(), parent)
+    : KCModule(KSSFactory::componentData(), parent)
 {
     mSetupProc = 0;
     mPreviewProc = 0;
@@ -110,18 +112,7 @@ KScreenSaver::KScreenSaver(QWidget *parent, const QStringList&)
 
     setButtons( KCModule::Help | KCModule::Default | KCModule::Apply );
 
-    // Add KDE specific screensaver path
-    QString relPath="System/ScreenSavers/";
-    KServiceGroup::Ptr servGroup = KServiceGroup::baseGroup( "screensavers" );
-    if (servGroup)
-    {
-      relPath=servGroup->relPath();
-      kDebug() << "relPath=" << relPath << endl;
-    }
 
-    KGlobal::dirs()->addResourceType("scrsav",
-                                     KGlobal::dirs()->kde_default("apps") +
-                                     relPath);
 
     readSettings();
 
@@ -372,6 +363,8 @@ KScreenSaver::~KScreenSaver()
     delete mTestProc;
     delete mSetupProc;
     delete mTestWin;
+
+    qDeleteAll(mSaverList);
 }
 
 //---------------------------------------------------------------------------
@@ -412,7 +405,7 @@ void KScreenSaver::load()
 //
 void KScreenSaver::readSettings()
 {
-    KConfig *config = new KConfig( "kdesktoprc");
+    KConfig *config = new KConfig( "kscreensaverrc");
 
     mImmutable = config->groupIsImmutable("ScreenSaver");
 
@@ -482,7 +475,7 @@ void KScreenSaver::save()
     if ( !mChanged )
         return;
 
-    KConfig *config = new KConfig( "kdesktoprc");
+    KConfig *config = new KConfig( "kscreensaverrc");
     config->setGroup( "ScreenSaver" );
 
     config->writeEntry("Enabled", mEnabled);
@@ -499,8 +492,8 @@ void KScreenSaver::save()
     // TODO (GJ): When you changed anything, these two lines will give a segfault
     // on exit. I don't know why yet.
 
-	QDBusInterface kscreensaver("org.kde.kdesktop", "/Screensaver", "org.kde.kdesktop.KScreensaver");
-	kscreensaver.call("configure");
+    org::kde::ScreenSaver desktop("org.kde.krunner", "/Screensaver", QDBusConnection::sessionBus());
+    desktop.configure();
 
     mChanged = false;
     emit changed(false);
@@ -511,27 +504,25 @@ void KScreenSaver::save()
 void KScreenSaver::findSavers()
 {
     if ( !mNumLoaded ) {
-        mSaverFileList = KGlobal::dirs()->findAllResources("scrsav",
-                            "*.desktop", false, true);
+	mSaverServices = KServiceTypeTrader::self()->query( "ScreenSaver");
         new Q3ListViewItem ( mSaverListView, i18n("Loading...") );
-        if ( mSaverFileList.isEmpty() )
+        if ( mSaverServices.isEmpty() )
             mLoadTimer->stop();
         else
             mLoadTimer->start( 50 );
     }
-
-    for ( int i = 0; i < 5 &&
-            mNumLoaded < mSaverFileList.count();
-            i++, mNumLoaded++ ) {
-        QString file = mSaverFileList[mNumLoaded];
-        SaverConfig *saver = new SaverConfig;
-        if (saver->read(file)) {
-            mSaverList.append(saver);
+    for( KService::List::const_iterator it = mSaverServices.begin();
+        it != mSaverServices.end(); it++,mNumLoaded++)
+    {
+      SaverConfig *saver = new SaverConfig;
+      QString file = KStandardDirs::locate("services", (*it)->desktopEntryPath());
+      if (saver->read(file)) {
+	      mSaverList.append(saver);
         } else
             delete saver;
     }
-
-    if ( mNumLoaded == mSaverFileList.count() ) {
+    
+    if ( mNumLoaded == mSaverServices.count() ) {
         Q3ListViewItem *selectedItem = 0;
         int categoryCount = 0;
         int indx = 0;
@@ -821,8 +812,8 @@ void KScreenSaver::slotTest()
         {
             mTestWin = new TestWin();
             mTestWin->setAttribute(Qt::WA_NoSystemBackground, true);
-            mTestWin->setGeometry(0, 0, kapp->desktop()->width(),
-                                    kapp->desktop()->height());
+            mTestWin->setGeometry(0, 0, qApp->desktop()->width(),
+                                    qApp->desktop()->height());
         }
 
         mTestWin->show();
