@@ -4,7 +4,10 @@
 TestWin::TestWin()
     : KSWidget(0)
 {
-    overrideWindowFlags(Qt::X11BypassWindowManagerHint);
+#ifdef __GNUC__
+#warning overrideWindowFlags(Qt::X11BypassWindowManagerHint) crash kcmshell screensaver -> slot test
+#endif
+    //overrideWindowFlags(Qt::X11BypassWindowManagerHint);
     setFocusPolicy(Qt::StrongFocus);
     KWin::setState( winId(), NET::StaysOnTop );
 }
