@@ -30,7 +30,6 @@
 #include <kwin.h>
 #include <kapplication.h>
 #include <kdebug.h>
-#include <kipc.h>
 #include <kmenu.h>
 #include <kwinmodule.h>
 
@@ -75,7 +74,7 @@ KBackgroundManager::KBackgroundManager(QWidget *desktop, KWinModule* kwinModule)
 {
 
     (void) new BackgroundAdaptor( this );
-    QDBus::sessionBus().registerObject( backgroundDBusObjectPath, this );
+    QDBusConnection::sessionBus().registerObject( backgroundDBusObjectPath, this );
 
     if( !properties_inited )
     {
@@ -130,7 +129,6 @@ KBackgroundManager::~KBackgroundManager()
     for (int i=0; i<m_Renderer.size(); i++)
         delete m_Renderer[i];
 
-    //delete m_pConfig; Very bad idea, this is KGlobal::config !
     delete m_pPixmapServer;
     delete m_pTimer;
 
@@ -356,8 +354,8 @@ void KBackgroundManager::exportBackground(int pixmap, int desk)
 
     m_Cache[desk]->exp_from = pixmap;
     m_pPixmapServer->add(pixmapName(desk+1),
-	    m_Cache[pixmap]->pixmap);
-    KIPC::sendMessageAll(KIPC::BackgroundChanged, desk+1);
+                         m_Cache[pixmap]->pixmap);
+    emit backgroundChanged(desk+1);
 }
 
 
