@@ -29,10 +29,13 @@
 #include "kdesktopsettings.h"
 #include "klaunchsettings.h"
 #include "desktopadaptor.h"
+#include <ksmserver_interface.h>
+#include <kwin_interface.h>
 
 #include <string.h>
 #include <unistd.h>
 #include <k3colordrag.h>
+#include <kglobalsettings.h>
 
 #include <QDir>
 #include <QEvent>
@@ -44,12 +47,11 @@
 #include <kstandarddirs.h>
 #include <kimageio.h>
 #include <kinputdialog.h>
-#include <kipc.h>
 #include <klocale.h>
 #include <kio/netaccess.h>
 #include <kprocess.h>
 #include <ksycoca.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kmessagebox.h>
 #include <kglobalaccel.h>
 #include <kauthorized.h>
@@ -91,7 +93,7 @@ bool KRootWidget::eventFilter ( QObject *, QEvent * e )
        if ( KUrl::List::canDecode( de->mimeData() ) )
        {
          KUrl url = KUrl::List::fromMimeData( de->mimeData() ).first();
-         KMimeType::Ptr mime = KMimeType::findByURL( url );
+         KMimeType::Ptr mime = KMimeType::findByUrl( url );
          if ( mime && ( KImageIO::isSupported( mime->name(), KImageIO::Reading ) || mime->is( "image/svg+xml" ) ) )
            imageURL = true;
        }
@@ -141,7 +143,9 @@ KDesktop::KDesktop( bool x_root_hack, bool wait_for_kded ) :
   setWindowTitle( "KDE Desktop" );
 
   (void) new DesktopAdaptor( this );
-  QDBus::sessionBus().registerObject("/Desktop", this);
+  QDBusConnection dbus = QDBusConnection::sessionBus();
+  dbus.registerObject("/Desktop", this);
+  dbus.connect(QString(), "/Desktop", "org.kde.kdesktop.Desktop", "reconfigure", this, SLOT(slotConfigure()));
 
   setAcceptDrops(true); // WStyle_Customize seems to disable that
   m_pKwinmodule = new KWinModule( this );
@@ -179,12 +183,10 @@ KDesktop::KDesktop( bool x_root_hack, bool wait_for_kded ) :
   connect( qApp, SIGNAL( aboutToQuit() ),
            this, SLOT( slotShutdown() ) );
 
-  connect(kapp, SIGNAL(settingsChanged(int)),
+  connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)),
           this, SLOT(slotSettingsChanged(int)));
-  kapp->addKipcEventMask(KIPC::SettingsChanged);
 
-  kapp->addKipcEventMask(KIPC::IconChanged);
-  connect(kapp, SIGNAL(iconChanged(int)), this, SLOT(slotIconChanged(int)));
+  connect(KGlobalSettings::self(), SIGNAL(iconChanged(int)), this, SLOT(slotIconChanged(int)));
 
   connect(KSycoca::self(), SIGNAL(databaseChanged()),
           this, SLOT(slotDatabaseChanged()));
@@ -286,9 +288,8 @@ KDesktop::initRoot()
         connect(m_actionCollection->action("Lock Session"), SIGNAL(triggered(bool)), krootwm, SLOT(slotLock()));
      }
    } else {
-      QDBusInterface ksmserver( "org.kde.ksmserver", "/KSMServer", "org.kde.KSMServerInterface" );
-      if ( ksmserver.isValid() )
-          ksmserver.call( "resumeStartup", QString( "kdesktop" ) );
+         org::kde::KSMServerInterface ksmserver("org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
+         ksmserver.resumeStartup(QString( "kdesktop" ));
    }
 
    KWin::setType( winId(), NET::Desktop );
@@ -303,7 +304,9 @@ KDesktop::backgroundInitDone()
     // avoid flicker
     if (m_bDesktopEnabled)
     {
+#ifdef __GNUC__
 #warning backgroundPixmap in Qt4 is a noop
+#endif
         /*
        const QPixmap *bg = QApplication::desktop()->screen()->backgroundPixmap();
        if ( bg )
@@ -312,10 +315,9 @@ KDesktop::backgroundInitDone()
        show();
        kapp->sendPostedEvents();
     }
+    org::kde::KSMServerInterface ksmserver("org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
+    ksmserver.suspendStartup(QString( "kdesktop" ));
 
-    QDBusInterface ksmserver( "org.kde.ksmserver", "/KSMServer", "org.kde.KSMServerInterface" );
-    if ( ksmserver.isValid() )
-        ksmserver.call( "suspendStartup", QString( "kdesktop" ) );
 }
 
 void
@@ -342,13 +344,13 @@ KDesktop::slotStart()
   // Global keys
   KActionCollection* actionCollection = m_actionCollection = new KActionCollection( this );
   (void) new KRootWm( this );
-  KAction* a = 0L;
+  QAction* a = 0L;
 
 #include "kdesktopbindings.cpp"
 
   m_actionCollection->readSettings();
 
-  connect(kapp, SIGNAL(appearanceChanged()), SLOT(slotConfigure()));
+  connect(KGlobalSettings::self(), SIGNAL(appearanceChanged()), SLOT(slotConfigure()));
 
   QTimer::singleShot(300, this, SLOT( slotUpAndRunning() ));
 }
@@ -517,7 +519,7 @@ void KDesktop::unselectAll()
 QStringList KDesktop::selectedURLs()
 {
     if (m_pIconView)
-        return m_pIconView->selectedURLs();
+        return m_pIconView->selectedUrls();
     return QStringList();
 }
 
@@ -572,13 +574,13 @@ void KDesktop::configure()
 void KDesktop::slotSettingsChanged(int category)
 {
     //kDebug(1204) << "KDesktop::slotSettingsChanged" << endl;
-    if (category == KApplication::SETTINGS_PATHS)
+    if (category == KGlobalSettings::SETTINGS_PATHS)
     {
         kDebug(1204) << "KDesktop::slotSettingsChanged SETTINGS_PATHS" << endl;
         if (m_pIconView)
-            m_pIconView->recheckDesktopURL();
+            m_pIconView->recheckDesktopUrl();
     }
-    else if (category == KApplication::SETTINGS_SHORTCUTS)
+    else if (category == KGlobalSettings::SETTINGS_SHORTCUTS)
     {
         kDebug(1204) << "KDesktop::slotSettingsChanged SETTINGS_SHORTCUTS" << endl;
         m_actionCollection->readSettings();
@@ -613,9 +615,8 @@ void KDesktop::refresh()
   m_bNeedRepaint |= 1;
   updateWorkArea();
 #endif
-  QDBusInterface kwin( "org.kde.kwin", "/KWin", "org.kde.KWin" );
-  if ( kwin.isValid() )
-      kwin.call( "refresh" );
+  org::kde::KWin kwin("org.kde.kwin", "/KWin", QDBusConnection::sessionBus());
+  kwin.refresh();
   refreshIcons();
 }
 
@@ -706,8 +707,8 @@ void KDesktop::slotSwitchDesktops(int delta)
 void KDesktop::handleColorDropEvent(QDropEvent * e)
 {
     KMenu popup;
-    QAction* primary = popup.addAction(SmallIconSet("colors"), i18n("Set as Primary Background Color"));
-    popup.addAction(SmallIconSet("colors"), i18n("Set as Secondary Background Color"));
+    QAction* primary = popup.addAction(KIcon("colors"), i18n("Set as Primary Background Color"));
+    popup.addAction(KIcon("colors"), i18n("Set as Secondary Background Color"));
     QAction* result = popup.exec(e->pos());
 
     if (result != 0) {
@@ -724,11 +725,11 @@ void KDesktop::handleImageDropEvent(QDropEvent * e)
     QAction* saveToDesktop  = 0;
     QAction* setAsWallpaper = 0;
     if ( m_pIconView )
-       saveToDesktop = popup.addAction(SmallIconSet("filesave"), i18n("&Save to Desktop..."));
+       saveToDesktop = popup.addAction(KIcon("filesave"), i18n("&Save to Desktop..."));
     if ( ( m_pIconView && m_pIconView->maySetWallpaper() ) || m_pRootWidget )
-       setAsWallpaper = popup.addAction(SmallIconSet("background"), i18n("Set as &Wallpaper"));
+       setAsWallpaper = popup.addAction(KIcon("background"), i18n("Set as &Wallpaper"));
     popup.addSeparator();
-    popup.addAction(SmallIconSet("cancel"), i18n("&Cancel"));
+    popup.addAction(KIcon("cancel"), i18n("&Cancel"));
     QAction* result = popup.exec(e->pos());
 
     if (result == saveToDesktop)
@@ -752,24 +753,29 @@ void KDesktop::handleImageDropEvent(QDropEvent * e)
 
         QImage i;
         Q3ImageDrag::decode(e, i);
-        KTempFile tmpFile(QString::null, filename);
-        i.save(tmpFile.name(), "PNG");
+        KTemporaryFile tmpFile;
+        tmpFile.setSuffix(filename);
+        tmpFile.open();
+        i.save(tmpFile.fileName(), "PNG");
         // We pass 0 as parent window because passing the desktop is not a good idea
         KUrl src;
-        src.setPath( tmpFile.name() );
-        KUrl dest( KDIconView::desktopURL() );
+        src.setPath( tmpFile.fileName() );
+        KUrl dest( KDIconView::desktopUrl() );
         dest.addPath( filename );
-        KIO::NetAccess::copy( src, dest, 0 );
-        tmpFile.unlink();
+        KIO::NetAccess::file_copy( src, dest, 0 );
     }
     else if (result == setAsWallpaper)
     {
         QImage i;
         Q3ImageDrag::decode(e, i);
-        KTempFile tmpFile(KGlobal::dirs()->saveLocation("wallpaper"), ".png");
-        i.save(tmpFile.name(), "PNG");
-        kDebug(1204) << "KDesktop::contentsDropEvent " << tmpFile.name() << endl;
-        bgMgr->setWallpaper(tmpFile.name());
+        KTemporaryFile tmpFile;
+        tmpFile.setPrefix(KGlobal::dirs()->saveLocation("wallpaper"));
+        tmpFile.setSuffix(".png");
+        tmpFile.setAutoRemove(false);
+        tmpFile.open();
+        i.save(tmpFile.fileName(), "PNG");
+        kDebug(1204) << "KDesktop::contentsDropEvent " << tmpFile.fileName() << endl;
+        bgMgr->setWallpaper(tmpFile.fileName());
     }
 }
 
@@ -786,8 +792,12 @@ void KDesktop::slotNewWallpaper(const KUrl &url)
         QFileInfo fileInfo( fileName );
         QString ext = fileInfo.suffix();
         // Store tempfile in a place where it will still be available after a reboot
-        KTempFile tmpFile( KGlobal::dirs()->saveLocation("wallpaper"), '.' + ext );
-        KUrl localURL; localURL.setPath( tmpFile.name() );
+        KTemporaryFile tmpFile;
+        tmpFile.setPrefix(KGlobal::dirs()->saveLocation("wallpaper"));
+        tmpFile.setSuffix('.' + ext);
+        tmpFile.setAutoRemove(false);
+        tmpFile.open();
+        KUrl localURL; localURL.setPath( tmpFile.fileName() );
         // We pass 0 as parent window because passing the desktop is not a good idea
         KIO::NetAccess::file_copy( url, localURL, -1, true /*overwrite*/ );
         bgMgr->setWallpaper( localURL.path() );
