@@ -40,7 +40,7 @@
 #include <konq_settings.h>
 #include <konq_undo.h>
 #include <kprotocolinfo.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <kstandarddirs.h>
 #include <kwin.h>
 #include <kdirnotify.h>
@@ -125,7 +125,7 @@ KDIconView::KDIconView( QWidget *parent, const char* name )
     connect( QApplication::clipboard(), SIGNAL(dataChanged()),
              this, SLOT(slotClipboardDataChanged()) );
 
-    setURL( desktopURL() ); // sets m_url
+    setUrl( desktopUrl() ); // sets m_url
 
     m_desktopDirs = KGlobal::dirs()->findDirs( "appdata", "Desktop" );
     initDotDirectories();
@@ -159,10 +159,10 @@ KDIconView::KDIconView( QWidget *parent, const char* name )
 
     connect( kapp->desktop(), SIGNAL( resized( int )), SLOT( desktopResized()));
 
-    OrgKdeKDirNotifyInterface *kdirnotify = new OrgKdeKDirNotifyInterface( QString(), QString(), QDBus::sessionBus() );
+    OrgKdeKDirNotifyInterface *kdirnotify = new OrgKdeKDirNotifyInterface( QString(), QString(), QDBusConnection::sessionBus() );
     kdirnotify->setParent(this);
     connect(kdirnotify, SIGNAL(FilesAdded(QString)), SLOT(slotFilesAdded(QString)));
-    connect(kdirnotify, SIGNAL(FilesChanged(QStringList)), SLOT(slotFilesChanged(QStringList)));
+    //connect(kdirnotify, SIGNAL(FilesChanged(QStringList)), SLOT(slotFilesChanged(QStringList)));
     connect(kdirnotify, SIGNAL(FilesRemoved(QStringList)), SLOT(slotFilesRemoved(QStringList)));
 }
 
@@ -179,7 +179,7 @@ KDIconView::~KDIconView()
 void KDIconView::initDotDirectories()
 {
     QStringList dirs = m_desktopDirs;
-    KUrl u = desktopURL();
+    KUrl u = desktopUrl();
     if (u.isLocalFile())
        dirs.prepend(u.path());
 
@@ -249,7 +249,7 @@ void KDIconView::initConfig( bool init )
         KDesktopSettings::self()->readConfig();
     }
 
-    KConfig * config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
 
     if ( !init ) {
       KDesktopShadowSettings *shadowSettings = static_cast<KDesktopShadowSettings *>(m_shadowEngine->shadowSettings());
@@ -345,11 +345,11 @@ void KDIconView::start()
 
     // Start the directory lister !
     m_dirLister->setShowingDotFiles( m_bShowDot );
-    KAuthorized::allowURLAction("list", KUrl(), url());
-    m_dirLister->openURL( url() );
+    KAuthorized::allowUrlAction("list", KUrl(), url());
+    m_dirLister->openUrl( url() );
 
     // Gather the list of directories to merge into the desktop
-    // (the main URL is desktopURL(), no need for it in the m_mergeDirs list)
+    // (the main URL is desktopUrl(), no need for it in the m_mergeDirs list)
     m_mergeDirs.clear();
     for ( QStringList::ConstIterator it = m_desktopDirs.begin() ; it != m_desktopDirs.end() ; ++it )
     {
@@ -358,8 +358,8 @@ void KDIconView::start()
         u.setPath( *it );
         m_mergeDirs.append( u );
         // And start listing this dir right now
-        KAuthorized::allowURLAction("list", KUrl(), u);
-        m_dirLister->openURL( u, true );
+        KAuthorized::allowUrlAction("list", KUrl(), u);
+        m_dirLister->openUrl( u, true );
     }
     configureMedia();
     createActions();
@@ -378,7 +378,7 @@ void KDIconView::configureMedia()
 	    	if ((*it1).url()=="media:/") return;
 	    }
     	m_mergeDirs.append(KUrl("media:/"));
-    	m_dirLister->openURL(KUrl("media:/"),true);
+    	m_dirLister->openUrl(KUrl("media:/"),true);
     }
     else
     {
@@ -404,36 +404,46 @@ void KDIconView::createActions()
 {
     if (m_bEditableDesktopIcons)
     {
-        KAction *undo = KStdAction::undo( KonqUndoManager::self(), SLOT( undo() ), &m_actionCollection, "undo" );
+        QAction *undo = m_actionCollection.addAction( KStandardAction::Undo, "undo",
+                                                      KonqUndoManager::self(), SLOT( undo() ) );
         connect( KonqUndoManager::self(), SIGNAL( undoAvailable( bool ) ),
-             undo, SLOT( setEnabled( bool ) ) );
+                 undo, SLOT( setEnabled( bool ) ) );
         connect( KonqUndoManager::self(), SIGNAL( undoTextChanged( const QString & ) ),
                  this, SLOT( slotUndoTextChanged( const QString & ) ) );
         undo->setEnabled( KonqUndoManager::self()->undoAvailable() );
 
-        KAction* paCut = KStdAction::cut( this, SLOT( slotCut() ), &m_actionCollection, "cut" );
-        KShortcut cutShortCut = paCut->shortcut();
+        QAction* paCut = m_actionCollection.addAction( KStandardAction::Cut, "cut", this, SLOT( slotCut() ) );
+        KShortcut cutShortCut( paCut->shortcuts() );
         cutShortCut.remove( Qt::SHIFT + Qt::Key_Delete ); // used for deleting files
-        paCut->setShortcut( cutShortCut );
+        paCut->setShortcuts( cutShortCut );
 
-        KStdAction::copy( this, SLOT( slotCopy() ), &m_actionCollection, "copy" );
-        KStdAction::paste( this, SLOT( slotPaste() ), &m_actionCollection, "paste" );
-        KAction *pasteTo = KStdAction::paste( this, SLOT( slotPopupPasteTo() ), &m_actionCollection, "pasteto" );
+        m_actionCollection.addAction( KStandardAction::Copy, "copy", this, SLOT( slotCopy() ) );
+        m_actionCollection.addAction( KStandardAction::Paste, "paste", this, SLOT( slotPaste() ) );
+        QAction *pasteTo = m_actionCollection.addAction( KStandardAction::Paste, "pasteto",
+                                                         this, SLOT( slotPopupPasteTo() ) );
         pasteTo->setEnabled( false ); // only enabled during popupMenu()
 
-        KAction *action = new KAction( i18n( "&Rename" ), &m_actionCollection, "rename" );
-        connect(action, SIGNAL(triggered(bool) ), SLOT( renameSelectedItem() ));
+        m_actionCollection.addAction( KStandardAction::Redisplay, "reload", this, SLOT(refreshIcons()) );
+
+        QAction *action = m_actionCollection.addAction( "rename" );
+        action->setText( i18n( "&Rename" ) );
+        connect(action, SIGNAL(triggered(bool)), SLOT(renameSelectedItem()));
         action->setShortcut(Qt::Key_F2);
-        action = new KAction( i18n( "&Properties" ), &m_actionCollection, "properties" );
-        connect(action, SIGNAL(triggered(bool) ), SLOT( slotProperties() ));
+        action = m_actionCollection.addAction( "properties" );
+        action->setText( i18n( "&Properties" ) );
+        connect(action, SIGNAL(triggered(bool)), SLOT(slotProperties()));
         action->setShortcut(Qt::ALT+Qt::Key_Return);
-        KAction* trash = new KAction( KIcon("edittrash"), i18n( "&Move to Trash" ), &m_actionCollection, "trash" );
+        QAction* trash = m_actionCollection.addAction( "trash" );
+        trash->setIcon( KIcon("edittrash") );
+        trash->setText( i18n( "&Move to Trash" ) );
         trash->setShortcut(Qt::Key_Delete);
         connect(trash, SIGNAL(triggered(bool)), SLOT(slotTrash()));
 
         KConfig config("kdeglobals", true, false);
         config.setGroup( "KDE" );
-        action = new KAction(KIcon("editdelete"),  i18n( "&Delete" ), &m_actionCollection, "del" );
+        action = m_actionCollection.addAction( "del" );
+        action->setIcon( KIcon("editdelete") );
+        action->setText( i18n( "&Delete" ) );
         connect(action, SIGNAL(triggered(bool)), SLOT( slotDelete() ));
         action->setShortcut(Qt::SHIFT+Qt::Key_Delete);
 
@@ -446,7 +456,7 @@ void KDIconView::createActions()
 
 void KDIconView::slotUndoTextChanged( const QString &text )
 {
-    KAction* undo = m_actionCollection.action( "undo" );
+    QAction* undo = m_actionCollection.action( "undo" );
     undo->setText( text );
 }
 
@@ -486,7 +496,7 @@ void KDIconView::setAutoAlign( bool b )
     }
     else {
         // change maxItemWidth, because when grid-align was active, it changed this for the grid
-        int sz = iconSize() ? iconSize() : KGlobal::iconLoader()->currentSize( K3Icon::Desktop );
+        int sz = iconSize() ? iconSize() : KIconLoader::global()->currentSize( K3Icon::Desktop );
         setMaxItemWidth( qMax( qMax( sz, previewIconSize( iconSize() ) ), KonqFMSettings::settings()->iconTextWidth() ) );
         setFont( font() );  // Force calcRect()
 
@@ -500,7 +510,7 @@ void KDIconView::desktopResized()
     saveIconPositions();
     resize( kapp->desktop()->size() );
     slotClear();
-    m_dirLister->openURL( url() );
+    m_dirLister->openUrl( url() );
 
     // list all desktop dirs
     m_mergeDirs.clear();
@@ -511,8 +521,8 @@ void KDIconView::desktopResized()
         u.setPath( *it );
         m_mergeDirs.append( u );
         // And start listing this dir right now
-        KAuthorized::allowURLAction("list", KUrl(), u);
-        m_dirLister->openURL( u, true );
+        KAuthorized::allowUrlAction("list", KUrl(), u);
+        m_dirLister->openUrl( u, true );
     }
     configureMedia();
 }
@@ -532,7 +542,7 @@ void KDIconView::lineupIcons(Q3IconView::Arrangement align)
 }
 
 // Only used for DCOP
-QStringList KDIconView::selectedURLs()
+QStringList KDIconView::selectedUrls()
 {
     QStringList seq;
 
@@ -546,22 +556,22 @@ QStringList KDIconView::selectedURLs()
     return seq;
 }
 
-void KDIconView::recheckDesktopURL()
+void KDIconView::recheckDesktopUrl()
 {
     // Did someone change the path to the desktop ?
-    kDebug(1204) << desktopURL().url() << endl;
+    kDebug(1204) << desktopUrl().url() << endl;
     kDebug(1204) << url().url() << endl;
-    if ( desktopURL() != url() )
+    if ( desktopUrl() != url() )
     {
         kDebug(1204) << "Desktop path changed from " << url().url() <<
-            " to " << desktopURL().url() << endl;
-        setURL( desktopURL() ); // sets m_url
+            " to " << desktopUrl().url() << endl;
+        setUrl( desktopUrl() ); // sets m_url
         initDotDirectories();
-        m_dirLister->openURL( url() );
+        m_dirLister->openUrl( url() );
     }
 }
 
-KUrl KDIconView::desktopURL()
+KUrl KDIconView::desktopUrl()
 {
     // Support both paths and URLs
     QString desktopPath = KGlobalSettings::desktopPath();
@@ -627,7 +637,7 @@ void KDIconView::wheelEvent( QWheelEvent* e )
 
 void KDIconView::slotProperties()
 {
-    (void) new KPropertiesDialog( selectedFileItems() );
+    KPropertiesDialog::showDialog( selectedFileItems(), this );
 }
 
 void KDIconView::slotContextMenuRequested(Q3IconViewItem *_item, const QPoint& _global)
@@ -717,7 +727,7 @@ void KDIconView::slotPopupPasteTo()
  */
 bool KDIconView::deleteGlobalDesktopFiles()
 {
-    KUrl desktop_URL = desktopURL();
+    KUrl desktop_URL = desktopUrl();
     if (!desktop_URL.isLocalFile())
         return false; // Dunno how to do this.
 
@@ -783,7 +793,7 @@ void KDIconView::popupMenu( const QPoint &_global, const KFileItemList& _items )
     if ( _items.count() == 1 )
         m_popupURL = _items.first()->url();
 
-    KAction* pasteTo = m_actionCollection.action( "pasteto" );
+    QAction* pasteTo = m_actionCollection.action( "pasteto" );
     if (pasteTo)
         pasteTo->setEnabled( m_actionCollection.action( "paste" )->isEnabled() );
 
@@ -830,7 +840,7 @@ void KDIconView::slotEnableAction( const char * name, bool enabled )
   if ( sName == "properties" || sName == "editMimeType" )
     return;
 
-  KAction * act = m_actionCollection.action( sName.data() );
+  QAction * act = m_actionCollection.action( sName.data() );
   if (act)
     act->setEnabled( enabled );
 }
@@ -936,7 +946,7 @@ void KDIconView::slotNewItems( const KFileItemList & entries )
   setIconArea( QRect(  0, 0, -1, -1 ) );
 
   QString desktopPath;
-  KUrl desktop_URL = desktopURL();
+  KUrl desktop_URL = desktopUrl();
   if (desktop_URL.isLocalFile())
     desktopPath = desktop_URL.path();
   // We have new items, so we'll need to repaint in slotCompleted
@@ -1219,8 +1229,11 @@ void KDIconView::slotClipboardDataChanged()
 
     QString actionText = KIO::pasteActionText();
     bool paste = !actionText.isEmpty();
-    if ( paste )
-        m_actionCollection.action( "paste" )->setText( actionText );
+    if ( paste ) {
+        QAction* pasteAction = m_actionCollection.action( "paste" );
+        if ( pasteAction )
+            pasteAction->setText( actionText );
+    }
     slotEnableAction( "paste", paste );
 }
 
@@ -1257,7 +1270,7 @@ void KDIconView::slotItemRenamed(Q3IconViewItem* _item, const QString &name)
           {
              // first and foremost, we make sure that this is a .desktop file
              // before we write anything to it
-             KMimeType::Ptr type = KMimeType::findByURL( fileItem->item()->url() );
+             KMimeType::Ptr type = KMimeType::findByUrl( fileItem->item()->url() );
              bool bDesktopFile = false;
 
              if (type->name() == "application/x-desktop")
