@@ -66,6 +66,8 @@
 #include <QX11Info>
 #include <kauthorized.h>
 
+#include <kxkb_interface.h>
+
 #ifndef AF_LOCAL
 # define AF_LOCAL	AF_UNIX
 #endif
@@ -87,7 +89,6 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
     frame->setLineWidth( 2 );
 
     QLabel *pixLabel = new QLabel( frame );
-    pixLabel->setObjectName( "pixlabel" );
     pixLabel->setPixmap(DesktopIcon("lock"));
 
     KUser user;
@@ -98,18 +99,17 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
     mStatusLabel = new QLabel( "<b> </b>", frame );
     mStatusLabel->setAlignment( Qt::AlignCenter );
 
-    mLayoutButton = new QPushButton( frame );
-    mLayoutButton->setFlat( true );
+    greet = plugin->info->create( this, this, QString(),
+              KGreeterPlugin::Authenticate, KGreeterPlugin::ExUnlock );
 
     KSeparator *sep = new KSeparator( Qt::Horizontal, frame );
 
-    mNewSessButton = new KPushButton( KGuiItem(i18n("Sw&itch User..."), "fork"), frame );
     ok = new KPushButton( i18n("Unl&ock"), frame );
-    cancel = new KPushButton( KStdGuiItem::cancel(), frame );
-
-    greet = plugin->info->create( this, 0, this, mLayoutButton, QString(),
-              KGreeterPlugin::Authenticate, KGreeterPlugin::ExUnlock );
+    cancel = new KPushButton( KStandardGuiItem::cancel(), frame );
+    mNewSessButton = new KPushButton( KGuiItem(i18n("Sw&itch User..."), "fork"), frame );
 
+    mLayoutButton = new QPushButton( frame );
+    mLayoutButton->setFlat( true );
 
     QVBoxLayout *unlockDialogLayout = new QVBoxLayout( this );
     unlockDialogLayout->addWidget( frame );
@@ -133,15 +133,11 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
     frameLayout->setMargin( KDialog::marginHint() );
     frameLayout->addWidget( pixLabel, 0, 0, 3, 1, Qt::AlignTop );
     frameLayout->addWidget( greetLabel, 0, 1 );
-    frameLayout->addItem( greet->getLayoutItem(), 1, 1 );
+    frameLayout->addWidget( greet->getWidgets().first(), 1, 1 );
     frameLayout->addLayout( layStatus, 2, 1 );
     frameLayout->addWidget( sep, 3, 0, 1, 2 );
     frameLayout->addLayout( layButtons, 4, 0, 1, 2 );
 
-    setTabOrder( ok, cancel );
-    setTabOrder( cancel, mNewSessButton );
-    setTabOrder( mNewSessButton, mLayoutButton );
-
     connect(mLayoutButton, SIGNAL(clicked()), this, SLOT(layoutClicked()));
     connect(cancel, SIGNAL(clicked()), SLOT(reject()));
     connect(ok, SIGNAL(clicked()), SLOT(slotOK()));
@@ -158,11 +154,11 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
 
     greet->start();
 
-    QDBusInterface kxkb( "org.kde.kxkb", "/kxkb", "org.kde.KXKB" );
+    org::kde::KXKB kxkb("org.kde.kxkb", "/kxkb" , QDBusConnection::sessionBus());
     if( kxkb.isValid() ) {
-        QDBusReply<QStringList> replyLayouts = kxkb.call("getLayoutsList");
+        QDBusReply<QStringList> replyLayouts = kxkb.getLayoutsList();
         layoutsList = replyLayouts;
-        QDBusReply<QString> replyCurrentLayout = kxkb.call("getCurrentLayout");
+        QDBusReply<QString> replyCurrentLayout = kxkb.getCurrentLayout();
         QString currentLayout = replyCurrentLayout;
         if( !currentLayout.isEmpty() && layoutsList.count() > 1 ) {
             currLayout = layoutsList.indexOf(currentLayout);
@@ -181,7 +177,6 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
 PasswordDlg::~PasswordDlg()
 {
     hide();
-    frameLayout->removeItem( greet->getLayoutItem() );
     delete greet;
 }
 
@@ -190,11 +185,10 @@ void PasswordDlg::layoutClicked()
 
     if( ++currLayout == layoutsList.size() )
         currLayout = 0;
-
-    QDBusInterface kxkb( "org.kde.kxkb", "/kxkb", "org.kde.KXKB" );
+    org::kde::KXKB kxkb("org.kde.kxkb", "/kxkb" , QDBusConnection::sessionBus());
     if( kxkb.isValid() ) {
         const QString currentLayout = layoutsList.at(currLayout);
-        QDBusReply<bool> setLayoutReply = kxkb.call("setLayout", currentLayout );
+        QDBusReply<bool> setLayoutReply = kxkb.setLayout(currentLayout );
         setLayoutText( setLayoutReply ? currentLayout : "err" );
     }
 }
@@ -509,7 +503,7 @@ void PasswordDlg::gplugMsgBox( QMessageBox::Icon type, const QString &text )
     QLabel *label1 = new QLabel( winFrame );
     label1->setPixmap( QMessageBox::standardIcon( type ) );
     QLabel *label2 = new QLabel( text, winFrame );
-    KPushButton *button = new KPushButton( KStdGuiItem::ok(), winFrame );
+    KPushButton *button = new KPushButton( KStandardGuiItem::ok(), winFrame );
     button->setDefault( true );
     button->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred ) );
     connect( button, SIGNAL( clicked() ), SLOT( accept() ) );
@@ -523,6 +517,11 @@ void PasswordDlg::gplugMsgBox( QMessageBox::Icon type, const QString &text )
     static_cast< LockProcess* >(parent())->execDialog( &dialog );
 }
 
+bool PasswordDlg::gplugHasNode( const QString & )
+{
+    return false;
+}
+
 void PasswordDlg::slotOK()
 {
     greet->next();
@@ -573,7 +572,7 @@ void PasswordDlg::slotStartNewSession()
     KPushButton *okbutton = new KPushButton( KGuiItem(i18n("&Start New Session"), "fork"), winFrame );
     okbutton->setDefault( true );
     connect( okbutton, SIGNAL( clicked() ), dialog, SLOT( accept() ) );
-    KPushButton *cbutton = new KPushButton( KStdGuiItem::cancel(), winFrame );
+    KPushButton *cbutton = new KPushButton( KStandardGuiItem::cancel(), winFrame );
     connect( cbutton, SIGNAL( clicked() ), dialog, SLOT( reject() ) );
 
     QBoxLayout *mbox = new QVBoxLayout( winFrame );
@@ -741,7 +740,7 @@ void PasswordDlg::slotSwitchUser()
         vbox2->addStretch( 1 );
     }
 
-    btn = new KPushButton( KStdGuiItem::cancel(), winFrame );
+    btn = new KPushButton( KStandardGuiItem::cancel(), winFrame );
     connect( btn, SIGNAL(clicked()), &dialog, SLOT(reject()) );
     vbox2->addWidget( btn );
 
