@@ -16,7 +16,7 @@
 //some image will be corrupted).
 
 #include <config.h>
-
+#include <config-kdesktop-lock.h>
 #include "lockprocess.h"
 #include "lockdlg.h"
 #include "autologout.h"
@@ -33,7 +33,7 @@
 #include <klocale.h>
 #include <klibloader.h>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
 #include <kauthorized.h>
 
 #include <qframe.h>
@@ -61,7 +61,6 @@
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
 #include <X11/Xatom.h>
-#include <X11/Intrinsic.h>
 
 #ifdef HAVE_DPMS
 extern "C" {
@@ -99,7 +98,7 @@ static Atom   gXA_SCREENSAVER_VERSION;
 // starting screensaver hacks, and password entry.f
 //
 LockProcess::LockProcess(bool child, bool useBlankOnly)
-    : QWidget(0L, "saver window", Qt::WX11BypassWM),
+    : QWidget(0L, Qt::WX11BypassWM),
       mOpenGLVisual(0),
       child_saver(child),
       mParent(0),
@@ -110,6 +109,7 @@ LockProcess::LockProcess(bool child, bool useBlankOnly)
       mForbidden(false),
       mAutoLogout(false)
 {
+    setObjectName("save window");
     setupSignals();
 
     kapp->installX11EventFilter(this);
@@ -188,12 +188,18 @@ LockProcess::~LockProcess()
     }
 }
 
-static int sigterm_pipe[2];
+static int signal_pipe[2];
 
 static void sigterm_handler(int)
 {
-    char tmp = 0;
-    ::write( sigterm_pipe[1], &tmp, 1);
+    char tmp = 'T';
+    ::write( signal_pipe[1], &tmp, 1);
+}
+
+static void sighup_handler(int)
+{
+    char tmp = 'H';
+    ::write( signal_pipe[1], &tmp, 1);
 }
 
 void LockProcess::timerEvent(QTimerEvent *ev)
@@ -208,13 +214,7 @@ void LockProcess::timerEvent(QTimerEvent *ev)
 
 void LockProcess::setupSignals()
 {
-    // ignore SIGHUP
     struct sigaction act;
-    act.sa_handler=SIG_IGN;
-    sigemptyset(&(act.sa_mask));
-    sigaddset(&(act.sa_mask), SIGHUP);
-    act.sa_flags = 0;
-    sigaction(SIGHUP, &act, 0L);
     // ignore SIGINT
     act.sa_handler=SIG_IGN;
     sigemptyset(&(act.sa_mask));
@@ -233,16 +233,29 @@ void LockProcess::setupSignals()
     sigaddset(&(act.sa_mask), SIGTERM);
     act.sa_flags = 0;
     sigaction(SIGTERM, &act, 0L);
+    // SIGHUP forces lock
+    act.sa_handler= sighup_handler;
+    sigemptyset(&(act.sa_mask));
+    sigaddset(&(act.sa_mask), SIGHUP);
+    act.sa_flags = 0;
+    sigaction(SIGHUP, &act, 0L);
 
-    pipe(sigterm_pipe);
-    QSocketNotifier* notif = new QSocketNotifier(sigterm_pipe[0], QSocketNotifier::Read, this);
-    connect( notif, SIGNAL(activated(int)), SLOT(sigtermPipeSignal()));
+    pipe(signal_pipe);
+    QSocketNotifier* notif = new QSocketNotifier(signal_pipe[0], QSocketNotifier::Read, this);
+    connect( notif, SIGNAL(activated(int)), SLOT(signalPipeSignal()));
 }
 
 
-void LockProcess::sigtermPipeSignal()
+void LockProcess::signalPipeSignal()
 {
-    quitSaver();
+    char tmp;
+    ::read( signal_pipe[0], &tmp, 1);
+    if( tmp == 'T' )
+        quitSaver();
+    else if( tmp == 'H' ) {
+        if( !mLocked )
+            startLock();
+    }
 }
 
 //---------------------------------------------------------------------------
@@ -402,17 +415,43 @@ void LockProcess::createSaverWindow()
 #ifdef HAVE_GLXCHOOSEVISUAL
     if( mOpenGLVisual )
     {
-        int attribs[] = { GLX_RGBA, GLX_DOUBLEBUFFER, GLX_DEPTH_SIZE, x11Depth(), None };
-        if( XVisualInfo* i = glXChooseVisual( x11Display(), x11Screen(), attribs ))
+        static int attribs[][ 15 ] =
         {
-            visual = i->visual;
-            static Colormap colormap = 0;
-            if( colormap != 0 )
-                XFreeColormap( x11Display(), colormap );
-            colormap = XCreateColormap( x11Display(), RootWindow( x11Display(), x11Screen()), visual, AllocNone );
-            attrs.colormap = colormap;
-            flags |= CWColormap;
-            XFree( i );
+        #define R GLX_RED_SIZE
+        #define G GLX_GREEN_SIZE
+        #define B GLX_BLUE_SIZE
+            { GLX_RGBA, R, 8, G, 8, B, 8, GLX_DEPTH_SIZE, 8, GLX_DOUBLEBUFFER, GLX_STENCIL_SIZE, 1, None },
+            { GLX_RGBA, R, 4, G, 4, B, 4, GLX_DEPTH_SIZE, 4, GLX_DOUBLEBUFFER, GLX_STENCIL_SIZE, 1, None },
+            { GLX_RGBA, R, 8, G, 8, B, 8, GLX_DEPTH_SIZE, 8, GLX_DOUBLEBUFFER, None },
+            { GLX_RGBA, R, 4, G, 4, B, 4, GLX_DEPTH_SIZE, 4, GLX_DOUBLEBUFFER, None },
+            { GLX_RGBA, R, 8, G, 8, B, 8, GLX_DEPTH_SIZE, 8, GLX_STENCIL_SIZE, 1, None },
+            { GLX_RGBA, R, 4, G, 4, B, 4, GLX_DEPTH_SIZE, 4, GLX_STENCIL_SIZE, 1, None },
+            { GLX_RGBA, R, 8, G, 8, B, 8, GLX_DEPTH_SIZE, 8, None },
+            { GLX_RGBA, R, 4, G, 4, B, 4, GLX_DEPTH_SIZE, 4, None },
+            { GLX_RGBA, GLX_DEPTH_SIZE, 8, GLX_DOUBLEBUFFER, GLX_STENCIL_SIZE, 1, None },
+            { GLX_RGBA, GLX_DEPTH_SIZE, 8, GLX_DOUBLEBUFFER, None },
+            { GLX_RGBA, GLX_DEPTH_SIZE, 8, GLX_STENCIL_SIZE, 1, None },
+            { GLX_RGBA, GLX_DEPTH_SIZE, 8, None }
+        #undef R
+        #undef G
+        #undef B
+        };
+        for( unsigned int i = 0;
+             i < sizeof( attribs ) / sizeof( attribs[ 0 ] );
+             ++i )
+        {
+            if( XVisualInfo* info = glXChooseVisual( x11Display(), x11Screen(), attribs[ i ] ))
+            {
+                visual = info->visual;
+                static Colormap colormap = 0;
+                if( colormap != 0 )
+                    XFreeColormap( x11Display(), colormap );
+                colormap = XCreateColormap( x11Display(), RootWindow( x11Display(), x11Screen()), visual, AllocNone );
+                attrs.colormap = colormap;
+                flags |= CWColormap;
+                XFree( info );
+                break;
+            }
         }
     }
 #endif
@@ -666,7 +705,7 @@ bool LockProcess::startSaver()
 void LockProcess::stopSaver()
 {
     kDebug(1204) << "LockProcess: stopping saver" << endl;
-    resume();
+    resume( true );
     stopHack();
     hideSaverWindow();
     mVisibility = false;
@@ -841,12 +880,10 @@ void LockProcess::suspend()
     mSuspended = true;
 }
 
-void LockProcess::resume()
+void LockProcess::resume( bool force )
 {
-    if (!mDialogs.isEmpty())
-        return; // no resuming with dialog visible
-    if(!mVisibility)
-        return; // no need to resume, not visible
+    if( !force && (!mDialogs.isEmpty() || !mVisibility ))
+        return; // no resuming with dialog visible or when not visible
     if(mSuspended)
     {
         bitBlt( this, 0, 0, &mSavedScreen );
@@ -919,7 +956,7 @@ int LockProcess::execDialog( QDialog *dlg )
     if( mDialogs.isEmpty() ) {
         XChangeActivePointerGrab( QX11Info::display(), GRABEVENTS,
                 QCursor(Qt::BlankCursor).handle(), CurrentTime);
-        resume();
+        resume( false );
     } else
         fakeFocusIn( mDialogs.first()->winId());
     return rt;
@@ -978,7 +1015,7 @@ bool LockProcess::x11Event(XEvent *event)
 		else
                 {
                     mSuspendTimer.stop();
-                    resume();
+                    resume( false );
                 }
                 if (event->xvisibility.state != VisibilityUnobscured)
                     stayOnTop();
@@ -1108,7 +1145,7 @@ void LockProcess::msgBox( QMessageBox::Icon type, const QString &txt )
     QLabel *label1 = new QLabel( winFrame );
     label1->setPixmap( QMessageBox::standardIcon( type ) );
     QLabel *label2 = new QLabel( txt, winFrame );
-    KPushButton *button = new KPushButton( KStdGuiItem::ok(), winFrame );
+    KPushButton *button = new KPushButton( KStandardGuiItem::ok(), winFrame );
     button->setDefault( true );
     button->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred ) );
     connect( button, SIGNAL( clicked() ), &box, SLOT( accept() ) );
