@@ -27,7 +27,7 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-
+#include <fixx11h.h>
 #include <pwd.h>
 #include <string.h>
 #include <errno.h>
@@ -52,13 +52,12 @@
 #include <kpassworddialog.h>
 #include <krun.h>
 #include <kwin.h>
-#include <kdesu/su.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
 #include <kguiitem.h>
-#include <kstdguiitem.h>
+#include <kstandardguiitem.h>
 #include <kmimetype.h>
 #include <kurifilter.h>
 #include <kcompletionbox.h>
@@ -75,7 +74,17 @@
 #include <QTextDocument>
 #include <kauthorized.h>
 
+// There's no kdesu on windows at this point
+#ifdef Q_OS_WIN
+#define HAVE_KDESU 0
+#else
+#define HAVE_KDESU 1
+#endif
+
+#if HAVE_KDESU
+#include <kdesu/su.h>
 #define KDESU_ERR strerror(errno)
+#endif
 
 Minicli::Minicli( QWidget *parent )
         :KDialog( parent ),
@@ -85,16 +94,8 @@ Minicli::Minicli( QWidget *parent )
   setButtons(None);
   KWin::setIcons( winId(), DesktopIcon("run"), SmallIcon("run") );
 
-  QVBoxLayout* mainLayout = new QVBoxLayout( this );
-  mainLayout->setMargin(0);
-  mainLayout->setSpacing(KDialog::spacingHint());
-
-  m_dlgWidget = new QWidget(this);
   m_dlg = new Ui::MinicliDlgUI();
-  m_dlg->setupUi(m_dlgWidget);
-
-  mainLayout->addWidget(m_dlgWidget);
-  setMainWidget(m_dlgWidget);
+  m_dlg->setupUi(mainWidget());
 
   m_dlg->lbRunIcon->setPixmap(DesktopIcon("kmenu"));
 
@@ -108,7 +109,7 @@ Minicli::Minicli( QWidget *parent )
   m_dlg->pbRun->setGuiItem (KGuiItem( i18n("&Run"), "run" ));
 
   // Cancel button...
-  m_dlg->pbCancel->setGuiItem ( KStdGuiItem::cancel() );
+  m_dlg->pbCancel->setGuiItem ( KStandardGuiItem::cancel() );
 
   if (!KAuthorized::authorizeKAction("shell_access"))
     m_dlg->pbOptions->hide();
@@ -120,7 +121,7 @@ Minicli::Minicli( QWidget *parent )
   m_dlg->gbAdvanced->hide();
 
   // URI Filter meta object...
-  m_filterData = new KURIFilterData();
+  m_filterData = new KUriFilterData();
 
   // Create a timer object...
   m_parseTimer = new QTimer(this);
@@ -129,9 +130,16 @@ Minicli::Minicli( QWidget *parent )
 
   m_prevCached = false;
   m_iPriority = 50;
+#if HAVE_KDESU
   m_iScheduler = StubProcess::SchedNormal;
+  m_dlg->cbRunAsOther->setEnabled(false);
+  m_dlg->cbRealtime->setEnabled(false);
+  m_dlg->cbPriority->setEnabled(false);
+  m_dlg->slPriority->setEnabled(false);
+#endif
 
   m_dlg->leUsername->setText("root");
+  m_dlg->lePassword->setPasswordMode(true);
 
   // Main widget buttons...
   connect( m_dlg->pbRun, SIGNAL(clicked()), this, SLOT(accept()) );
@@ -176,7 +184,7 @@ void Minicli::setCommand(const QString& command)
 
 QSize Minicli::sizeHint() const
 {
-  int maxWidth = qApp->desktop()->screenGeometry((QWidget*)this).width();
+  int maxWidth = qApp->desktop()->screenGeometry(this).width();
   if (maxWidth < 603)
   {
     // a sensible max for smaller screens
@@ -225,7 +233,7 @@ void Minicli::loadConfig()
   if (box)
     box->setActivateOnSelect( false );
 
-  m_finalFilters = KURIFilter::self()->pluginNames();
+  m_finalFilters = KUriFilter::self()->pluginNames();
   m_finalFilters.removeAll("kuriikwsfilter");
 
   m_middleFilters = m_finalFilters;
@@ -317,19 +325,20 @@ void Minicli::reset()
   m_dlg->pbRun->setEnabled( false );
 
   m_iPriority = 50;
+#if HAVE_KDESU
   m_iScheduler = StubProcess::SchedNormal;
+  m_dlg->cbRealtime->setChecked( m_iScheduler == StubProcess::SchedRealtime );
+  m_dlg->cbRunAsOther->setChecked(false);
+#endif
 
   m_dlg->cbRunInTerminal->setChecked(false);
-  m_dlg->cbRunAsOther->setChecked(false);
 
   m_dlg->leUsername->setText("root");
 
   m_dlg->cbPriority->setChecked(false);
-
   m_dlg->slPriority->setValue(m_iPriority);
 
-  m_dlg->cbRealtime->setChecked( m_iScheduler == StubProcess::SchedRealtime );
-  m_dlg->lePassword->erase();
+  m_dlg->lePassword->clear();
 
   m_FocusWidget = 0;
   m_iconName.clear();
@@ -396,6 +405,7 @@ int Minicli::runCommand()
   if (!KAuthorized::authorizeKAction("shell_access"))
     useTerminal = false;
 
+#if HAVE_KDESU
   if( needsKDEsu() )
   {
     QByteArray user;
@@ -439,7 +449,7 @@ int Minicli::runCommand()
         proc_checkpwd.setScheduler(m_iScheduler);
       }
 
-      if (proc_checkpwd.checkInstall(m_dlg->lePassword->password()) != 0)
+      if (proc_checkpwd.checkInstall(m_dlg->lePassword->text().toLocal8Bit()) != 0)
       {
           KMessageBox::sorry(this, i18n("Incorrect password; please try again."));
         return 1;
@@ -490,9 +500,11 @@ int Minicli::runCommand()
     sigprocmask(SIG_BLOCK, &sset, 0L);
     proc.setTerminal(true);
     proc.setErase(true);
-    _exit(proc.exec(m_dlg->lePassword->password()));
+    _exit(proc.exec(m_dlg->lePassword->text().toLocal8Bit()));
+    return 0;
   }
   else
+#endif // HAVE_KDESU
   {
     QString exec;
 
@@ -514,16 +526,16 @@ int Minicli::runCommand()
     {
       switch( m_filterData->uriType() )
       {
-        case KURIFilterData::LOCAL_FILE:
-        case KURIFilterData::LOCAL_DIR:
-        case KURIFilterData::NET_PROTOCOL:
-        case KURIFilterData::HELP:
+        case KUriFilterData::LOCAL_FILE:
+        case KUriFilterData::LOCAL_DIR:
+        case KUriFilterData::NET_PROTOCOL:
+        case KUriFilterData::HELP:
         {
           // No need for kfmclient, KRun does it all (David)
           (void) new KRun( m_filterData->uri(), 0 );
           return 0;
         }
-        case KURIFilterData::EXECUTABLE:
+        case KUriFilterData::EXECUTABLE:
         {
           if( !m_filterData->hasArgsAndOptions() )
           {
@@ -538,7 +550,7 @@ int Minicli::runCommand()
           }
         }
         // fall-through to shell case
-        case KURIFilterData::SHELL:
+        case KUriFilterData::SHELL:
         {
           if (KAuthorized::authorizeKAction("shell_access"))
           {
@@ -558,8 +570,8 @@ int Minicli::runCommand()
             return 1;
           }
         }
-        case KURIFilterData::UNKNOWN:
-        case KURIFilterData::ERROR:
+        case KUriFilterData::UNKNOWN:
+        case KUriFilterData::ERROR:
         default:
         {
           // Look for desktop file
@@ -676,11 +688,11 @@ void Minicli::parseLine( bool final )
   m_filterData->setData( cmd );
 
   if( final )
-    KURIFilter::self()->filterURI( *(m_filterData), m_finalFilters );
+    KUriFilter::self()->filterUri( *(m_filterData), m_finalFilters );
   else
-    KURIFilter::self()->filterURI( *(m_filterData), m_middleFilters );
+    KUriFilter::self()->filterUri( *(m_filterData), m_middleFilters );
 
-  bool isTerminalApp = ((m_filterData->uriType() == KURIFilterData::EXECUTABLE) &&
+  bool isTerminalApp = ((m_filterData->uriType() == KUriFilterData::EXECUTABLE) &&
                         m_terminalAppList.contains(m_filterData->uri().url()));
 
   if( !isTerminalApp )
@@ -722,7 +734,7 @@ void Minicli::setIcon ()
 #ifdef __GNUC__
 #warning "Yet another overlay thingie!"
 #endif
-    QPixmap overlay( KStandardDirs::locate ( "icon", KMimeType::favIconForURL( m_filterData->uri() ) + ".png" ) );
+    QPixmap overlay( KStandardDirs::locate ( "icon", KMimeType::favIconForUrl( m_filterData->uri() ) + ".png" ) );
     if ( !overlay.isNull() )
     {
       int x = icon.width() - overlay.width();
@@ -751,8 +763,10 @@ void Minicli::setIcon ()
 
 void Minicli::updateAuthLabel()
 {
-  if (m_dlg->cbPriority->isChecked() && (m_iPriority > 50) ||
-      (m_iScheduler != StubProcess::SchedNormal))
+  if (m_dlg->cbPriority->isChecked() && (m_iPriority > 50)
+#if HAVE_KDESU
+      || (m_iScheduler != StubProcess::SchedNormal))
+#endif
   {
     if (!m_prevCached && !m_dlg->leUsername->text().isEmpty())
     {
@@ -846,13 +860,18 @@ void Minicli::slotChangeScheduler(bool enable)
 
 bool Minicli::needsKDEsu()
 {
+#if HAVE_KDESU
   return ((m_dlg->cbPriority->isChecked() && ((m_iPriority > 50) ||
           (m_iScheduler != StubProcess::SchedNormal))) ||
           (m_dlg->cbRunAsOther->isChecked() && !m_dlg->leUsername->text().isEmpty()));
+#else
+  return false;
+#endif
 }
 
 void Minicli::slotRealtime(bool enabled)
 {
+#if HAVE_KDESU
   m_iScheduler = enabled ? StubProcess::SchedRealtime : StubProcess::SchedNormal;
 
   if (enabled)
@@ -870,6 +889,7 @@ void Minicli::slotRealtime(bool enabled)
   }
 
   updateAuthLabel();
+#endif
 }
 
 void Minicli::slotPriority(int priority)
@@ -888,16 +908,22 @@ void Minicli::slotPriority(int priority)
 
 QString Minicli::calculate(const QString &exp)
 {
-   QString result;
-   QString cmd = QString("echo $((%1))").arg(exp);
-   FILE *fs = popen(QFile::encodeName(cmd).data(), "r");
-   if (fs)
-   {
-      QTextStream ts(fs, QIODevice::ReadOnly);
-      result = ts.readLine().trimmed();
-      pclose(fs);
-   }
-   return result;
+    QString result, cmd;
+    const QString bc = KStandardDirs::findExe("bc");
+    if ( !bc.isEmpty() )
+        cmd = QString("echo %1 | %2").arg(KProcess::quote(QString("scale=8; ")+exp), KProcess::quote(bc));
+    else
+        cmd = QString("echo $((%1))").arg(exp);
+    FILE *fs = popen(QFile::encodeName(cmd).data(), "r");
+    if (fs)
+    {
+        { // scope for QTextStream
+            QTextStream ts(fs, QIODevice::ReadOnly);
+            result = ts.readLine().trimmed();
+        }
+        pclose(fs);
+    }
+    return result;
 }
 
 void Minicli::fontChange( const QFont & )
