@@ -33,7 +33,6 @@ from the copyright holder.
  *
  * user verification and session initiation.
  */
-#include <config-kdm.h>
 #include "dm.h"
 #include "dm_auth.h"
 #include "dm_error.h"
@@ -51,7 +50,6 @@ extern int key_setnet( struct key_netstarg *arg );
 #endif
 #ifdef HAVE_SETUSERCONTEXT
 # include <login_cap.h>
-# define USE_LOGIN_CAP 1
 #endif
 #ifdef USE_PAM
 # ifdef HAVE_PAM_PAM_APPL_H
@@ -72,7 +70,7 @@ extern int loginsuccess( const char *User, const char *Host, const char *Tty, ch
 # ifdef KERBEROS
 #  include <sys/param.h>
 #  include <krb.h>
-#  ifndef NO_AFS
+#  ifdef AFS
 #   include <kafs.h>
 #  endif
 # endif
@@ -101,6 +99,13 @@ char *curdmrc;
 char *newdmrc;
 
 static struct passwd *p;
+#ifdef HAVE_SETUSERCONTEXT
+# ifdef HAVE_LOGIN_GETCLASS
+login_cap_t *lc;
+# else
+struct login_cap *lc;
+# endif
+#endif
 #ifdef USE_PAM
 static pam_handle_t *pamh;
 #elif defined(_AIX)
@@ -132,7 +137,7 @@ static char krbtkfile[MAXPATHLEN];
 
 #ifdef USE_PAM
 
-# ifdef PAM_MESSAGE_NONCONST
+# ifndef PAM_MESSAGE_CONST
 typedef struct pam_message pam_message_type;
 typedef void *pam_gi_type;
 # else
@@ -410,7 +415,7 @@ AccNoPass( const char *un, struct passwd *pw )
 	return 0;
 }
 
-#if !defined(USE_PAM) && !defined(_AIX) && defined(USE_LOGIN_CAP)
+#if !defined(USE_PAM) && !defined(_AIX) && defined(HAVE_SETUSERCONTEXT)
 # define LC_RET0 do { login_close(lc); return 0; } while(0)
 #else
 # define LC_RET0 return 0
@@ -438,13 +443,6 @@ Verify( GConvFunc gconv, int rootok )
 # if defined(HAVE_STRUCT_PASSWD_PW_EXPIRE) || defined(USESHADOW)
 	int tim, expir, warntime, quietlog;
 # endif
-# ifdef USE_LOGIN_CAP
-#  ifdef HAVE_LOGIN_GETCLASS
-	login_cap_t *lc;
-#  else
-	struct login_cap *lc;
-#  endif
-# endif
 #endif
 
 	Debug( "Verify ...\n" );
@@ -744,23 +742,11 @@ Verify( GConvFunc gconv, int rootok )
 	if (msg)
 		free( (void *)msg );
 
-#else /* USE_PAM || _AIX */
+#endif /* USE_PAM || _AIX */
 
-# ifdef HAVE_GETUSERSHELL
-	for (;;) {
-		if (!(s = getusershell())) {
-			Debug( "shell not in /etc/shells\n" );
-			endusershell();
-			V_RET_FAIL( "Your login shell is not listed in /etc/shells" );
-		}
-		if (!strcmp( s, p->pw_shell )) {
-			endusershell();
-			break;
-		}
-	}
-# endif
+#ifndef _AIX
 
-# ifdef USE_LOGIN_CAP
+# ifdef HAVE_SETUSERCONTEXT
 #  ifdef HAVE_LOGIN_GETCLASS
 	lc = login_getclass( p->pw_class );
 #  else
@@ -768,106 +754,45 @@ Verify( GConvFunc gconv, int rootok )
 #  endif
 	if (!lc)
 		V_RET_FAIL( 0 );
+
+	p->pw_shell = login_getcapstr( lc, "shell", p->pw_shell, p->pw_shell );
 # endif
 
+# ifndef USE_PAM
 
-/* restrict_nologin */
-# ifndef _PATH_NOLOGIN
-#  define _PATH_NOLOGIN "/etc/nologin"
-# endif
+/* restrict_expired */
+#  if defined(HAVE_STRUCT_PASSWD_PW_EXPIRE) || defined(USESHADOW)
 
-	if ((
-# ifdef USE_LOGIN_CAP
-	     /* Do we ignore a nologin file? */
-	     !login_getcapbool( lc, "ignorenologin", 0 )) &&
-	    (!stat( (nolg = login_getcapstr( lc, "nologin", "", NULL )), &st ) ||
-# endif
-		 !stat( (nolg = _PATH_NOLOGIN), &st )))
-	{
-		PrepErrorGreet();
-		GSendInt( V_MSG_ERR );
-		if (st.st_size && (fd = open( nolg, O_RDONLY )) >= 0) {
-			if ((buf = Malloc( st.st_size + 1 ))) {
-				if (read( fd, buf, st.st_size ) == st.st_size) {
-					buf[st.st_size] = 0;
-					GSendStr( buf );
-					free( buf );
-					close( fd );
-					GSendInt( V_FAIL );
-					LC_RET0;
-				}
-				free( buf );
-			}
-			close( fd );
-		}
-		GSendStr( "Logins are not allowed at the moment.\nTry again later" );
-		GSendInt( V_FAIL );
-		LC_RET0;
-	}
-
-
-/* restrict_nohome */
-# ifdef USE_LOGIN_CAP
-	if (login_getcapbool( lc, "requirehome", 0 )) {
-		struct stat st;
-		if (!*p->pw_dir || stat( p->pw_dir, &st ) || st.st_uid != p->pw_uid) {
-			PrepErrorGreet();
-			GSendInt( V_MSG_ERR );
-			GSendStr( "Home folder not available" );
-			GSendInt( V_FAIL );
-			LC_RET0;
-		}
-	}
-# endif
-
-
-/* restrict_time */
-# ifdef USE_LOGIN_CAP
-#  ifdef HAVE_AUTH_TIMEOK
-	if (!auth_timeok( lc, time( NULL ) )) {
-		PrepErrorGreet();
-		GSendInt( V_MSG_ERR );
-		GSendStr( "You are not allowed to login at the moment" );
-		GSendInt( V_FAIL );
-		LC_RET0;
-	}
-#  endif
-# endif
-
-
-/* restrict_expired; this MUST be the last one */
-# if defined(HAVE_STRUCT_PASSWD_PW_EXPIRE) || defined(USESHADOW)
-
-#  if !defined(HAVE_STRUCT_PASSWD_PW_EXPIRE) || (!defined(USE_LOGIN_CAP) && defined(USESHADOW))
+#   if !defined(HAVE_STRUCT_PASSWD_PW_EXPIRE) || (!defined(HAVE_SETUSERCONTEXT) && defined(USESHADOW))
 	if (sp)
-#  endif
+#   endif
 	{
 
-#  define DEFAULT_WARN	(2L * 7L)  /* Two weeks */
+#   define DEFAULT_WARN	(2L * 7L)  /* Two weeks */
 
 		tim = time( NULL ) / 86400L;
 
-#  ifdef USE_LOGIN_CAP
+#   ifdef HAVE_SETUSERCONTEXT
 		quietlog = login_getcapbool( lc, "hushlogin", 0 );
 		warntime = login_getcaptime( lc, "warnexpire",
 		                             DEFAULT_WARN * 86400L,
 		                             DEFAULT_WARN * 86400L ) / 86400L;
-#  else
+#   else
 		quietlog = 0;
-#	ifdef USESHADOW
+#    ifdef USESHADOW
 		warntime = sp->sp_warn != -1 ? sp->sp_warn : DEFAULT_WARN;
-#	else
+#    else
 		warntime = DEFAULT_WARN;
-#	endif
-#  endif
+#    endif
+#   endif
 
-#  ifdef HAVE_STRUCT_PASSWD_PW_EXPIRE
+#   ifdef HAVE_STRUCT_PASSWD_PW_EXPIRE
 		if (p->pw_expire) {
 			expir = p->pw_expire / 86400L;
-#  else
+#   else
 		if (sp->sp_expire != -1) {
 			expir = sp->sp_expire;
-#  endif
+#   endif
 			if (tim > expir) {
 				PrepErrorGreet();
 				GSendInt( V_MSG_ERR );
@@ -888,10 +813,10 @@ Verify( GConvFunc gconv, int rootok )
 			}
 		}
 
-#  ifdef HAVE_STRUCT_PASSWD_PW_EXPIRE
+#   ifdef HAVE_STRUCT_PASSWD_PW_EXPIRE
 		if (p->pw_change) {
 			expir = p->pw_change / 86400L;
-#  else
+#   else
 		if (!sp->sp_lstchg) {
 			PrepErrorGreet();
 			GSendInt( V_MSG_ERR );
@@ -910,7 +835,7 @@ Verify( GConvFunc gconv, int rootok )
 				GSendInt( V_FAIL );
 				LC_RET0;
 			}
-#  endif
+#   endif
 			if (tim > expir) {
 				PrepErrorGreet();
 				GSendInt( V_MSG_ERR );
@@ -934,13 +859,84 @@ Verify( GConvFunc gconv, int rootok )
 
 	}
 
-# endif /* HAVE_STRUCT_PASSWD_PW_EXPIRE || USESHADOW */
+#  endif /* HAVE_STRUCT_PASSWD_PW_EXPIRE || USESHADOW */
 
-# ifdef USE_LOGIN_CAP
-	login_close( lc );
+/* restrict_nologin */
+#  ifndef _PATH_NOLOGIN
+#   define _PATH_NOLOGIN "/etc/nologin"
+#  endif
+
+	if ((
+#  ifdef HAVE_SETUSERCONTEXT
+	     /* Do we ignore a nologin file? */
+	     !login_getcapbool( lc, "ignorenologin", 0 )) &&
+	    (!stat( (nolg = login_getcapstr( lc, "nologin", "", NULL )), &st ) ||
+#  endif
+		 !stat( (nolg = _PATH_NOLOGIN), &st )))
+	{
+		PrepErrorGreet();
+		GSendInt( V_MSG_ERR );
+		if (st.st_size && (fd = open( nolg, O_RDONLY )) >= 0) {
+			if ((buf = Malloc( st.st_size + 1 ))) {
+				if (read( fd, buf, st.st_size ) == st.st_size) {
+					buf[st.st_size] = 0;
+					GSendStr( buf );
+					free( buf );
+					close( fd );
+					GSendInt( V_FAIL );
+					LC_RET0;
+				}
+				free( buf );
+			}
+			close( fd );
+		}
+		GSendStr( "Logins are not allowed at the moment.\nTry again later" );
+		GSendInt( V_FAIL );
+		LC_RET0;
+	}
+
+/* restrict_time */
+#  if defined(HAVE_SETUSERCONTEXT) && defined(HAVE_AUTH_TIMEOK)
+	if (!auth_timeok( lc, time( NULL ) )) {
+		PrepErrorGreet();
+		GSendInt( V_MSG_ERR );
+		GSendStr( "You are not allowed to login at the moment" );
+		GSendInt( V_FAIL );
+		LC_RET0;
+	}
+#  endif
+
+#  ifdef HAVE_GETUSERSHELL
+	for (;;) {
+		if (!(s = getusershell())) {
+			Debug( "shell not in /etc/shells\n" );
+			endusershell();
+			V_RET_FAIL( "Your login shell is not listed in /etc/shells" );
+		}
+		if (!strcmp( s, p->pw_shell )) {
+			endusershell();
+			break;
+		}
+	}
+#  endif
+
+# endif /* !USE_PAM */
+
+/* restrict_nohome */
+# ifdef HAVE_SETUSERCONTEXT
+	if (login_getcapbool( lc, "requirehome", 0 )) {
+		struct stat st;
+		if (!*p->pw_dir || stat( p->pw_dir, &st ) || st.st_uid != p->pw_uid) {
+			PrepErrorGreet();
+			GSendInt( V_MSG_ERR );
+			GSendStr( "Home folder not available" );
+			GSendInt( V_FAIL );
+			LC_RET0;
+		}
+	}
 # endif
 
-#endif /* USE_PAM || _AIX */
+#endif /* !_AIX */
 
 	return 1;
 
@@ -956,6 +952,51 @@ static const char *envvars[] = {
 };
 
 
+#if defined(USE_PAM) && defined(HAVE_INITGROUPS)
+int num_saved_gids;
+gid_t saved_gids[NGROUPS];
+
+static int
+saveGids( void )
+{
+	if ((num_saved_gids = getgroups( as(saved_gids), saved_gids )) < 0) {
+		LogError( "saving groups failed: %m\n" );
+		return 0;
+	}
+	return 1;
+}
+
+static int
+restoreGids( void )
+{
+	if (setgroups( num_saved_gids, saved_gids ) < 0) {
+		LogError( "restoring groups failed: %m\n" );
+		return 0;
+	}
+	if (setgid( p->pw_gid ) < 0) {
+		LogError( "restoring gid failed: %m\n" );
+		return 0;
+	}
+	return 1;
+}
+#endif /* USE_PAM && HAVE_INITGROUPS */
+
+static int
+resetGids( void )
+{
+#ifdef HAVE_INITGROUPS
+	if (setgroups( 0, &p->pw_gid /* anything */ ) < 0) {
+		LogError( "restoring groups failed: %m\n" );
+		return 0;
+	}
+#endif
+	if (setgid( 0 ) < 0) {
+		LogError( "restoring gid failed: %m\n" );
+		return 0;
+	}
+	return 1;
+}
+
 static int
 SetGid( const char *name, int gid )
 {
@@ -966,6 +1007,7 @@ SetGid( const char *name, int gid )
 #ifdef HAVE_INITGROUPS
 	if (initgroups( name, gid ) < 0) {
 		LogError( "initgroups for %s failed: %m\n", name );
+		setgid( 0 );
 		return 0;
 	}
 #endif	 /* QNX4 doesn't support multi-groups, no initgroups() */
@@ -985,7 +1027,12 @@ SetUid( const char *name, int uid )
 static int
 SetUser( const char *name, int uid, int gid )
 {
-	return SetGid( name, gid ) && SetUid( name, uid );
+	if (SetGid( name, gid )) {
+		if (SetUid( name, uid ))
+			return 1;
+		resetGids();
+	}
+	return 0;
 }
 
 #if defined(SECURE_RPC) || defined(K5AUTH)
@@ -1044,15 +1091,22 @@ mergeSessionArgs( int cansave )
 }
 
 static int removeAuth;
+#ifdef USE_PAM
+static int removeSession;
+static int removeCreds;
+#endif
 
 int
-StartClient()
+StartClient( volatile int *pid )
 {
 	const char *home, *sessargs, *desksess;
 	char **env, *xma;
 	char **argv, *fname, *str;
 #ifdef USE_PAM
-	char **pam_env;
+	char ** volatile pam_env;
+# ifndef HAVE_PAM_GETENVLIST
+	char **saved_env;
+# endif
 	struct pam_conv pconv;
 	int pretc;
 #else
@@ -1066,7 +1120,7 @@ StartClient()
 	extern char **environ;
 #endif
 	char *failsafeArgv[2], *lname;
-	int i, pid, lfd;
+	int i, lfd;
 
 	if (StrCmp( dmrcuser, curuser )) {
 		if (curdmrc) { free( curdmrc ); curdmrc = 0; }
@@ -1089,7 +1143,7 @@ StartClient()
 		free( (void *)msg );
 	}
 # else /* _AIX */
-#  if defined(KERBEROS) && !defined(NO_AFS)
+#  if defined(KERBEROS) && defined(AFS)
 	if (krbtkfile[0] != '\0') {
 		if (k_hasafs()) {
 			if (k_setpag() == -1)
@@ -1107,23 +1161,7 @@ StartClient()
 
 	env = baseEnv( curuser );
 	xma = 0;
-	if (td->ctrl.fpath && StrDup( &xma, td->ctrl.fpath )) {
-		if ((td->allowShutdown == SHUT_ALL ||
-		     (td->allowShutdown == SHUT_ROOT && !curuser)) &&
-		    StrApp( &xma, ",maysd", (char *)0 ))
-		{
-			if (td->allowNuke == SHUT_ALL ||
-			    (td->allowNuke == SHUT_ROOT && !curuser))
-				StrApp( &xma, ",mayfn", (char *)0 );
-			StrApp( &xma, td->defSdMode == SHUT_FORCENOW ? ",fn" :
-			        td->defSdMode == SHUT_TRYNOW ? ",tn" : ",sched",
-			        (char *)0 );
-		}
-		if ((td->displayType & d_location) == dLocal && AnyReserveDisplays())
-			StrApp( &xma, ",rsvd", (char *)0 );
-	} else
-		StrDup( &xma, "true" );
-	StrApp( &xma, ",method=", curtype, (char *)0 );
+	StrApp( &xma, "method=", curtype, (char *)0 );
 	if (td_setup)
 		StrApp( &xma, ",auto", (char *)0 );
 	if (xma) {
@@ -1190,24 +1228,95 @@ StartClient()
 		mergeSessionArgs( TRUE );
 
 	Debug( "now starting the session\n" );
+
 #ifdef USE_PAM
+	/* the greeter is gone by now ... */
 	pconv.conv = PAM_conv_null;
 	pconv.appdata_ptr = 0;
-	pam_set_item( pamh, PAM_CONV, &pconv ); /* XXX this can fail */
-	pam_open_session( pamh, 0 ); /* XXX this can fail, too */
+	if ((pretc = pam_set_item( pamh, PAM_CONV, &pconv )) != PAM_SUCCESS) {
+		ReInitErrorLog();
+		LogError( "pam_set_item() for %s failed: %s\n",
+		          curuser, pam_strerror( pamh, pretc ) );
+		return 0;
+	}
 	ReInitErrorLog();
 #endif
+
+#ifdef USE_PAM
+
+# ifdef HAVE_SETUSERCONTEXT
+	if (setusercontext( lc, p, p->pw_uid, LOGIN_SETGROUP )) {
+		LogError( "setusercontext(groups) for %s failed: %m\n",
+		          curuser );
+		return 0;
+	}
+# else
+	if (!SetGid( curuser, curgid ))
+		return 0;
+# endif
+
+# ifndef HAVE_PAM_GETENVLIST
+	if (!(pam_env = initStrArr( 0 ))) {
+		resetGids();
+		return 0;
+	}
+	saved_env = environ;
+	environ = pam_env;
+# endif
+	removeCreds = 1; /* set it first - i don't trust PAM's rollback */
+	pretc = pam_setcred( pamh, 0 );
+	ReInitErrorLog();
+# ifndef HAVE_PAM_GETENVLIST
+	pam_env = environ;
+	environ = saved_env;
+# endif
+# ifdef HAVE_INITGROUPS
+	/* This seems to be a strange place for it, but do it:
+	   - after the initial groups are set
+	   - after pam_setcred might have set something, even in the error case
+	   - before pam_setcred(DELETE_CRED) might need it
+	 */
+	if (!saveGids())
+		return 0;
+# endif
+	if (pretc != PAM_SUCCESS) {
+		LogError( "pam_setcred() for %s failed: %s\n",
+		          curuser, pam_strerror( pamh, pretc ) );
+		resetGids();
+		return 0;
+	}
+
+	removeSession = 1; /* set it first - same as above */
+	pretc = pam_open_session( pamh, 0 );
+	ReInitErrorLog();
+	if (pretc != PAM_SUCCESS) {
+		LogError( "pam_open_session() for %s failed: %s\n",
+		          curuser, pam_strerror( pamh, pretc ) );
+		resetGids();
+		return 0;
+	}
+
+	/* we don't want sessreg and the startup/reset scripts run with user
+	   credentials. unfortunately, we can reset only the gids. */
+	resetGids();
+
+# define D_LOGIN_SETGROUP LOGIN_SETGROUP
+#else /* USE_PAM */
+# define D_LOGIN_SETGROUP 0
+#endif /* USE_PAM */
+
 	removeAuth = 1;
 	chownCtrl( &td->ctrl, curuid );
 	endpwent();
 #if !defined(USE_PAM) && defined(USESHADOW) && !defined(_AIX)
 	endspent();
 #endif
-	ClearCloseOnFork( mstrtalk.pipe->wfd );
-	switch (pid = Fork()) {
+	ClearCloseOnFork( mstrtalk.pipe->fd.w );
+	switch (Fork( pid )) {
 	case 0:
 
 		sessreg( td, getpid(), curuser, curuid );
+
 		if (source( systemEnviron, td->startup, td_setup )) {
 			LogError( "Cannot execute startup script %\"s\n", td->startup );
 			exit( 1 );
@@ -1217,32 +1326,15 @@ StartClient()
 			exit( 1 );
 		GSet( &mstrtalk );
 
-		/* Do system-dependent login setup here */
 		setsid();
 
 	/* Memory leaks are ok here as we exec() soon. */
 
 #if defined(USE_PAM) || !defined(_AIX)
 
-# ifndef HAVE_SETUSERCONTEXT
-		if (!SetGid( curuser, curgid ))
-			exit( 1 );
-# endif
 # ifdef USE_PAM
-#  ifdef _AIX
-		if (!(environ = initStrArr( 0 )))
-			exit( 1 );
-#  endif
-		if ((pretc = pam_setcred( pamh, 0 )) != PAM_SUCCESS) {
-			ReInitErrorLog();
-			LogError( "pam_setcred() for %s failed: %s\n",
-			          curuser, pam_strerror( pamh, pretc ) );
-			exit( 1 );
-		}
 		/* pass in environment variables set by libpam and modules it called */
-#  ifdef _AIX
-		pam_env = environ;
-#  else
+#  ifdef HAVE_PAM_GETENVLIST
 		pam_env = pam_getenvlist( pamh );
 		ReInitErrorLog();
 #  endif
@@ -1250,19 +1342,36 @@ StartClient()
 			for (; *pam_env; pam_env++)
 				userEnviron = putEnv( *pam_env, userEnviron );
 # endif
-# ifndef HAVE_SETUSERCONTEXT
-#  ifdef HAVE_SETLOGIN
+
+# ifdef HAVE_SETLOGIN
 		if (setlogin( curuser ) < 0) {
 			LogError( "setlogin for %s failed: %m\n", curuser );
 			exit( 1 );
 		}
-#  endif
+#  define D_LOGIN_SETLOGIN LOGIN_SETLOGIN
+# else
+#  define D_LOGIN_SETLOGIN 0
+# endif
+
+# if defined(USE_PAM) && defined(HAVE_INITGROUPS)
+		if (!restoreGids())
+			exit( 1 );
+# endif
+
+# ifndef HAVE_SETUSERCONTEXT
+
+#  ifdef USE_PAM
 		if (!SetUid( curuser, curuid ))
 			exit( 1 );
-# else /* HAVE_SETUSERCONTEXT */
+#  else
+		if (!SetUser( curuser, curuid, curgid ))
+			exit( 1 );
+#  endif
+
+# else /* !HAVE_SETUSERCONTEXT */
 
 		/*
-		 * Destroy environment unless user has requested its preservation.
+		 * Destroy environment.
 		 * We need to do this before setusercontext() because that may
 		 * set or reset some environment variables.
 		 */
@@ -1273,7 +1382,9 @@ StartClient()
 		 * Set the user's credentials: uid, gid, groups,
 		 * environment variables, resource limits, and umask.
 		 */
-		if (setusercontext( NULL, p, p->pw_uid, LOGIN_SETALL ) < 0) {
+		if (setusercontext( lc, p, p->pw_uid,
+		        LOGIN_SETALL & ~(D_LOGIN_SETGROUP|D_LOGIN_SETLOGIN) ) < 0)
+		{
 			LogError( "setusercontext for %s failed: %m\n", curuser );
 			exit( 1 );
 		}
@@ -1281,8 +1392,9 @@ StartClient()
 		for (i = 0; environ[i]; i++)
 			userEnviron = putEnv( environ[i], userEnviron );
 
-# endif /* HAVE_SETUSERCONTEXT */
-#else /* _AIX */
+# endif /* !HAVE_SETUSERCONTEXT */
+
+#else /* PAM || !_AIX */
 		/*
 		 * Set the user's credentials: uid, gid, groups,
 		 * audit classes, user limits, and umask.
@@ -1414,7 +1526,7 @@ StartClient()
 		GSendInt( curuid );
 		GSendStr( curuser );
 		GSendStr( desksess );
-		close( mstrtalk.pipe->wfd );
+		close( mstrtalk.pipe->fd.w );
 		userEnviron = setEnv( userEnviron, "DESKTOP_SESSION", desksess );
 		for (i = 0; td->sessionsDirs[i]; i++) {
 			fname = 0;
@@ -1453,64 +1565,90 @@ StartClient()
 		          failsafeArgv[0] );
 		exit( 1 );
 	case -1:
-		RegisterCloseOnFork( mstrtalk.pipe->wfd );
+		RegisterCloseOnFork( mstrtalk.pipe->fd.w );
 		LogError( "Forking session on %s failed: %m\n", td->name );
 		return 0;
 	default:
-		RegisterCloseOnFork( mstrtalk.pipe->wfd );
-		Debug( "StartSession, fork succeeded %d\n", pid );
-		return pid;
+		RegisterCloseOnFork( mstrtalk.pipe->fd.w );
+		Debug( "StartSession, fork succeeded %d\n", *pid );
+		return 1;
 	}
 }
 
 void
 SessionExit( int status )
 {
+	int pid;
+#ifdef USE_PAM
+	int pretc;
+#endif
+
+	if (removeAuth) {
+		if (source( systemEnviron, td->reset, td_setup ))
+			LogError( "Cannot execute reset script %\"s\n", td->reset );
+		sessreg( td, 0, 0, 0 );
+
+		switch (Fork( &pid )) {
+		case 0:
+#if defined(USE_PAM) && defined(HAVE_INITGROUPS)
+			if (restoreGids() && SetUid( curuser, curuid ))
+#else
+			if (SetUser( curuser, curuid, curgid ))
+#endif
+
+			{
+				RemoveUserAuthorization( td );
+#ifdef K5AUTH
+				Krb5Destroy( td->name );
+#endif /* K5AUTH */
+#if !defined(USE_PAM) && !defined(_AIX)
+# ifdef KERBEROS
+				if (krbtkfile[0]) {
+					(void)dest_tkt();
+#  ifdef AFS
+					if (k_hasafs())
+						(void)k_unlog();
+#  endif
+				}
+# endif
+#endif /* !USE_PAM && !_AIX*/
+			}
+			exit( 0 );
+		case -1:
+			LogError( "Cannot clean up session: fork() failed: %m" );
+			break;
+		default:
+			Wait4( &pid );
+			break;
+		}
+	}
+
+#ifdef USE_PAM
+	if (removeCreds) {
+# ifdef HAVE_INITGROUPS
+		restoreGids();
+# endif
+		if (removeSession)
+			if ((pretc = pam_close_session( pamh, 0 )) != PAM_SUCCESS)
+				LogError( "pam_close_session() failed: %s\n",
+				          pam_strerror( pamh, pretc ) );
+		if ((pretc = pam_setcred( pamh, PAM_DELETE_CRED )) != PAM_SUCCESS)
+			LogError( "pam_setcred(DELETE_CRED) failed: %s\n",
+			          pam_strerror( pamh, pretc ) );
+		resetGids();
+	}
+	if (pamh) {
+		pam_end( pamh, PAM_SUCCESS );
+		ReInitErrorLog();
+	}
+#endif
+
 	/* make sure the server gets reset after the session is over */
 	if (td->serverPid >= 2) {
 		if (!td->terminateServer && td->resetSignal)
 			TerminateProcess( td->serverPid, td->resetSignal );
 	} else
 		ResetServer( td );
-	if (removeAuth) {
-#ifdef USE_PAM
-		int pretc;
-		if ((pretc = pam_setcred( pamh, PAM_DELETE_CRED )) != PAM_SUCCESS)
-			LogError( "pam_setcred(DELETE_CRED) for %s failed: %s\n",
-			          curuser, pam_strerror( pamh, pretc ) );
-		pam_close_session( pamh, 0 );
-		pam_end( pamh, PAM_SUCCESS );
-		ReInitErrorLog();
-#endif
-
-		if (source( systemEnviron, td->reset, td_setup ))
-			LogError( "Cannot execute reset script %\"s\n", td->reset );
-		sessreg( td, 0, 0, 0 );
-
-		SetUser( curuser, curuid, curgid );
-		RemoveUserAuthorization( td );
-#ifdef K5AUTH
-		Krb5Destroy( td->name );
-#endif /* K5AUTH */
-#if !defined(USE_PAM) && !defined(_AIX)
-# ifdef KERBEROS
-		if (krbtkfile[0]) {
-			(void)dest_tkt();
-#  ifndef NO_AFS
-			if (k_hasafs())
-				(void)k_unlog();
-#  endif
-		}
-# endif
-#endif /* !USE_PAM && !_AIX*/
-#ifdef USE_PAM
-	} else {
-		if (pamh) {
-			pam_end( pamh, PAM_SUCCESS );
-			ReInitErrorLog();
-		}
-#endif
-	}
 	Debug( "display %s exiting with status %d\n", td->name, status );
 	exit( status );
 }
@@ -1539,12 +1677,12 @@ ReadDmrc()
 		return GE_Error;
 	if (pipe( pfd ))
 		return GE_Error;
-	if ((pid = Fork()) < 0) {
+	switch (Fork( &pid )) {
+	case -1:
 		close( pfd[0] );
 		close( pfd[1] );
 		return GE_Error;
-	}
-	if (!pid) {
+	case 0:
 		if (!SetUser( p->pw_name, p->pw_uid, p->pw_gid ))
 			exit( 0 );
 		if (!(data = iniLoad( fname ))) {
@@ -1573,6 +1711,6 @@ ReadDmrc()
 		}
 	}
 	close( pfd[0] );
-	(void)Wait4( pid );
+	Wait4( &pid );
 	return err;
 }
