@@ -22,11 +22,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
+#include <greet.h>
+
 #include <X11/Xlib.h>
 #include <X11/Xresource.h>
 
-#include <config.h>
-
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -48,22 +48,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 # include <utmp.h>
 #endif
 
-#include "config.ci"
-
-#if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
-# define ATTR_UNUSED __attribute__((unused))
-#else
-# define ATTR_UNUSED
-#endif
-
-#if defined(__sun) && !defined(__sun__)
-# define __sun__
-#endif
-
-#define as(ar) ((int)(sizeof(ar)/sizeof(ar[0])))
-
-#define __stringify(x) #x
-#define stringify(x) __stringify(x)
+#include <config.ci>
 
 #define RCVERSTR stringify(RCVERMAJOR) "." stringify(RCVERMINOR)
 
@@ -673,7 +658,7 @@ static const char def_session1[] =
 "    xsess_tmp=";
 static const char def_session2[] =
 "\n"
-"    $SHELL -c \"if (-f /etc/csh.login) source /etc/csh.login; if (-f ~/.login) source ~/.login; /bin/sh -c export > $xsess_tmp\"\n"
+"    $SHELL -c \"if (-f /etc/csh.login) source /etc/csh.login; if (-f ~/.login) source ~/.login; /bin/sh -c export >! $xsess_tmp\"\n"
 "    . $xsess_tmp\n"
 "    rm -f $xsess_tmp\n"
 "    ;;\n"
@@ -1116,10 +1101,6 @@ joinArgs( StrList *argv )
 	return rs;
 }
 
-# define dLocation  1
-# define dLocal     0
-# define dForeign   1
-
 static struct displayMatch {
 	const char *name;
 	int len, type;
@@ -1202,7 +1183,7 @@ absorb_xservers( const char *sect ATTR_UNUSED, char **value )
 			se->reserve = 1;
 			word = ReadWord( &file, 1 );
 		}
-		if (((se->type & dLocation) == dLocal) != (word != 0))
+		if (((se->type & d_location) == dLocal) != (word != 0))
 			continue;
 		argp = &se->argv;
 		arglp = &se->arglv;
@@ -1241,7 +1222,7 @@ absorb_xservers( const char *sect ATTR_UNUSED, char **value )
 			word = ReadWord( &file, 1 );
 		}
 		*argp = *arglp = 0;
-		if ((se->type & dLocation) == dLocal) {
+		if ((se->type & d_location) == dLocal) {
 			nldpys++;
 			dpymask |= 1 << atoi( se->name + 1 );
 			if (se->reserve)
@@ -1257,7 +1238,7 @@ absorb_xservers( const char *sect ATTR_UNUSED, char **value )
 	cpvt = 0;
 	getInitTab();
 	for (se = serverList, mtty = maxTTY; se; se = se->next)
-		if ((se->type & dLocation) == dLocal) {
+		if ((se->type & d_location) == dLocal) {
 			mtty++;
 			if (se->vt != mtty) {
 				cpvt = 1;
@@ -1273,7 +1254,7 @@ absorb_xservers( const char *sect ATTR_UNUSED, char **value )
 
 	se1 = 0, cpcmd = cpcmdl = 0;
 	for (se = serverList; se; se = se->next)
-		if ((se->type & dLocation) == dLocal) {
+		if ((se->type & d_location) == dLocal) {
 			if (!se1)
 				se1 = se;
 			else {
@@ -1287,7 +1268,7 @@ absorb_xservers( const char *sect ATTR_UNUSED, char **value )
 		putfqval( "X-:*-Core", "ServerCmd", se1->argvs );
 		putfqval( "X-:*-Core", "ServerArgsLocal", se1->arglvs );
 		for (se = serverList; se; se = se->next)
-			if ((se->type & dLocation) == dLocal) {
+			if ((se->type & d_location) == dLocal) {
 				char sec[32];
 				sprintf( sec, "X-%s-Core", se->name );
 				if (cpcmd)
@@ -1563,7 +1544,7 @@ edit_startup( File *file )
 	             "test -f $PIDFILE && kill `cat $PIDFILE`\n" )))
 		chg1 = 1;
 	if (oldver < 0x0203) {
-		chg2 = 
+		chg2 =
 #ifdef _AIX
 			delstr( file, "\n"
 "# We create a pseudodevice for finger.  (host:0 becomes [kx]dm/host_0)\n" );
@@ -1603,7 +1584,7 @@ edit_startup( File *file )
 " $USER\n" ) |
 			delstr( file, "\n"
 "exec sessreg -a -l $DISPLAY -u /var/run/utmp -x */Xservers $USER\n" );
-		putval( "UseSessReg", chg2 ? "true" : "false");
+		putval( "UseSessReg", chg2 ? "true" : "false" );
 	}
 	return chg1 | chg2;
 }
@@ -1684,7 +1665,7 @@ mk_session( Entry *ce, Section *cs ATTR_UNUSED )
 		linkfile( ce );
 	else {
 		tmpf = locate( "mktemp" ) ?
-		           "`mktemp`" :
+		           "`mktemp /tmp/xsess-env-XXXXXX`" :
 		           locate( "tempfile" ) ?
 		               "`tempfile`" :
 		               "$HOME/.xsession-env-$DISPLAY";
@@ -2340,7 +2321,7 @@ handleXdmVal( const char *dpy, const char *key, char *value,
 		     !strcmp( key + 1, ents[i].xname + 1 )))
 		{
 			if (ents[i].ksec == (char *)-1) {
-				ents[i].func (0, &value);
+				ents[i].func( 0, &value );
 				break;
 			}
 			sprintf( sname, ents[i].ksec, dpy );
