@@ -26,9 +26,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifndef KDMCONFIG_H
 #define KDMCONFIG_H
 
-#include <config.h>
-
-#include "config.ci"
+#include <greet.h>
+#include <config.ci>
 
 #ifdef __cplusplus
 
@@ -42,9 +41,7 @@ extern bool _authorized;
 
 CONF_GREET_CPP_DECLS
 
-// this file happens to be included everywhere, so just put it here
-struct dpySpec;
-void decodeSess( dpySpec *sess, QString &user, QString &loc );
+void init_config_qapp();
 
 extern "C"
 #endif
