@@ -24,41 +24,30 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include "kdmshutdown.h"
 #include "kdm_greet.h"
+#include "utils.h"
 
-#include <kapplication.h>
-#include <kseparator.h>
-#include <klocale.h>
-#include <kpushbutton.h>
-#include <kstdguiitem.h>
-#include <kprocio.h>
 #include <kdialog.h>
+#include <klocale.h>
+#include <kprocio.h>
+#include <kseparator.h>
 #include <kstandarddirs.h>
+#include <KStandardGuiItem>
 #include <kuser.h>
 
-#include <QComboBox>
-#include <QStyle>
-#include <QLayout>
-#include <q3accel.h>
-#include <QMenu>
+#include <QAction>
+#include <QApplication>
 #include <QCheckBox>
-#include <QLineEdit>
-#include <QLabel>
+#include <QComboBox>
 #include <QDateTime>
-#include <q3listview.h>
-#include <q3header.h>
-#include <QDateTime>
-//Added by qt3to4:
-#include <QPixmap>
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QBoxLayout>
 #include <QFrame>
-#include <QVBoxLayout>
-#include <QMouseEvent>
-#include <Q3VButtonGroup>
-
-#define KDmh KDialog::marginHint()
-#define KDsh KDialog::spacingHint()
+#include <QGroupBox>
+#include <QHeaderView>
+#include <QLabel>
+#include <QLineEdit>
+#include <QMenu>
+#include <QStyle>
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
 
 #include <stdlib.h>
 
@@ -80,8 +69,6 @@ KDMShutdownBase::KDMShutdownBase( int _uid, QWidget *_parent )
 	, needRoot( -1 )
 	, uid( _uid )
 {
-    box->setSpacing( KDsh );
-    box->setMargin( KDmh );
 }
 
 KDMShutdownBase::~KDMShutdownBase()
@@ -111,19 +98,20 @@ KDMShutdownBase::complete( QWidget *prevWidget )
 		                          KGreeterPlugin::Shutdown );
 		verify->selectPlugin( curPlugin );
 		box->addLayout( verify->getLayout() );
-		Q3Accel *accel = new Q3Accel( this );
-		accel->insertItem( Qt::ALT+Qt::Key_A, 0 );
-		connect( accel, SIGNAL(activated( int )), SLOT(slotActivatePlugMenu()) );
+		verify->getLayout()->setParent( box );
+		QAction *action = new QAction( this );
+		action->setShortcut( Qt::ALT+Qt::Key_A );
+		connect( action, SIGNAL(triggered( bool )), SLOT(slotActivatePlugMenu()) );
 	}
 
 	box->addWidget( new KSeparator( Qt::Horizontal, this ) );
 
 	QBoxLayout *hlay = new QHBoxLayout();
-	box->addItem( hlay );
-	hlay->setSpacing( KDsh );
+	box->addLayout( hlay );
+	hlay->setParent( box );
 	hlay->addStretch( 1 );
 	if (mayOk) {
-		okButton = new KPushButton( KStdGuiItem::ok(), this );
+		okButton = new KPushButton( KStandardGuiItem::ok(), this );
 		okButton->setSizePolicy( fp );
 		okButton->setDefault( true );
 		hlay->addWidget( okButton );
@@ -138,7 +126,7 @@ KDMShutdownBase::complete( QWidget *prevWidget )
 		hlay->addStretch( 1 );
 		connect( schedButton, SIGNAL(clicked()), SLOT(slotSched()) );
 	}
-	cancelButton = new KPushButton( KStdGuiItem::cancel(), this );
+	cancelButton = new KPushButton( KStandardGuiItem::cancel(), this );
 	cancelButton->setSizePolicy( fp );
 	if (!mayOk)
 		cancelButton->setDefault( true );
@@ -147,6 +135,9 @@ KDMShutdownBase::complete( QWidget *prevWidget )
 	connect( cancelButton, SIGNAL(clicked()), SLOT(reject()) );
 
 	updateNeedRoot();
+
+	adjustSize();
+	layout()->activate();
 }
 
 void
@@ -254,10 +245,10 @@ KDMShutdown::KDMShutdown( int _uid, QWidget *_parent )
 	QSizePolicy fp( QSizePolicy::Fixed, QSizePolicy::Fixed );
 
 	QHBoxLayout *hlay = new QHBoxLayout();
-	box->addItem( hlay );
-	hlay->setSpacing( KDsh );
+	box->addLayout( hlay );
+	hlay->setParent( box );
 
-	howGroup = new Q3VButtonGroup( i18n("Shutdown Type"), this );
+	howGroup = new QGroupBox( i18n("Shutdown Type"), this );
 	hlay->addWidget( howGroup, 0, Qt::AlignTop );
 
 	QRadioButton *rb;
@@ -267,6 +258,10 @@ KDMShutdown::KDMShutdown( int _uid, QWidget *_parent )
 
 	restart_rb = new KDMRadioButton( i18n("&Restart computer"), howGroup );
 
+	QBoxLayout *hwlay = new QVBoxLayout( howGroup );
+	hwlay->addWidget( rb );
+	hwlay->addWidget( restart_rb );
+
 	connect( rb, SIGNAL(doubleClicked()), SLOT(accept()) );
 	connect( restart_rb, SIGNAL(doubleClicked()), SLOT(accept()) );
 
@@ -276,18 +271,17 @@ KDMShutdown::KDMShutdown( int _uid, QWidget *_parent )
 		char **tlist = GRecvStrArr( 0 );
 		int defaultTarget = GRecvInt();
 		oldTarget = GRecvInt();
-		QWidget *hlp = new QWidget( howGroup );
-		targets = new QComboBox( hlp );
+		targets = new QComboBox();
 		for (int i = 0; tlist[i]; i++)
 			targets->addItem( QString::fromLocal8Bit( tlist[i] ) );
 		freeStrArr( tlist );
 		targets->setCurrentIndex( oldTarget == -1 ? defaultTarget : oldTarget );
-		QHBoxLayout *hb = new QHBoxLayout( hlp );
-		hb->setSpacing( KDsh );
-		hb->setMargin( 0 );
-		int spc = kapp->style()->pixelMetric( QStyle::PM_ExclusiveIndicatorWidth )
-		          + howGroup->insideSpacing();
-		hb->addSpacing( spc );
+		QHBoxLayout *hb = new QHBoxLayout();
+		hwlay->addLayout( hb );
+		hb->setParent( hwlay );
+		hb->addSpacing(
+			style()->pixelMetric( QStyle::PM_ExclusiveIndicatorWidth )
+			+ hb->spacing() );
 		hb->addWidget( targets );
 		connect( targets, SIGNAL(activated( int )), SLOT(slotTargetChanged()) );
 	}
@@ -295,7 +289,7 @@ KDMShutdown::KDMShutdown( int _uid, QWidget *_parent )
 
 	howGroup->setSizePolicy( fp );
 
-	schedGroup = new Q3GroupBox( i18n("Scheduling"), this );
+	schedGroup = new QGroupBox( i18n("Scheduling"), this );
 	hlay->addWidget( schedGroup, 0, Qt::AlignTop );
 
 	le_start = new QLineEdit( schedGroup );
@@ -314,14 +308,11 @@ KDMShutdown::KDMShutdown( int _uid, QWidget *_parent )
 		cb_force->setEnabled( false );
 
 	QGridLayout *grid = new QGridLayout( schedGroup );
-	grid->setSpacing( KDsh );
-	grid->setMargin( KDmh );
-	grid->addRowSpacing( 0, schedGroup->fontMetrics().height() - 5 );
-	grid->addWidget( lab1, 1, 0, Qt::AlignRight );
-	grid->addWidget( le_start, 1, 1 );
-	grid->addWidget( lab2, 2, 0, Qt::AlignRight );
-	grid->addWidget( le_timeout, 2, 1 );
-	grid->addWidget( cb_force, 3, 0, 1, 2 );
+	grid->addWidget( lab1, 0, 0, Qt::AlignRight );
+	grid->addWidget( le_start, 0, 1 );
+	grid->addWidget( lab2, 1, 0, Qt::AlignRight );
+	grid->addWidget( le_timeout, 1, 1 );
+	grid->addWidget( cb_force, 2, 0, 1, 2 );
 
 	schedGroup->setSizePolicy( fp );
 
@@ -457,7 +448,6 @@ KDMDelayedPushButton::KDMDelayedPushButton( const KGuiItem &item,
 void KDMDelayedPushButton::setPopup( QMenu *p )
 {
 	pop = p;
-#warning setMenu might do more than setIsMenuButton
 	setMenu( p );
 }
 
@@ -485,32 +475,30 @@ KDMSlimShutdown::KDMSlimShutdown( QWidget *_parent )
 	, targetList( 0 )
 {
 	QHBoxLayout *hbox = new QHBoxLayout( this );
-	hbox->setSpacing( KDsh );
-	hbox->setMargin( KDmh );
 
 	QFrame *lfrm = new QFrame( this );
 	lfrm->setFrameStyle( QFrame::Panel | QFrame::Sunken );
 	hbox->addWidget( lfrm, Qt::AlignCenter );
 	QLabel *icon = new QLabel( lfrm );
 	icon->setPixmap( QPixmap( KStandardDirs::locate( "data", "kdm/pics/shutdown.jpg" ) ) );
-	QVBoxLayout *iconlay = new QVBoxLayout( lfrm );
-	iconlay->addWidget( icon );
+	icon->setFixedSize( icon->sizeHint() );
+	lfrm->setFixedSize( icon->sizeHint() );
 
-	QVBoxLayout *buttonlay = new QVBoxLayout(  );
-        hbox->addItem( buttonlay );
-	buttonlay->setSpacing( KDsh );
+	QVBoxLayout *buttonlay = new QVBoxLayout();
+	hbox->addLayout( buttonlay );
+	buttonlay->setParent( hbox );
 
 	buttonlay->addStretch( 1 );
 
 	KPushButton *btnHalt = new
-		KPushButton( KGuiItem( i18n("&Turn Off Computer"), "exit" ), this );
+	KPushButton( KGuiItem( i18n("&Turn Off Computer"), "exit" ), this );
 	buttonlay->addWidget( btnHalt );
 	connect( btnHalt, SIGNAL(clicked()), SLOT(slotHalt()) );
 
 	buttonlay->addSpacing( KDialog::spacingHint() );
 
 	KDMDelayedPushButton *btnReboot = new
-		KDMDelayedPushButton( KGuiItem( i18n("&Restart Computer"), "reload" ), this );
+	KDMDelayedPushButton( KGuiItem( i18n("&Restart Computer"), "reload" ), this );
 	buttonlay->addWidget( btnReboot );
 	connect( btnReboot, SIGNAL(clicked()), SLOT(slotReboot()) );
 
@@ -523,13 +511,14 @@ KDMSlimShutdown::KDMSlimShutdown( QWidget *_parent )
 		QMenu *targets = new QMenu( this );
 		for (int i = 0; targetList[i]; i++) {
 			QString t( QString::fromLocal8Bit( targetList[i] ) );
-			targets->insertItem( i == cur ?
-			                     i18nc("current option in boot loader",
-			                          "%1 (current)", t ) :
-			                     t, i );
+			(targets->addAction( i == cur ?
+			                     i18nc( "current option in boot loader",
+			                            "%1 (current)", t ) :
+			                     t ))->setData( i );
 		}
 		btnReboot->setPopup( targets );
-		connect( targets, SIGNAL(activated(int)), SLOT(slotReboot(int)) );
+		connect( targets, SIGNAL(triggered( QAction * )),
+		         SLOT(slotReboot( QAction * )) );
 	}
 	GSet( 0 );
 
@@ -537,7 +526,7 @@ KDMSlimShutdown::KDMSlimShutdown( QWidget *_parent )
 
 	if (_scheduledSd != SHUT_NEVER) {
 		KPushButton *btnSched = new
-			KPushButton( KGuiItem( i18n("&Schedule...") ), this );
+		KPushButton( KGuiItem( i18n("&Schedule...") ), this );
 		buttonlay->addWidget( btnSched );
 		connect( btnSched, SIGNAL(clicked()), SLOT(slotSched()) );
 
@@ -548,7 +537,7 @@ KDMSlimShutdown::KDMSlimShutdown( QWidget *_parent )
 
 	buttonlay->addSpacing( 0 );
 
-	KPushButton *btnBack = new KPushButton( KStdGuiItem::cancel(), this );
+	KPushButton *btnBack = new KPushButton( KStandardGuiItem::cancel(), this );
 	buttonlay->addWidget( btnBack );
 	connect( btnBack, SIGNAL(clicked()), SLOT(reject()) );
 
@@ -582,8 +571,9 @@ KDMSlimShutdown::slotReboot()
 }
 
 void
-KDMSlimShutdown::slotReboot( int opt )
+KDMSlimShutdown::slotReboot( QAction *action )
 {
+	int opt = action->data().toInt();
 	if (checkShutdown( SHUT_REBOOT, targetList[opt] ))
 		doShutdown( SHUT_REBOOT, targetList[opt] );
 }
@@ -627,7 +617,7 @@ KDMConfShutdown::KDMConfShutdown( int _uid, dpySpec *sess, int type, const char
 #endif
 	box->addWidget( new QLabel( QString( "<qt><center><b><nobr>"
 	                                     "%1%2"
-	                                     "</nobr></b></center><br></qt>" )
+	                                     "</nobr></b></center></qt>" )
 	                            .arg( (type == SHUT_HALT) ?
 	                                  i18n("Turn Off Computer") :
 #ifdef HAVE_VTS
@@ -652,25 +642,37 @@ KDMConfShutdown::KDMConfShutdown( int _uid, dpySpec *sess, int type, const char
 		                          i18n("No permission to abort active sessions:"),
 		                          this );
 		box->addWidget( lab );
-		Q3ListView *lv = new Q3ListView( this );
-		lv->setSelectionMode( Q3ListView::NoSelection );
+		QTreeWidget *lv = new QTreeWidget( this );
+		lv->setRootIsDecorated( false );
+		lv->setSelectionMode( QAbstractItemView::NoSelection );
 		lv->setAllColumnsShowFocus( true );
-		lv->header()->setResizeEnabled( false );
-		lv->addColumn( i18n("Session") );
-		lv->addColumn( i18n("Location") );
-		Q3ListViewItem *itm;
+		lv->setUniformRowHeights( true );
+		lv->setEditTriggers( QAbstractItemView::NoEditTriggers );
+		lv->setColumnCount( 2 );
+		lv->setHeaderLabels( QStringList() << i18n("Session") << i18n("Location") );
 		int ns = 0;
 		QString user, loc;
 		do {
 			decodeSess( sess, user, loc );
-			itm = new Q3ListViewItem( lv, user, loc );
+			new QTreeWidgetItem( lv, QStringList() << user << loc );
 			sess = sess->next, ns++;
 		} while (sess);
 		int fw = lv->frameWidth() * 2;
-		lv->setFixedHeight( fw + lv->header()->height() +
-			itm->height() * (ns < 3 ? 3 : ns > 10 ? 10 : ns) );
+		int hh = lv->header()->sizeHint().height();
+		int ih = lv->itemDelegate()->sizeHint(
+			QStyleOptionViewItem(), lv->model()->index( 0, 0 ) ).height();
+		lv->setFixedHeight( fw + hh + ih * (ns < 3 ? 3 : ns > 10 ? 10 : ns) );
 		box->addWidget( lv );
 		complete( lv );
+		int cw[2];
+		for (int i = 0; i < 2; i++)
+			cw[i] = qMax( static_cast<QAbstractItemView *>(lv)->sizeHintForColumn( i ),
+			              lv->header()->sectionSizeHint( i ) );
+		int w = lv->maximumViewportSize().width(), w2 = w / 2;
+		int m = (w < cw[0] + cw[1]) ?
+		        	(cw[0] + (w - cw[1])) / 2 :
+		        	(cw[0] > w2) ? cw[0] : (cw[1] > w2) ? (w - cw[1]) : w2;
+		lv->header()->resizeSection( 0, m );
 	} else
 		complete( 0 );
 }
