@@ -31,61 +31,41 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "themer/kdmitem.h"
 #include "themer/kdmlabel.h"
 
-#include <kapplication.h>
 #include <klocale.h>
-#include <kstandarddirs.h>
 #include <kseparator.h>
-#include <k3listview.h>
 #include <ksimpleconfig.h>
+#include <kstandarddirs.h>
 #include <kstringhandler.h>
-#include <QEventLoop>
 
-#undef Unsorted // x headers suck - make qdir.h work with --enable-final
+#include <QAction>
 #include <QDir>
 #include <QFile>
-#include <QImage>
-#include <QMovie>
-#include <QMenu>
-#include <QTimer>
-#include <q3header.h>
-#include <QStyle>
-#include <QLayout>
-#include <QLabel>
-#include <QPushButton>
-#include <QToolTip>
-#include <q3accel.h>
-#include <QEventLoop>
-#include <QSet>
-#include <QPixmap>
-#include <QEvent>
 #include <QKeyEvent>
-#include <QBoxLayout>
-#include <QHBoxLayout>
-#include <QFrame>
-#include <Q3ValueList>
-#include <QVBoxLayout>
-#include <QAbstractEventDispatcher>
-#include <q3dict.h>
+#include <QLabel>
+#include <QListWidget>
+#include <QListWidgetItem>
+#include <QMenu>
+#include <QMovie>
+#include <QPushButton>
+#include <QStyle>
 
-#include <pwd.h>
-#include <grp.h>
+#include <sys/types.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <sys/types.h>
+#include <pwd.h>
+#include <grp.h>
 
 #include <X11/Xlib.h>
 
-class UserListView : public K3ListView {
+class UserListView : public QListWidget {
   public:
 	UserListView( QWidget *parent = 0 )
-		: K3ListView( parent )
+		: QListWidget( parent )
 		, cachedSizeHint( -1, 0 )
 	{
 		setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Ignored );
-		header()->hide();
-		addColumn( QString() );
-		setColumnAlignment( 0, Qt::AlignVCenter );
-		setResizeMode( Q3ListView::LastColumn );
+		setUniformItemSizes( true );
+		setIconSize( QSize( 48, 48 ) );
 	}
 
 	mutable QSize cachedSizeHint;
@@ -95,18 +75,53 @@ class UserListView : public K3ListView {
 	{
 		if (!cachedSizeHint.isValid()) {
 			ensurePolished();
-			uint maxw = 0;
-			for (Q3ListViewItem *itm = firstChild(); itm; itm = itm->nextSibling()) {
-				uint thisw = itm->width( fontMetrics(), this, 0 );
+			QStyleOptionViewItem vo( viewOptions() );
+			QAbstractListModel *md( static_cast<QAbstractListModel *>(model()) );
+			uint maxw = 0, h = 0;
+			for (int i = 0, rc = md->rowCount(); i < rc; i++) {
+				QSize sh = itemDelegate()->sizeHint( vo, md->index( i ) );
+				uint thisw = sh.width();
 				if (thisw > maxw)
 					maxw = thisw;
+				h += sh.height();
 			}
 			cachedSizeHint.setWidth(
 				style()->pixelMetric( QStyle::PM_ScrollBarExtent ) +
 				frameWidth() * 2 + maxw );
+			cachedSizeHint.setHeight( frameWidth() * 2 + h );
 		}
 		return cachedSizeHint;
 	}
+
+	virtual void keyPressEvent( QKeyEvent *event )
+	{
+		switch (event->key()) {
+		case Qt::Key_Enter:
+		case Qt::Key_Return:
+			if (currentIndex().isValid())
+				emit activated(currentIndex());
+			event->accept();
+			break;
+		default:
+			QListWidget::keyPressEvent( event );
+			break;
+		}
+	}
+};
+
+class UserListViewItem : public QListWidgetItem {
+  public:
+	UserListViewItem( UserListView *parent, const QString &text,
+	                  const QPixmap &pixmap, const QString &username )
+		: QListWidgetItem( parent )
+		, login( username )
+	{
+		setIcon( pixmap );
+		setText( text );
+		parent->cachedSizeHint.setWidth( -1 );
+	}
+
+	QString login;
 };
 
 
@@ -120,8 +135,8 @@ KGreeter::KGreeter( bool framed )
   , userList( 0 )
   , nNormals( 0 )
   , nSpecials( 0 )
-  , curPrev( -1 )
-  , curSel( -1 )
+  , curPrev( 0 )
+  , curSel( 0 )
   , prevValid( true )
   , needLoad( false )
 {
@@ -130,9 +145,9 @@ KGreeter::KGreeter( bool framed )
 
 	if (_userList) {
 		userView = new UserListView( this );
-		connect( userView, SIGNAL(clicked( Q3ListViewItem * )),
-		         SLOT(slotUserClicked( Q3ListViewItem * )) );
-		connect( userView, SIGNAL(doubleClicked( Q3ListViewItem * )),
+		connect( userView, SIGNAL(itemPressed( QListWidgetItem * )),
+		         SLOT(slotUserClicked( QListWidgetItem * )) );
+		connect( userView, SIGNAL(itemActivated( QListWidgetItem * )),
 		         SLOT(accept()) );
 	}
 	if (_userCompletion)
@@ -141,8 +156,8 @@ KGreeter::KGreeter( bool framed )
 		insertUsers();
 
 	sessMenu = new QMenu( this );
-	connect( sessMenu, SIGNAL(activated( int )),
-	         SLOT(slotSessionSelected( int )) );
+	connect( sessMenu, SIGNAL(triggered( QAction * )),
+	         SLOT(slotSessionSelected( QAction * )) );
 	insertSessions();
 
 	if (curPlugin < 0) {
@@ -159,22 +174,6 @@ KGreeter::~KGreeter()
 	delete stsFile;
 }
 
-class UserListViewItem : public K3ListViewItem {
-  public:
-	UserListViewItem( UserListView *parent, const QString &text,
-	                  const QPixmap &pixmap, const QString &username )
-		: K3ListViewItem( parent )
-		, login( username )
-	{
-		setPixmap( 0, pixmap );
-		setMultiLinesEnabled( true );
-		setText( 0, text );
-		parent->cachedSizeHint.setWidth( -1 );
-	}
-
-	QString login;
-};
-
 void
 KGreeter::insertUser( const QImage &default_pix,
                       const QString &username, struct passwd *ps )
@@ -199,7 +198,7 @@ KGreeter::insertUser( const QImage &default_pix,
 		if (p.load( fn + ".icon" ) || p.load( fn )) {
 			QSize ns( 48, 48 );
 			if (p.size() != ns)
-				p = p.convertDepth( 32 ).scaled( ns, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+				p = p.convertToFormat( QImage::Format_RGB32 ).scaled( ns, Qt::KeepAspectRatio, Qt::SmoothTransformation );
 			goto gotit;
 		}
 		dp = 1 - dp;
@@ -207,37 +206,25 @@ KGreeter::insertUser( const QImage &default_pix,
 	p = default_pix;
   gotit:
 	QString realname = KStringHandler::from8Bit( ps->pw_gecos );
-	realname.truncate( realname.indexOf( ',' ) );
+	realname.truncate( realname.indexOf( ',' ) & (~0U >> 1) );
 	if (realname.isEmpty() || realname == username)
-                new UserListViewItem( userView, username, QPixmap::fromImage( p ), username );
+		new UserListViewItem( userView, username, QPixmap::fromImage( p ), username );
 	else {
 		realname.append( "\n" ).append( username );
 		new UserListViewItem( userView, realname, QPixmap::fromImage( p ), username );
 	}
 }
 
-class KCStringList : public Q3ValueList<QByteArray> {
-  public:
-	bool contains( const char *str ) const
-	{
-		for (ConstIterator it = begin(); it != end(); ++it)
-			if (*it == str)
-				return true;
-		return false;
-	}
-};
-
 class UserList {
   public:
 	UserList( char **in );
 	bool hasUser( const char *str ) const { return users.contains( str ); }
-	bool hasGroup( gid_t gid ) const
-		{ return groups.find( gid ) != groups.end(); }
+	bool hasGroup( gid_t gid ) const { return groups.contains( gid ); }
 	bool hasGroups() const { return !groups.isEmpty(); }
-	KCStringList users;
 
   private:
-	Q3ValueList<gid_t> groups;
+	QSet<gid_t> groups;
+	QSet<QByteArray> users;
 };
 
 UserList::UserList( char **in )
@@ -248,11 +235,11 @@ UserList::UserList( char **in )
 		if (**in == '@') {
 			if ((grp = getgrnam( *in + 1 ))) {
 				for (; *grp->gr_mem; grp->gr_mem++)
-					users.append( *grp->gr_mem );
-				groups.append( grp->gr_gid );
+					users.insert( *grp->gr_mem );
+				groups.insert( grp->gr_gid );
 			}
 		} else
-			users.append( *in );
+			users.insert( *in );
 }
 
 void
@@ -263,12 +250,12 @@ KGreeter::insertUsers()
 	// XXX remove seteuid-voodoo when we run as nobody
 	if (!(ps = getpwnam( "nobody" )))
 		return;
-        if (setegid( ps->pw_gid )) 
-                return;
-        if (seteuid( ps->pw_uid )) {
-                setegid(0);
-                return;
-        }
+	if (setegid( ps->pw_gid ))
+		return;
+	if (seteuid( ps->pw_uid )) {
+		setegid( 0 );
+		return;
+	}
 
 	QImage default_pix;
 	if (userView) {
@@ -278,7 +265,7 @@ KGreeter::insertUsers()
 		QSize ns( 48, 48 );
 		if (default_pix.size() != ns)
 			default_pix =
-			  default_pix.convertDepth( 32 ).scaled( ns, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+			  default_pix.convertToFormat( QImage::Format_RGB32 ).scaled( ns, Qt::KeepAspectRatio, Qt::SmoothTransformation );
 	}
 	if (_showUsers == SHOW_ALL) {
 		UserList noUsers( _noUsers );
@@ -318,24 +305,22 @@ KGreeter::insertUsers()
 				}
 			}
 		} else {
-			KCStringList::ConstIterator it = users.users.begin();
-			for (; it != users.users.end(); ++it)
-				if ((ps = getpwnam( (*it).data() )) &&
-				    (ps->pw_uid || _showRoot))
-					insertUser( default_pix, QFile::decodeName( *it ), ps );
+			for (int i = 0; _users[i]; i++)
+				if ((ps = getpwnam( _users[i] )) && (ps->pw_uid || _showRoot))
+					insertUser( default_pix, QFile::decodeName( _users[i] ), ps );
 		}
 	}
 	endpwent();
 	if (_sortUsers) {
 		if (userView)
-			userView->sort();
+			userView->sortItems();
 		if (userList)
 			userList->sort();
 	}
 
 	// XXX remove seteuid-voodoo when we run as nobody
 	seteuid( 0 );
-        setegid( 0 );
+	setegid( 0 );
 }
 
 void
@@ -355,26 +340,26 @@ KGreeter::putSession( const QString &type, const QString &name, bool hid, const
 void
 KGreeter::insertSessions()
 {
-	for (char **dit = _sessionsDirs; *dit; ++dit) {
-		QStringList ents = QDir( *dit ).entryList();
-		for (QStringList::ConstIterator it = ents.begin(); it != ents.end(); ++it)
-			if ((*it).endsWith( ".desktop" )) {
-				KSimpleConfig dsk( QString( *dit ).append( '/' ).append( *it ) );
+	for (char **dit = _sessionsDirs; *dit; ++dit)
+		foreach (QString ent, QDir( *dit ).entryList())
+			if (ent.endsWith( ".desktop" )) {
+				KSimpleConfig dsk( QString( *dit ).append( '/' ).append( ent ) );
 				dsk.setGroup( "Desktop Entry" );
-				putSession( (*it).left( (*it).length() - 8 ),
+				putSession( ent.left( ent.length() - 8 ),
 				            dsk.readEntry( "Name" ),
-				            (dsk.readEntry( "Hidden", QVariant(false )).toBool() ||
+				            (dsk.readEntry( "Hidden", false ) ||
 				             (dsk.hasKey( "TryExec" ) &&
 				              KStandardDirs::findExe( dsk.readEntry( "TryExec" ) ).isEmpty())),
 				            dsk.readEntry( "Exec" ).toLatin1() );
 			}
-	}
 	putSession( "default", i18n("Default"), false, "default" );
 	putSession( "custom", i18n("Custom"), false, "custom" );
 	putSession( "failsafe", i18n("Failsafe"), false, "failsafe" );
 	qSort( sessionTypes );
 	for (int i = 0; i < sessionTypes.size() && !sessionTypes[i].hid; i++) {
-		sessMenu->insertItem( sessionTypes[i].name, i );
+		sessionTypes[i].action = sessMenu->addAction( sessionTypes[i].name );
+		sessionTypes[i].action->setData( i );
+		sessionTypes[i].action->setCheckable( true );
 		switch (sessionTypes[i].prio) {
 		case 0: case 1: nSpecials++; break;
 		case 2: nNormals++; break;
@@ -386,13 +371,14 @@ void
 KGreeter::slotUserEntered()
 {
 	if (userView) {
-		Q3ListViewItem *item;
-		for (item = userView->firstChild(); item; item = item->nextSibling())
-			if (((UserListViewItem *)item)->login == curUser) {
-				userView->setSelected( item, true );
-				userView->ensureItemVisible( item );
+		for (int i = 0, rc = userView->model()->rowCount(); i < rc; i++) {
+			UserListViewItem *item =
+				static_cast<UserListViewItem *>(userView->item( i ));
+			if (item->login == curUser) {
+				userView->setCurrentItem( item );
 				goto oke;
 			}
+		}
 		userView->clearSelection();
 	}
   oke:
@@ -403,7 +389,7 @@ KGreeter::slotUserEntered()
 }
 
 void
-KGreeter::slotUserClicked( Q3ListViewItem *item )
+KGreeter::slotUserClicked( QListWidgetItem *item )
 {
 	if (item) {
 		curUser = ((UserListViewItem *)item)->login;
@@ -413,12 +399,14 @@ KGreeter::slotUserClicked( Q3ListViewItem *item )
 }
 
 void
-KGreeter::slotSessionSelected( int id )
+KGreeter::slotSessionSelected( QAction *action )
 {
-	if (id != curSel) {
-		sessMenu->setItemChecked( curSel, false );
-		sessMenu->setItemChecked( id, true );
-		curSel = id;
+	if (action != curSel) {
+		if (curSel)
+			curSel->setChecked( false );
+		if (action)
+			action->setChecked( true );
+		curSel = action;
 		verify->gplugActivity();
 	}
 }
@@ -439,13 +427,13 @@ KGreeter::accept()
 }
 
 void // private
-KGreeter::setPrevWM( int wm )
+KGreeter::setPrevWM( QAction *wm )
 {
 	if (curPrev != wm) {
-		if (curPrev != -1)
-			sessMenu->changeItem( curPrev, sessionTypes[curPrev].name );
-		if (wm != -1)
-			sessMenu->changeItem( wm, sessionTypes[wm].name + i18n(" (previous)") );
+		if (curPrev)
+			curPrev->setText( sessionTypes[curPrev->data().toInt()].name );
+		if (wm)
+			wm->setText( sessionTypes[wm->data().toInt()].name + i18n(" (previous)") );
 		curPrev = wm;
 	}
 }
@@ -486,13 +474,13 @@ KGreeter::slotLoadPrevWM()
 				/* forge a session with this hash - default & custom more probable */
 				/* XXX - this should do a statistical analysis of the real users */
 #if 1
-				setPrevWM( crc % (nSpecials * 2 + nNormals) % (nSpecials + nNormals) );
+				setPrevWM( sessionTypes[crc % (nSpecials * 2 + nNormals) % (nSpecials + nNormals)].action );
 #else
 				i = crc % (nSpecials * 2 + nNormals);
 				if (i < nNormals)
-					setPrevWM( i + nSpecials );
+					setPrevWM( sessionTypes[i + nSpecials].action );
 				else
-					setPrevWM( (i - nNormals) / 2 );
+					setPrevWM( sessionTypes[(i - nNormals) / 2].action );
 #endif
 				return;
 			}
@@ -500,17 +488,17 @@ KGreeter::slotLoadPrevWM()
 			for (int i = 0; i < sessionTypes.count() && !sessionTypes[i].hid; i++)
 				if (sessionTypes[i].type == sess) {
 					free( sess );
-					setPrevWM( i );
+					setPrevWM( sessionTypes[i].action );
 					return;
 				}
-			if (curSel == -1)
+			if (!curSel)
 				MsgBox( sorrybox, i18n("Your saved session type '%1' is not valid any more.\n"
 				                       "Please select a new one, otherwise 'default' will be used.", sess ) );
 			free( sess );
 			prevValid = false;
 		}
 	}
-	setPrevWM( -1 );
+	setPrevWM( 0 );
 }
 
 void // protected
@@ -550,7 +538,7 @@ KGreeter::verifyClear()
 {
 	curUser.clear();
 	slotUserEntered();
-	slotSessionSelected( -1 );
+	slotSessionSelected( 0 );
 }
 
 void
@@ -561,10 +549,10 @@ KGreeter::verifyOk()
 		                       dName :
 		                       dName + '_' + verify->pluginName(),
 		                     verify->getEntity() );
-	if (curSel != -1) {
+	if (curSel) {
 		GSendInt( G_PutDmrc );
 		GSendStr( "Session" );
-		GSendStr( sessionTypes[curSel].type.toUtf8() );
+		GSendStr( sessionTypes[curSel->data().toInt()].type.toUtf8() );
 	} else if (!prevValid) {
 		GSendInt( G_PutDmrc );
 		GSendStr( "Session" );
@@ -577,10 +565,19 @@ KGreeter::verifyOk()
 void
 KGreeter::verifyFailed()
 {
+	if (userView)
+		userView->setEnabled( false );
 	if (needLoad)
 		slotLoadPrevWM();
 }
 
+void
+KGreeter::verifyRetry()
+{
+	if (userView)
+		userView->setEnabled( true );
+}
+
 void
 KGreeter::verifySetUser( const QString &user )
 {
@@ -597,68 +594,67 @@ KStdGreeter::KStdGreeter()
 	QBoxLayout *main_box;
 #ifdef WITH_KDM_XCONSOLE
 	if (consoleView) {
-            QBoxLayout *ex_box = new QVBoxLayout( this );
-            ex_box->setSpacing( 10 );
-            ex_box->setMargin( 10 );
-            main_box = new QHBoxLayout( ex_box );
-            main_box->setMargin( 10 );
-            ex_box->addWidget( consoleView );
+		QBoxLayout *ex_box = new QVBoxLayout( this );
+		main_box = new QHBoxLayout();
+		ex_box->addLayout( main_box );
+		main_box->setParent( ex_box );
+		ex_box->addWidget( consoleView );
 	} else
 #endif
-        {
-            main_box = new QHBoxLayout( this );
-            main_box->setMargin( 10 );
-            main_box->setSpacing( 10 );
-        }
+	{
+		main_box = new QHBoxLayout( this );
+	}
+	int rs = main_box->spacing();
+	main_box->setSpacing( main_box->margin() );
 
-	if (userView)
+	if (userView) {
+		userView->setAlternatingRowColors( true );
 		main_box->addWidget( userView );
+	}
 
-	QBoxLayout *inner_box = new QVBoxLayout(  );
-        main_box->addItem( inner_box );
-        inner_box->setMargin( 10 );
+	QBoxLayout *inner_box = new QVBoxLayout();
+	main_box->addLayout( inner_box );
+	inner_box->setParent( main_box );
+	inner_box->setSpacing( rs );
 
 	if (!_authorized && _authComplain) {
 		QLabel *complainLabel = new QLabel(
 			i18n("Warning: this is an unsecured session"), this );
 		complainLabel->setToolTip(
-		               i18n("This display requires no X authorization.\n"
-		                    "This means that anybody can connect to it,\n"
-		                    "open windows on it or intercept your input.") );
+			i18n("This display requires no X authorization.\n"
+			     "This means that anybody can connect to it,\n"
+			     "open windows on it or intercept your input.") );
 		complainLabel->setAlignment( Qt::AlignCenter );
-		complainLabel->setFont( _failFont );
-		complainLabel->setPaletteForegroundColor( Qt::red );
+		complainLabel->setFont( *_failFont );
+		QPalette p;
+		p.setColor( QPalette::WindowText, Qt::red );
+		complainLabel->setPalette( p );
 		inner_box->addWidget( complainLabel );
 	}
 	if (!_greetString.isEmpty()) {
 		QLabel *welcomeLabel = new QLabel( _greetString, this );
 		welcomeLabel->setAlignment( Qt::AlignCenter );
-		welcomeLabel->setFont( _greetFont );
+		welcomeLabel->setFont( *_greetFont );
 		inner_box->addWidget( welcomeLabel );
 	}
 
 	switch (_logoArea) {
 		case LOGO_CLOCK:
-			clock = new KdmClock( this, "clock" );
+			clock = new KdmClock( this );
 			break;
 		case LOGO_LOGO:
 			{
-				QMovie movie( _logo );
-				QAbstractEventDispatcher::instance()->processEvents( QEventLoop::ExcludeUserInput | QEventLoop::ExcludeSocketNotifiers );
-				QPixmap pixmap;
-				if (!movie.framePixmap().isNull() || pixmap.load( _logo )) {
+				QMovie *movie = new QMovie( this );
+				movie->setFileName( _logo );
+				if (movie->isValid()) {
+					movie->start();
 					pixLabel = new QLabel( this );
-					if (!movie.framePixmap().isNull()) {
-						pixLabel->setMovie( &movie );
-						if (!movie.framePixmap().hasAlpha())
-							pixLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
-					} else {
-						pixLabel->setPixmap( pixmap );
-						if (!pixmap.hasAlpha())
-							pixLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
-					}
+					pixLabel->setMovie( movie );
+					if (!movie->currentImage().hasAlphaChannel())
+						pixLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
 					pixLabel->setIndent( 0 );
-				}
+				} else
+					delete movie;
 			}
 			break;
 	}
@@ -668,6 +664,7 @@ KStdGreeter::KStdGreeter()
 			inner_box->addWidget( clock, 0, Qt::AlignCenter );
 		else if (pixLabel)
 			inner_box->addWidget( pixLabel, 0, Qt::AlignCenter );
+		inner_box->addSpacing( inner_box->spacing() );
 	} else {
 		if (clock)
 			main_box->addWidget( clock, 0, Qt::AlignCenter );
@@ -695,25 +692,26 @@ KStdGreeter::KStdGreeter()
 		                 pluginList, KGreeterPlugin::Authenticate,
 		                 KGreeterPlugin::Login );
 	inner_box->addLayout( sverify->getLayout() );
+	sverify->getLayout()->setParent( inner_box );
+	QMenu *plugMenu = sverify->getPlugMenu();
 	sverify->selectPlugin( curPlugin );
 	verify = sverify;
 
 	inner_box->addWidget( new KSeparator( Qt::Horizontal, this ) );
 
 	QBoxLayout *hbox2 = new QHBoxLayout();
-	inner_box->addItem( hbox2 );
-	hbox2->setSpacing( 10 );
+	inner_box->addLayout( hbox2 );
+	hbox2->setParent( inner_box );
 	hbox2->addWidget( goButton );
 	hbox2->addStretch( 1 );
 	hbox2->addWidget( menuButton );
 	hbox2->addStretch( 1 );
 
-	if (sessMenu->count() > 1) {
+	if (sessMenu->actions().count() > 1) {
 		inserten( i18n("Session &Type"), Qt::ALT+Qt::Key_T, sessMenu );
 		needSep = true;
 	}
 
-	QMenu *plugMenu = verify->getPlugMenu();
 	if (plugMenu) {
 		inserten( i18n("&Authentication Method"), Qt::ALT+Qt::Key_A, plugMenu );
 		needSep = true;
@@ -726,7 +724,7 @@ KStdGreeter::KStdGreeter()
 #endif
 
 	if (optMenu)
-		menuButton->setPopup( optMenu );
+		menuButton->setMenu( optMenu );
 	else
 		menuButton->hide();
 
@@ -753,8 +751,6 @@ void
 KStdGreeter::verifyFailed()
 {
 	goButton->setEnabled( false );
-	if (userView)
-		userView->setEnabled( false );
 	inherited::verifyFailed();
 }
 
@@ -762,28 +758,23 @@ void
 KStdGreeter::verifyRetry()
 {
 	goButton->setEnabled( true );
-	if (userView)
-		userView->setEnabled( true );
+	inherited::verifyRetry();
 }
 
 
-KThemedGreeter::KThemedGreeter()
+KThemedGreeter::KThemedGreeter( KdmThemer *_themer )
 	: KGreeter( true )
-	, themer( 0 )
+	, themer( _themer )
 //	, clock( 0 )
 {
 	// We do all painting ourselves
-	setAttribute(Qt::WA_NoSystemBackground, true);
+	setAttribute( Qt::WA_NoSystemBackground, true );
 	// Allow tracking the mouse position
 	setMouseTracking( true );
 
 	adjustGeometry();
 
-	themer = new KdmThemer( _theme, "console", this );
-	if (!themer->isOK()) {
-		themer = 0;
-		return;
-	}
+	themer->setWidget( this );
 
 	connect( themer, SIGNAL(activated( const QString & )),
 	         SLOT(slotThemeActivated( const QString & )) );
@@ -793,27 +784,28 @@ KThemedGreeter::KThemedGreeter()
 	caps_warning = themer->findNode( "caps-lock-warning" );
 	xauth_warning = themer->findNode( "xauth-warning" ); // kdm ext
 	pam_error = themer->findNode( "pam-error" );
+	KdmLabel *pam_error_label = qobject_cast<KdmLabel *>(pam_error);
+	if (pam_error_label)
+		pam_error_label->setText( i18n("Login Failed.") );
 	timed_label = themer->findNode( "timed-label" );
-	if (pam_error && pam_error->isA( "KdmLabel" ))
-		static_cast<KdmLabel*>(pam_error)->setText( i18n("Login Failed.") );
 
 	KdmItem *itm;
 	if ((itm = themer->findNode( "pam-message" ))) // done via msgboxes
-		itm->hide( true );
+		itm->setVisible( false );
 	if ((itm = themer->findNode( "language_button" ))) // not implemented yet
-		itm->hide( true );
+		itm->setVisible( false );
 
 #ifdef WITH_KDM_XCONSOLE
 	if (console_rect) {
 		if (consoleView)
 			console_rect->setWidget( consoleView );
 		else
-			console_rect->hide( true );
+			console_rect->setVisible( false );
 	}
 #endif
 
 	if (xauth_warning && (_authorized || !_authComplain))
-		xauth_warning->hide( true );
+		xauth_warning->setVisible( false );
 
 //	if (!_greetString.isEmpty()) {
 //	}
@@ -832,27 +824,22 @@ KThemedGreeter::KThemedGreeter()
 		new KGThemedVerify( this, themer, this, prec, QString(),
 		                    pluginList, KGreeterPlugin::Authenticate,
 		                    KGreeterPlugin::Login );
+	QMenu *plugMenu = tverify->getPlugMenu();
 	tverify->selectPlugin( curPlugin );
 	verify = tverify;
 
-	session_button = 0;
-	if ((itm = themer->findNode( "session_button" ))) {
-		if (sessMenu->count() <= 1)
-			itm->hide( true );
-		else {
-			session_button = itm;
-			Q3Accel *accel = new Q3Accel( this );
-			accel->insertItem( Qt::ALT+Qt::Key_T, 0 );
-			connect( accel, SIGNAL(activated( int )), SLOT(slotSessMenu()) );
+	if ((session_button = themer->findNode( "session_button" ))) {
+		if (sessMenu->actions().count() <= 1) {
+			session_button->setVisible( false );
+			session_button = 0;
 		}
 	} else {
-		if (sessMenu->count() > 1) {
+		if (sessMenu->actions().count() > 1) {
 			inserten( i18n("Session &Type"), Qt::ALT+Qt::Key_T, sessMenu );
 			needSep = true;
 		}
 	}
 
-	QMenu *plugMenu = verify->getPlugMenu();
 	if (plugMenu) {
 		inserten( i18n("&Authentication Method"), Qt::ALT+Qt::Key_A, plugMenu );
 		needSep = true;
@@ -864,16 +851,23 @@ KThemedGreeter::KThemedGreeter()
 	completeMenu();
 #endif
 
-	system_button = themer->findNode( "system_button" );
-	Q3Accel *accel = new Q3Accel( this );
-	accel->insertItem( Qt::ALT+Qt::Key_M, 0 );
-	connect( accel, SIGNAL(activated( int )), SLOT(slotActionMenu()) );
+	if ((system_button = themer->findNode( "system_button" ))) {
+		if (optMenu)
+			addAction( optMenu->menuAction() );
+		else
+			system_button->setVisible( false );
+	}
 
 	pluginSetup();
 
 	verify->start();
 }
 
+KThemedGreeter::~KThemedGreeter()
+{
+	themer->setWidget( 0 );
+}
+
 bool
 KThemedGreeter::event( QEvent *e )
 {
@@ -889,17 +883,16 @@ KThemedGreeter::pluginSetup()
 
 	if (userView && verify->entitiesLocal() && verify->entityPresettable() && userlist_rect) {
 		userlist_rect->setWidget( userView );
-		userView->show();
+		userlist_rect->setVisible( true );
 	} else {
 		if (userView)
 			userView->hide();
 		if (userlist_rect)
-			userlist_rect->hide( true );
+			userlist_rect->setVisible( false );
 	}
-
-	update();
 }
 
+#if 0
 void
 KThemedGreeter::verifyFailed()
 {
@@ -911,37 +904,28 @@ void
 KThemedGreeter::verifyRetry()
 {
 //	goButton->setEnabled( true );
+	inherited::verifyRetry();
 }
-
-QString KThemedGreeter::timedUser = QString();
-int KThemedGreeter::timedDelay = -1;
+#endif
 
 void
 KThemedGreeter::updateStatus( bool fail, bool caps, int timedleft )
 {
-	if (pam_error) {
-		if (fail)
-			pam_error->show( true );
-		else
-			pam_error->hide( true );
-	}
-	if (caps_warning) {
-		if (caps)
-			caps_warning->show( true );
-		else
-			caps_warning->hide( true );
-	}
+	if (pam_error)
+		pam_error->setVisible( fail );
+	if (caps_warning)
+		caps_warning->setVisible( caps );
 	if (timed_label) {
 		if (timedleft) {
-			if (timedleft != timedDelay) {
-				timedDelay = timedleft;
-				timedUser = curUser;
-				timed_label->show( true );
+			if (timedleft != KdmLabel::timedDelay) {
+				KdmLabel::timedDelay = timedleft;
+				KdmLabel::timedUser = curUser;
+				timed_label->setVisible( true );
 				timed_label->update();
 			}
 		} else {
-			timedDelay = -1;
-			timed_label->hide( true );
+			KdmLabel::timedDelay = -1;
+			timed_label->setVisible( false );
 		}
 	}
 }
@@ -976,7 +960,7 @@ void
 KThemedGreeter::keyPressEvent( QKeyEvent *e )
 {
 	inherited::keyPressEvent( e );
-	if (!(e->state() & Qt::KeyboardModifierMask) &&
+	if (!(e->modifiers() & Qt::KeyboardModifierMask) &&
 	    (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter))
 		accept();
 }
