@@ -31,34 +31,24 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "themer/kdmthemer.h"
 #include "themer/kdmitem.h"
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <klibloader.h>
-#include <kseparator.h>
 #include <kguiitem.h>
-#include <kstdguiitem.h>
+#include <klibloader.h>
+#include <klocale.h>
 #include <kpushbutton.h>
+#include <krandom.h>
+#include <kseparator.h>
+#include <KStandardGuiItem>
 
-#include <QRegExp>
-#include <QMenu>
-#include <QLayout>
-#include <QFile>
-#include <QLabel>
-//Added by qt3to4:
-#include <QGridLayout>
+#include <QAction>
+#include <QApplication>
 #include <QEvent>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
-
-#include <pwd.h>
-#include <sys/types.h>
-#include <stdlib.h>
-#include <unistd.h>
+#include <QKeyEvent>
+#include <QLabel>
+#include <QMenu>
+#include <QX11Info>
 
 #include <X11/Xlib.h> // for updateLockStatus()
 #include <fixx11h.h> // ... and make eventFilter() work again
-#include <QX11Info>
-#include <krandom.h>
 
 #define FULL_GREET_TO 40 // normal inactivity timeout
 #define TIMED_GREET_TO 20 // inactivity timeout when persisting timed login
@@ -74,7 +64,7 @@ void KGVerifyHandler::updateStatus( bool, bool, int )
 {
 }
 
-KGVerify::KGVerify( KGVerifyHandler *_handler, KdmThemer *_themer,
+KGVerify::KGVerify( KGVerifyHandler *_handler,
                     QWidget *_parent, QWidget *_predecessor,
                     const QString &_fixedUser,
                     const PluginList &_pluginList,
@@ -85,7 +75,6 @@ KGVerify::KGVerify( KGVerifyHandler *_handler, KdmThemer *_themer,
 	, fixedEntity( _fixedUser )
 	, pluginList( _pluginList )
 	, handler( _handler )
-	, themer( _themer )
 	, parent( _parent )
 	, predecessor( _predecessor )
 	, plugMenu( 0 )
@@ -100,7 +89,7 @@ KGVerify::KGVerify( KGVerifyHandler *_handler, KdmThemer *_themer,
 	, isClear( true )
 {
 	connect( &timer, SIGNAL(timeout()), SLOT(slotTimeout()) );
-	connect( kapp, SIGNAL(activity()), SLOT(slotActivity()) );
+	connect( qApp, SIGNAL(activity()), SLOT(slotActivity()) );
 
 	_parent->installEventFilter( this );
 }
@@ -119,10 +108,14 @@ KGVerify::getPlugMenu()
 		uint np = pluginList.count();
 		if (np > 1) {
 			plugMenu = new QMenu( parent );
-			connect( plugMenu, SIGNAL(activated( int )),
-			         SLOT(slotPluginSelected( int )) );
-			for (uint i = 0; i < np; i++)
-				plugMenu->insertItem( i18n(greetPlugins[pluginList[i]].info->name), pluginList[i] );
+			connect( plugMenu, SIGNAL(triggered( QAction * )),
+			         SLOT(slotPluginSelected( QAction * )) );
+			for (uint i = 0; i < np; i++) {
+				int pid = pluginList[i];
+				greetPlugins[pid].action = plugMenu->addAction( i18n(greetPlugins[pid].info->name) );
+				greetPlugins[pid].action->setData( i );
+				greetPlugins[pid].action->setCheckable( true );
+			}
 		}
 	}
 	return plugMenu;
@@ -158,24 +151,22 @@ KGVerify::pluginName() const
 	QString name( greetPlugins[pluginList[curPlugin]].library->fileName() );
 	uint st = name.lastIndexOf( '/' ) + 1;
 	uint en = name.indexOf( '.', st );
-	if (en - st > 7 && QConstString( name.unicode() + st, 7 ).string() == "kgreet_")
+	if (en - st > 7 && QString::fromRawData( name.unicode() + st, 7 ) == QLatin1String("kgreet_"))
 		st += 7;
 	return name.mid( st, en - st );
 }
 
 static void
-showWidgets( QLayoutItem *li )
+setTabOrder( QWidget *&pred, const QObjectList &list)
 {
-	QWidget *w;
-	QLayout *l;
-
-	if ((w = li->widget()))
-		w->show();
-	else if ((l = li->layout())) {
-		QLayoutIterator it = l->iterator();
-		for (QLayoutItem *itm = it.current(); itm; itm = ++it)
-			 showWidgets( itm );
-	}
+	foreach (QObject *o, list)
+		if (QWidget *w = qobject_cast<QWidget *>(o)) {
+			if (w->focusPolicy() & Qt::TabFocus) {
+				QWidget::setTabOrder( pred, w );
+				pred = w;
+			} else
+				setTabOrder( pred, o->children() );
+		}
 }
 
 void // public
@@ -187,13 +178,34 @@ KGVerify::selectPlugin( int id )
 	}
 	curPlugin = id;
 	if (plugMenu)
-		plugMenu->setItemChecked( id, true );
+		greetPlugins[pluginList[id]].action->setChecked( true );
 	pName = ("greet_" + pluginName()).toLatin1();
 	Debug( "new %s\n", pName.data() );
-	greet = greetPlugins[pluginList[id]].info->create( this, themer, parent, predecessor, fixedEntity, func, ctx );
+	greet = greetPlugins[pluginList[id]].info->create( this, parent, fixedEntity, func, ctx );
+	if (QWidget *pred = predecessor)
+		setTabOrder( pred, *(const QObjectList *)&greet->getWidgets() );
 	timeable = _autoLoginDelay && entityPresettable() && isClassic();
 }
 
+void // private slot
+KGVerify::slotPluginSelected( QAction *action )
+{
+	if (failed)
+		return;
+	int id = action->data().toInt();
+	if (id != curPlugin) {
+		greetPlugins[pluginList[curPlugin]].action->setChecked( false );
+		parent->setUpdatesEnabled( false );
+		Debug( "delete %s\n", pName.data() );
+		delete greet;
+		selectPlugin( id );
+		handler->verifyPluginChanged( id );
+		if (running)
+			start();
+		parent->setUpdatesEnabled( true );
+	}
+}
+
 void // public
 KGVerify::loadUsers( const QStringList &users )
 {
@@ -281,7 +293,7 @@ KGVerify::start()
 {
 	authTok = (func == KGreeterPlugin::ChAuthTok);
 	cont = false;
-	if (func == KGreeterPlugin::Authenticate) {
+	if (func == KGreeterPlugin::Authenticate && ctx == KGreeterPlugin::Login) {
 		if (scheduleAutoLogin( true )) {
 			if (!_autoLoginAgain)
 				_autoLoginDelay = 0, timeable = false;
@@ -487,7 +499,7 @@ KGVerify::VInfoBox( QWidget *parent, const QString &user, const char *msg )
 		int expire = rx.cap( 1 ).toInt();
 		mesg = expire ?
 			i18np("Your account expires tomorrow.",
-			     "Your account expires in %n days.", expire) :
+			      "Your account expires in %1 days.", expire) :
 			i18n("Your account expires today.");
 	} else {
 		rx.setPattern( "^Warning: your password will expire in (\\d+) day" );
@@ -495,7 +507,7 @@ KGVerify::VInfoBox( QWidget *parent, const QString &user, const char *msg )
 			int expire = rx.cap( 1 ).toInt();
 			mesg = expire ?
 				i18np("Your password expires tomorrow.",
-				     "Your password expires in %n days.", expire) :
+				      "Your password expires in %1 days.", expire) :
 				i18n("Your password expires today.");
 		}
 	}
@@ -523,16 +535,15 @@ KGVerify::handleFailVerify( QWidget *parent )
 			{
 				QStringList pgs( _pluginsLogin );
 				pgs += _pluginsShutdown;
-				QStringList::ConstIterator it;
-				for (it = pgs.begin(); it != pgs.end(); ++it)
-					if (*it == "classic" || *it == "modern") {
-						pgs = QStringList(*it);
+				foreach (QString pg, pgs)
+					if (pg == "classic" || pg == "modern") {
+						pgs = QStringList( pg );
 						goto gotit;
-					} else if (*it == "generic") {
-						pgs = QStringList("modern");
+					} else if (pg == "generic") {
+						pgs = QStringList( "modern" );
 						goto gotit;
 					}
-				pgs = QStringList("classic");
+				pgs = QStringList( "classic" );
 			  gotit:
 				KGChTok chtok( parent, user, init( pgs ), 0,
 				               KGreeterPlugin::AuthChAuthTok,
@@ -701,7 +712,7 @@ KGVerify::handleVerify()
 					greet->failed();
 					MsgBox( sorrybox,
 					        i18n("Authenticated user (%1) does not match requested user (%2).\n",
-					          ent, fixedEntity ) );
+					             ent, fixedEntity ) );
 					goto retry;
 				}
 			}
@@ -769,7 +780,7 @@ KGVerify::gplugReturnBinary( const char *data )
 void
 KGVerify::gplugSetUser( const QString &user )
 {
-    Debug( "%s: gplugSetUser(%\"s)\n", pName.data(), qPrintable( user ) );
+	Debug( "%s: gplugSetUser(%\"s)\n", pName.data(), qPrintable( user ) );
 	curUser = user;
 	handler->verifySetUser( user );
 }
@@ -800,7 +811,7 @@ KGVerify::gplugActivity()
 void
 KGVerify::gplugMsgBox( QMessageBox::Icon type, const QString &text )
 {
-    Debug( "%s: gplugMsgBox(%d, %\"s)\n", pName.data(), type, qPrintable( text ) );
+	Debug( "%s: gplugMsgBox(%d, %\"s)\n", pName.data(), type, qPrintable( text ) );
 	MsgBox( type, text );
 }
 
@@ -858,10 +869,9 @@ KGVerify::getConf( void *, const char *key, const QVariant &dflt )
 		return QVariant( _echoMode );
 	else {
 		QString fkey = QString::fromLatin1( key ) + '=';
-		for (QStringList::ConstIterator it = _pluginOptions.begin();
-		     it != _pluginOptions.end(); ++it)
-			if ((*it).startsWith( fkey ))
-				return (*it).mid( fkey.length() );
+		foreach (QString pgo, _pluginOptions)
+			if (pgo.startsWith( fkey ))
+				return pgo.mid( fkey.length() );
 		return dflt;
 	}
 }
@@ -873,12 +883,12 @@ KGVerify::init( const QStringList &plugins )
 {
 	PluginList pluginList;
 
-	for (QStringList::ConstIterator it = plugins.begin(); it != plugins.end(); ++it) {
+	foreach (QString pg, plugins) {
 		GreeterPluginHandle plugin;
 		QString path = KLibLoader::self()->findLibrary(
-			((*it)[0] == '/' ? *it : "kgreet_" + *it ).toLatin1() );
+			(pg[0] == '/' ? pg : "kgreet_" + pg ).toLatin1() );
 		if (path.isEmpty()) {
-                    LogError( "GreeterPlugin %s does not exist\n", qPrintable( *it ) );
+                    LogError( "GreeterPlugin %s does not exist\n", qPrintable( pg ) );
 			continue;
 		}
 		uint i, np = greetPlugins.count();
@@ -886,23 +896,23 @@ KGVerify::init( const QStringList &plugins )
 			if (greetPlugins[i].library->fileName() == path)
 				goto next;
 		if (!(plugin.library = KLibLoader::self()->library( path.toLatin1() ))) {
-                    LogError( "Cannot load GreeterPlugin %s (%s)\n", qPrintable( *it ), qPrintable( path ) );
+                    LogError( "Cannot load GreeterPlugin %s (%s)\n", qPrintable( pg ), qPrintable( path ) );
 			continue;
 		}
 		if (!plugin.library->hasSymbol( "kgreeterplugin_info" )) {
 			LogError( "GreeterPlugin %s (%s) is no valid greet widget plugin\n",
-			          qPrintable( *it ), qPrintable( path ) );
+			          qPrintable( pg ), qPrintable( path ) );
 			plugin.library->unload();
 			continue;
 		}
 		plugin.info = (kgreeterplugin_info*)plugin.library->symbol( "kgreeterplugin_info" );
 		if (!plugin.info->init( QString(), getConf, 0 )) {
 			LogError( "GreeterPlugin %s (%s) refuses to serve\n",
-			          qPrintable( *it ), qPrintable( path ) );
+			          qPrintable( pg ), qPrintable( path ) );
 			plugin.library->unload();
 			continue;
 		}
-		Debug( "GreeterPlugin %s (%s) loaded\n", qPrintable( *it ), plugin.info->name );
+		Debug( "GreeterPlugin %s (%s) loaded\n", qPrintable( pg ), plugin.info->name );
 		greetPlugins.append( plugin );
 	  next:
 		pluginList.append( i );
@@ -926,7 +936,7 @@ KGStdVerify::KGStdVerify( KGVerifyHandler *_handler, QWidget *_parent,
                           const PluginList &_pluginList,
                           KGreeterPlugin::Function _func,
                           KGreeterPlugin::Context _ctx )
-	: inherited( _handler, 0, _parent, _predecessor, _fixedUser,
+	: inherited( _handler, _parent, _predecessor, _fixedUser,
 	             _pluginList, _func, _ctx )
 	, failedLabelState( 0 )
 {
@@ -934,7 +944,7 @@ KGStdVerify::KGStdVerify( KGVerifyHandler *_handler, QWidget *_parent,
 	grid->setAlignment( Qt::AlignCenter );
 
 	failedLabel = new QLabel( parent );
-	failedLabel->setFont( _failFont );
+	failedLabel->setFont( *_failFont );
 	grid->addWidget( failedLabel, 1, 0, Qt::AlignCenter );
 
 	updateLockStatus();
@@ -942,34 +952,21 @@ KGStdVerify::KGStdVerify( KGVerifyHandler *_handler, QWidget *_parent,
 
 KGStdVerify::~KGStdVerify()
 {
-	grid->removeItem( greet->getLayoutItem() );
+}
+
+bool
+KGStdVerify::gplugHasNode( const QString & )
+{
+	return false;
 }
 
 void // public
 KGStdVerify::selectPlugin( int id )
 {
 	inherited::selectPlugin( id );
-	grid->addItem( greet->getLayoutItem(), 0, 0 );
-	showWidgets( greet->getLayoutItem() );
-}
-
-void // private slot
-KGStdVerify::slotPluginSelected( int id )
-{
-	if (failed)
-		return;
-	if (id != curPlugin) {
-		plugMenu->setItemChecked( curPlugin, false );
-		parent->setUpdatesEnabled( false );
-		grid->removeItem( greet->getLayoutItem() );
-		Debug( "delete %s\n", pName.data() );
-		delete greet;
-		selectPlugin( id );
-		handler->verifyPluginChanged( id );
-		if (running)
-			start();
-		parent->setUpdatesEnabled( true );
-	}
+	QWidget *w = greet->getWidgets().first();
+	grid->addWidget( w, 0, 0 );
+	w->show();
 }
 
 void
@@ -990,22 +987,21 @@ KGStdVerify::updateStatus()
 
 	if (failedLabelState != nfls) {
 		failedLabelState = nfls;
+		QPalette p;
 		if (nfls < 0) {
-			failedLabel->setPaletteForegroundColor( Qt::black );
 			failedLabel->setText( i18np( "Automatic login in 1 second ...",
-			                            "Automatic login in %n seconds ...",
-			                            timedLeft ) );
+			                             "Automatic login in %1 seconds ...",
+			                             timedLeft ) );
 		} else {
 			switch (nfls) {
 			default:
 				failedLabel->clear();
 				break;
 			case 3:
-				failedLabel->setPaletteForegroundColor( Qt::red );
-				failedLabel->setText( i18n("Warning: Caps Lock on") );
+				p.setColor( QPalette::WindowText, Qt::red );
+				failedLabel->setText( i18n("Warning: Caps Lock is on") );
 				break;
 			case 2:
-				failedLabel->setPaletteForegroundColor( Qt::black );
 				failedLabel->setText( authTok ?
 				                         i18n("Change failed") :
 				                         fixedEntity.isEmpty() ?
@@ -1014,6 +1010,7 @@ KGStdVerify::updateStatus()
 				break;
 			}
 		}
+		failedLabel->setPalette( p );
 	}
 }
 
@@ -1024,8 +1021,9 @@ KGThemedVerify::KGThemedVerify( KGVerifyHandler *_handler,
                                 const PluginList &_pluginList,
                                 KGreeterPlugin::Function _func,
                                 KGreeterPlugin::Context _ctx )
-	: inherited( _handler, _themer, _parent, _predecessor, _fixedUser,
-	             _pluginList, _func, _ctx )
+	: inherited( _handler, _parent, _predecessor, _fixedUser,
+	             _pluginList, _func, _ctx  )
+	, themer( _themer )
 {
 	updateLockStatus();
 }
@@ -1034,40 +1032,36 @@ KGThemedVerify::~KGThemedVerify()
 {
 }
 
+bool
+KGThemedVerify::gplugHasNode( const QString &id )
+{
+	return themer->findNode( id ) != 0;
+}
+
 void // public
 KGThemedVerify::selectPlugin( int id )
 {
+	if (curPlugin != -1)
+		themer->setTypeVisible( QString( "plugin-specific-" ).append( pluginName() ), false );
 	inherited::selectPlugin( id );
-	QLayoutItem *l;
-	KdmItem *n;
-	if (themer && (l = greet->getLayoutItem())) {
-		if (!(n = themer->findNode( "talker" )))
+	themer->setTypeVisible( QString( "plugin-specific-" ).append( pluginName() ), true );
+	QSet<QString> oldTypes = showTypes;
+	showTypes.clear();
+	foreach (QWidget *w, greet->getWidgets())
+		if (KdmItem *n = themer->findNode( w->objectName() )) {
+			QString tn( QString( "plugin-" ).append( w->objectName() ) );
+			themer->setTypeVisible( tn, true );
+			showTypes.insert( tn );
+			oldTypes.remove( tn );
+			n->setWidget( w );
+		} else {
 			MsgBox( errorbox,
-			        i18n("Theme not usable with authentication method '%1'.",
-			          i18n(greetPlugins[pluginList[id]].info->name) ) );
-		else {
-			n->setLayoutItem( l );
-			showWidgets( l );
+			        i18n( "Theme not usable with authentication method '%1'.",
+			              i18n( greetPlugins[pluginList[id]].info->name ) ) );
+			break;
 		}
-	}
-	if (themer)
-		themer->updateGeometry( true );
-}
-
-void // private slot
-KGThemedVerify::slotPluginSelected( int id )
-{
-	if (failed)
-		return;
-	if (id != curPlugin) {
-		plugMenu->setItemChecked( curPlugin, false );
-		Debug( "delete %s\n", pName.data() );
-		delete greet;
-		selectPlugin( id );
-		handler->verifyPluginChanged( id );
-		if (running)
-			start();
-	}
+	foreach (QString t, oldTypes)
+		themer->setTypeVisible( t, false );
 }
 
 void
@@ -1087,26 +1081,27 @@ KGChTok::KGChTok( QWidget *_parent, const QString &user,
 	, verify( 0 )
 {
 	QSizePolicy fp( QSizePolicy::Fixed, QSizePolicy::Fixed );
-	okButton = new KPushButton( KStdGuiItem::ok(), this );
+	okButton = new KPushButton( KStandardGuiItem::ok(), this );
 	okButton->setSizePolicy( fp );
 	okButton->setDefault( true );
-	cancelButton = new KPushButton( KStdGuiItem::cancel(), this );
+	cancelButton = new KPushButton( KStandardGuiItem::cancel(), this );
 	cancelButton->setSizePolicy( fp );
 
 	verify = new KGStdVerify( this, this, cancelButton, user, pluginList, func, ctx );
 	verify->selectPlugin( curPlugin );
 
 	QVBoxLayout *box = new QVBoxLayout( this );
-	box->setSpacing( 10 );
 
 	box->addWidget( new QLabel( i18n("Changing authentication token"), this ), 0, Qt::AlignHCenter );
 
 	box->addLayout( verify->getLayout() );
+	verify->getLayout()->setParent( box );
 
 	box->addWidget( new KSeparator( Qt::Horizontal, this ) );
 
 	QHBoxLayout *hlay = new QHBoxLayout();
-	box->addItem( hlay );
+	box->addLayout( hlay );
+	hlay->setParent( box );
 	hlay->addStretch( 1 );
 	hlay->addWidget( okButton );
 	hlay->addStretch( 1 );
