@@ -37,7 +37,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kglobalsettings.h>
 #include <kwin.h>
 #include <kwinmodule.h>
-#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -48,6 +47,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <netwm.h>
 #include <ktoolinvocation.h>
 #include <kauthorized.h>
+#include <kmanagerselection.h>
 
 #include "utils.h"
 #include "kickertip.h"
@@ -59,6 +59,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "pagerapplet.h"
 #include "pagerapplet.moc"
 
+#include "kdesktop_background_interface.h"
+
 #ifdef FocusOut
 #undef FocusOut
 #endif
@@ -88,10 +90,21 @@ KMiniPager::KMiniPager(const QString& configFile, Plasma::Type type, int actions
                        QWidget *parent, const char *name)
     : KPanelApplet( configFile, type, actions, parent, name ),
       m_layout(0),
+      m_desktopLayoutOwner( NULL ),
       m_shadowEngine(0),
       m_contextMenu(0),
       m_settings( new PagerSettings(sharedConfig()) )
 {
+    int scnum = QApplication::desktop()->screenNumber(this);
+    QRect desk = QApplication::desktop()->screenGeometry(scnum);
+    if (desk.width() <= 800)
+    {
+        KConfigSkeleton::ItemInt* item = dynamic_cast<KConfigSkeleton::ItemBool*>(m_settings->findItem("Preview"));
+        if (item)
+        {
+            item->setDefaultValue(false);
+        }
+    }
     m_settings->readConfig();
     TaskManager::self()->trackGeometry();
 
@@ -100,13 +113,6 @@ KMiniPager::KMiniPager(const QString& configFile, Plasma::Type type, int actions
 
     setFont( KGlobalSettings::taskbarFont() );
 
-    int scnum = QApplication::desktop()->screenNumber(this);
-    QRect desk = QApplication::desktop()->screenGeometry(scnum);
-    if (desk.width() <= 800)
-    {
-        m_settings->setPreview(false);
-    }
-
     m_kwin = new KWinModule(this);
     m_activeWindow = m_kwin->activeWindow();
     m_curDesk = m_kwin->currentDesktop();
@@ -129,7 +135,10 @@ KMiniPager::KMiniPager(const QString& configFile, Plasma::Type type, int actions
     connect( m_kwin, SIGNAL( windowRemoved(WId) ), this, SLOT( slotWindowRemoved(WId) ) );
     connect( m_kwin, SIGNAL( windowChanged(WId,unsigned int) ), this, SLOT( slotWindowChanged(WId,unsigned int) ) );
     connect( m_kwin, SIGNAL( desktopNamesChanged() ), this, SLOT( slotDesktopNamesChanged() ) );
-    connect( kapp, SIGNAL(backgroundChanged(int)), SLOT(slotBackgroundChanged(int)) );
+
+    m_backgroundInterface = new org::kde::kdesktop::Background( "kdesktop", "/Background", QDBusConnection::sessionBus() );
+    connect( m_backgroundInterface, SIGNAL(backgroundChanged(int)),
+             SLOT(slotBackgroundChanged(int)) );
 
     if (KAuthorized::authorizeKAction("kicker_rmb") &&
         KAuthorized::authorizeControlModule("kde-kcmtaskbar.desktop"))
@@ -306,17 +315,28 @@ void KMiniPager::updateDesktopLayout(int o, int x, int y)
     {
       return;
     }
-#warning "kde4: port to dbus"
-#if 0
-    if ( !(DCOPRef( "kwin", "KWinInterface" ).call( "setDesktopLayout(int, int, int) ", o, x, y) ).isValid() )
-    {
-        kDebug() << "KMiniPager: Call to KWinInterface::setDesktopLayout(int, int, int) failed" << endl;
-        return;
-    }
-#endif
     desktopLayoutOrientation = o;
     desktopLayoutX = x;
     desktopLayoutY = y;
+    if( x == -1 ) // do-the-maths-yourself is encoded as 0 in the wm spec
+        x = 0;
+    if( y == -1 )
+        y = 0;
+    if( m_desktopLayoutOwner == NULL )
+    { // must own manager selection before setting global desktop layout
+        int screen = QX11Info::appScreen();
+        m_desktopLayoutOwner = new KSelectionOwner( QString( "_NET_DESKTOP_LAYOUT_S%1" ).arg( screen ).latin1(),
+            screen, this );
+        if( !m_desktopLayoutOwner->claim( false ))
+        {
+            delete m_desktopLayoutOwner;
+            m_desktopLayoutOwner = NULL;
+            return;
+        }
+    }
+    NET::Orientation orient = o == Qt::Horizontal ? NET::OrientationHorizontal : NET::OrientationVertical;
+    NETRootInfo i( QX11Info::display(), 0 );
+    i.setDesktopLayout( orient, x, y, NET::DesktopLayoutCornerTopLeft );
 }
 
 void KMiniPager::paintEvent(QPaintEvent *)
@@ -773,7 +793,9 @@ void KMiniPager::slotDesktopNamesChanged()
 
 void KMiniPager::showPager()
 {
+#ifdef __GNUC__
 #warning "kde4: port dcop stuff"
+#endif	
 #if 0
     DCOPClient *dcop=kapp->dcopClient();
 
@@ -814,7 +836,9 @@ void KMiniPager::showKPager(bool toggleShow)
         default:
             pt=mapToGlobal( QPoint(x(), y()) );
     }
+#ifdef __GNUC__
 #warning "kde4: port to dbus"
+#endif    
 #if 0
     if (toggleShow)
     {
@@ -829,7 +853,9 @@ void KMiniPager::showKPager(bool toggleShow)
 
 void KMiniPager::applicationRegistered( const QByteArray  & appName )
 {
+#ifdef __GNUC__	
 #warning "kde4 port to dbus"
+#endif	
 #if 0
     if (appName == "kpager")
     {
