@@ -81,7 +81,9 @@ SystemTrayApplet::SystemTrayApplet(const QString& configFile, Plasma::Type type,
 
     // kApplication notifies us of settings changes. added to support
     // disabling of frame effect on mouse hover
+#ifdef __GNUC__
 #warning "kde4: dcop port it"
+#endif    
     //kapp->dcopClient()->setNotifications(true);
     //connectDCOPSignal("kicker", "kicker", "configurationChanged()", "loadSettings()", false);
 
@@ -181,6 +183,7 @@ bool SystemTrayApplet::x11Event( XEvent *e )
             if( isWinManaged( (WId)e->xclient.data.l[2] ) ) // we already manage it
                 return true;
             embedWindow( e->xclient.data.l[2], false );
+            updateVisibleWins();
             layoutTray();
             emit updateLayout();
             return true;
@@ -210,13 +213,12 @@ void SystemTrayApplet::preferences()
     connect(m_settingsDialog, SIGNAL(finished()), this, SLOT(settingsDialogFinished()));
 
     m_iconSelector = new KActionSelector(m_settingsDialog);
-    m_iconSelector->setAvailableLabel(i18n("Visible icons:"));
-    m_iconSelector->setSelectedLabel(i18n("Hidden icons:"));
-    m_iconSelector->setShowUpDownButtons(false);
+    m_iconSelector->setAvailableLabel(i18n("Hidden icons:"));
+    m_iconSelector->setSelectedLabel(i18n("Visible icons:"));
     m_settingsDialog->setMainWidget(m_iconSelector);
 
-    QListWidget *shownListWidget = m_iconSelector->availableListWidget();
-    QListWidget *hiddenListWidget = m_iconSelector->selectedListWidget();
+    QListWidget *hiddenListWidget = m_iconSelector->availableListWidget();
+    QListWidget *shownListWidget = m_iconSelector->selectedListWidget();
 
     TrayEmbedList::const_iterator it = m_shownWins.begin();
     TrayEmbedList::const_iterator itEnd = m_shownWins.end();
@@ -260,26 +262,46 @@ void SystemTrayApplet::applySettings()
     }
 
     KConfig *conf = config();
-    conf->setGroup("HiddenTrayIcons");
-    QString name;
 
-    // use the following snippet of code someday to implement ordering
-    // of icons
-    //
-    // m_visibleIconList.clear();
-    // QListBoxItem* item = m_iconSelector->availableListBox()->firstItem();
-    // for (; item; item = item->next())
-    // {
-    //    m_visibleIconList.append(item->text());
-    // }
-    // conf->writeEntry("Visible", m_visibleIconList);
-    // selection.clear();
+    // Save the sort order and hidden status using the window class (WM_CLASS) rather
+    // than window name (caption) - window name is i18n-ed, so it's for example
+    // not possible to create default settings.
+    // For backwards compatibility, name is kept as it is, class is preceded by '!'.
+    QMap< QString, QString > windowNameToClass;
+    for( TrayEmbedList::ConstIterator it = m_shownWins.begin();
+         it != m_shownWins.end();
+         ++it ) {
+        KWin::WindowInfo info = KWin::windowInfo( (*it)->containerWinId(), NET::WMName, NET::WM2WindowClass);
+        windowNameToClass[ info.name() ] = '!' + info.windowClassClass();
+    }
+    for( TrayEmbedList::ConstIterator it = m_hiddenWins.begin();
+         it != m_hiddenWins.end();
+         ++it ) {
+        KWin::WindowInfo info = KWin::windowInfo( (*it)->containerWinId(), NET::WMName, NET::WM2WindowClass);
+        windowNameToClass[ info.name() ] = '!' + info.windowClassClass();
+    }
 
-    m_hiddenIconList.clear();
-    QList<QListWidgetItem*> list = m_iconSelector->selectedListWidget()->findItems(QString("*"), Qt::MatchRegExp);
+    conf->setGroup("SortedTrayIcons");
+    m_sortOrderIconList.clear();
+    QList<QListWidgetItem*> list = m_iconSelector->availableListWidget()->findItems(QString("*"), Qt::MatchRegExp);
     foreach (QListWidgetItem* item, list)
     {
-        m_hiddenIconList.append(item->text());
+        if( windowNameToClass.contains(item->text()))
+            m_sortOrderIconList.append(windowNameToClass[item->text()]);
+        else
+            m_sortOrderIconList.append(item->text());
+    }
+    conf->writeEntry("SortOrder", m_sortOrderIconList);
+
+    conf->setGroup("HiddenTrayIcons");
+    m_hiddenIconList.clear();
+    list = m_iconSelector->availableListWidget()->findItems(QString("*"), Qt::MatchRegExp);
+    foreach (QListWidgetItem* item, list)
+    {
+        if( windowNameToClass.contains(item->text()))
+            m_hiddenIconList.append(windowNameToClass[item->text()]);
+        else
+            m_hiddenIconList.append(item->text());
     }
     conf->writeEntry("Hidden", m_hiddenIconList);
     conf->sync();
@@ -409,13 +431,15 @@ void SystemTrayApplet::loadSettings()
     KConfig *conf = config();
     conf->setGroup("General");
 
-    if (conf->readEntry("ShowPanelFrame", QVariant(false)).toBool())
+    if (conf->readEntry("ShowPanelFrame", false))
     {
         setFrameStyle(Panel | Sunken);
     }
 
     conf->setGroup("HiddenTrayIcons");
     m_hiddenIconList = conf->readEntry("Hidden", QStringList() );
+    conf->setGroup("SortedTrayIcons");
+    m_sortOrderIconList = conf->readListEntry("SortOrder", QStringList());
 }
 
 void SystemTrayApplet::systemTrayWindowAdded( WId w )
@@ -504,6 +528,8 @@ bool SystemTrayApplet::isWinManaged(WId w)
 bool SystemTrayApplet::shouldHide(WId w)
 {
     return m_hiddenIconList.contains(KWin::windowInfo(w,NET::WMName).name());
+    return m_hiddenIconList.contains(KWin::windowInfo(w,NET::WMName).name())
+        || m_hiddenIconList.contains('!'+KWin::windowInfo(w,0,NET::WM2WindowClass).windowClassClass());
 }
 
 void SystemTrayApplet::updateVisibleWins()
@@ -525,6 +551,35 @@ void SystemTrayApplet::updateVisibleWins()
             (*emb)->hide();
         }
     }
+    
+    QMap< TrayEmbed*, QString > names; // cache names and classes
+    QMap< TrayEmbed*, QString > classes;
+    for( TrayEmbedList::const_iterator it = m_shownWins.begin();
+         it != m_shownWins.end();
+         ++it ) {
+        KWin::WindowInfo info = KWin::windowInfo((*it)->containerWinId(),NET::WMName,NET::WM2WindowClass);
+        names[ *it ] = info.name();
+        classes[ *it ] = '!'+info.windowClassClass();
+    }
+    TrayEmbedList newList;
+    for( QStringList::const_iterator it1 = m_sortOrderIconList.begin();
+         it1 != m_sortOrderIconList.end();
+         ++it1 ) {
+        for( TrayEmbedList::iterator it2 = m_shownWins.begin();
+             it2 != m_shownWins.end();
+             ) {
+            if( (*it1).startsWith("!") ? classes[ *it2 ] == *it1 : names[ *it2 ] == *it1 ) {
+                newList.append( *it2 ); // don't bail out, there may be multiple ones
+                it2 = m_shownWins.erase( it2 );
+            } else
+                ++it2;
+        }
+    }
+    for( TrayEmbedList::const_iterator it = m_shownWins.begin();
+         it != m_shownWins.end();
+         ++it )
+        newList.append( *it ); // append unsorted items
+    m_shownWins = newList;
 }
 
 void SystemTrayApplet::toggleExpanded()
@@ -552,14 +607,14 @@ void SystemTrayApplet::refreshExpandButton()
     if (orientation() == Qt::Vertical)
     {
         m_expandButton->setPixmap(m_showHidden ?
-            kapp->iconLoader()->loadIcon("1downarrow", K3Icon::Panel, 16) :
-            kapp->iconLoader()->loadIcon("1uparrow", K3Icon::Panel, 16));
+            KIconLoader::global()->loadIcon("1downarrow", K3Icon::Panel, 16) :
+            KIconLoader::global()->loadIcon("1uparrow", K3Icon::Panel, 16));
     }
     else
     {
         m_expandButton->setPixmap((m_showHidden ^ kapp->layoutDirection() == Qt::RightToLeft) ?
-            kapp->iconLoader()->loadIcon("1rightarrow", K3Icon::Panel, 16) :
-            kapp->iconLoader()->loadIcon("1leftarrow", K3Icon::Panel, 16));
+            KIconLoader::global()->loadIcon("1rightarrow", K3Icon::Panel, 16) :
+            KIconLoader::global()->loadIcon("1leftarrow", K3Icon::Panel, 16));
     }
 }
 
