@@ -75,6 +75,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "pluginmanager.h"
 
 #include "containerarea.h"
+#include <kconfiggroup.h>
 
 using namespace Qt;
 
@@ -253,7 +254,9 @@ void ContainerArea::defaultContainerConfig()
     }
 
     // system tray applet
+#ifdef __GNUC__
 #warning "once qxembed is back and system tray works again, renable this"
+#endif    
 /*    a = manager->createAppletContainer(
         "systemtrayapplet.desktop",
         true,
@@ -926,7 +929,7 @@ void ContainerArea::mouseMoveEvent(QMouseEvent *ev)
         _moveAC->populateMimeData(data);
         QDrag* dd = new QDrag(this);
         dd->setMimeData(data);
-        dd->setPixmap(kapp->iconLoader()->loadIcon(_moveAC->icon(), K3Icon::Small));
+        dd->setPixmap(KIconLoader::global()->loadIcon(_moveAC->icon(), K3Icon::Small));
         grabKeyboard();
         dd->start();
         releaseKeyboard();
@@ -1251,16 +1254,16 @@ void ContainerArea::dropEvent(QDropEvent *ev)
             {
                 // directory
                 QMenu* menu = new QMenu(this);
-                QAction* fileManager = menu->addAction(SmallIconSet("folder"),
+                QAction* fileManager = menu->addAction(KIcon("folder"),
                                                        i18n("Add as &File Manager URL"),
                                                        0, 0, Qt::CTRL+Qt::Key_F);
-                /* QAction* urlBrowser = */ menu->addAction(SmallIconSet("kdisknav"),
+                /* QAction* urlBrowser = */ menu->addAction(KIcon("kdisknav"),
                                                       i18n("Add as Quick&Browser"),
                                                       0, 0, Qt::CTRL+Qt::Key_B);
                 if (menu->exec(mapToGlobal(ev->pos())) == fileManager)
                 {
                     a = new BrowserButtonContainer(url.path(), m_opMenu,
-                                                   KMimeType::iconNameForURL(url),
+                                                   KMimeType::iconNameForUrl(url),
                                                    m_contents);
                 }
                 else
@@ -1269,7 +1272,7 @@ void ContainerArea::dropEvent(QDropEvent *ev)
                 }
                 delete menu;
 	    }
-            else if ( KMimeType::findByURL(url)->name() == "application/x-desktop" ) {
+            else if ( KMimeType::findByUrl(url)->name() == "application/x-desktop" ) {
 		// a local desktop file being dragged from an external program.
 		// Make a copy first.
 		KDesktopFile df(url.path());
@@ -1286,8 +1289,8 @@ void ContainerArea::dropEvent(QDropEvent *ev)
                 QString pixmapFile;
                 //KMimeType::pixmapForURL(url, 0, K3Icon::Panel, 0,
                 //                        K3Icon::DefaultState, &pixmapFile);
-                QString iconName = KMimeType::iconNameForURL(url);
-                KGlobal::iconLoader()->loadIcon(iconName, K3Icon::Panel, 0, K3Icon::DefaultState, &pixmapFile );
+                QString iconName = KMimeType::iconNameForUrl(url);
+                KIconLoader::global()->loadIcon(iconName, K3Icon::Panel, 0, K3Icon::DefaultState, &pixmapFile );
                 PanelExeDialog dlg(QString::null, QString::null, url.path(),
                                    pixmapFile, QString::null, false, 0);
                 if (dlg.exec() == QDialog::Accepted)
@@ -1636,8 +1639,9 @@ void ContainerArea::scrollTo(BaseContainer* b)
     {
         return;
     }
-
+#ifdef __GNUC__
 #warning FIX THIS
+#endif    
     //int x, y;
     //viewportToContents(b->pos().x(), b->pos().y(), x, y);
     //ensureVisible(x, y);
