@@ -40,6 +40,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kwinmodule.h>
+#include <kglobalsettings.h>
 
 #include "utils.h"
 #include "kicker.h"
@@ -47,6 +48,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "pluginmanager.h"
 
 #include "extensionmanager.h"
+#include <kconfiggroup.h>
 
 static KStaticDeleter<ExtensionManager> extensionManagerDeleter;
 ExtensionManager* ExtensionManager::m_self = 0;
@@ -90,7 +92,7 @@ ExtensionManager::~ExtensionManager()
 void ExtensionManager::initialize()
 {
 //    kDebug(1210) << "ExtensionManager::loadContainerConfig()" << endl;
-    KConfig* config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     PluginManager* pm = PluginManager::self();
 
     // set up the "main" panel
@@ -111,7 +113,7 @@ void ExtensionManager::initialize()
         m_mainPanel = pm->createExtensionContainer(
                             "childpanelextension.desktop",
                             true,
-                            QString(kapp->aboutData()->appName()) + "rc",
+                            QString(KGlobal::mainComponent().aboutData()->appName()) + "rc",
                             "Main Panel");
     }
 
@@ -176,8 +178,8 @@ void ExtensionManager::initialize()
 void ExtensionManager::configureMenubar(bool duringInit)
 {
     KConfig menuConfig("kdesktoprc", true);
-    if (KConfigGroup(&menuConfig, "KDE").readEntry("macStyle", QVariant(false)).toBool()
-        || KConfigGroup(&menuConfig, "Menubar").readEntry("ShowMenubar", QVariant(false)).toBool())
+    if (KConfigGroup(&menuConfig, "KDE").readEntry("macStyle", false)
+        || KConfigGroup(&menuConfig, "Menubar").readEntry("ShowMenubar", false))
     {
         if (KGlobal::dirs()->findResource("applets", "menuapplet.desktop").isEmpty() ||
             m_menubarPanel)
@@ -211,7 +213,7 @@ void ExtensionManager::configureMenubar(bool duringInit)
         updateMenubar();
 
         m_menubarPanel->show();
-        connect(kapp, SIGNAL(kdisplayFontChanged()), SLOT(updateMenubar()));
+        connect(KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()), SLOT(updateMenubar()));
     }
     else if (m_menubarPanel)
     {
@@ -236,10 +238,10 @@ void ExtensionManager::migrateMenubar()
     // panel, meaning kickerrc itself would have to be vastly modified
     // with lots of complications. not work it IMHO.
 
-    KConfig* config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->setGroup("General");
 
-    if (config->readEntry("CheckedForMenubar", QVariant(false)).toBool())
+    if (config->readEntry("CheckedForMenubar", false))
     {
         return;
     }
@@ -289,7 +291,7 @@ void ExtensionManager::migrateMenubar()
                     if (appletFile.indexOf("menuapplet.desktop") != -1)
                     {
                         QString menubarConfig = KStandardDirs::locate("config", extension);
-                        KIO::NetAccess::copy(menubarConfig,
+                        KIO::NetAccess::file_copy(menubarConfig,
                                              KStandardDirs::locateLocal("config",
                                              "kicker_menubarpanelrc"), 0);
                         elist.removeAll(appletId);
@@ -312,7 +314,7 @@ void ExtensionManager::saveContainerConfig()
 {
 //    kDebug(1210) << "ExtensionManager::saveContainerConfig()" << endl;
 
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
 
     // build the extension list
     QStringList elist;
