@@ -39,7 +39,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QStyle>
 #include <QStyleOptionFrame>
 #include <kapplication.h>
-#include <kaboutkde.h>
 #include <kactioncollection.h>
 #include <kbookmarkmenu.h>
 #include <kconfig.h>
@@ -65,12 +64,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "recentapps.h"
 
 #include "k_mnu.h"
+#include "kdesktop_interface.h"
+#include "kdesktop_screensaver_interface.h"
 #include "k_mnu.moc"
 
 PanelKMenu::PanelKMenu()
   : PanelServiceMenu(QString(), QString(), 0, "KMenu")
   , bookmarkMenu(0)
-  , bookmarkOwner(0)
 {
     // set the first client id to some arbitrarily large value.
     client_id = 10000;
@@ -95,7 +95,6 @@ PanelKMenu::~PanelKMenu()
 {
     clearSubmenus();
     delete bookmarkMenu;
-    delete bookmarkOwner;
 }
 #if 0
 void PanelKMenu::slotServiceStartedByStorageId(QString starter,
@@ -185,9 +184,9 @@ void PanelKMenu::initialize()
     if (loadSidePixmap())
     {
         // in case we've been through here before, let's disconnect
-        disconnect(kapp, SIGNAL(kdisplayPaletteChanged()),
+        disconnect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
                    this, SLOT(paletteChanged()));
-        connect(kapp, SIGNAL(kdisplayPaletteChanged()),
+        connect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
                 this, SLOT(paletteChanged()));
     }
     else
@@ -220,11 +219,9 @@ void PanelKMenu::initialize()
     {
         // Need to create a new popup each time, it's deleted by subMenus.clear()
         KMenu * bookmarkParent = new KMenu(this);
-	bookmarkParent->setObjectName("bookmarks" );
-        if(!bookmarkOwner)
-            bookmarkOwner = new KBookmarkOwner;
+        bookmarkParent->setObjectName("bookmarks" );
         delete bookmarkMenu; // can't reuse old one, the popup has been deleted
-        bookmarkMenu = new KBookmarkMenu( KonqBookmarkManager::self(), bookmarkOwner, bookmarkParent, actionCollection, true, false );
+        bookmarkMenu = new KBookmarkMenu( KonqBookmarkManager::self(), 0, bookmarkParent, actionCollection );
 
         insertItem(Plasma::menuIconSet("bookmark"),
                    i18n("Bookmarks"), bookmarkParent);
@@ -330,9 +327,9 @@ void PanelKMenu::slotLock()
     if ( kicker_screen_number )
         interface.sprintf("org.kde.kdesktop-screen-%d", kicker_screen_number);
 
-    QDBusInterface kdesktop(interface, "/ScreenSaver", "org.kde.kdesktop.KScreensaver");
-    if ( kdesktop.isValid() )
-        kdesktop.call("lock");
+    org::kde::kdesktop::ScreenSaver screenSaverInterface( interface, "/ScreenSaver", QDBusConnection::sessionBus() );
+    if ( screenSaverInterface.isValid() )
+        screenSaverInterface.lock();
 }
 
 void PanelKMenu::slotLogout()
@@ -349,8 +346,8 @@ void PanelKMenu::slotPopulateSessions()
     if (KAuthorized::authorizeKAction("start_new_session") && (p = dm.numReserve()) >= 0)
     {
         if (KAuthorized::authorizeKAction("lock_screen"))
-	  sessionsMenu->insertItem(/*SmallIconSet("lockfork"),*/ i18n("Lock Current && Start New Session"), 100 );
-        sessionsMenu->insertItem(SmallIconSet("fork"), i18n("Start New Session"), 101 );
+	  sessionsMenu->insertItem(/*KIcon("lockfork"),*/ i18n("Lock Current && Start New Session"), 100 );
+        sessionsMenu->insertItem(KIcon("fork"), i18n("Start New Session"), 101 );
         if (!p) {
             sessionsMenu->setItemEnabled( 100, false );
             sessionsMenu->setItemEnabled( 101, false );
@@ -409,18 +406,18 @@ void PanelKMenu::doNewSession( bool lock )
 
 void PanelKMenu::slotSaveSession()
 {
-    QDBusInterface ksmserver("org.kde.ksmserver", "/ksmserver");
+    QDBusInterface ksmserver("org.kde.ksmserver", "/ksmserver", "org.kde.KSMServerInterface");
     ksmserver.call("saveCurrentSession");
 }
 
 void PanelKMenu::slotRunCommand()
 {
-    QString interface( "kdesktop" );
+    QString interface( "org.kde.kdesktop" );
     if ( kicker_screen_number )
-        interface.sprintf("kdesktop-screen-%d", kicker_screen_number);
+        interface.sprintf("org.kde.kdesktop-screen-%d", kicker_screen_number);
 
-    QDBusInterface kdesktop(interface, "/KDesktopIface");
-    kdesktop.call("popupExecuteCommand");
+    org::kde::kdesktop::Desktop desktopInterface( interface, "/Desktop", QDBusConnection::sessionBus() );
+    desktopInterface.popupExecuteCommand( QString() );
 }
 
 void PanelKMenu::slotEditUserContact()
@@ -459,7 +456,9 @@ void PanelKMenu::resizeEvent(QResizeEvent * e)
 //    kDebug(1210) << geometry().width() << ", " << geometry().height() << endl;
 
     PanelServiceMenu::resizeEvent(e);
+#ifdef __GNUC__
 #warning "KDE4: Qt4 doesn't seem to provide a way of doing this, will need different impl. for side image"
+#endif    
 //    setFrameRect( QStyle::visualRect( layoutDirection(), rect(), QRect( sidePixmap.width(), 0,
 //                                      width() - sidePixmap.width(), height() ) ) );
 }
