@@ -39,6 +39,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kdebug.h>
 #include <kdesktopfile.h>
 #include <kglobalsettings.h>
+#include <kicon.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmimetype.h>
@@ -50,11 +51,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <ksycocaentry.h>
 #include <kservice.h>
 #include <ktoolinvocation.h>
-#include <kio/job.h>
+#include <kio/copyjob.h>
 #include <kauthorized.h>
 #include <kworkspace.h>
 #include <QtDBus/QtDBus>
 
+#include "kdesktop_interface.h"
 #include "utils.h"
 #include "kicker.h"
 #include "kickerSettings.h"
@@ -302,22 +304,30 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
                                       const QStringList *suppressGenericNames /* = 0 */,
                                       const QString & aliasname)
 {
-    QString serviceName = aliasname.isEmpty() ? s->name():aliasname;
-    // add comment
-    QString comment = s->genericName();
+    QString serviceName = (aliasname.isEmpty() ? s->name() : aliasname).simplified();
+    QString comment = s->genericName().simplified();
+
     if (!comment.isEmpty())
     {
         if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
         {
-            if (!suppressGenericNames ||
-                !suppressGenericNames->contains(s->untranslatedGenericName()))
+            if ((!suppressGenericNames ||
+                 !suppressGenericNames->contains(s->untranslatedGenericName())) &&
+                serviceName.indexOf(comment, 0, Qt::CaseInsensitive) == -1)
             {
-                serviceName = QString("%1 (%2)").arg(serviceName).arg(comment);
+                if (comment.indexOf(serviceName, 0, Qt::CaseInsensitive) == -1)
+                {
+                    serviceName = QString("%1 %2").arg(serviceName, comment);
+                }
+                else
+                {
+                    serviceName = comment;
+                }
             }
         }
         else if (KickerSettings::menuEntryFormat() == KickerSettings::DescriptionAndName)
         {
-            serviceName = QString("%1 (%2)").arg(comment).arg(serviceName);
+            serviceName = QString("%1 (%2)").arg(comment, serviceName);
         }
         else if (KickerSettings::menuEntryFormat() == KickerSettings::DescriptionOnly)
         {
@@ -475,22 +485,22 @@ void PanelServiceMenu::mouseReleaseEvent(QMouseEvent * ev)
         case KST_KService:
             if (KAuthorized::authorizeKAction("editable_desktop_icons"))
             {
-                popupMenu_->insertItem(SmallIconSet("desktop"),
+                popupMenu_->insertItem(KIcon("desktop"),
                     i18n("Add Item to Desktop"), AddItemToDesktop);
             }
             if (KAuthorized::authorizeKAction("kicker_rmb"))
             {
-                popupMenu_->insertItem(SmallIconSet("kicker"),
+                popupMenu_->insertItem(KIcon("kicker"),
                     i18n("Add Item to Main Panel"), AddItemToPanel);
             }
             if (KAuthorized::authorizeKAction("menuedit"))
             {
-                popupMenu_->insertItem(SmallIconSet("kmenuedit"),
+                popupMenu_->insertItem(KIcon("kmenuedit"),
                     i18n("Edit Item"), EditItem);
             }
             if (KAuthorized::authorizeKAction("run_command"))
             {
-                popupMenu_->insertItem(SmallIconSet("run"),
+                popupMenu_->insertItem(KIcon("run"),
                     i18n("Put Into Run Dialog"), PutIntoRunDialog);
             }
             break;
@@ -498,17 +508,17 @@ void PanelServiceMenu::mouseReleaseEvent(QMouseEvent * ev)
         case KST_KServiceGroup:
             if (KAuthorized::authorizeKAction("editable_desktop_icons"))
             {
-                popupMenu_->insertItem(SmallIconSet("desktop"),
+                popupMenu_->insertItem(KIcon("desktop"),
                     i18n("Add Menu to Desktop"), AddMenuToDesktop);
             }
             if (KAuthorized::authorizeKAction("kicker_rmb"))
             {
-                popupMenu_->insertItem(SmallIconSet("kicker"),
+                popupMenu_->insertItem(KIcon("kicker"),
                     i18n("Add Menu to Main Panel"), AddMenuToPanel);
             }
             if (KAuthorized::authorizeKAction("menuedit"))
             {
-                popupMenu_->insertItem(SmallIconSet("kmenuedit"),
+                popupMenu_->insertItem(KIcon("kmenuedit"),
                     i18n("Edit Menu"), EditMenu);
             }
             break;
@@ -567,8 +577,9 @@ void PanelServiceMenu::slotContextMenu(int selected)
         case PutIntoRunDialog:
 			{
             service = KService::Ptr::staticCast(contextKSycocaEntry_);
-            QDBusInterface kickerInterface("org.kde.kdesktop", "/default");
-            kickerInterface.call("popupExecuteCommand", service->exec());
+
+            org::kde::kdesktop::Desktop desktopInterface( "kdesktop", "/Desktop", QDBusConnection::sessionBus() );
+            desktopInterface.popupExecuteCommand( service->exec() );
             break;
 			}
 	case AddMenuToDesktop:
@@ -643,7 +654,7 @@ void PanelServiceMenu::mouseMoveEvent(QMouseEvent * ev)
 
         case KST_KService:
         {
-            icon = KService::Ptr::staticCast(e)->pixmap(K3Icon::Small);
+            icon = SmallIcon(KService::Ptr::staticCast(e)->icon());
             QString filePath = KService::Ptr::staticCast(e)->desktopEntryPath();
             if (filePath[0] != '/')
             {
@@ -656,8 +667,7 @@ void PanelServiceMenu::mouseMoveEvent(QMouseEvent * ev)
         case KST_KServiceGroup:
         {
             KServiceGroup::Ptr g = KServiceGroup::Ptr::staticCast(e);
-            icon = KGlobal::iconLoader()
-                   ->loadIcon(g->icon(), K3Icon::Small);
+            icon = KIconLoader::global()->loadIcon(g->icon(), K3Icon::Small);
             url = "programs:/" + g->relPath();
             break;
         }
