@@ -40,6 +40,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kapplication.h>
 #include <kdebug.h>
 #include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kglobalaccel.h>
 #include <kactioncollection.h>
 #include <kaction.h>
@@ -112,8 +113,9 @@ TaskBar::TaskBar( QWidget *parent )
             this, SLOT(desktopChanged(int)));
     connect(TaskManager::self(), SIGNAL(windowChanged(Task::TaskPtr)),
             this, SLOT(windowChanged(Task::TaskPtr)));
-
+#ifdef __GNUC__
 #warning dcop signal
+#endif
 #if 0
     connectDCOPSignal("", "", "kdeTaskBarConfigChanged()",
                       "configChanged()", false);
@@ -135,10 +137,10 @@ TaskBar::TaskBar( QWidget *parent )
 
     blocklayout = false;
 
-    connect(kapp, SIGNAL(settingsChanged(int)), SLOT(slotSettingsChanged(int)));
+    connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), SLOT(slotSettingsChanged(int)));
     keys = new KActionCollection( this );
     KActionCollection* actionCollection = keys;
-    KAction* a = 0L;
+    QAction* a = 0L;
 #include "taskbarbindings.cpp"
     keys->readSettings();
 }
@@ -275,7 +277,7 @@ void TaskBar::configure()
 		break;
         }
 
-        m_windowListButton->setIcon(kapp->iconLoader()->loadIcon(icon,
+        m_windowListButton->setIcon(KIconLoader::global()->loadIcon(icon,
                                                                  K3Icon::Panel,
                                                                  16));
         m_windowListButton->setMinimumSize(m_windowListButton->sizeHint());
@@ -343,8 +345,9 @@ void TaskBar::resizeEvent( QResizeEvent* e )
             reGroup();
         }
     }
-
+#ifdef __GNUC__
     #warning Fix this!!
+#endif
     //Panner::resizeEvent( e );
 
     if ( !blocklayout )
@@ -731,6 +734,12 @@ void TaskBar::reLayout()
         // actual button height
         int bheight = contentsRect().height() / rows;
 
+        // avoid zero division later
+        if (bheight < 1)
+        {
+            bheight = 1;
+        }
+
         // buttons per row
         int bpr = (int)ceil( (double)list.count() / rows);
 
@@ -1067,7 +1076,7 @@ void TaskBar::slotActivatePreviousTask()
 
 void TaskBar::slotSettingsChanged( int category )
 {
-    if( category == (int) KApplication::SETTINGS_SHORTCUTS )
+    if( category == KGlobalSettings::SETTINGS_SHORTCUTS )
     {
         keys->readSettings();
     }
@@ -1216,21 +1225,21 @@ void TaskBar::popupDirectionChange(Plasma::Position d)
     switch (d)
     {
         case Plasma::Up:
-            icon = "1uparrow";
-            at = Qt::UpArrow;
-            break;
-        case Plasma::Down:
             icon = "1downarrow";
             at = Qt::DownArrow;
             break;
-        case Plasma::Left:
-            icon = "1leftarrow";
-            at = Qt::LeftArrow;
+        case Plasma::Down:
+            icon = "1uparrow";
+            at = Qt::UpArrow;
             break;
-        case Plasma::Right:
+        case Plasma::Left:
             icon = "1rightarrow";
             at = Qt::RightArrow;
             break;
+        case Plasma::Right:
+            icon = "1leftarrow";
+            at = Qt::LeftArrow;
+            break;
 	case Plasma::Floating:
 	    icon = "1uparrow";
 	    at = Qt::UpArrow;
@@ -1241,7 +1250,7 @@ void TaskBar::popupDirectionChange(Plasma::Position d)
 
     if (m_windowListButton)
     {
-        m_windowListButton->setIcon(kapp->iconLoader()->loadIcon(icon,
+        m_windowListButton->setIcon(KIconLoader::global()->loadIcon(icon,
                                                                  K3Icon::Panel,
                                                                  16));
         m_windowListButton->setMinimumSize(m_windowListButton->sizeHint());
