@@ -608,8 +608,8 @@ void TaskContainer::drawButton(QPainter *p)
         QRect tr = QStyle::visualRect(layoutDirection(), rect(),
                                       QRect(br.x() + textPos + 1, 0,
                                             width() - textPos, height()));
-        int textFlags = Qt::AlignVCenter | Qt::TextSingleLine;
-        textFlags |= reverse ? Qt::AlignRight : Qt::AlignLeft;
+        int textFlags = Qt::TextSingleLine;
+        textFlags |= QStyle::visualAlignment(layoutDirection(), Qt::AlignVCenter | Qt::AlignLeft);
         QPen textPen;
 
         // get the color for the text label
@@ -1493,7 +1493,7 @@ void TaskContainer::updateTipData(KickerTip::Data& data)
     {
         data.message = m_startup->text();
         data.subtext = i18n("Loading application ...");
-        data.icon = KGlobal::iconLoader()->loadIcon(m_startup->icon(),
+        data.icon = KIconLoader::global()->loadIcon(m_startup->icon(),
                                                     K3Icon::Small,
                                                     K3Icon::SizeMedium,
                                                     K3Icon::DefaultState,
@@ -1561,13 +1561,13 @@ void TaskContainer::updateTipData(KickerTip::Data& data)
         else
         {
             QStringList desktopNames = desktopMap.values();
-            details.append(i18n("On %1", desktopNames.join(", ")) + "<br>");
+            details.append("<p>" + i18nc("On <virtual desktop name>", "On %1", desktopNames.join(", ")) + "</p>");
         }
     }
 
     if (demandsAttention)
     {
-        details.append(i18n("Requesting attention") + "<br>");
+        details.append("<p>" + i18n("Requesting attention") + "</p>");
     }
 
     QString name = this->name();
