@@ -30,6 +30,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QPixmap>
 #include <QList>
 
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kglobal.h>
@@ -99,7 +100,7 @@ void TaskManager::configure_startup()
 {
     KConfig c("klaunchrc", true);
     c.setGroup("FeedbackStyle");
-    if (!c.readEntry("TaskbarButton", QVariant(true)).toBool())
+    if (!c.readEntry("TaskbarButton", true))
         return;
     _startup_info = new KStartupInfo( KStartupInfo::CleanOnCantDetect, this );
     connect( _startup_info,
@@ -635,7 +636,7 @@ Task::Task(WId win, QObject *parent, const char *name)
     // try to guess the icon from the classhint
     if(_pixmap.isNull())
     {
-        KGlobal::iconLoader()->loadIcon(className().toLower(),
+        KIconLoader::global()->loadIcon(className().toLower(),
                                                     K3Icon::Small,
                                                     K3Icon::Small,
                                                     K3Icon::DefaultState,
@@ -716,7 +717,7 @@ void Task::refreshIcon()
     // try to guess the icon from the classhint
     if(_pixmap.isNull())
     {
-        KGlobal::iconLoader()->loadIcon(className().toLower(),
+        KIconLoader::global()->loadIcon(className().toLower(),
                                                     K3Icon::Small,
                                                     K3Icon::Small,
                                                     K3Icon::DefaultState,
@@ -923,7 +924,7 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
 
       // Icon of last resort
       if( pixmap.isNull() ) {
-        pixmap = KGlobal::iconLoader()->loadIcon( "go",
+        pixmap = KIconLoader::global()->loadIcon( "go",
                                                   K3Icon::NoGroup,
                                                   K3Icon::SizeSmall );
         isStaticIcon = true;
@@ -946,7 +947,7 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
 
       // Icon of last resort
       if( pixmap.isNull() ) {
-        pixmap = KGlobal::iconLoader()->loadIcon( "go",
+        pixmap = KIconLoader::global()->loadIcon( "go",
                             K3Icon::NoGroup,
                             K3Icon::SizeMedium );
         isStaticIcon = true;
@@ -960,7 +961,7 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
 
       // If not, try to get one from the classname
       if ( pixmap.isNull() || pixmap.width() != size || pixmap.height() != size ) {
-        pixmap = KGlobal::iconLoader()->loadIcon( className(),
+        pixmap = KIconLoader::global()->loadIcon( className(),
                             K3Icon::NoGroup,
                             size,
                             K3Icon::DefaultState,
@@ -977,7 +978,7 @@ QPixmap Task::bestIcon( int size, bool &isStaticIcon )
 
       // Icon of last resort
       if( pixmap.isNull() ) {
-        pixmap = KGlobal::iconLoader()->loadIcon( "go",
+        pixmap = KIconLoader::global()->loadIcon( "go",
                                                   K3Icon::NoGroup,
                                                   size );
         isStaticIcon = true;
