@@ -29,9 +29,7 @@
 #include <QToolTip>
 #include <qmime.h>
 #include <q3dragobject.h>
-//Added by qt3to4:
 #include <QPaintEvent>
-#include <Q3PtrList>
 #include <QMouseEvent>
 #include <QX11Info>
 
@@ -40,12 +38,12 @@
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <kipc.h>
 #include <kkeydialog.h>
 #include <kicon.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ksavefile.h>
+#include <ksessionmanager.h>
 #include <kstandarddirs.h>
 #include <ksimpleconfig.h>
 #include <kstringhandler.h>
@@ -57,9 +55,10 @@
 #include <qdbusconnection.h>
 #include <kiconloader.h>
 #include <khelpmenu.h>
-#include <kstdguiitem.h>
+#include <kstandardguiitem.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
+#include <kconfiggroup.h>
 
 #include "configdialog.h"
 #include "toplevel.h"
@@ -76,8 +75,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
-#include <kclipboard.h>
-
 namespace {
     /**
      * Use this when manipulating the clipboard
@@ -105,13 +102,15 @@ namespace {
 /**
  * Helper class to save history upon session exit.
  */
-class KlipperSessionManaged : public KSessionManaged
+class KlipperSessionManager : public KSessionManager
 {
 public:
-    KlipperSessionManaged( KlipperWidget* k )
+    KlipperSessionManager( KlipperWidget* k )
         : klipper( k )
         {}
 
+    virtual ~KlipperSessionManager() {}
+
     /**
      * Save state upon session exit.
      *
@@ -125,25 +124,18 @@ private:
     KlipperWidget* klipper;
 };
 
-extern bool qt_qclipboard_bailout_hack;
-#if KDE_IS_VERSION( 3, 9, 0 )
-#warning Check status of #80072 with Qt4.
-#endif
-
-static void ensureGlobalSyncOff(KConfig* config);
+static void ensureGlobalSyncOff(KSharedConfigPtr config);
 
 // config == KGlobal::config for process, otherwise applet
-KlipperWidget::KlipperWidget( QWidget *parent, KConfig* config )
+KlipperWidget::KlipperWidget(QWidget *parent, const KSharedConfigPtr &config)
     : QWidget( parent )
     , m_overflowCounter( 0 )
     , locklevel( 0 )
     , m_config( config )
     , m_pendingContentsCheck( false )
-    , session_managed( new KlipperSessionManaged( this ))
+    , session_managed( new KlipperSessionManager( this ))
 {
-    qt_qclipboard_bailout_hack = true;
-
-    QDBus::sessionBus().registerObject("/klipper", this, QDBusConnection::ExportSlots);
+    QDBusConnection::sessionBus().registerObject("/klipper", this, QDBusConnection::ExportScriptableSlots);
 
     // We don't use the clipboardsynchronizer anymore, and it confuses Klipper
     ensureGlobalSyncOff(m_config);
@@ -158,34 +150,41 @@ KlipperWidget::KlipperWidget( QWidget *parent, KConfig* config )
     m_pendingCheckTimer.setSingleShot( true );
     connect( &m_pendingCheckTimer, SIGNAL( timeout()), SLOT( slotCheckPending()));
 
-    m_history = new History( this, "main_history" );
+    m_history = new History( this );
 
     // we need that collection, otherwise KToggleAction is not happy :}
     //QString defaultGroup( "default" );
     KActionCollection *collection = new KActionCollection( this );
-    toggleURLGrabAction = new KToggleAction( collection, "toggleUrlGrabAction" );
+    toggleURLGrabAction = new KToggleAction( this );
+    collection->addAction( "toggleUrlGrabAction", toggleURLGrabAction );
     toggleURLGrabAction->setEnabled( true );
     //toggleURLGrabAction->setGroup( defaultGroup );
-    clearHistoryAction = new KAction(KIcon("history_clear"),  i18n("C&lear Clipboard History"), collection, "clearHistoryAction" );
+    clearHistoryAction = collection->addAction( "clearHistoryAction" );
+    clearHistoryAction->setIcon( KIcon("history_clear") );
+    clearHistoryAction->setText( i18n("C&lear Clipboard History") );
     connect(clearHistoryAction, SIGNAL(triggered(bool) ), history(), SLOT( slotClear() ));
     connect( clearHistoryAction, SIGNAL( activated() ), SLOT( slotClearClipboard() ) );
     //clearHistoryAction->setGroup( defaultGroup );
-    configureAction = new KAction(KIcon("configure"),  i18n("&Configure Klipper..."), collection, "configureAction" );
+    configureAction = collection->addAction( "configureAction" );
+    configureAction->setIcon( KIcon("configure") );
+    configureAction->setText( i18n("&Configure Klipper...") );
     connect(configureAction, SIGNAL(triggered(bool) ), SLOT( slotConfigure() ));
     //configureAction->setGroup( defaultGroup );
-    quitAction = new KAction( KIcon("exit"), i18n("&Quit"), collection, "quitAction" );
+    quitAction = collection->addAction( "quitAction" );
+    quitAction->setIcon( KIcon("exit") );
+    quitAction->setText( i18n("&Quit") );
     connect(quitAction, SIGNAL(triggered(bool) ), SLOT( slotQuit() ));
     //quitAction->setGroup( "exit" );
     myURLGrabber = 0L;
-    KConfig *kc = m_config;
+    KConfig *kc = m_config.data();
     readConfiguration( kc );
     setURLGrabberEnabled( bURLGrabber );
 
     hideTimer = new QTime();
     showTimer = new QTime();
 
-    readProperties(m_config);
-    connect(kapp, SIGNAL(settingsChanged(int)), SLOT(slotSettingsChanged(int)));
+    readProperties(m_config.data());
+    connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), SLOT(slotSettingsChanged(int)));
 
     poll = new ClipboardPoll( this );
     connect( poll, SIGNAL( clipboardChanged( bool ) ),
@@ -195,14 +194,15 @@ KlipperWidget::KlipperWidget( QWidget *parent, KConfig* config )
     adjustSize();
 
     globalKeys = KGlobalAccel::self();
-    KGlobalAccel* keys = globalKeys;
     KActionCollection* actionCollection = collection;
-    KAction* a = 0L;
+    QAction* a = 0L;
 #include "klipperbindings.cpp"
     // the keys need to be read from kdeglobals, not kickerrc --ellis, 22/9/02
     globalKeys->readSettings();
     //globalKeys->updateConnections();
+#ifdef __GNUC__
 #warning TODO PORT ME (KGlobalAccel related)
+#endif
     //toggleURLGrabAction->setShortcut(globalKeys->shortcut("Enable/Disable Clipboard Actions"));
 
     connect( toggleURLGrabAction, SIGNAL( toggled( bool )),
@@ -229,9 +229,6 @@ KlipperWidget::~KlipperWidget()
     delete showTimer;
     delete hideTimer;
     delete myURLGrabber;
-    if( m_config != KGlobal::config())
-        delete m_config;
-    qt_qclipboard_bailout_hack = false;
 }
 
 void KlipperWidget::adjustSize()
@@ -416,7 +413,7 @@ void KlipperWidget::saveHistory() {
         return;
     }
     KSaveFile history_file( history_file_name );
-    if ( history_file.status() != 0  ) {
+    if ( !history_file.open() ) {
         kWarning() << failed_save_warning << endl;
         return;
     }
@@ -427,7 +424,8 @@ void KlipperWidget::saveHistory() {
         history_stream << item;
     }
     quint32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
-    *history_file.dataStream() << crc << data;
+    QDataStream ds ( &history_file );
+    ds << crc << data;
 }
 
 void KlipperWidget::readProperties(KConfig *kc)
@@ -465,15 +463,15 @@ void KlipperWidget::readProperties(KConfig *kc)
 void KlipperWidget::readConfiguration( KConfig *kc )
 {
     kc->setGroup("General");
-    bPopupAtMouse = kc->readEntry("PopupAtMousePosition", QVariant(false)).toBool();
-    bKeepContents = kc->readEntry("KeepClipboardContents", QVariant(true)).toBool();
-    bURLGrabber = kc->readEntry("URLGrabberEnabled", QVariant(false)).toBool();
-    bReplayActionInHistory = kc->readEntry("ReplayActionInHistory", QVariant(false)).toBool();
-    bNoNullClipboard = kc->readEntry("NoEmptyClipboard", QVariant(true)).toBool();
-    bUseGUIRegExpEditor = kc->readEntry("UseGUIRegExpEditor", QVariant(true )).toBool();
+    bPopupAtMouse = kc->readEntry("PopupAtMousePosition", false);
+    bKeepContents = kc->readEntry("KeepClipboardContents", true);
+    bURLGrabber = kc->readEntry("URLGrabberEnabled", false);
+    bReplayActionInHistory = kc->readEntry("ReplayActionInHistory", false);
+    bNoNullClipboard = kc->readEntry("NoEmptyClipboard", true);
+    bUseGUIRegExpEditor = kc->readEntry("UseGUIRegExpEditor", true);
     history()->max_size( kc->readEntry("MaxClipItems", 7) );
-    bIgnoreSelection = kc->readEntry("IgnoreSelection", QVariant(false)).toBool();
-    bSynchronize = kc->readEntry("Synchronize", QVariant(false)).toBool();
+    bIgnoreSelection = kc->readEntry("IgnoreSelection", false);
+    bSynchronize = kc->readEntry("Synchronize", false);
     bSelectionTextOnly = kc->readEntry("SelectionTextOnly",true);
     bIgnoreImages = kc->readEntry("IgnoreImages",true);
 }
@@ -509,10 +507,12 @@ void KlipperWidget::saveSession()
 
 void KlipperWidget::slotSettingsChanged( int category )
 {
-    if ( category == (int) KApplication::SETTINGS_SHORTCUTS ) {
+    if ( category == (int) KGlobalSettings::SETTINGS_SHORTCUTS ) {
         globalKeys->readSettings();
         //globalKeys->updateConnections();
+#ifdef __GNUC__
 #warning TODO PORT ME (KGlobalAccel related)
+#endif
         //toggleURLGrabAction->setShortcut(globalKeys->shortcut("Enable/Disable Clipboard Actions"));
     }
 }
@@ -531,7 +531,7 @@ void KlipperWidget::slotConfigure()
     bool haveURLGrabber = bURLGrabber;
     if ( !myURLGrabber ) { // temporary, for the config-dialog
         setURLGrabberEnabled( true );
-        readConfiguration( m_config );
+        readConfiguration( m_config.data() );
     }
 
     ConfigDialog *dlg = new ConfigDialog( myURLGrabber->actionList(),
@@ -560,7 +560,9 @@ void KlipperWidget::slotConfigure()
         // the keys need to be written to kdeglobals, not kickerrc --ellis, 22/9/02
         globalKeys->writeSettings(0, true);
         //globalKeys->updateConnections();
+#ifdef __GNUC__
 #warning TODO PORT ME (KGlobalAccel related)
+#endif
 //        toggleURLGrabAction->setShortcut(globalKeys->shortcut("Enable/Disable Clipboard Actions"));
 
         myURLGrabber->setActionList( dlg->actionList() );
@@ -570,7 +572,7 @@ void KlipperWidget::slotConfigure()
 
         history()->max_size( dlg->maxItems() );
 
-        writeConfiguration( m_config );
+        writeConfiguration( m_config.data() );
 
     }
     setURLGrabberEnabled( haveURLGrabber );
@@ -588,9 +590,9 @@ void KlipperWidget::slotQuit()
     }
 
     saveSession();
-    int autoStart = KMessageBox::questionYesNoCancel( 0L, i18n("Should Klipper start automatically\nwhen you login?"), i18n("Automatically Start Klipper?"), i18n("Start"), i18n("Do Not Start") );
+    int autoStart = KMessageBox::questionYesNoCancel( 0L, i18n("Should Klipper start automatically\nwhen you login?"), i18n("Automatically Start Klipper?"),KGuiItem(i18n("Start")), KGuiItem(i18n("Do Not Start")) );
 
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->setGroup("General");
     if ( autoStart == KMessageBox::Yes ) {
         config->writeEntry("AutoStart", true);
@@ -631,7 +633,7 @@ void KlipperWidget::setURLGrabberEnabled( bool enable )
 {
     if (enable != bURLGrabber) {
       bURLGrabber = enable;
-      KConfig *kc = m_config;
+      KConfig *kc = m_config.data();
       kc->setGroup("General");
       kc->writeEntry("URLGrabberEnabled", bURLGrabber);
       m_lastURLGrabberTextSelection = QString();
@@ -884,8 +886,6 @@ void KlipperWidget::checkClipData( bool selectionMode )
 // if this actually needs to be more configurable than only text vs all klipper knows.
         if( bIgnoreImages )
             return;
-        else
-            ; // ok
     }
     else // unknown, ignore
         return;
@@ -1144,7 +1144,9 @@ Klipper::Klipper( QWidget* parent )
 // find newInstance()  (which doesn't do anything in Klipper anyway)
 int Klipper::newInstance()
 {
+#ifdef __GNUC__
 #warning replacement?
+#endif
  //   kapp->dcopClient()->setPriorityCall(false); // Allow other dcop calls
 
     return 0;
@@ -1157,15 +1159,14 @@ void Klipper::quitProcess()
     kapp->quit();
 }
 
-static void ensureGlobalSyncOff(KConfig* config) {
+static void ensureGlobalSyncOff(KSharedConfigPtr config) {
     config->setGroup("General");
-    if ( config->readEntry( "SynchronizeClipboardAndSelection" , QVariant(false)).toBool() ) {
+    if ( config->readEntry( "SynchronizeClipboardAndSelection" , false) ) {
         kDebug() << "Shutting off global synchronization" << endl;
         config->writeEntry("SynchronizeClipboardAndSelection", false, KConfig::Normal | KConfig::Global );
         config->sync();
-        KClipboardSynchronizer::setSynchronizing( false );
-        KClipboardSynchronizer::setReverseSynchronizing( false );
-        KIPC::sendMessageAll( KIPC::ClipboardConfigChanged, 0 );
+        kapp->setSynchronizeClipboard(false);
+        KGlobalSettings::self()->emitChange( KGlobalSettings::ClipboardConfigChanged, 0 );
     }
 
 }
