@@ -141,7 +141,7 @@ void TreeItem::setup()
 
 static QPixmap appIcon(const QString &iconName)
 {
-    QPixmap normal = KGlobal::iconLoader()->loadIcon(iconName, K3Icon::Small, 0, K3Icon::DefaultState, 0L, true);
+    QPixmap normal = KIconLoader::global()->loadIcon(iconName, K3Icon::Small, 0, K3Icon::DefaultState, 0L, true);
     // make sure they are not larger than 20x20
     if (normal.width() > 20 || normal.height() > 20)
     {
@@ -198,10 +198,10 @@ TreeView::TreeView( bool controlCenter, KActionCollection *ac, QWidget *parent,
     KSharedConfig::Ptr		pConfig = KSharedConfig::openConfig("kickerrc");
 
     pConfig->setGroup("menus");
-    m_detailedMenuEntries = pConfig->readEntry("DetailedMenuEntries", QVariant(true)).toBool();
+    m_detailedMenuEntries = pConfig->readEntry("DetailedMenuEntries", true);
     if (m_detailedMenuEntries)
     {
-        m_detailedEntriesNamesFirst = pConfig->readEntry("DetailedEntriesNamesFirst", QVariant(false)).toBool();
+        m_detailedEntriesNamesFirst = pConfig->readEntry("DetailedEntriesNamesFirst", false);
     }
 }
 
@@ -217,7 +217,7 @@ void TreeView::setViewMode(bool showHidden)
 
     // setup rmb menu
     m_rmb = new QMenu(this);
-    KAction *action;
+    QAction *action;
 
     action = m_ac->action("edit_cut");
     if(action) {
