@@ -33,7 +33,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-
+#include <config-ksmserver.h>
 #include <pwd.h>
 #include <sys/types.h>
 #include <sys/param.h>
@@ -73,7 +73,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <unistd.h>
 #include <kapplication.h>
 #include <kstaticdeleter.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kprocess.h>
 
 #include "server.h"
@@ -89,6 +89,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <QX11Info>
 #include <QApplication>
 #include <krandom.h>
+#include "klauncher_interface.h"
 
 KSMServer* the_server = 0;
 
@@ -116,15 +117,15 @@ void KSMServer::startApplication( QStringList command, const QString& clientMach
     }
     if ( !clientMachine.isEmpty() && clientMachine != "localhost" ) {
         command.prepend( clientMachine );
-	command.prepend( xonCommand ); // "xon" by default
+        command.prepend( xonCommand ); // "xon" by default
     }
     int n = command.count();
-    QDBusInterface klauncher( "org.kde.klauncher", "/KLauncher", "org.kde.KLauncher" );
+    org::kde::KLauncher klauncher("org.kde.klauncher", "/KLauncher", QDBusConnection::sessionBus());
     QString app = command[0];
     QStringList argList;
     for ( int i=1; i < n; i++)
        argList.append( command[i]);
-    klauncher.call( "exec_blind", app, argList );
+    klauncher.exec_blind(app, argList );
 }
 
 /*! Utility function to execute a command on the local machine. Used
@@ -141,7 +142,8 @@ void KSMServer::executeCommand( const QStringList& command )
 }
 
 IceAuthDataEntry *authDataEntries = 0;
-static KTempFile *remAuthFile = 0;
+
+static KTemporaryFile *remTempFile;
 
 static IceListenObj *listenObjs = 0;
 int numTransports = 0;
@@ -392,19 +394,19 @@ Status SetAuthentication_local (int count, IceListenObj *listenObjs)
 Status SetAuthentication (int count, IceListenObj *listenObjs,
                           IceAuthDataEntry **authDataEntries)
 {
-    KTempFile addAuthFile;
-    addAuthFile.setAutoDelete(true);
+    KTemporaryFile addTempFile;
+    KTemporaryFile *remTempFile = new KTemporaryFile;
 
-    remAuthFile = new KTempFile;
-    remAuthFile->setAutoDelete(true);
-
-    if ((addAuthFile.status() != 0) || (remAuthFile->status() != 0))
+    if (!addTempFile.open() || !remTempFile->open())
         return 0;
 
     if ((*authDataEntries = (IceAuthDataEntry *) malloc (
                          count * 2 * sizeof (IceAuthDataEntry))) == NULL)
         return 0;
 
+    FILE *addAuthFile = fopen(addTempFile.fileName().toAscii(), "r+");
+    FILE *remAuthFile = fopen(remTempFile->fileName().toAscii(), "r+");
+
     for (int i = 0; i < numTransports * 2; i += 2) {
         (*authDataEntries)[i].network_id =
             IceGetListenConnectionString (listenObjs[i/2]);
@@ -424,15 +426,15 @@ Status SetAuthentication (int count, IceListenObj *listenObjs,
             IceGenerateMagicCookie (MAGIC_COOKIE_LEN);
         (*authDataEntries)[i+1].auth_data_length = MAGIC_COOKIE_LEN;
 
-        write_iceauth (addAuthFile.fstream(), remAuthFile->fstream(), &(*authDataEntries)[i]);
-        write_iceauth (addAuthFile.fstream(), remAuthFile->fstream(), &(*authDataEntries)[i+1]);
+        write_iceauth (addAuthFile, remAuthFile, &(*authDataEntries)[i]);
+        write_iceauth (addAuthFile, remAuthFile, &(*authDataEntries)[i+1]);
 
         IceSetPaAuthData (2, &(*authDataEntries)[i]);
 
         IceSetHostBasedAuthProc (listenObjs[i/2], HostBasedAuthProc);
     }
-    addAuthFile.close();
-    remAuthFile->close();
+    fclose(addAuthFile);
+    fclose(remAuthFile);
 
     QString iceAuth = KGlobal::dirs()->findExe("iceauth");
     if (iceAuth.isEmpty())
@@ -442,7 +444,7 @@ Status SetAuthentication (int count, IceListenObj *listenObjs,
     }
 
     KProcess p;
-    p << iceAuth << "source" << addAuthFile.name();
+    p << iceAuth << "source" << addTempFile.fileName();
     p.start(KProcess::Block);
 
     return (1);
@@ -472,11 +474,11 @@ void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
     }
 
     KProcess p;
-    p << iceAuth << "source" << remAuthFile->name();
+    p << iceAuth << "source" << remTempFile->fileName();
     p.start(KProcess::Block);
 
-    delete remAuthFile;
-    remAuthFile = 0;
+    delete remTempFile;
+    remTempFile = 0;
 }
 
 static int Xio_ErrorHandler( Display * )
@@ -583,9 +585,8 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local )
   : sessionGroup( "" )
 {
     new KSMServerInterfaceAdaptor( this );
-    QDBus::sessionBus().registerObject("/KSMServer", this);
-    klauncherSignals = new QDBusInterface("org.kde.klauncher",
-        "/KLauncher", "org.kde.KLauncher", QDBus::sessionBus() );
+    QDBusConnection::sessionBus().registerObject("/KSMServer", this);
+    klauncherSignals = new QDBusInterface("org.kde.klauncher", "/KLauncher", "org.kde.KLauncher", QDBusConnection::sessionBus() );
     if( !klauncherSignals->isValid())
         kWarning() << "kded not running?" << endl;
     kcminitSignals = NULL;
@@ -599,12 +600,11 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local )
     dialogActive = false;
     saveSession = false;
     wmPhase1WaitingCount = 0;
-    KConfig* config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->setGroup("General" );
     clientInteracting = 0;
     xonCommand = config->readEntry( "xonCommand", "xon" );
 
-    connect( &knotifyTimeoutTimer, SIGNAL( timeout()), SLOT( knotifyTimeout()));
     connect( &startupSuspendTimeoutTimer, SIGNAL( timeout()), SLOT( startupSuspendTimeout()));
     connect( &pendingShutdown, SIGNAL( timeout()), SLOT( pendingShutdownTimeout()));
 
@@ -657,8 +657,8 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local )
         fclose(f);
         setenv( "SESSION_MANAGER", session_manager, true  );
        // Pass env. var to kdeinit.
-       QDBusInterface klauncher( "org.kde.klauncher", "/KLauncher", "org.kde.KLauncher" );
-       klauncher.call( "setLaunchEnv", "SESSION_MANAGER", (const char*) session_manager );
+       org::kde::KLauncher klauncher("org.kde.klauncher", "/KLauncher", QDBusConnection::sessionBus());
+       klauncher.setLaunchEnv( "SESSION_MANAGER", (const char*) session_manager );
     }
 
     if (only_local) {
@@ -812,7 +812,7 @@ QString KSMServer::currentSession()
 
 void KSMServer::discardSession()
 {
-    KConfig* config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->setGroup( sessionGroup );
     int count =  config->readEntry( "count", 0 );
 	foreach ( KSMClient *c, clients ) {
@@ -833,7 +833,7 @@ void KSMServer::discardSession()
 
 void KSMServer::storeSession()
 {
-    KConfig* config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->reparseConfiguration(); // config may have changed in the KControl module
     config->setGroup("General" );
     excludeApps = config->readEntry( "excludeApps" ).toLower().split( QRegExp( "[,:]" ), QString::SkipEmptyParts );
@@ -893,14 +893,14 @@ void KSMServer::storeSession()
     config->setGroup("General");
     config->writeEntry( "screenCount", ScreenCount(QX11Info::display()));
 
-    storeLegacySession( config );
+    storeLegacySession(config.data());
     config->sync();
 }
 
 QStringList KSMServer::sessionList()
 {
     QStringList sessions ( "default" );
-    KConfig* config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     QStringList groups = config->groupList();
     for ( QStringList::ConstIterator it = groups.begin(); it != groups.end(); it++ )
         if ( (*it).startsWith( "Session: " ) )
