@@ -71,10 +71,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <unistd.h>
 #include <kapplication.h>
 #include <kstaticdeleter.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kprocess.h>
 #include <kwinmodule.h>
-#include <knotifyclient.h>
+#include <knotification.h>
 #include <dmctl.h>
 #include "server.h"
 #include "global.h"
@@ -90,8 +90,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 void KSMServer::logout( int confirm, int sdtype, int sdmode )
 {
     shutdown( (KWorkSpace::ShutdownConfirm)confirm,
-              (KWorkSpace::ShutdownType)sdtype,
-              (KWorkSpace::ShutdownMode)sdmode );
+            (KWorkSpace::ShutdownType)sdtype,
+            (KWorkSpace::ShutdownMode)sdmode );
 }
 
 void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
@@ -115,15 +115,15 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
         return;
     }
 
-    KConfig *config = KGlobal::config();
+    KSharedConfig::Ptr config = KGlobal::config();
     config->reparseConfiguration(); // config may have changed in the KControl module
 
     config->setGroup("General" );
 
     bool logoutConfirmed =
         (confirm == KWorkSpace::ShutdownConfirmYes) ? false :
-       (confirm == KWorkSpace::ShutdownConfirmNo) ? true :
-                  !config->readEntry( "confirmLogout", true );
+    (confirm == KWorkSpace::ShutdownConfirmNo) ? true :
+                !config->readEntry( "confirmLogout", true );
     bool maysd = false;
     if (config->readEntry( "offerShutdown", true ) && DM().canShutdown())
         maysd = true;
@@ -135,7 +135,7 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
         sdtype = KWorkSpace::ShutdownTypeNone;
     } else if (sdtype == KWorkSpace::ShutdownTypeDefault)
         sdtype = (KWorkSpace::ShutdownType)
-                 config->readEntry( "shutdownType", (int)KWorkSpace::ShutdownTypeNone );
+                config->readEntry( "shutdownType", (int)KWorkSpace::ShutdownTypeNone );
     if (sdmode == KWorkSpace::ShutdownModeDefault)
         sdmode = KWorkSpace::ShutdownModeInteractive;
 
@@ -154,9 +154,9 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
 
     if ( logoutConfirmed ) {
 
-	shutdownType = sdtype;
-	shutdownMode = sdmode;
-	bootOption = bopt;
+        shutdownType = sdtype;
+        shutdownMode = sdmode;
+        bootOption = bopt;
 
         // shall we save the session on logout?
         saveSession = ( config->readEntry( "loginMode", "restorePreviousLogout" ) == "restorePreviousLogout" );
@@ -166,14 +166,14 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
 
         // Set the real desktop background to black so that exit looks
         // clean regardless of what was on "our" desktop.
-		QPalette palette;
+                QPalette palette;
         palette.setColor( kapp->desktop()->backgroundRole(), Qt::black );
         kapp->desktop()->setPalette(palette);
         state = Shutdown;
         wmPhase1WaitingCount = 0;
         saveType = saveSession?SmSaveBoth:SmSaveGlobal;
 #ifndef NO_LEGACY_SESSION_MANAGEMENT
-	performLegacySessionSave();
+        performLegacySessionSave();
 #endif
         startProtection();
         foreach( KSMClient* c, clients ) {
@@ -195,14 +195,14 @@ void KSMServer::shutdown( KWorkSpace::ShutdownConfirm confirm,
             if( isWM( c )) {
                 ++wmPhase1WaitingCount;
                 SmsSaveYourself( c->connection(), saveType,
-                             true, SmInteractStyleAny, false );
+                            true, SmInteractStyleAny, false );
             }
 
         }
         if( wmPhase1WaitingCount == 0 ) { // no WM, simply start them all
             foreach( KSMClient* c, clients )
                 SmsSaveYourself( c->connection(), saveType,
-                             true, SmInteractStyleAny, false );
+                            true, SmInteractStyleAny, false );
         }
         if ( clients.isEmpty() )
             completeShutdownOrCheckpoint();
@@ -353,7 +353,9 @@ void KSMServer::handlePendingInteractions()
 
 void KSMServer::cancelShutdown( KSMClient* c )
 {
-    kWarning( 1218 ) << "Client " << c->program() << " (" << c->clientId() << ") canceled shutdown." << endl;
+    kDebug( 1218 ) << "Client " << c->program() << " (" << c->clientId() << ") canceled shutdown." << endl;
+    KNotification::event( "cancellogout" , i18n( "Logout canceled by '%1'", c->program()),
+        QPixmap() , 0l , KNotification::DefaultEvent  );
     clientInteracting = 0;
     foreach( KSMClient* c, clients ) {
         SmsShutdownCancelled( c->connection() );
@@ -367,10 +369,21 @@ void KSMServer::cancelShutdown( KSMClient* c )
     state = Idle;
 }
 
+void KSMServer::startProtection()
+{
+    protectionTimer.setSingleShot( true );
+    protectionTimer.start( 10000 );
+}
+
+void KSMServer::endProtection()
+{
+    protectionTimer.stop();
+}
+
 /*
-   Internal protection slot, invoked when clients do not react during
-  shutdown.
- */
+Internal protection slot, invoked when clients do not react during
+shutdown.
+*/
 void KSMServer::protectionTimeout()
 {
     if ( ( state != Shutdown && state != Checkpoint ) || clientInteracting )
@@ -414,41 +427,23 @@ void KSMServer::completeShutdownOrCheckpoint()
         discardSession();
 
     if ( state == Shutdown ) {
-        bool waitForKNotify = true;
 #ifdef __GNUC__
 #warning KNotify TODO
 #endif
-#if 0
+	/*  How to check if the deamon is still running.    We will not start the knotify daemon just for playing a sound before shutdown.  or do wa want that ?
+
         knotifySignals = QDBus::sessionBus().findInterface("org.kde.knotify",
             "/knotify", "org.kde.KNotify" );
         if( !knotifySignals->isValid())
             kWarning() << "knotify not running?" << endl;
-        if( !kapp->dcopClient()->connectDCOPSignal( "knotify", "",
-            "notifySignal(QString,QString,QString,QString,QString,int,int,int,int)",
-            "ksmserver", "notifySlot(QString,QString,QString,QString,QString,int,int,int,int)", false )) {
-            waitForKNotify = false;
-        }
-        if( !kapp->dcopClient()->connectDCOPSignal( "knotify", "",
-            "playingFinished(int,int)",
-            "ksmserver", "logoutSoundFinished(int,int)", false )) {
-            waitForKNotify = false;
-        }
-#else
-        waitForKNotify = false;
-#endif
-        // event() can return -1 if KNotifyClient short-circuits and avoids KNotify
-        logoutSoundEvent = KNotifyClient::event( 0, "exitkde" ); // KDE says good bye
-        if( logoutSoundEvent <= 0 )
-            waitForKNotify = false;
-        if( waitForKNotify ) {
-            state = WaitingForKNotify;
-            knotifyTimeoutTimer.setSingleShot( true );
-            knotifyTimeoutTimer.start( 20000 );
-            return;
-        }
-        startKilling();
+	*/
+
+        KNotification *n = KNotification::event( "exitkde" , QString() , QPixmap() , 0l ,  KNotification::DefaultEvent  ); // KDE says good bye
+        connect(n, SIGNAL( closed() ) , this, SLOT(logoutSoundFinished()) );
+	state = WaitingForKNotify;
+ 
     } else if ( state == Checkpoint ) {
-	foreach( KSMClient* c, clients ) {
+        foreach( KSMClient* c, clients ) {
             SmsSaveComplete( c->connection());
         }
         state = Idle;
@@ -457,15 +452,14 @@ void KSMServer::completeShutdownOrCheckpoint()
 
 void KSMServer::startKilling()
 {
-    knotifyTimeoutTimer.stop();
-    state = KillingWM;
+        state = KillingWM;
 // kill the WM first, so that it doesn't track changes that happen as a result of other
 // clients going away (e.g. if KWin is set to remember position of a window, it could
 // shift because of Kicker going away and KWin would remember wrong position)
     foreach( KSMClient* c, clients ) {
         if( isWM( c )) {
             kDebug( 1218 ) << "Killing WM: " << c->program() << "(" << c->clientId() << ")" << endl;
-            QTimer::singleShot( 1000, this, SLOT( timeoutWMQuit()));
+            QTimer::singleShot( 2000, this, SLOT( timeoutWMQuit()));
             SmsDie( c->connection());
             return;
         }
@@ -485,9 +479,9 @@ void KSMServer::performStandardKilling()
     }
 
     kDebug( 1218 ) << " We killed all clients. We have now clients.count()=" <<
-       clients.count() << endl;
+    clients.count() << endl;
     completeKilling();
-    QTimer::singleShot( 4000, this, SLOT( timeoutQuit() ) );
+    QTimer::singleShot( 10000, this, SLOT( timeoutQuit() ) );
 }
 
 void KSMServer::completeKilling()
@@ -511,35 +505,14 @@ void KSMServer::completeKilling()
     }
 }
 
-// called when KNotify performs notification for logout (not when sound is finished though)
-void KSMServer::notifySlot(QString event ,QString app,QString,QString,QString,int present,int,int,int)
+
+void KSMServer::logoutSoundFinished(  )
 {
     if( state != WaitingForKNotify )
         return;
-    if( event != "exitkde" || app != "ksmserver" )
-        return;
-    if( present & KNotifyClient::Sound ) // logoutSoundFinished() will be called
-        return;
     startKilling();
 }
 
-// This is stupid. The normal DCOP signal connected to notifySlot() above should be simply
-// emitted in KNotify only after the sound is finished playing.
-void KSMServer::logoutSoundFinished( int event, int )
-{
-    if( state != WaitingForKNotify )
-        return;
-    if( event != logoutSoundEvent )
-        return;
-    startKilling();
-}
-
-void KSMServer::knotifyTimeout()
-{
-    if( state != WaitingForKNotify )
-        return;
-    startKilling();
-}
 
 void KSMServer::timeoutWMQuit()
 {
