@@ -12,17 +12,13 @@ main(int argc, char *argv[])
    KCmdLineArgs::init(argc, argv, &about);
 
    KApplication a;
-   a.iconLoader()->addAppDir("ksmserver");
+   KIconLoader::global()->addAppDir("ksmserver");
    KSMShutdownFeedback::start();
 
    KWorkSpace::ShutdownType sdtype = KWorkSpace::ShutdownTypeNone;
    QString bopt;
-   (void)KSMShutdownDlg::confirmShutdown( true,
-                                          sdtype,
-                                          bopt );
-/*   (void)KSMShutdownDlg::confirmShutdown( false,
-                                          sdtype,
-                                          bopt ); */
+   (void)KSMShutdownDlg::confirmShutdown( true, sdtype, bopt );
+/*   (void)KSMShutdownDlg::confirmShutdown( false, sdtype, bopt ); */
 
    KSMShutdownFeedback::stop();
 }
