@@ -22,44 +22,43 @@
 #include <kcolorbutton.h>
 #include <kcolordialog.h>
 #include <klineedit.h>
-#include <k3listview.h>
 #include <klocale.h>
 #include <knuminput.h>
 
-#include <QCheckBox>
-#include <QGroupBox>
-#include <q3groupbox.h>
-#include <QImage>
-#include <QLabel>
-#include <QLayout>
-#include <QPixmap>
-#include <QPushButton>
-#include <QRadioButton>
-
-#include <QGridLayout>
-#include <QList>
+#include <QtCore/QAbstractTableModel>
+#include <QtCore/QList>
+#include <QtGui/QCheckBox>
+#include <QtGui/QGridLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QHeaderView>
+#include <QtGui/QImage>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QPixmap>
+#include <QtGui/QPushButton>
+#include <QtGui/QTreeView>
 
 #include "FancyPlotterSettings.h"
 
 FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
-  : KPageDialog( parent )
+  : KPageDialog( parent ), mModel( new SensorModel( this ) )
 {
   setFaceType( Tabbed );
   setCaption( i18n( "Signal Plotter Settings" ) );
   setButtons( Ok | Apply | Cancel );
   setObjectName( "FancyPlotterSettings" );
-  setModal( true );
+  setModal( false );
   showButtonSeparator( true );
 
   QFrame *page = 0;
   QGridLayout *pageLayout = 0;
   QGridLayout *boxLayout = 0;
-  Q3GroupBox *groupBox = 0;
+  QGroupBox *groupBox = 0;
   QLabel *label = 0;
 
   // Style page
   page = new QFrame();
-  addPage( page, i18n( "Style" ) );
+  addPage( page, i18n( "General" ) );
   pageLayout = new QGridLayout( page );
   pageLayout->setSpacing( spacingHint() );
   pageLayout->setMargin( 0 );
@@ -72,19 +71,10 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   pageLayout->addWidget( mTitle, 0, 1 );
   label->setBuddy( mTitle );
 
-  QGroupBox *buttonBox = new QGroupBox(i18n( "Graph Drawing Style" ),page);
-  
-
-  QVBoxLayout *vbox = new QVBoxLayout;
-  vbox->addStretch(2);
-  mUsePolygonStyle = new QRadioButton( i18n( "Basic polygons" ) );
-  vbox->addWidget(mUsePolygonStyle);
-  mUsePolygonStyle->setChecked( true );
-  mUseOriginalStyle = new QRadioButton( i18n( "Original - single line per data point" ) );
-  vbox->addWidget(mUseOriginalStyle);
-
-  buttonBox->setLayout(vbox);
-  pageLayout->addWidget( buttonBox, 1, 0, 1, 2 );
+  mStackBeams = new QCheckBox( i18n("Stack the beams on top of each other"), page);
+  mStackBeams->setWhatsThis( i18n("The beams are stacked on top of each other, and the area is drawn filled in. So if one beam has a value of 2 and another beam has a value of 3, the first beam will be draw at value 2 and the other beam drawn at 2+3=5") );
+  pageLayout->addWidget( mStackBeams, 1, 0,1,2);
+  pageLayout->setRowStretch( 2, 1 );
 
   // Scales page
   page = new QFrame();
@@ -93,9 +83,9 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   pageLayout->setSpacing( spacingHint() );
   pageLayout->setMargin( 0 );
 
-  groupBox = new Q3GroupBox( 0, Qt::Vertical, i18n( "Vertical Scale" ), page );
-  boxLayout = new QGridLayout(  );
-  groupBox->layout()->addItem( boxLayout );
+  groupBox = new QGroupBox( i18n( "Vertical Scale" ), page );
+  boxLayout = new QGridLayout;
+  groupBox->setLayout( boxLayout );
   boxLayout->setSpacing( spacingHint() );
   boxLayout->setColumnStretch( 2, 1 );
 
@@ -125,9 +115,9 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
 
   pageLayout->addWidget( groupBox, 0, 0 );
 
-  groupBox = new Q3GroupBox( 0, Qt::Vertical, i18n( "Horizontal Scale" ), page );
-  boxLayout = new QGridLayout(  );
-  groupBox->layout()->addItem( boxLayout );
+  groupBox = new QGroupBox( i18n( "Horizontal Scale" ), page );
+  boxLayout = new QGridLayout;
+  groupBox->setLayout( boxLayout );
   boxLayout->setSpacing( spacingHint() );
   boxLayout->setRowStretch( 1, 1 );
 
@@ -148,9 +138,9 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   pageLayout->setSpacing( spacingHint() );
   pageLayout->setMargin( 0 );
 
-  groupBox = new Q3GroupBox( 0, Qt::Vertical, i18n( "Lines" ), page );
-  boxLayout = new QGridLayout(  );
-  groupBox->layout()->addItem( boxLayout );
+  groupBox = new QGroupBox( i18n( "Lines" ), page );
+  boxLayout = new QGridLayout;
+  groupBox->setLayout( boxLayout );
   boxLayout->setSpacing( spacingHint() );
   boxLayout->setColumnStretch( 1, 1 );
 
@@ -179,8 +169,8 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   boxLayout->addWidget( label, 1, 2 );
 
   mHorizontalLinesCount = new KIntNumInput( 0, groupBox );
-  mHorizontalLinesCount->setMinimum( 2 );
-  mHorizontalLinesCount->setMaximum( 20 );
+  mHorizontalLinesCount->setMinimum( 1 );
+  mHorizontalLinesCount->setMaximum( 100 );
   mHorizontalLinesCount->setWhatsThis( i18n( "Enter the number of horizontal lines here." ) );
   boxLayout->addWidget( mHorizontalLinesCount , 1, 3 );
   label->setBuddy( mHorizontalLinesCount );
@@ -189,9 +179,9 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
 
   pageLayout->addWidget( groupBox, 0, 0, 1, 2 );
 
-  groupBox = new Q3GroupBox( 0, Qt::Vertical, i18n( "Text" ), page );
-  boxLayout = new QGridLayout( );
-  groupBox->layout()->addItem( boxLayout );
+  groupBox = new QGroupBox( i18n( "Text" ), page );
+  boxLayout = new QGridLayout;
+  groupBox->setLayout( boxLayout );
   boxLayout->setSpacing( spacingHint() );
   boxLayout->setColumnStretch( 1, 1 );
 
@@ -216,33 +206,39 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
 
   pageLayout->addWidget( groupBox, 1, 0 );
 
-  groupBox = new Q3GroupBox( 0, Qt::Vertical, i18n( "Colors" ), page );
-  boxLayout = new QGridLayout( );
-  groupBox->layout()->addItem( boxLayout );
+  groupBox = new QGroupBox( i18n( "Colors" ), page );
+  boxLayout = new QGridLayout;
+  groupBox->setLayout( boxLayout );
   boxLayout->setSpacing( spacingHint() );
 
-  label = new QLabel( i18n( "Vertical lines:" ), groupBox );
+  label = new QLabel( i18n( "Font:" ), groupBox );
   boxLayout->addWidget( label, 0, 0 );
+  mFontColor = new KColorButton( groupBox );
+  boxLayout->addWidget( mFontColor, 0, 1 );
+  label->setBuddy( mFontColor );
 
+
+  label = new QLabel( i18n( "Vertical lines:" ), groupBox );
+  boxLayout->addWidget( label, 1, 0 );
   mVerticalLinesColor = new KColorButton( groupBox );
-  boxLayout->addWidget( mVerticalLinesColor, 0, 1 );
+  boxLayout->addWidget( mVerticalLinesColor, 1, 1 );
   label->setBuddy( mVerticalLinesColor );
 
   label = new QLabel( i18n( "Horizontal lines:" ), groupBox );
-  boxLayout->addWidget( label, 1, 0 );
+  boxLayout->addWidget( label, 2, 0 );
 
   mHorizontalLinesColor = new KColorButton( groupBox );
-  boxLayout->addWidget( mHorizontalLinesColor, 1, 1 );
+  boxLayout->addWidget( mHorizontalLinesColor, 2, 1 );
   label->setBuddy( mHorizontalLinesColor );
 
   label = new QLabel( i18n( "Background:" ), groupBox );
-  boxLayout->addWidget( label, 2, 0 );
+  boxLayout->addWidget( label, 3, 0 );
 
   mBackgroundColor = new KColorButton( groupBox );
-  boxLayout->addWidget( mBackgroundColor, 2, 1 );
+  boxLayout->addWidget( mBackgroundColor, 3, 1 );
   label->setBuddy( mBackgroundColor );
 
-  boxLayout->setRowStretch( 3, 1 );
+  boxLayout->setRowStretch( 4, 1 );
 
   pageLayout->addWidget( groupBox, 1, 1 );
 
@@ -257,46 +253,40 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   pageLayout->setRowStretch( 2, 1 );
   pageLayout->setRowStretch( 5, 1 );
 
-  mSensorView = new K3ListView( page );
-  mSensorView->addColumn( i18n( "#" ) );
-  mSensorView->addColumn( i18n( "Host" ) );
-  mSensorView->addColumn( i18n( "Sensor" ) );
-  mSensorView->addColumn( i18n( "Unit" ) );
-  mSensorView->addColumn( i18n( "Status" ) );
-  mSensorView->setAllColumnsShowFocus( true );
-  pageLayout->addWidget( mSensorView, 0, 0, 6, 1 );
-  mSensorView->setSortColumn ( -1 );
+  mView = new QTreeView( page );
+  mView->header()->setStretchLastSection( true );
+  mView->setRootIsDecorated( false );
+  mView->setItemsExpandable( false );
+  mView->setModel( mModel );
+  pageLayout->addWidget( mView, 0, 0, 6, 1 );
+
   mEditButton = new QPushButton( i18n( "Set Color..." ), page );
-  mEditButton->setEnabled( false );
   mEditButton->setWhatsThis( i18n( "Push this button to configure the color of the sensor in the diagram." ) );
   pageLayout->addWidget( mEditButton, 0, 1 );
 
-  
-  if(!locked) {
-	  
-  mRemoveButton = new QPushButton( i18n( "Delete" ), page );
-  mRemoveButton->setEnabled( false );
-  mRemoveButton->setWhatsThis( i18n( "Push this button to delete the sensor." ) );
-  pageLayout->addWidget( mRemoveButton, 1, 1 );
+  mRemoveButton = 0;
+  mMoveUpButton = 0;
+  mMoveDownButton = 0;
+  if ( !locked ) {
+    mRemoveButton = new QPushButton( i18n( "Delete" ), page );
+    mRemoveButton->setWhatsThis( i18n( "Push this button to delete the sensor." ) );
+    pageLayout->addWidget( mRemoveButton, 1, 1 );
+    connect( mRemoveButton, SIGNAL( clicked() ), SLOT( removeSensor() ) );
 
-  mMoveUpButton = new QPushButton( i18n( "Move Up" ), page );
-  mMoveUpButton->setEnabled( false );
-  pageLayout->addWidget( mMoveUpButton, 3, 1 );
+    mMoveUpButton = new QPushButton( i18n( "Move Up" ), page );
+    mMoveUpButton->setEnabled( false );
+    pageLayout->addWidget( mMoveUpButton, 2, 1 );
+    connect( mMoveUpButton, SIGNAL( clicked() ), SLOT( moveUpSensor() ) );
 
-  mMoveDownButton = new QPushButton( i18n( "Move Down" ), page );
-  mMoveDownButton->setEnabled( false );
-  pageLayout->addWidget( mMoveDownButton, 4, 1 );
-  
-  connect( mRemoveButton, SIGNAL( clicked() ), SLOT( removeSensor() ) );
-  connect( mMoveUpButton, SIGNAL( clicked() ), SLOT( moveUpSensor() ) );
-  connect( mMoveDownButton, SIGNAL( clicked() ), SLOT( moveDownSensor() ) );
+    mMoveDownButton = new QPushButton( i18n( "Move Down" ), page );
+    mMoveDownButton->setEnabled( false );
+    pageLayout->addWidget( mMoveDownButton, 3, 1 );
+    connect( mMoveDownButton, SIGNAL( clicked() ), SLOT( moveDownSensor() ) );
+
+    connect(mView->selectionModel(), SIGNAL(currentRowChanged( const QModelIndex &, const QModelIndex &)), this, SLOT( selectionChanged(const QModelIndex &)));
 
-  } else {
-    mRemoveButton = 0;
-    mMoveUpButton = 0;
-    mMoveDownButton = 0;
   }
-  
+
   connect( mUseAutoRange, SIGNAL( toggled( bool ) ), mMinValue,
            SLOT( setDisabled( bool ) ) );
   connect( mUseAutoRange, SIGNAL( toggled( bool ) ), mMaxValue,
@@ -313,11 +303,8 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
            SLOT( setEnabled( bool ) ) );
   connect( mShowHorizontalLines, SIGNAL( toggled( bool ) ), mShowLabels,
            SLOT( setEnabled( bool ) ) );
-  connect( mSensorView, SIGNAL( selectionChanged( Q3ListViewItem* ) ),
-           SLOT( selectionChanged( Q3ListViewItem* ) ) );
 
   connect( mEditButton, SIGNAL( clicked() ), SLOT( editSensor() ) );
-  connect ( mSensorView, SIGNAL( doubleClicked( Q3ListViewItem *, const QPoint &, int )), SLOT(editSensor()));
 
   KAcceleratorManager::manage( this );
 }
@@ -326,6 +313,31 @@ FancyPlotterSettings::~FancyPlotterSettings()
 {
 }
 
+void FancyPlotterSettings::setStackBeams( bool stack )
+{
+  mStackBeams->setChecked(stack);
+}
+bool FancyPlotterSettings::stackBeams() const {
+  return mStackBeams->isChecked();
+}
+void FancyPlotterSettings::moveUpSensor()
+{
+  mModel->moveUpSensor(mView->selectionModel()->currentIndex());
+  selectionChanged(mView->selectionModel()->currentIndex());
+}
+void FancyPlotterSettings::moveDownSensor()
+{
+  mModel->moveDownSensor(mView->selectionModel()->currentIndex());
+  selectionChanged(mView->selectionModel()->currentIndex());
+}
+void FancyPlotterSettings::selectionChanged(const QModelIndex &newCurrent)
+{
+  mMoveUpButton->setEnabled(newCurrent.isValid() && newCurrent.row() > 0);
+  mMoveDownButton->setEnabled(newCurrent.isValid() && newCurrent.row() < mModel->rowCount() -1 );
+  mEditButton->setEnabled(newCurrent.isValid());
+  mRemoveButton->setEnabled(newCurrent.isValid());
+}
+
 void FancyPlotterSettings::setTitle( const QString &title )
 {
   mTitle->setText( title );
@@ -368,19 +380,6 @@ double FancyPlotterSettings::maxValue() const
   return mMaxValue->text().toDouble();
 }
 
-void FancyPlotterSettings::setUsePolygonStyle( bool value )
-{
-  if ( value )
-    mUsePolygonStyle->setChecked( true );
-  else
-    mUseOriginalStyle->setChecked( true );
-}
-
-bool FancyPlotterSettings::usePolygonStyle() const
-{
-  return mUsePolygonStyle->isChecked();
-}
-
 void FancyPlotterSettings::setHorizontalScale( int scale )
 {
   mHorizontalScale->setValue( scale );
@@ -497,7 +496,15 @@ int FancyPlotterSettings::fontSize() const
 {
   return mFontSize->value();
 }
+void FancyPlotterSettings::setFontColor( const QColor &color )
+{
+  mFontColor->setColor( color );
+}
 
+QColor FancyPlotterSettings::fontColor() const
+{
+  return mFontColor->color();
+}
 void FancyPlotterSettings::setBackgroundColor( const QColor &color )
 {
   mBackgroundColor->setColor( color );
@@ -508,141 +515,70 @@ QColor FancyPlotterSettings::backgroundColor() const
   return mBackgroundColor->color();
 }
 
-void FancyPlotterSettings::setSensors( const QList< QStringList > &list )
+void FancyPlotterSettings::setSensors( const SensorModelEntry::List &list )
 {
-  mSensorView->clear();
+  mModel->setSensors( list );
 
-  QList< QStringList >::ConstIterator it;
-  for ( it = list.begin(); it != list.end(); ++it ) {
-    Q3ListViewItem* lvi = new Q3ListViewItem( mSensorView,
-                                            (*it)[ 0 ],   // id
-                                            (*it)[ 1 ],   // host name
-                                            (*it)[ 2 ],   // sensor name
-                                            (*it)[ 3 ],   // unit
-                                            (*it)[ 4 ] ); // status
-    QPixmap pm( 12, 12 );
-    pm.fill( QColor( (*it)[ 5 ] ) );
-    lvi->setPixmap( 2, pm );
-    mSensorView->insertItem( lvi );
-  }
+  mView->selectionModel()->setCurrentIndex( mModel->index( 0, 0 ), QItemSelectionModel::SelectCurrent |
+                                                                   QItemSelectionModel::Rows );
 }
 
-QList< QStringList > FancyPlotterSettings::sensors() const
+SensorModelEntry::List FancyPlotterSettings::sensors() const
 {
-  QList< QStringList > list;
-
-  Q3ListViewItemIterator it( mSensorView );
-
-  for ( ; it.current(); ++it ) {
-    QStringList entry;
-    entry << it.current()->text( 0 );
-    entry << it.current()->text( 1 );
-    entry << it.current()->text( 2 );
-    entry << it.current()->text( 3 );
-    entry << it.current()->text( 4 );
-    QRgb rgb = it.current()->pixmap( 2 )->toImage().pixel( 1, 1 );
-    QColor color( qRed( rgb ), qGreen( rgb ), qBlue( rgb ) );
-    entry << ( color.name() );
-
-    list.append( entry );
-  }
-
-  return list;
+  return mModel->sensors();
 }
 
 void FancyPlotterSettings::editSensor()
 {
-  Q3ListViewItem* lvi = mSensorView->currentItem();
-
-  if ( !lvi )
+  if ( !mView->selectionModel() )
     return;
 
-  QColor color = lvi->pixmap( 2 )->toImage().pixel( 1, 1 );
+  const QModelIndex index = mView->selectionModel()->currentIndex();
+  if ( !index.isValid() )
+    return;
+
+  SensorModelEntry sensor = mModel->sensor( index );
+
+  QColor color = sensor.color();
   int result = KColorDialog::getColor( color, parentWidget() );
   if ( result == KColorDialog::Accepted ) {
-    QPixmap newPm( 12, 12 );
-    newPm.fill( color );
-    lvi->setPixmap( 2, newPm );
+    sensor.setColor( color );
+    mModel->setSensor( sensor, index );
   }
 }
 
 void FancyPlotterSettings::removeSensor()
 {
-  Q3ListViewItem* lvi = mSensorView->currentItem();
+  if ( !mView->selectionModel() )
+    return;
 
-  if ( lvi ) {
-    /* Before we delete the currently selected item, we determine a
-     * new item to be selected. That way we can ensure that multiple
-     * items can be deleted without forcing the user to select a new
-     * item between the deletes. If all items are deleted, the buttons
-     * are disabled again. */
-    Q3ListViewItem* newSelected = 0;
-    if ( lvi->itemBelow() ) {
-      lvi->itemBelow()->setSelected( true );
-      newSelected = lvi->itemBelow();
-    } else if ( lvi->itemAbove() ) {
-      lvi->itemAbove()->setSelected( true );
-      newSelected = lvi->itemAbove();
-    } else
-      selectionChanged( 0 );
-
-    delete lvi;
-
-    if ( newSelected )
-      mSensorView->ensureItemVisible( newSelected );
-  }
+  const QModelIndex index = mView->selectionModel()->currentIndex();
+  if ( !index.isValid() )
+    return;
+  mModel->removeSensor( index );
+  selectionChanged( mView->selectionModel()->currentIndex() );
 }
 
-void FancyPlotterSettings::moveUpSensor()
+void FancyPlotterSettings::clearDeleted()
 {
-  if ( mSensorView->currentItem() != 0 ) {
-    Q3ListViewItem* item = mSensorView->currentItem()->itemAbove();
-    if ( item ) {
-      if ( item->itemAbove() )
-      {
-        mSensorView->currentItem()->moveItem( item->itemAbove() );
-      }
-      else
-      {
-        item->moveItem( mSensorView->currentItem() );
-      }
-    }
-
-    // Re-calculate the "sensor number" field
-    item = mSensorView->firstChild();
-    for ( uint count = 1; item; item = item->itemBelow(), count++ )
-      item->setText( 0, QString( "%1" ).arg( count ) );
-
-    selectionChanged( mSensorView->currentItem() );
-  }
+  mModel->clearDeleted();
 }
 
-void FancyPlotterSettings::moveDownSensor()
+QList<int> FancyPlotterSettings::deleted() const
 {
-  if ( mSensorView->currentItem() != 0 ) {
-    if ( mSensorView->currentItem()->itemBelow() )
-      mSensorView->currentItem()->moveItem( mSensorView->currentItem()->itemBelow() );
-
-    // Re-calculate the "sensor number" field
-    Q3ListViewItem* item = mSensorView->firstChild();
-    for ( uint count = 1; item; item = item->itemBelow(), count++ )
-      item->setText( 0, QString( "%1" ).arg( count ) );
-
-    selectionChanged( mSensorView->currentItem() );
-  }
+  return mModel->deleted();
 }
 
-void FancyPlotterSettings::selectionChanged( Q3ListViewItem *item )
+QList<int> FancyPlotterSettings::order() const
 {
-  bool state = ( item != 0 );
-
-  mEditButton->setEnabled( state );
-
-  if(mRemoveButton) {
-    mRemoveButton->setEnabled( state );
-    mMoveUpButton->setEnabled( state && item->itemAbove() );
-    mMoveDownButton->setEnabled( state && item->itemBelow() );
-  }
+  return mModel->order();
 }
 
+void FancyPlotterSettings::resetOrder()
+{
+  mModel->resetOrder();
+}
+
+
+
 #include "FancyPlotterSettings.moc"
