@@ -1,7 +1,7 @@
 /*
     KSysGuard, the KDE System Guard
 
-	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
+    Copyright (c) 2006 John Tapsell <tapsell@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,25 +22,9 @@
 #ifndef _ReniceDlg_h_
 #define _ReniceDlg_h_
 
-/*
- * kapp.h includes a dirty X.h file that contains marcos that collide with
- * qslider.h. The following defines work around this problem.
- */
-#ifdef Above
-#undef Above
-#endif
-#ifdef Below
-#undef Below
-#endif
-
 #include <kdialog.h>
-#include <QLabel>
-#include <QLayout>
-#include <qlcdnumber.h>
-#include <QPushButton>
-#include <QSlider>
-//Added by qt3to4:
-#include <QBoxLayout>
+
+class Ui_ReniceDlgUi;
 
 /**
  * This class creates and handles a simple dialog to change the scheduling
@@ -51,36 +35,14 @@ class ReniceDlg : public KDialog
 	Q_OBJECT
 
 public:
-	ReniceDlg(QWidget* parent, const char* name, int currentPPrio, int pid);
-	~ReniceDlg()
-	{
-		delete message;
+	ReniceDlg(QWidget* parent, int currentPPrio, const QStringList& pid);
+	int newPriority;
 
-		delete slider;
-		delete lcd;
-		delete vLay;
-	}
 public Q_SLOTS:
-    void slotOk();
-    void slotCancel();
+	void slotOk();
 
 private:
-	int value;
-
-	QBoxLayout* vLay;
-	QBoxLayout* butLay;
-	QBoxLayout* sldLay;
-
-	QLabel* message;
-
-	QSlider* slider;
-	QLCDNumber* lcd;
-
-private Q_SLOTS:
-	void setPriorityValue(int priority)
-	{
-		value = priority;
-	}
+	Ui_ReniceDlgUi *reniceDlgUi;
 };
 
 #endif
