@@ -27,7 +27,6 @@
 #include <QEvent>
 #include <QDropEvent>
 #include <QDragEnterEvent>
-#include <QCustomEvent>
 #include <QFile>
 #include <QByteArray>
 
@@ -67,7 +66,7 @@ WorkSheet::WorkSheet( uint rows, uint columns, uint interval, QWidget* parent )
   mRows = mColumns = 0;
   mGridLayout = 0;
   mDisplayList = 0;
-  updateInterval( interval );
+  setUpdateInterval( interval );
   mFileName = "";
 
   createGrid( rows, columns );
@@ -113,9 +112,11 @@ bool WorkSheet::load( const QString &fileName )
 
   // Check for proper size.
   QDomElement element = doc.documentElement();
-  updateInterval( element.attribute( "interval" ).toUInt() );
-  if ( updateInterval() < 1 || updateInterval() > 300 )
-    updateInterval( 2 );
+  unsigned int interval = element.attribute( "interval", "2" ).toUInt();
+  if( interval  <1 || interval > 900 )  //make sure the interval is fairly sane
+    interval = 2;
+
+  setUpdateInterval(interval);
 
   mTitle = element.attribute( "title");
   bool ok;
@@ -147,6 +148,9 @@ bool WorkSheet::load( const QString &fileName )
                               element.attribute( "shell" ),
                               element.attribute( "command" ), port );
   }
+  //if no hosts are specified, at least connect to localhost
+  if(dnList.count() == 0)
+    KSGRD::SensorMgr->engage( "localhost", "", "ksysguardd", -1);
 
   // Load the displays and place them into the work sheet.
   dnList = element.elementsByTagName( "display" );
@@ -292,6 +296,7 @@ const QString& WorkSheet::fileName() const
 
 void WorkSheet::setTitle( const QString &title )
 {
+  kDebug() << "Set title " << title << endl;
   mTitle = title;
   emit titleChanged(this);
 }
@@ -306,12 +311,6 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const QString &hostName,
                                              const QString& sensorDescr,
                                              uint row, uint column )
 {
-  if ( !KSGRD::SensorMgr->engageHost( hostName ) ) {
-    QString msg = i18n( "It is impossible to connect to \'%1\'." ,  hostName );
-    KMessageBox::error( this, msg );
-
-    return 0;
-  }
 
   /* If the by 'row' and 'column' specified display is a QGroupBox dummy
    * display we replace the widget. Otherwise we just try to add
@@ -330,15 +329,15 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const QString &hostName,
       QAction *a4 = pm.addAction( i18n( "Log to a &file" ) );
       QAction *execed = pm.exec( QCursor::pos() );
       if (execed == a1)
-	newDisplay = new FancyPlotter( this, sensorDescr, &mSharedSettings );
+        newDisplay = new FancyPlotter( this, sensorDescr, &mSharedSettings );
       else if (execed == a2)
-	newDisplay = new MultiMeter( this, sensorDescr, &mSharedSettings);
+        newDisplay = new MultiMeter( this, sensorDescr, &mSharedSettings);
       else if (execed == a3)
-	 newDisplay = new DancingBars( this, sensorDescr, &mSharedSettings);
+        newDisplay = new DancingBars( this, sensorDescr, &mSharedSettings);
       else if (execed == a4)
-	newDisplay = new SensorLogger( this, sensorDescr, &mSharedSettings);
+        newDisplay = new SensorLogger( this, sensorDescr, &mSharedSettings);
       else
-	 return 0;
+        return 0;
     } else if ( sensorType == "listview" )
       newDisplay = new ListView( this, sensorDescr, &mSharedSettings);
     else if ( sensorType == "logfile" )
@@ -372,15 +371,16 @@ void WorkSheet::settings()
   }
 
   if ( dlg.exec() ) {
-    updateInterval( dlg.interval() );
-    for (uint r = 0; r < mRows; ++r)
-      for (uint c = 0; c < mColumns; ++c)
-        if ( mDisplayList[ r ][ c ]->useGlobalUpdateInterval() )
-          mDisplayList[ r ][ c ]->setUpdateInterval( updateInterval() );
+    setUpdateInterval( dlg.interval() );
 
-    if(!mSharedSettings.locked)
-	    resizeGrid( dlg.rows(), dlg.columns() );
-    setTitle(dlg.sheetTitle());
+    if (!mSharedSettings.locked)
+      resizeGrid( dlg.rows(), dlg.columns() );
+
+    if(mRows == 1 && mColumns ==1) {
+      mDisplayList[ 0 ][ 0 ]->setTitle(dlg.sheetTitle());
+    } else {
+      setTitle(dlg.sheetTitle());
+    }
   }
 }
 
@@ -396,36 +396,48 @@ void WorkSheet::applyStyle()
       mDisplayList[ r ][ c ]->applyStyle();
 }
 
-void WorkSheet::dragEnterEvent( QDragEnterEvent *e )
+void WorkSheet::dragEnterEvent( QDragEnterEvent *event )
 {
-  e->setAccepted( Q3TextDrag::canDecode( e ) );
+  if ( event->mimeData()->hasText() )
+    event->acceptProposedAction();
 }
 
-void WorkSheet::dropEvent( QDropEvent *e )
+void WorkSheet::dropEvent( QDropEvent *event )
 {
-  QString dragObject;
+  if ( !event->mimeData()->hasText() )
+    return;
 
-  if ( Q3TextDrag::decode( e, dragObject) ) {
-    // The host name, sensor name and type are separated by a ' '.
-    QStringList parts = dragObject.split( ' ');
+  const QString dragObject = event->mimeData()->text();
 
-    QString hostName = parts[ 0 ];
-    QString sensorName = parts[ 1 ];
-    QString sensorType = parts[ 2 ];
-    QString sensorDescr = parts[ 3 ];
+  // The host name, sensor name and type are separated by a ' '.
+  QStringList parts = dragObject.split( ' ');
 
-    if ( hostName.isEmpty() || sensorName.isEmpty() || sensorType.isEmpty() ) {
-      return;
+  QString hostName = parts[ 0 ];
+  QString sensorName = parts[ 1 ];
+  QString sensorType = parts[ 2 ];
+  QString sensorDescr = parts[ 3 ];
+
+  if ( hostName.isEmpty() || sensorName.isEmpty() || sensorType.isEmpty() )
+    return;
+
+  /* Find the sensor display that is supposed to get the drop
+   * event and replace or add sensor. */
+  for ( uint r = 0; r < mRows; ++r ) {
+    for ( uint c = 0; c < mColumns; ++c ) {
+      const QSize displaySize = mDisplayList[ r ][ c ]->size();
+
+      const QPoint displayPoint( displaySize.width(), displaySize.height() );
+
+      const QRect widgetRect = QRect( mDisplayList[ r ][ c ]->mapToGlobal( QPoint( 0, 0 ) ),
+                                      mDisplayList[ r ][ c ]->mapToGlobal( displayPoint ) );
+
+      const QPoint globalPos = mapToGlobal( event->pos() );
+
+      if ( widgetRect.contains( globalPos ) ) {
+        addDisplay( hostName, sensorName, sensorType, sensorDescr, r, c );
+        return;
+      }
     }
-
-    /* Find the sensor display that is supposed to get the drop
-     * event and replace or add sensor. */
-    for ( uint r = 0; r < mRows; ++r )
-      for ( uint c = 0; c < mColumns; ++c )
-        if ( mDisplayList[ r ][ c ]->geometry().contains( e->pos() ) ) {
-          addDisplay( hostName, sensorName, sensorType, sensorDescr, r, c );
-          return;
-        }
   }
 }
 
@@ -434,16 +446,21 @@ QSize WorkSheet::sizeHint() const
   return QSize( 200,150 );
 }
 
-void WorkSheet::customEvent( QCustomEvent *e )
+bool WorkSheet::event( QEvent *e )
 {
   if ( e->type() == QEvent::User ) {
     // SensorDisplays send out this event if they want to be removed.
     if ( KMessageBox::warningContinueCancel( this, i18n( "Do you really want to delete the display?" ),
-      i18n("Delete Display"), KStdGuiItem::del() )
+      i18n("Delete Display"), KStandardGuiItem::del() )
          == KMessageBox::Continue ) {
-      removeDisplay( (KSGRD::SensorDisplay*)e->data() );
+      KSGRD::SensorDisplay::DeleteEvent *event = static_cast<KSGRD::SensorDisplay::DeleteEvent*>( e );
+      removeDisplay( event->display() );
+
+      return true;
     }
   }
+
+  return QWidget::event( e );
 }
 
 bool WorkSheet::replaceDisplay( uint row, uint column, QDomElement& element )
@@ -471,8 +488,7 @@ bool WorkSheet::replaceDisplay( uint row, uint column, QDomElement& element )
     return false;
   }
 
-  if ( newDisplay->useGlobalUpdateInterval() )
-    newDisplay->setUpdateInterval( updateInterval() );
+  connect(&mTimer, SIGNAL( timeout()), newDisplay, SLOT( timerTick()));
 
   // load display specific settings
   if ( !newDisplay->restoreSettings( element ) )
@@ -486,23 +502,34 @@ bool WorkSheet::replaceDisplay( uint row, uint column, QDomElement& element )
 
 void WorkSheet::replaceDisplay( uint row, uint column, KSGRD::SensorDisplay* newDisplay )
 {
-  // remove the old display at this location
-  delete mDisplayList[ row ][ column ];
-
-  // insert new display
-  if ( !newDisplay )
-    mDisplayList[ row ][ column ] = new DummyDisplay( this, &mSharedSettings );
-  else {
-    mDisplayList[ row ][ column ] = newDisplay;
-    if ( mDisplayList[ row ][ column ]->useGlobalUpdateInterval() )
-      mDisplayList[ row ][ column ]->setUpdateInterval( updateInterval() );
-    connect( newDisplay, SIGNAL( showPopupMenu( KSGRD::SensorDisplay* ) ),
-             SLOT( showPopupMenu( KSGRD::SensorDisplay* ) ) );
+  // remove the old display && sensor frame at this location
+  if ( mDisplayList[ row ][ column ] ) {
+    if ( qstrcmp( mDisplayList[ row ][ column ]->parent()->metaObject()->className(), "SensorFrame" ) == 0 ) {
+      delete mDisplayList[ row ][ column ]->parent(); // destroys the child (display) as well
+    } else {
+      delete mDisplayList[ row ][ column ];
+    }
   }
 
-  SensorFrame *frame = new SensorFrame(mDisplayList[ row ][ column ]);
+  // insert new display
+  if ( !newDisplay ) {
+    newDisplay = new DummyDisplay( this, &mSharedSettings );
+    mDisplayList[ row ][ column ] = newDisplay;
+  }  else {
+    mDisplayList[ row ][ column ] = newDisplay;
+    connect( newDisplay, SIGNAL( showPopupMenu( KSGRD::SensorDisplay* ) ),
+             SLOT( showPopupMenu( KSGRD::SensorDisplay* ) ) );
+    newDisplay->setDeleteNotifier( this );
+  }
 
-  mGridLayout->addWidget( frame, row, column );
+  if(mRows == 1 && mColumns == 1) {  //if there's only item, then why bother with a frame?
+    mGridLayout->addWidget( mDisplayList[ row ][ column ], row, column );
+    connect( newDisplay, SIGNAL(changeTitle(const QString&)), SLOT(setTitle(const QString&)));
+    setTitle(newDisplay->title());
+  } else {
+    SensorFrame *frame = new SensorFrame(mDisplayList[ row ][ column ]);
+    mGridLayout->addWidget( frame, row, column );
+  }
   if ( isVisible() ) {
     mDisplayList[ row ][ column ]->show();
   }
@@ -656,13 +683,21 @@ QString WorkSheet::currentDisplayAsXML()
   return doc.toString();
 }
 
-void WorkSheet::setIsOnTop( bool /* onTop */ )
+void WorkSheet::setUpdateInterval( unsigned int secs)
 {
-/*
-  for ( uint r = 0; r < mRows; ++r )
-    for ( uint c = 0; c < mColumns; ++c )
-      mDisplayList[ r ][ c ]->setIsOnTop( onTop );
-*/
+  if(secs == 0)
+    mTimer.stop();
+  else {
+    mTimer.setInterval(secs*1000);
+    mTimer.start();
+  }
+}
+int WorkSheet::updateInterval() const
+{
+  if(mTimer.isActive())
+    return mTimer.interval()/1000;
+  else
+    return 0;
 }
 
 #include "WorkSheet.moc"
