@@ -221,8 +221,8 @@ void Workspace::setActiveClient( Client* c, allowed_t )
     ++set_active_client_recursion;
     if( active_client != NULL )
         { // note that this may call setActiveClient( NULL ), therefore the recursion counter
-            active_client->setActive( false );
-    }
+        active_client->setActive( false );
+        }
     active_client = c;
     Q_ASSERT( c == NULL || c->isActive());
     if( active_client != NULL )
@@ -263,6 +263,7 @@ void Workspace::activateClient( Client* c, bool force )
     {
     if( c == NULL )
         {
+        focusToNull();
         setActiveClient( NULL, Allowed );
         return;
         }
@@ -668,11 +669,11 @@ void Client::demandAttention( bool set )
         // to be set.
         // Delayed call to KNotify also solves the problem of having X server grab in manage(),
         // which may deadlock when KNotify (or KLauncher when launching KNotify) need to access X.
-        Notify::Event e = isOnCurrentDesktop() ? Notify::DemandAttentionCurrent : Notify::DemandAttentionOther;
+
         // Setting the demands attention state needs to be done directly in KWin, because
         // KNotify would try to set it, resulting in a call to KNotify again, etc.
-        if( Notify::makeDemandAttention( e ))
-            info->setState( set ? NET::DemandsAttention : 0, NET::DemandsAttention );
+
+        info->setState( set ? NET::DemandsAttention : 0, NET::DemandsAttention );
 
         if( demandAttentionKNotifyTimer == NULL )
             {
