@@ -199,10 +199,15 @@ bool Workspace::workspaceEvent( XEvent * e )
         XUngrabKeyboard( display(), xTime() );
         }
 
-    if ( e->type == PropertyNotify || e->type == ClientMessage ) 
+    if( e->type == PropertyNotify || e->type == ClientMessage )
         {
-        if ( netCheck( e ) )
-            return true;
+        unsigned long dirty[ NETRootInfo::PROPERTIES_SIZE ];
+        rootInfo->event( e, dirty, NETRootInfo::PROPERTIES_SIZE );
+        if( dirty[ NETRootInfo::PROTOCOLS ] & NET::DesktopNames )
+            saveDesktopSettings();
+        if( dirty[ NETRootInfo::PROTOCOLS2 ] & NET::WM2DesktopLayout )
+            setDesktopLayout( rootInfo->desktopLayoutOrientation(), rootInfo->desktopLayoutColumnsRows().width(),
+                rootInfo->desktopLayoutColumnsRows().height(), rootInfo->desktopLayoutCorner());
         }
 
     // events that should be handled before Clients can get them
@@ -451,10 +456,6 @@ bool Workspace::workspaceEvent( XEvent * e )
             if( electricBorder( e ))
                 return true;
             break;
-        case MappingNotify:
-            XRefreshKeyboardMapping( &e->xmapping );
-            tab_box->updateKeyMapping();
-            break;
         default:
             break;
         }
@@ -495,20 +496,6 @@ Window Workspace::findSpecialEventWindow( XEvent* e )
         };
     }
 
-/*!
-  Handles client messages sent to the workspace
- */
-bool Workspace::netCheck( XEvent* e )
-    {
-    unsigned int dirty = rootInfo->event( e );
-
-    if ( dirty & NET::DesktopNames )
-        saveDesktopSettings();
-
-    return dirty != 0;
-    }
-
-
 // ****************************************
 // Client
 // ****************************************
@@ -631,9 +618,6 @@ bool Client::windowEvent( XEvent* e )
                 workspace()->updateColormap();
             }
             break;
-        case VisibilityNotify:
-            visibilityNotifyEvent( &e->xvisibility );
-            break;
         default:
             if( e->xany.window == window())
             {
@@ -1011,18 +995,13 @@ void Client::ungrabButton( int modifier )
  */
 void Client::updateMouseGrab()
     {
-    if( workspace()->globalShortcutsDisabled())
-        {
-        XUngrabButton( display(), AnyButton, AnyModifier, wrapperId());
-        // keep grab for the simple click without modifiers if needed
-        if( !( !options->clickRaise || not_obscured ))
-            grabButton( None );
-        return;
-        }
     if( isActive() && !workspace()->forcedGlobalMouseGrab()) // see Workspace::establishTabBoxGrab()
         {
         // remove the grab for no modifiers only if the window
         // is unobscured or if the user doesn't want click raise
+        // (it is unobscured if it the topmost in the unconstrained stacking order, i.e. it is
+        // the most recently raised window)
+        bool not_obscured = workspace()->topClientOnDesktop( workspace()->currentDesktop(), true, false ) == this;
         if( !options->clickRaise || not_obscured )
             ungrabButton( None );
         else
@@ -1457,17 +1436,6 @@ void Client::focusOutEvent( XFocusOutEvent* e )
         setActive( false );
     }
 
-void Client::visibilityNotifyEvent( XVisibilityEvent * e)
-    {
-    if( e->window != frameId())
-        return; // care only about the whole frame
-    bool new_not_obscured = e->state == VisibilityUnobscured;
-    if( not_obscured == new_not_obscured )
-        return;
-    not_obscured = new_not_obscured;
-    updateMouseGrab();
-    }
-
 // performs _NET_WM_MOVERESIZE
 void Client::NETMoveResize( int x_root, int y_root, NET::Direction direction )
     {
