@@ -43,6 +43,11 @@ namespace KWinInternal
  */
 void Workspace::desktopResized()
     {
+    QRect geom = QApplication::desktop()->geometry();
+    NETSize desktop_geometry;
+    desktop_geometry.width = geom.width();
+    desktop_geometry.height = geom.height();
+    rootInfo->setDesktopGeometry( -1, desktop_geometry );
     updateClientArea();
     checkElectricBorders( true );
     }
@@ -210,7 +215,7 @@ QRect Workspace::clientArea( clientAreaOption opt, const QPoint& p, int desktop
     if( desktop == NETWinInfo::OnAllDesktops || desktop == 0 )
         desktop = currentDesktop();
     QDesktopWidget *desktopwidget = KApplication::desktop();
-    int screen = desktopwidget->screenNumber( p );
+    int screen = desktopwidget->isVirtualDesktop() ? desktopwidget->screenNumber( p ) : desktopwidget->primaryScreen();
     if( screen < 0 )
         screen = desktopwidget->primaryScreen();
     QRect sarea = screenarea // may be NULL during KWin initialization
@@ -2225,7 +2230,7 @@ bool Client::startMoveResize()
     XMapRaised( display(), move_resize_grab_window );
     if( XGrabPointer( display(), move_resize_grab_window, False,
         ButtonPressMask | ButtonReleaseMask | PointerMotionMask | EnterWindowMask | LeaveWindowMask,
-        GrabModeAsync, GrabModeAsync, None, cursor.handle(), xTime() ) == Success )
+        GrabModeAsync, GrabModeAsync, move_resize_grab_window, cursor.handle(), xTime() ) == Success )
         has_grab = true;
     if( XGrabKeyboard( display(), frameId(), False, GrabModeAsync, GrabModeAsync, xTime() ) == Success )
         has_grab = true;
