@@ -62,8 +62,6 @@
 #include <kdecoration_plugins_p.h>
 #include <kdecorationfactory.h>
 #include <kvbox.h>
-#include "kwindecorationadaptor.h"
-#include <QtDBus/QtDBus>
 
 // KCModule plugin interface
 // =========================
@@ -71,14 +69,12 @@ typedef KGenericFactory<KWinDecorationModule, QWidget> KWinDecoFactory;
 K_EXPORT_COMPONENT_FACTORY( kcm_kwindecoration, KWinDecoFactory("kcmkwindecoration") )
 
 KWinDecorationModule::KWinDecorationModule(QWidget* parent, const QStringList &)
-	: KCModule(KWinDecoFactory::instance(), parent),
-          kwinConfig("kwinrc"),
-          pluginObject(0)
+    : KCModule(KWinDecoFactory::componentData(), parent),
+    kwinConfig(KSharedConfig::openConfig("kwinrc")),
+    pluginObject(0)
 {
-    new DecorationAdaptor(this);
-    QDBus::sessionBus().registerObject("/KWinClientDecoration", this);
-    kwinConfig.setGroup("Style");
-        plugins = new KDecorationPreviewPlugins( &kwinConfig );
+    kwinConfig->setGroup("Style");
+    plugins = new KDecorationPreviewPlugins(kwinConfig);
 
 	QVBoxLayout* layout = new QVBoxLayout(this);
     layout->setMargin(0);
@@ -176,8 +172,8 @@ KWinDecorationModule::KWinDecorationModule(QWidget* parent, const QStringList &)
 	// Set up the decoration lists and other UI settings
 	findDecorations();
 	createDecorationList();
-	readConfig( &kwinConfig );
-	resetPlugin( &kwinConfig );
+	readConfig( kwinConfig.data() );
+	resetPlugin( kwinConfig.data() );
 
 	tabWidget->addTab( pluginPage, i18n("&Window Decoration") );
 	tabWidget->addTab( buttonPage, i18n("&Buttons") );
@@ -439,7 +435,7 @@ void KWinDecorationModule::readConfig( KConfig* conf )
 {
 	// General tab
 	// ============
-	cbShowToolTips->setChecked( conf->readEntry("ShowToolTips", QVariant(true )).toBool());
+	cbShowToolTips->setChecked( conf->readEntry("ShowToolTips", true));
 //	cbUseMiniWindows->setChecked( conf->readEntry("MiniWindowBorders", QVariant(false)).toBool());
 
 	// Find the corresponding decoration name to that of
@@ -466,7 +462,7 @@ void KWinDecorationModule::readConfig( KConfig* conf )
 
 	// Buttons tab
 	// ============
-	bool customPositions = conf->readEntry("CustomButtonPositions", QVariant(false)).toBool();
+	bool customPositions = conf->readEntry("CustomButtonPositions", false);
 	cbUseCustomButtonPositions->setChecked( customPositions );
 	buttonPositionWidget->setEnabled( customPositions );
 	// Menu and onAllDesktops buttons are default on LHS
@@ -534,8 +530,11 @@ void KWinDecorationModule::save()
 	emit pluginSave( &kwinConfig );
 
 	kwinConfig.sync();
-        QDBusInterface kwin( "org.kde.kwin", "/KWin", "org.kde.KWin" );
-        kwin.call( "reconfigure" );
+    // Send signal to all kwin instances
+    QDBusMessage message =
+        QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig");
+    QDBusConnection::sessionBus().send(message);
+
 }
 
 
