@@ -384,16 +384,16 @@ void RulesWidget::setRules( Rules* rules )
     role->setText( rules->windowrole );
     role_match->setCurrentIndex( rules->windowrolematch );
     roleMatchChanged();
-    types->setSelected( 0, rules->types & NET::NormalMask );
-    types->setSelected( 1, rules->types & NET::DialogMask );
-    types->setSelected( 2, rules->types & NET::UtilityMask );
-    types->setSelected( 3, rules->types & NET::DockMask );
-    types->setSelected( 4, rules->types & NET::ToolbarMask );
-    types->setSelected( 5, rules->types & NET::MenuMask );
-    types->setSelected( 6, rules->types & NET::SplashMask );
-    types->setSelected( 7, rules->types & NET::DesktopMask );
-    types->setSelected( 8, rules->types & NET::OverrideMask );
-    types->setSelected( 9, rules->types & NET::TopMenuMask );
+    types->item(0)->setSelected( rules->types & NET::NormalMask );
+    types->item(1)->setSelected( rules->types & NET::DialogMask );
+    types->item(2)->setSelected( rules->types & NET::UtilityMask );
+    types->item(3)->setSelected( rules->types & NET::DockMask );
+    types->item(4)->setSelected( rules->types & NET::ToolbarMask );
+    types->item(5)->setSelected( rules->types & NET::MenuMask );
+    types->item(6)->setSelected( rules->types & NET::SplashMask );
+    types->item(7)->setSelected( rules->types & NET::DesktopMask );
+    types->item(8)->setSelected( rules->types & NET::OverrideMask );
+    types->item(9)->setSelected( rules->types & NET::TopMenuMask );
     title->setText( rules->title );
     title_match->setCurrentIndex( rules->titlematch );
     titleMatchChanged();
@@ -467,25 +467,25 @@ Rules* RulesWidget::rules() const
     rules->windowrolematch = static_cast< Rules::StringMatch >( role_match->currentIndex());
     rules->types = 0;
     bool all_types = true;
-    for( unsigned int i = 0;
+    for( int i = 0;
          i < types->count();
          ++i )
-        if( !types->isSelected( i ))
+        if( !types->item(i)->isSelected())
             all_types = false;
     if( all_types ) // if all types are selected, use AllTypesMask (for future expansion)
         rules->types = NET::AllTypesMask;
     else
         {
-        rules->types |= types->isSelected( 0 ) ? NET::NormalMask : 0;
-        rules->types |= types->isSelected( 1 ) ? NET::DialogMask : 0;
-        rules->types |= types->isSelected( 2 ) ? NET::UtilityMask : 0;
-        rules->types |= types->isSelected( 3 ) ? NET::DockMask : 0;
-        rules->types |= types->isSelected( 4 ) ? NET::ToolbarMask : 0;
-        rules->types |= types->isSelected( 5 ) ? NET::MenuMask : 0;
-        rules->types |= types->isSelected( 6 ) ? NET::SplashMask : 0;
-        rules->types |= types->isSelected( 7 ) ? NET::DesktopMask : 0;
-        rules->types |= types->isSelected( 8 ) ? NET::OverrideMask : 0;
-        rules->types |= types->isSelected( 9 ) ? NET::TopMenuMask : 0;
+        rules->types |= types->item(0)->isSelected() ? NET::NormalMask : 0;
+        rules->types |= types->item(1)->isSelected() ? NET::DialogMask : 0;
+        rules->types |= types->item(2)->isSelected() ? NET::UtilityMask : 0;
+        rules->types |= types->item(3)->isSelected() ? NET::DockMask : 0;
+        rules->types |= types->item(4)->isSelected() ? NET::ToolbarMask : 0;
+        rules->types |= types->item(5)->isSelected() ? NET::MenuMask : 0;
+        rules->types |= types->item(6)->isSelected() ? NET::SplashMask : 0;
+        rules->types |= types->item(7)->isSelected() ? NET::DesktopMask : 0;
+        rules->types |= types->item(8)->isSelected() ? NET::OverrideMask : 0;
+        rules->types |= types->item(9)->isSelected() ? NET::TopMenuMask : 0;
         }
     rules->title = title->text();
     rules->titlematch = static_cast< Rules::StringMatch >( title_match->currentIndex());
@@ -568,19 +568,19 @@ void RulesWidget::detected( bool ok )
         roleMatchChanged();
         if( detect_dlg->selectedWholeApp())
             {
-            for( unsigned int i = 0;
+            for( int i = 0;
                  i < types->count();
                  ++i )
-                types->setSelected( i, true );
+                types->item(i)->setSelected( true );
             }
         else
             {
             NET::WindowType type = detect_dlg->selectedType();
-            for( unsigned int i = 0;
+            for( int i = 0;
                  i < types->count();
                  ++i )
-                types->setSelected( i, false );
-            types->setSelected( typeToCombo( type ), true );
+                types->item(i)->setSelected( false );
+            types->item( typeToCombo(type) )->setSelected( true );
             }
         title->setText( detect_dlg->selectedTitle());
         title_match->setCurrentIndex( detect_dlg->titleMatch());
@@ -654,10 +654,10 @@ bool RulesWidget::finalCheck()
             description->setText( i18n( "Unnamed entry" ));
         }
     bool all_types = true;
-    for( unsigned int i = 0;
+    for( int i = 0;
          i < types->count();
          ++i )
-        if( !types->isSelected( i ))
+        if( !types->item(i)->isSelected())
             all_types = false;
     if( wmclass_match->currentIndex() == Rules::UnimportantMatch && all_types )
         {
@@ -779,11 +779,8 @@ ShortcutDialog::ShortcutDialog( const KShortcut& cut, QWidget* parent )
 
 void ShortcutDialog::accept()
     {
-    for( int i = 0;
-         ;
-         ++i )
+    foreach( const QKeySequence &seq, shortcut() )
         {
-        QKeySequence seq = shortcut().seq( i );
         if( seq.isEmpty())
             break;
         if( seq[0] == Qt::Key_Escape )
@@ -800,7 +797,7 @@ void ShortcutDialog::accept()
         if( (seq[0] & Qt::KeyboardModifierMask) == 0 )
             { // no shortcuts without modifiers
             KShortcut cut = shortcut();
-            cut.setSeq( i, QKeySequence());
+            cut.remove( seq );
             setShortcut( cut );
             return;
             }
