@@ -34,6 +34,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <QX11Info>
 #include <kactioncollection.h>
 #include <kkeyserver.h>
+#include <kconfiggroup.h>
 
 // specify externals before namespace
 
@@ -53,7 +54,6 @@ TabBox::TabBox( Workspace *ws, const char *name )
 
     no_tasks = i18n("*** No Windows ***");
     m = DesktopMode; // init variables
-    updateKeyMapping();
     reconfigure();
     reset();
     connect(&delayedShowTimer, SIGNAL(timeout()), this, SLOT(show()));
@@ -126,7 +126,9 @@ void TabBox::createClientList(ClientList &list, int desktop /*-1 = all*/, Client
                 else if( !list.contains( modal ))
                     list += modal;
                 else
-                    ; // nothing
+                    {
+                    // nothing
+                    }
                 }
             }
 
@@ -424,7 +426,7 @@ void TabBox::drawContents( QPainter * )
                   else
                     s += (*it)->caption();
 
-                  s = KStringHandler::cPixelSqueeze(s, fontMetrics(), r.width() - 5 - iconWidth - 8);
+                  s = fontMetrics().elidedText(s, Qt::ElideMiddle, r.width() - 5 - iconWidth - 8);
 
                   // draw text
                   if ( (*it) == current_client )
@@ -548,7 +550,7 @@ void TabBox::drawContents( QPainter * )
 void TabBox::updateOutline()
     {
     Client* c = currentClient();
-    if( c == NULL )
+    if( c == NULL || this->isHidden() || !c->isShown( true ) || !c->isOnCurrentDesktop())
         {
         XUnmapWindow( display(), outline_left );
         XUnmapWindow( display(), outline_right );
@@ -557,63 +559,66 @@ void TabBox::updateOutline()
         return;
         }
     // left/right parts are between top/bottom, they don't reach as far as the corners
-    XMoveResizeWindow( display(), outline_left, c->x(), c->y() + 7, 7, c->height() - 14 );
-    XMoveResizeWindow( display(), outline_right, c->x() + c->width() - 7, c->y() + 7, 7, c->height() - 14 );
-    XMoveResizeWindow( display(), outline_top, c->x(), c->y(), c->width(), 7 );
-    XMoveResizeWindow( display(), outline_bottom, c->x(), c->y() + c->height() - 7, c->width(), 7 );
+    XMoveResizeWindow( display(), outline_left, c->x(), c->y() + 5, 5, c->height() - 10 );
+    XMoveResizeWindow( display(), outline_right, c->x() + c->width() - 5, c->y() + 5, 5, c->height() - 10 );
+    XMoveResizeWindow( display(), outline_top, c->x(), c->y(), c->width(), 5 );
+    XMoveResizeWindow( display(), outline_bottom, c->x(), c->y() + c->height() - 5, c->width(), 5 );
     {
-    QPixmap pix( 7, c->height() - 14 );
+    QPixmap pix( 5, c->height() - 10 );
     QPainter p( &pix );
     p.setPen( Qt::white );
     p.drawLine( 0, 0, 0, pix.height() - 1 );
-    p.drawLine( 6, 0, 6, pix.height() - 1 );
+    p.drawLine( 4, 0, 4, pix.height() - 1 );
     p.setPen( Qt::gray );
     p.drawLine( 1, 0, 1, pix.height() - 1 );
-    p.drawLine( 5, 0, 5, pix.height() - 1 );
-    p.fillRect( QRect( QPoint( 2, 0 ), QPoint( 4, pix.height() - 1 )), Qt::black );
+    p.drawLine( 3, 0, 3, pix.height() - 1 );
+    p.setPen( Qt::black );
+    p.drawLine( 2, 0, 2, pix.height() - 1 );
     p.end();
     XSetWindowBackgroundPixmap( display(), outline_left, pix.handle());
     XSetWindowBackgroundPixmap( display(), outline_right, pix.handle());
     }
     {
-    QPixmap pix( c->width(), 7 );
+    QPixmap pix( c->width(), 5 );
     QPainter p( &pix );
     p.setPen( Qt::white );
     p.drawLine( 0, 0, pix.width() - 1 - 0, 0 );
-    p.drawLine( 6, 6, pix.width() - 1 - 6, 6 );
-    p.drawLine( 0, 0, 0, 6 );
-    p.drawLine( pix.width() - 1 - 0, 0, pix.width() - 1 - 0, 6 );
+    p.drawLine( 4, 4, pix.width() - 1 - 4, 4 );
+    p.drawLine( 0, 0, 0, 4 );
+    p.drawLine( pix.width() - 1 - 0, 0, pix.width() - 1 - 0, 4 );
     p.setPen( Qt::gray );
     p.drawLine( 1, 1, pix.width() - 1 - 1, 1 );
-    p.drawLine( 5, 5, pix.width() - 1 - 5, 5 );
-    p.drawLine( 1, 1, 1, 6 );
-    p.drawLine( 5, 5, 5, 6 );
-    p.drawLine( pix.width() - 1 - 1, 1, pix.width() - 1 - 1, 6 );
-    p.drawLine( pix.width() - 1 - 5, 5, pix.width() - 1 - 5, 6 );
-    p.fillRect( QRect( QPoint( 2, 2 ), QPoint( pix.width() - 1 - 4, 4 )), Qt::black );
-    p.fillRect( QRect( QPoint( 2, 2 ), QPoint( 4, 6 )), Qt::black );
-    p.fillRect( QRect( QPoint( pix.width() - 1 - 4, 2 ), QPoint( pix.width() - 1 - 2, 6 )), Qt::black );
+    p.drawLine( 3, 3, pix.width() - 1 - 3, 3 );
+    p.drawLine( 1, 1, 1, 4 );
+    p.drawLine( 3, 3, 3, 4 );
+    p.drawLine( pix.width() - 1 - 1, 1, pix.width() - 1 - 1, 4 );
+    p.drawLine( pix.width() - 1 - 3, 3, pix.width() - 1 - 3, 4 );
+    p.setPen( Qt::black );
+    p.drawLine( 2, 2, pix.width() - 1 - 2, 2 );
+    p.drawLine( 2, 2, 2, 4 );
+    p.drawLine( pix.width() - 1 - 2, 2, pix.width() - 1 - 2, 4 );
     p.end();
     XSetWindowBackgroundPixmap( display(), outline_top, pix.handle());
     }
     {
-    QPixmap pix( c->width(), 7 );
+    QPixmap pix( c->width(), 5 );
     QPainter p( &pix );
     p.setPen( Qt::white );
-    p.drawLine( 6, 0, pix.width() - 1 - 6, 0 );
-    p.drawLine( 0, 6, pix.width() - 1 - 0, 6 );
-    p.drawLine( 0, 6, 0, 0 );
-    p.drawLine( pix.width() - 1 - 0, 6, pix.width() - 1 - 0, 0 );
+    p.drawLine( 4, 0, pix.width() - 1 - 4, 0 );
+    p.drawLine( 0, 4, pix.width() - 1 - 0, 4 );
+    p.drawLine( 0, 4, 0, 0 );
+    p.drawLine( pix.width() - 1 - 0, 4, pix.width() - 1 - 0, 0 );
     p.setPen( Qt::gray );
-    p.drawLine( 5, 1, pix.width() - 1 - 5, 1 );
-    p.drawLine( 1, 5, pix.width() - 1 - 1, 5 );
-    p.drawLine( 5, 1, 5, 0 );
-    p.drawLine( 1, 5, 1, 0 );
-    p.drawLine( pix.width() - 1 - 5, 1, pix.width() - 1 - 5, 0 );
-    p.drawLine( pix.width() - 1 - 1, 5, pix.width() - 1 - 1, 0 );
-    p.fillRect( QRect( QPoint( 2, 2 ), QPoint( pix.width() - 1 - 4, 4 )), Qt::black );
-    p.fillRect( QRect( QPoint( 2, 0 ), QPoint( 4, 4 )), Qt::black );
-    p.fillRect( QRect( QPoint( pix.width() - 1 - 4, 0 ), QPoint( pix.width() - 1 - 2, 4 )), Qt::black );
+    p.drawLine( 3, 1, pix.width() - 1 - 3, 1 );
+    p.drawLine( 1, 3, pix.width() - 1 - 1, 3 );
+    p.drawLine( 3, 1, 3, 0 );
+    p.drawLine( 1, 3, 1, 0 );
+    p.drawLine( pix.width() - 1 - 3, 1, pix.width() - 1 - 3, 0 );
+    p.drawLine( pix.width() - 1 - 1, 3, pix.width() - 1 - 1, 0 );
+    p.setPen( Qt::black );
+    p.drawLine( 2, 2, pix.width() - 1 - 2, 2 );
+    p.drawLine( 2, 0, 2, 2 );
+    p.drawLine( pix.width() - 1 - 2, 0, pix.width() - 1 - 2 , 2 );
     p.end();
     XSetWindowBackgroundPixmap( display(), outline_bottom, pix.handle());
     }
@@ -640,7 +645,7 @@ void TabBox::hide()
 
 void TabBox::reconfigure()
     {
-    KConfig * c(KGlobal::config());
+    KSharedConfigPtr c(KGlobal::config());
     c->setGroup("TabBox");
     options_traverse_all = c->readEntry("TraverseAll", false );
     }
@@ -665,7 +670,7 @@ void TabBox::reconfigure()
  */
 void TabBox::delayedShow()
     {
-    KConfig * c(KGlobal::config());
+    KSharedConfigPtr c(KGlobal::config());
     c->setGroup("TabBox");
     bool delay = c->readEntry("ShowDelay", true);
 
@@ -784,10 +789,6 @@ bool areKeySymXsDepressed( bool bAll, const uint keySyms[], int nKeySyms )
     return bAll;
     }
 
-static const int MAX_KEYSYMS = 4;
-static uint alt_keysyms[ MAX_KEYSYMS ];
-static uint win_keysyms[ MAX_KEYSYMS ];
-
 static bool areModKeysDepressed( const QKeySequence& seq )
     {
     uint rgKeySyms[10];
@@ -808,17 +809,18 @@ static bool areModKeysDepressed( const QKeySequence& seq )
         }
     if( mod & Qt::ALT )
         {
-        for( int i = 0;
-             i < MAX_KEYSYMS && alt_keysyms[ i ] != NoSymbol;
-             ++i )
-            rgKeySyms[nKeySyms++] = alt_keysyms[ i ];
+        rgKeySyms[nKeySyms++] = XK_Alt_L;
+        rgKeySyms[nKeySyms++] = XK_Alt_R;
         }
     if( mod & Qt::META )
         {
-        for( int i = 0;
-             i < MAX_KEYSYMS && win_keysyms[ i ] != NoSymbol;
-             ++i )
-            rgKeySyms[nKeySyms++] = win_keysyms[ i ];
+        // It would take some code to determine whether the Win key
+        // is associated with Super or Meta, so check for both.
+        // See bug #140023 for details.
+        rgKeySyms[nKeySyms++] = XK_Super_L;
+        rgKeySyms[nKeySyms++] = XK_Super_R;
+        rgKeySyms[nKeySyms++] = XK_Meta_L;
+        rgKeySyms[nKeySyms++] = XK_Meta_R;
         }
 
     return areKeySymXsDepressed( false, rgKeySyms, nKeySyms );
@@ -826,52 +828,10 @@ static bool areModKeysDepressed( const QKeySequence& seq )
 
 static bool areModKeysDepressed( const KShortcut& cut )
     {
-    for( int i = 0;
-	 i < cut.count();
-	 ++i )
-	{
-	if( areModKeysDepressed( cut.seq( i )))
-	    return true;
-	}
-    return false;
-    }
+    if( areModKeysDepressed( cut.primary()) || areModKeysDepressed( cut.alternate()) )
+        return true;
 
-void TabBox::updateKeyMapping()
-    {
-    const int size = 6;
-    uint keysyms[ size ] = { XK_Alt_L, XK_Alt_R, XK_Super_L, XK_Super_R, XK_Meta_L, XK_Meta_R };
-    XModifierKeymap* map = XGetModifierMapping( display() );
-    int altpos = 0;
-    int winpos = 0;
-    int winmodpos = -1;
-    int winmod = KKeyServer::modXMeta();
-    while( winmod > 0 ) // get position of the set bit in winmod
-        {
-        winmod >>= 1;
-        ++winmodpos;
-        }
-    for( int i = 0;
-         i < MAX_KEYSYMS;
-         ++i )
-        alt_keysyms[ i ] = win_keysyms[ i ] = NoSymbol;
-    for( int i = 0;
-         i < size;
-         ++i )
-        {
-        KeyCode keycode = XKeysymToKeycode( display(), keysyms[ i ] );
-        for( int j = 0;
-             j < map->max_keypermod;
-             ++j )
-            {
-            if( map->modifiermap[ 3 * map->max_keypermod + j ] == keycode ) // Alt
-                if( altpos < MAX_KEYSYMS )
-                    alt_keysyms[ altpos++ ] = keysyms[ i ];
-            if( winmodpos >= 0 && map->modifiermap[ winmodpos * map->max_keypermod + j ] == keycode )
-                if( winpos < MAX_KEYSYMS )
-                    win_keysyms[ winpos++ ] = keysyms[ i ];
-            }
-        }
-    XFreeModifiermap( map );
+    return false;
     }
 
 void Workspace::slotWalkThroughWindows()
@@ -1152,8 +1112,8 @@ void Workspace::tabBoxKeyPress( int keyQt )
         backward = cutWalkThroughWindowsReverse.contains( keyQt );
         if (forward || backward)
             {
-            kDebug(125) << "== " << cutWalkThroughWindows.toStringInternal()
-                << " or " << cutWalkThroughWindowsReverse.toStringInternal() << endl;
+            kDebug(125) << "== " << cutWalkThroughWindows.toString()
+                << " or " << cutWalkThroughWindowsReverse.toString() << endl;
             KDEWalkThroughWindows( forward );
             }
         }
