@@ -58,42 +58,51 @@ QMenu* Workspace::clientPopup()
 
         advanced_popup = new QMenu( popup );
         advanced_popup->setFont(KGlobalSettings::menuFont());
-        connect( advanced_popup, SIGNAL( triggered(QAction*) ), this, SLOT( clientPopupActivated(QAction*) ) );
 
         mKeepAboveOpAction = advanced_popup->addAction( i18n("Keep &Above Others") );
-        mKeepAboveOpAction->setIcon( SmallIconSet( "up" ) );
-        mKeepAboveOpAction->setShortcut( keys->action("Window Above Other Windows")->shortcut() );
+        mKeepAboveOpAction->setIcon( KIcon( "up" ) );
+        KAction *kaction = qobject_cast<KAction*>( keys->action("Window Above Other Windows") );
+        if ( kaction!=0 )
+            mKeepAboveOpAction->setShortcut( kaction->globalShortcut().primary() );
         mKeepAboveOpAction->setCheckable( true );
         mKeepAboveOpAction->setData( Options::KeepAboveOp );
 
         mKeepBelowOpAction = advanced_popup->addAction( i18n("Keep &Below Others") );
-        mKeepBelowOpAction->setIcon( SmallIconSet( "down" ) );
-        mKeepBelowOpAction->setShortcut( keys->action("Window Below Other Windows")->shortcut() );
+        mKeepBelowOpAction->setIcon( KIcon( "down" ) );
+        kaction = qobject_cast<KAction*>( keys->action("Window Below Other Windows") );
+        if ( kaction!=0 )
+            mKeepBelowOpAction->setShortcut( kaction->globalShortcut().primary() );
         mKeepBelowOpAction->setCheckable( true );
         mKeepBelowOpAction->setData( Options::KeepBelowOp );
 
         mFullScreenOpAction = advanced_popup->addAction( i18n("&Fullscreen") );
-        mFullScreenOpAction->setIcon( SmallIconSet( "window_fullscreen" ) );
-        mFullScreenOpAction->setShortcut( keys->action("Window Fullscreen")->shortcut() );
+        mFullScreenOpAction->setIcon( KIcon( "window_fullscreen" ) );
+        kaction = qobject_cast<KAction*>( keys->action("Window Fullscreen") );
+        if ( kaction!=0 )
+            mFullScreenOpAction->setShortcut( kaction->globalShortcut().primary() );
         mFullScreenOpAction->setCheckable( true );
         mFullScreenOpAction->setData( Options::FullScreenOp );
 
         mNoBorderOpAction = advanced_popup->addAction( i18n("&No Border") );
-        mNoBorderOpAction->setShortcut( keys->action("Window No Border")->shortcut() );
+        kaction = qobject_cast<KAction*>( keys->action("Window No Border") );
+        if ( kaction!=0 )
+            mNoBorderOpAction->setShortcut( kaction->globalShortcut().primary() );
         mNoBorderOpAction->setCheckable( true );
         mNoBorderOpAction->setData( Options::NoBorderOp );
 
         QAction *action = advanced_popup->addAction( i18n("Window &Shortcut...") );
-        action->setIcon( SmallIconSet("key_bindings") );
-        action->setShortcut( keys->action("Setup Window Shortcut")->shortcut() );
+        action->setIcon( KIcon("key_bindings") );
+        kaction = qobject_cast<KAction*>( keys->action("Setup Window Shortcut") );
+        if ( kaction!=0 )
+            action->setShortcut( kaction->globalShortcut().primary() );
         action->setData( Options::SetupWindowShortcutOp );
 
         action = advanced_popup->addAction( i18n("&Special Window Settings...") );
-        action->setIcon( SmallIconSet( "wizard" ) );
+        action->setIcon( KIcon( "wizard" ) );
         action->setData( Options::WindowRulesOp );
 
         action = advanced_popup->addAction( i18n("&Special Application Settings...") );
-        action->setIcon( SmallIconSet( "wizard" ) );
+        action->setIcon( KIcon( "wizard" ) );
         action->setData( Options::ApplicationRulesOp );
 
         action = popup->addMenu( advanced_popup );
@@ -123,42 +132,54 @@ QMenu* Workspace::clientPopup()
         }
 
         mMoveOpAction = popup->addAction( i18n("&Move") );
-        mMoveOpAction->setIcon( SmallIconSet( "move" ) );
-        mMoveOpAction->setShortcut( keys->action("Window Move")->shortcut() );
+        mMoveOpAction->setIcon( KIcon( "move" ) );
+        kaction = qobject_cast<KAction*>( keys->action("Window Move") );
+        if ( kaction!=0 )
+            mMoveOpAction->setShortcut( kaction->globalShortcut().primary() );
         mMoveOpAction->setData( Options::MoveOp );
 
         mResizeOpAction = popup->addAction( i18n("Re&size") );
-        mResizeOpAction->setShortcut( keys->action("Window Resize")->shortcut() );
+        kaction = qobject_cast<KAction*>( keys->action("Window Resize") );
+        if ( kaction!=0 )
+            mResizeOpAction->setShortcut( kaction->globalShortcut().primary() );
         mResizeOpAction->setData( Options::ResizeOp );
 
         mMinimizeOpAction = popup->addAction( i18n("Mi&nimize") );
-        mMinimizeOpAction->setShortcut( keys->action("Window Minimize")->shortcut() );
+        kaction = qobject_cast<KAction*>( keys->action("Window Minimize") );
+        if ( kaction!=0 )
+            mMinimizeOpAction->setShortcut( kaction->globalShortcut().primary() );
         mMinimizeOpAction->setData( Options::MinimizeOp );
 
         mMaximizeOpAction = popup->addAction( i18n("Ma&ximize") );
-        mMaximizeOpAction->setShortcut( keys->action("Window Maximize")->shortcut() );
+        kaction = qobject_cast<KAction*>( keys->action("Window Maximize") );
+        if ( kaction!=0 )
+            mMaximizeOpAction->setShortcut( kaction->globalShortcut().primary() );
         mMaximizeOpAction->setCheckable( true );
         mMaximizeOpAction->setData( Options::MaximizeOp );
 
         mShadeOpAction = popup->addAction( i18n("Sh&ade") );
-        mShadeOpAction->setShortcut( keys->action("Window Shade")->shortcut() );
+        kaction = qobject_cast<KAction*>( keys->action("Window Shade") );
+        if ( kaction!=0 )
+            mShadeOpAction->setShortcut( kaction->globalShortcut().primary() );
         mShadeOpAction->setCheckable( true );
         mShadeOpAction->setData( Options::ShadeOp );
 
         popup->addSeparator();
 
-        if (!KGlobal::config()->isImmutable() && 
+        if (!KGlobal::config()->isImmutable() &&
             !KAuthorized::authorizeControlModules(Workspace::configModules(true)).isEmpty())
             {
               action = popup->addAction( i18n("Configur&e Window Behavior...") );
-              action->setIcon( SmallIconSet( "configure" ) );
+              action->setIcon( KIcon( "configure" ) );
               connect( action, SIGNAL( triggered() ), this, SLOT( configureWM() ) );
               popup->addSeparator();
             }
 
         mCloseOpAction = popup->addAction( i18n("&Close") );
-        mCloseOpAction->setIcon( SmallIconSet( "fileclose" ) );
-        mCloseOpAction->setShortcut( keys->action("Window Close")->shortcut() );
+        mCloseOpAction->setIcon( KIcon( "fileclose" ) );
+        kaction = qobject_cast<KAction*>( keys->action("Window Close") );
+        if ( kaction!=0 )
+            mCloseOpAction->setShortcut( kaction->globalShortcut().primary() );
         mCloseOpAction->setData( Options::CloseOp );
         }
     return popup;
@@ -294,7 +315,7 @@ void Workspace::initShortcuts()
     {
     keys = new KActionCollection( this );
     KActionCollection* actionCollection = keys;
-    KAction* a = 0L;
+    QAction* a = 0L;
 
     // a separate KActionCollection is needed for the shortcut for disabling global shortcuts,
     // otherwise it would also disable itself
@@ -310,12 +331,29 @@ void Workspace::readShortcuts()
     {
     KGlobalAccel::self()->readSettings();
 
-    cutWalkThroughDesktops = keys->action("Walk Through Desktops")->shortcut();
-    cutWalkThroughDesktopsReverse = keys->action("Walk Through Desktops (Reverse)")->shortcut();
-    cutWalkThroughDesktopList = keys->action("Walk Through Desktop List")->shortcut();
-    cutWalkThroughDesktopListReverse = keys->action("Walk Through Desktop List (Reverse)")->shortcut();
-    cutWalkThroughWindows = keys->action("Walk Through Windows")->shortcut();
-    cutWalkThroughWindowsReverse = keys->action("Walk Through Windows (Reverse)")->shortcut();
+    KAction *kaction = qobject_cast<KAction*>( keys->action("Walk Through Desktops") );
+    if ( kaction!=0 )
+        cutWalkThroughDesktops = kaction->globalShortcut();
+
+    kaction = qobject_cast<KAction*>( keys->action("Walk Through Desktops (Reverse)") );
+    if ( kaction!=0 )
+        cutWalkThroughDesktopsReverse = kaction->globalShortcut();
+
+    kaction = qobject_cast<KAction*>( keys->action("Walk Through Desktop List") );
+    if ( kaction!=0 )
+        cutWalkThroughDesktopList = kaction->globalShortcut();
+
+    kaction = qobject_cast<KAction*>( keys->action("Walk Through Desktop List (Reverse)") );
+    if ( kaction!=0 )
+        cutWalkThroughDesktopListReverse = kaction->globalShortcut();
+
+    kaction = qobject_cast<KAction*>( keys->action("Walk Through Windows") );
+    if ( kaction!=0 )
+        cutWalkThroughWindows = kaction->globalShortcut();
+
+    kaction = qobject_cast<KAction*>( keys->action("Walk Through Windows (Reverse)") );
+    if ( kaction!=0 )
+        cutWalkThroughWindowsReverse = kaction->globalShortcut();
 
     delete popup;
     popup = NULL; // so that it's recreated next time
@@ -363,10 +401,10 @@ void Workspace::setupWindowShortcutDone( bool ok )
 void Workspace::clientShortcutUpdated( Client* c )
     {
     QString key = QString::number( c->window());
-    KAction* action = client_keys->action( key.toLatin1().constData() );
-    if( !c->shortcut().isNull())
+    QAction* action = client_keys->action( key.toLatin1().constData() );
+    if( !c->shortcut().isEmpty())
         {
-        action->setShortcut(c->shortcut());
+        action->setShortcuts(c->shortcut());
         connect(action, SIGNAL(triggered(bool)), c, SLOT(shortcutActivated()));
         action->setEnabled( true );
         }
@@ -403,7 +441,7 @@ void Workspace::clientPopupActivated( QAction *action )
     }
 
 
-void Workspace::performWindowOperation( Client* c, Options::WindowOperation op ) 
+void Workspace::performWindowOperation( Client* c, Options::WindowOperation op )
     {
     if ( !c )
         return;
@@ -412,7 +450,7 @@ void Workspace::performWindowOperation( Client* c, Options::WindowOperation op )
         QCursor::setPos( c->geometry().center() );
     if (op == Options::ResizeOp || op == Options::UnrestrictedResizeOp )
         QCursor::setPos( c->geometry().bottomRight());
-    switch ( op ) 
+    switch ( op )
         {
         case Options::MoveOp:
             c->performMouseCommand( Options::MouseMove, QCursor::pos() );
@@ -501,7 +539,7 @@ void Workspace::performWindowOperation( Client* c, Options::WindowOperation op )
 bool Client::performMouseCommand( Options::MouseCommand command, QPoint globalPos, bool handled )
     {
     bool replay = false;
-    switch (command) 
+    switch (command)
         {
         case Options::MouseRaise:
             workspace()->raiseClient( this );
@@ -668,13 +706,13 @@ void Workspace::slotActivateAttentionWindow()
 void Workspace::slotSwitchDesktopNext()
     {
     int d = currentDesktop() + 1;
-     if ( d > numberOfDesktops() ) 
+     if ( d > numberOfDesktops() )
         {
-        if ( options->rollOverDesktops ) 
+        if ( options->rollOverDesktops )
             {
             d = 1;
             }
-        else 
+        else
             {
             return;
             }
@@ -685,7 +723,7 @@ void Workspace::slotSwitchDesktopNext()
 void Workspace::slotSwitchDesktopPrevious()
     {
     int d = currentDesktop() - 1;
-    if ( d <= 0 ) 
+    if ( d <= 0 )
         {
         if ( options->rollOverDesktops )
           d = numberOfDesktops();
@@ -870,7 +908,7 @@ void Workspace::slotWindowToNextDesktop()
     {
     windowToNextDesktop( active_popup_client ? active_popup_client : active_client );
     }
-    
+
 void Workspace::windowToNextDesktop( Client* c )
     {
     int d = currentDesktop() + 1;
@@ -892,7 +930,7 @@ void Workspace::slotWindowToPreviousDesktop()
     {
     windowToPreviousDesktop( active_popup_client ? active_popup_client : active_client );
     }
-    
+
 void Workspace::windowToPreviousDesktop( Client* c )
     {
     int d = currentDesktop() - 1;
@@ -987,7 +1025,7 @@ void Workspace::slotSendToDesktop( QAction *action )
       int desk = action->data().toInt();
     if ( !active_popup_client )
         return;
-    if ( desk == 0 ) 
+    if ( desk == 0 )
         { // the 'on_all_desktops' menu entry
         active_popup_client->setOnAllDesktops( !active_popup_client->isOnAllDesktops());
         return;
@@ -1104,7 +1142,7 @@ void Client::setShortcut( const QString& _cut )
                  ++i )
                 {
                 KShortcut c( base + list[ i ] );
-                if( !c.isNull())
+                if( !c.isEmpty())
                     keys.append( c );
                 }
             }
@@ -1146,7 +1184,7 @@ bool Workspace::shortcutAvailable( const KShortcut& cut, Client* ignore ) const
          ++it )
         {
         if( (*it) != ignore && (*it)->shortcut() == cut )
-            return false;    
+            return false;
         }
     return true;
     }
