@@ -28,9 +28,9 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <kglobalaccel.h>
 #include <QDesktopWidget>
 #include <QToolButton>
-#include <kipc.h>
 #include <kactioncollection.h>
 #include <kaction.h>
+#include <kconfiggroup.h>
 #include <QtDBus/QtDBus>
 
 #include "plugins.h"
@@ -52,6 +52,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <stdio.h>
 #include <kauthorized.h>
 #include <ktoolinvocation.h>
+#include <kglobalsettings.h>
 
 namespace KWinInternal
 {
@@ -124,8 +125,10 @@ Workspace::Workspace( bool restore )
     block_stacking_updates( 0 ),
     forced_global_mouse_grab( false )
     {
-    new KWinAdaptor( "org.kde.kwin", "/KWin", QDBus::sessionBus(), this );
-
+    (void) new KWinAdaptor( this );
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    dbus.registerObject("/KWin", this);
+    dbus.connect(QString(), "/KWin", "org.kde.KWin", "reloadConfig", this, SLOT(slotReloadConfig()));
     _self = this;
     mgr = new PluginMgr;
     root = rootWindow();
@@ -275,6 +278,7 @@ void Workspace::init()
         NET::WM2ExtendedStrut |
         NET::WM2KDETemporaryRules |
         NET::WM2ShowingDesktop |
+        NET::WM2DesktopLayout |
         0
         ,
         NET::ActionMove |
@@ -319,11 +323,12 @@ void Workspace::init()
             SLOT(slotReconfigure()));
     connect( &updateToolWindowsTimer, SIGNAL( timeout()), this, SLOT( slotUpdateToolWindows()));
 
-    connect(kapp, SIGNAL(appearanceChanged()), this,
+    connect(KGlobalSettings::self(), SIGNAL(appearanceChanged()), this,
             SLOT(slotReconfigure()));
-    connect(kapp, SIGNAL(settingsChanged(int)), this,
+    connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), this,
             SLOT(slotSettingsChanged(int)));
-    connect(kapp, SIGNAL( kipcMessage( int, int )), this, SLOT( kipcMessage( int, int )));
+    connect(KGlobalSettings::self(), SIGNAL(blockShortcuts(int)), this,
+            SLOT(slotBlockShortcuts(int)));
 
     active_client = NULL;
     rootInfo->setActiveWindow( None );
@@ -386,7 +391,6 @@ void Workspace::init()
         NETSize desktop_geometry;
         desktop_geometry.width = geom.width();
         desktop_geometry.height = geom.height();
-    // TODO update also after gaining XRANDR support
         rootInfo->setDesktopGeometry( -1, desktop_geometry );
         setShowingDesktop( false );
 
@@ -426,7 +430,11 @@ Workspace::~Workspace()
         {
 	// only release the window
         (*it)->releaseWindow( true );
-        // no removeClient() is called !
+        // No removeClient() is called, it does more than just removing.
+        // However, remove from some lists to e.g. prevent performTransiencyCheck()
+        // from crashing.
+        clients.remove( *it );
+        desktops.remove( *it );
         }
     delete desktop_widget;
     delete tab_box;
@@ -511,6 +519,7 @@ void Workspace::addClient( Client* c, allowed_t )
     updateStackingOrder( true ); // propagate new client
     if( c->isUtility() || c->isMenu() || c->isToolbar())
         updateToolWindows( true );
+    checkNonExistentClients();
     }
 
 /*
@@ -523,7 +532,7 @@ void Workspace::removeClient( Client* c, allowed_t )
 
     if( client_keys_client == c )
         setupWindowShortcutDone( false );
-    if( !c->shortcut().isNull())
+    if( !c->shortcut().isEmpty())
         c->setShortcut( QString() ); // remove from client_keys
 
     if( c->isDialog())
@@ -592,7 +601,13 @@ void Workspace::updateFocusChains( Client* c, FocusChainChange change )
                     focus_chain[ i ].prepend( c );
                 }
             else if( !focus_chain[ i ].contains( c ))
-                focus_chain[ i ].prepend( c ); // otherwise add as the last one
+                { // add it after the active one
+                if( active_client != NULL && active_client != c
+                    && !focus_chain[ i ].isEmpty() && focus_chain[ i ].last() == active_client )
+                    focus_chain[ i ].insert( focus_chain[ i ].size() - 1, c );
+                else
+                    focus_chain[ i ].append( c ); // otherwise add as the first one
+                }
             }
         }
     else    //now only on desktop, remove it anywhere else
@@ -612,7 +627,13 @@ void Workspace::updateFocusChains( Client* c, FocusChainChange change )
                     focus_chain[ i ].prepend( c );
                     }
                 else if( !focus_chain[ i ].contains( c ))
-                    focus_chain[ i ].prepend( c );
+                    { // add it after the active one
+                    if( active_client != NULL && active_client != c
+                        && !focus_chain[ i ].isEmpty() && focus_chain[ i ].last() == active_client )
+                        focus_chain[ i ].insert( focus_chain[ i ].size() - 1, c );
+                    else
+                        focus_chain[ i ].append( c ); // otherwise add as the first one
+                    }
                 }
             else
                 focus_chain[ i ].removeAll( c );
@@ -629,7 +650,13 @@ void Workspace::updateFocusChains( Client* c, FocusChainChange change )
         global_focus_chain.prepend( c );
         }
     else if( !global_focus_chain.contains( c ))
-        global_focus_chain.prepend( c );
+        { // add it after the active one
+        if( active_client != NULL && active_client != c
+            && !global_focus_chain.isEmpty() && global_focus_chain.last() == active_client )
+            global_focus_chain.insert( global_focus_chain.size() - 1, c );
+        else
+            global_focus_chain.append( c ); // otherwise add as the first one
+        }
     }
 
 void Workspace::updateCurrentTopMenu()
@@ -847,6 +874,11 @@ void Workspace::updateColormap()
         }
     }
 
+void Workspace::slotReloadConfig()
+{
+  reconfigure();
+}
+
 void Workspace::reconfigure()
     {
     reconfigureTimer.start( 200 );
@@ -856,7 +888,7 @@ void Workspace::reconfigure()
 void Workspace::slotSettingsChanged(int category)
     {
     kDebug(1212) << "Workspace::slotSettingsChanged()" << endl;
-    if( category == (int) KApplication::SETTINGS_SHORTCUTS )
+    if( category == KGlobalSettings::SETTINGS_SHORTCUTS )
         readShortcuts();
     }
 
@@ -934,7 +966,7 @@ void Workspace::slotReconfigure()
 
 void Workspace::loadDesktopSettings()
     {
-    KConfig* c = KGlobal::config();
+    KSharedConfig::Ptr c = KGlobal::config();
     QString groupname;
     if (screen_number == 0)
         groupname = "Desktops";
@@ -963,7 +995,7 @@ void Workspace::loadDesktopSettings()
 
 void Workspace::saveDesktopSettings()
     {
-    KConfig* c = KGlobal::config();
+    KSharedConfig::Ptr c = KGlobal::config();
     QString groupname;
     if (screen_number == 0)
         groupname = "Desktops";
@@ -1202,7 +1234,10 @@ bool Workspace::setCurrentDesktop( int new_desktop )
     // and active_client is on_all_desktops and under mouse (hence == old_active_client),
     // conserve focus (thanks to Volker Schatz <V.Schatz at thphys.uni-heidelberg.de>)
     else if( active_client && active_client->isShown( true ) && active_client->isOnCurrentDesktop())
-      c= active_client;
+      c = active_client;
+
+    if( c == NULL && !desktops.isEmpty())
+        c = findDesktop( true, currentDesktop());
 
     if( c != active_client )
         setActiveClient( NULL, Allowed );
@@ -1212,15 +1247,6 @@ bool Workspace::setCurrentDesktop( int new_desktop )
     else
         focusToNull();
 
-    if( !desktops.isEmpty() )
-        {
-        Window w_tmp;
-        int i_tmp;
-        XGetInputFocus( display(), &w_tmp, &i_tmp );
-        if( w_tmp == null_focus_window ) // CHECKME?
-            requestFocus( findDesktop( true, currentDesktop()));
-        }
-
     updateCurrentTopMenu();
 
     // Update focus chain:
@@ -1471,25 +1497,26 @@ void Workspace::sendClientToDesktop( Client* c, int desk, bool dont_activate )
     updateClientArea();
     }
 
-void Workspace::setDesktopLayout(int o, int x, int y)
+void Workspace::setDesktopLayout(NET::Orientation o, int x, int y,NET::DesktopLayoutCorner c)
     {
-    layoutOrientation = (Qt::Orientation) o;
+    Q_UNUSED( c ); // I don't find this worth bothering, feel free to
+    layoutOrientation = ( o == NET::OrientationHorizontal ? Qt::Horizontal : Qt::Vertical );
     layoutX = x;
     layoutY = y;
     }
 
 void Workspace::calcDesktopLayout(int &x, int &y) const
     {
-    x = layoutX;
+    x = layoutX; // <= 0 means compute it from the other and total number of desktops
     y = layoutY;
-    if ((x == -1) && (y > 0))
+    if((x <= 0) && (y > 0))
        x = (numberOfDesktops()+y-1) / y;
-    else if ((y == -1) && (x > 0))
+    else if((y <=0) && (x > 0))
        y = (numberOfDesktops()+x-1) / x;
 
-    if (x == -1)
+    if(x <=0)
        x = 1;
-    if (y == -1)
+    if (y <= 0)
        y = 1;
     }
 
@@ -1974,8 +2001,7 @@ void Workspace::createBorderWindows()
     XSetWindowAttributes attributes;
     unsigned long valuemask;
     attributes.override_redirect = True;
-    attributes.event_mask =  (EnterWindowMask | LeaveWindowMask |
-                              VisibilityChangeMask);
+    attributes.event_mask =  ( EnterWindowMask | LeaveWindowMask );
     valuemask=  (CWOverrideRedirect | CWEventMask | CWCursor );
     attributes.cursor = XCreateFontCursor(display(),
                                           XC_sb_up_arrow);
@@ -2332,9 +2358,10 @@ void Workspace::helperDialog( const QString& message, const Client* c )
     QString type;
     if( message == "noborderaltf3" )
         {
-        KAction* action = keys->action( "Window Operations Menu" );
+        KAction* action = qobject_cast<KAction*>(keys->action( "Window Operations Menu" ));
+        if (action==0) assert( false );
         QString shortcut = QString( "%1 (%2)" ).arg( action->text() )
-            .arg( action->shortcut().seq( 0 ).toString());
+            .arg( action->globalShortcut().primary().toString());
         args << "--msgbox" <<
               i18n( "You have selected to show a window without its border.\n"
                     "Without the border, you will not be able to enable the border "
@@ -2345,9 +2372,10 @@ void Workspace::helperDialog( const QString& message, const Client* c )
         }
     else if( message == "fullscreenaltf3" )
         {
-        KAction* action = keys->action( "Window Operations Menu" );
+        KAction* action = qobject_cast<KAction*>(keys->action( "Window Operations Menu" ));
+        if (action==0) assert( false );
         QString shortcut = QString( "%1 (%2)" ).arg( action->text() )
-            .arg( action->shortcut().seq( 0 ).toString());
+            .arg( action->globalShortcut().primary().toString());
         args << "--msgbox" <<
               i18n( "You have selected to show a window in fullscreen mode.\n"
                     "If the application itself does not have an option to turn the fullscreen "
@@ -2466,21 +2494,19 @@ void Workspace::disableGlobalShortcutsForClient( bool disable )
         {
         if( disable )
             pending_dfc = true;
-        KIPC::sendMessageAll( KIPC::BlockShortcuts, disable );
+        KGlobalSettings::self()->emitChange( KGlobalSettings::BlockShortcuts, disable );
         // kwin will get the kipc message too
         }
     }
 
 void Workspace::disableGlobalShortcuts( bool disable )
     {
-    KIPC::sendMessageAll( KIPC::BlockShortcuts, disable );
+    KGlobalSettings::self()->emitChange( KGlobalSettings::BlockShortcuts, disable );
     // kwin will get the kipc message too
     }
 
-void Workspace::kipcMessage( int id, int data )
+void Workspace::slotBlockShortcuts( int data )
     {
-    if( id != KIPC::BlockShortcuts )
-        return;
     if( pending_dfc && data )
         {
         global_shortcuts_disabled_for_client = true;
