@@ -181,7 +181,7 @@ class Workspace : public QObject, public KDecorationDefines
 
         ClientList ensureStackingOrder( const ClientList& clients ) const;
 
-        Client* topClientOnDesktop( int desktop, bool unconstrained = false ) const;
+        Client* topClientOnDesktop( int desktop, bool unconstrained = false, bool only_normal = true ) const;
         Client* findDesktop( bool topmost, int desktop ) const;
         void sendClientToDesktop( Client* c, int desktop, bool dont_activate );
         void windowToPreviousDesktop( Client* c );
@@ -224,7 +224,7 @@ class Workspace : public QObject, public KDecorationDefines
         void circulateDesktopApplications();
 
         QString desktopName( int desk ) const;
-        void setDesktopLayout(int o, int x, int y);
+        void setDesktopLayout(NET::Orientation o, int x, int y, NET::DesktopLayoutCorner c);
         void setShowingDesktop( bool showing );
         void resetShowingDesktop( bool keep_hidden );
         bool showingDesktop() const;
@@ -233,7 +233,7 @@ class Workspace : public QObject, public KDecorationDefines
 
         void sendPingToWindow( Window w, Time timestamp ); // called from Client::pingWindow()
         void sendTakeActivity( Client* c, Time timestamp, long flags ); // called from Client::takeActivity()
-        
+
     // only called from Client::destroyClient() or Client::releaseWindow()
         void removeClient( Client*, allowed_t );
         void setActiveClient( Client*, allowed_t );
@@ -247,7 +247,7 @@ class Workspace : public QObject, public KDecorationDefines
         void focusToNull(); // SELI public?
         enum FocusChainChange { FocusChainMakeFirst, FocusChainMakeLast, FocusChainUpdate };
         void updateFocusChains( Client* c, FocusChainChange change );
-        
+
         bool forcedGlobalMouseGrab() const;
         void clientShortcutUpdated( Client* c );
         bool shortcutAvailable( const KShortcut& cut, Client* ignore = NULL ) const;
@@ -274,7 +274,7 @@ class Workspace : public QObject, public KDecorationDefines
 
         void cancelDelayFocus();
         void requestDelayFocus( Client* );
-        
+
         void toggleTopDockShadows(bool on);
 
     public slots:
@@ -390,7 +390,7 @@ class Workspace : public QObject, public KDecorationDefines
         void setupWindowShortcutDone( bool );
 
         void updateClientArea();
-        
+
     private slots:
         void desktopPopupAboutToShow();
         void clientPopupAboutToShow();
@@ -405,16 +405,16 @@ class Workspace : public QObject, public KDecorationDefines
         void gotTemporaryRulesMessage( const QString& );
         void cleanupTemporaryRules();
         void writeWindowRules();
-        void kipcMessage( int id, int data );
+        void slotBlockShortcuts(int data);
+	void slotReloadConfig();
         // kompmgr
         void setPopupClientOpacity(int v);
         void resetClientOpacity();
         void setTransButtonText(int value);
-        // end 
+        // end
 
     protected:
         bool keyPressMouseEmulation( XKeyEvent& ev );
-        bool netCheck( XEvent* e );
 
     private:
         void init();
@@ -490,7 +490,7 @@ class Workspace : public QObject, public KDecorationDefines
         void raiseElectricBorders();
 
     // ------------------
-    
+
         void helperDialog( const QString& message, const Client* c );
 
         void calcDesktopLayout(int &x, int &y) const;
@@ -536,13 +536,13 @@ class Workspace : public QObject, public KDecorationDefines
         ClientList clients;
         ClientList desktops;
 
-        ClientList unconstrained_stacking_order;
-        ClientList stacking_order;
-        QVector< ClientList > focus_chain;
+        ClientList unconstrained_stacking_order; // topmost last
+        ClientList stacking_order; // topmost last
+        QVector< ClientList > focus_chain; // currently ative last
         ClientList global_focus_chain; // this one is only for things like tabbox's MRU
         ClientList should_get_focus; // last is most recent
         ClientList attention_chain;
-        
+
         bool showing_desktop;
         ClientList showing_desktop_clients;
         int block_showing_desktop;
@@ -654,10 +654,13 @@ class Workspace : public QObject, public KDecorationDefines
         Window null_focus_window;
         bool forced_global_mouse_grab;
         friend class StackingUpdatesBlocker;
-        
+
         //kompmgr
         QSlider *transSlider;
         QPushButton *transButton;
+
+    private:
+        friend bool performTransiencyCheck();
     };
 
 // helper for Workspace::blockStackingUpdates() being called in pairs (true/false)
