@@ -19,22 +19,26 @@
 #ifndef PLASMA_INTERFACE_H
 #define PLASMA_INTERFACE_H
 
+#include <QString>
+
 namespace Plasma
 {
 
 class Interface
 {
     public:
-        static Interface* interface() { return m_interface; }
+        static Interface* self() { return m_interface; }
 
-        bool loadDataEngine(const QString& name) = 0;
-        bool unloadDataEngine(const QString& name) = 0;
+        virtual bool loadDataEngine(const QString& name) = 0;
+        virtual void unloadDataEngine(const QString& name) = 0;
 
     protected:
-        Interface() : m_interface(0) {}
+        Interface();
+        virtual ~Interface();
         static Interface* m_interface;
 };
 
 } // Plasma namespace
 
 #endif // multiple inclusion guard
+
